@@ -1,18 +1,45 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: amenu.c,v 1.14 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
-/*#include	"item.h"*/
+#include	"item.h"
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 /*#include	"town_prot.h"*/
 #include	"item_prot.h"
@@ -29,6 +58,7 @@
 #include	"chr_prot.h"
 #include	"party_prot.h"
 #include	"mnstr_prot.h"
+/*#include	"pet_prot.h"*/
 /*#include	"fight_prot.h"*/
 /*#include	"fx_prot.h"*/
 /*#include	"trap_prot.h"*/
@@ -42,379 +72,264 @@
 
 /**/
 
-long	auto_mark_cur_n;
+/* ưޡ */
 
-mbr_t	*g_sel_mbr;
+#define	AUTO_MARK_MAX_N	12
 
-menu_t	ls_menu_auto_mark[1 + 1 + ((1 + 3) * AUTO_MARK_MAX_N) + 1];
+#define	FLG_AUTO_MARK_EDIT_CONT	(1 << 0)
+#define	FLG_AUTO_MARK_EDIT_PRIORITY	(1 << 1)
 
-menu_t	ls_menu_appoint_item[1 + 1 + (AUTO_MARK_APPOINT_ITEM_MAX_N * 2) + 1];
+typedef enum {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_TRGT_ITEM,
+	AUTO_MARK_TRGT_DOOR,
+	AUTO_MARK_TRGT_TRAP,
+	AUTO_MARK_TRGT_MBR,
+	AUTO_MARK_TRGT_UNCHANGE,
+	AUTO_MARK_TRGT_CLEAR,
+} auto_mark_trgt_t;
+
+typedef enum {
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_DIST_MEDIUM,
+	AUTO_MARK_DIST_FAR,
+} auto_mark_dist_t;
+
+typedef enum {
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_ACT_THROW,
+	AUTO_MARK_ACT_TAIL,
+	AUTO_MARK_ACT_PICK_UP,
+	AUTO_MARK_ACT_BREAK,
+	AUTO_MARK_ACT_OPEN,
+	AUTO_MARK_ACT_CLOSE,
+	AUTO_MARK_ACT_JAM,
+	AUTO_MARK_ACT_DISARM,
+	AUTO_MARK_ACT_PEEP,
+	AUTO_MARK_ACT_SRCH,
+} auto_mark_act_t;
+
+typedef enum {
+	AUTO_MARK_COND_NEAREST,
+	AUTO_MARK_COND_DISPERSE,
+	AUTO_MARK_COND_STAGGER,
+	AUTO_MARK_COND_OWN,
+} auto_mark_cond_t;
+
+typedef struct {
+	auto_mark_trgt_t	trgt;
+	auto_mark_dist_t	dist;
+	auto_mark_act_t	act;
+	auto_mark_cond_t	cond;
+	unsigned long	flg;
+} auto_mark_t;
 
-menu_t	ls_menu_auto_mark_edit[] = {
-	{
-		"/Edit",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		cb_menu_auto_mark_edit_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Title",
-		"<Title>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
-/* Target */
-	{
-		"/Edit/Target",
-		"<Branch>",
-		'T',
-		"",
-		N_MSG_NULL, "",
-		cb_menu_auto_mark_trgt_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Title",
-		"<Title>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Monster",
-		"<Item>",
-		'X',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_MNSTR, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_MNSTR,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Item",
-		"<Item>",
-		'I',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_ITEM, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_ITEM,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Door",
-		"<Item>",
-		'D',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_DOOR, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_DOOR,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Trap",
-		"<Item>",
-		'T',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_TRAP, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_TRAP,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Member",
-		"<Item>",
-		'P',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_MBR, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_MBR,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Unchange",
-		"<Item>",
-		'U',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_UNCHANGE, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_UNCHANGE,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Target/Clear",
-		"<Item>",
-		'C',
-		"",
-		N_MSG_MENU_AUTO_MARK_TRGT_CLEAR, "",
-		cb_menu_auto_mark_trgt, (void *)AUTO_MARK_TRGT_CLEAR,
-		FLG_NULL,
-	},
-/* Dist */
-	{
-		"/Edit/Dist",
-		"<Branch>",
-		'D',
-		"",
-		N_MSG_NULL, "",
-		cb_menu_auto_mark_dist_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Dist/Title",
-		"<Title>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Dist/Near",
-		"<Item>",
-		'N',
-		"",
-		N_MSG_MENU_AUTO_MARK_DIST_NEAR, "",
-		cb_menu_auto_mark_dist, (void *)AUTO_MARK_DIST_NEAR,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Dist/Medium",
-		"<Item>",
-		'M',
-		"",
-		N_MSG_MENU_AUTO_MARK_DIST_MEDIUM, "",
-		cb_menu_auto_mark_dist, (void *)AUTO_MARK_DIST_MEDIUM,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Dist/Far",
-		"<Item>",
-		'F',
-		"",
-		N_MSG_MENU_AUTO_MARK_DIST_FAR, "",
-		cb_menu_auto_mark_dist, (void *)AUTO_MARK_DIST_FAR,
-		FLG_NULL,
-	},
-/* Action */
-	{
-		"/Edit/Action",
-		"<Branch>",
-		'A',
-		"",
-		N_MSG_NULL, "",
-		cb_menu_auto_mark_act_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Title",
-		"<Title>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Fight",
-		"<Item>",
-		'F',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_FIGHT, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_FIGHT,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Throw",
-		"<Item>",
-		'T',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_THROW, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_THROW,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Tail",
-		"<Item>",
-		'L',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_TAIL, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_TAIL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Pick up",
-		"<Item>",
-		'P',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_PICK_UP, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_PICK_UP,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Open",
-		"<Item>",
-		'O',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_OPEN, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_OPEN,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Close",
-		"<Item>",
-		'C',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_CLOSE, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_CLOSE,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Jam",
-		"<Item>",
-		'J',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_JAM, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_JAM,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Disarm",
-		"<Item>",
-		'D',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_DISARM, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_DISARM,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Break",
-		"<Item>",
-		'B',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_BREAK, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_BREAK,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Peep",
-		"<Item>",
-		'P',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_PEEP, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_PEEP,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Action/Search",
-		"<Item>",
-		'S',
-		"",
-		N_MSG_MENU_AUTO_MARK_ACT_SRCH, "",
-		cb_menu_auto_mark_act, (void *)AUTO_MARK_ACT_SRCH,
-		FLG_NULL,
-	},
-/* Condition */
-	{
-		"/Edit/Condition",
-		"<Branch>",
-		'C',
-		"",
-		N_MSG_NULL, "",
-		cb_menu_auto_mark_cond_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Condition/Title",
-		"<Title>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Condition/Nearest",
-		"<Item>",
-		'N',
-		"",
-		N_MSG_MENU_AUTO_MARK_COND_NEAREST, "",
-		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_NEAREST,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Condition/Disperse",
-		"<Item>",
-		'D',
-		"",
-		N_MSG_MENU_AUTO_MARK_COND_DISPERSE, "",
-		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_DISPERSE,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Condition/Stagger",
-		"<Item>",
-		'S',
-		"",
-		N_MSG_MENU_AUTO_MARK_COND_STAGGER, "",
-		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_STAGGER,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Condition/Own",
-		"<Item>",
-		'O',
-		"",
-		N_MSG_MENU_AUTO_MARK_COND_OWN, "",
-		cb_menu_auto_mark_cond, (void *)AUTO_MARK_COND_OWN,
-		FLG_NULL,
-	},
-/* Appoint Item */
-	{
-		"/Edit/Appoint item",
-		"<Branch>",
-		'I',
-		"",
-		N_MSG_MENU_AUTO_MARK_EDIT_APPOINT_ITEM, "",
-		cb_menu_auto_mark_appoint_item, NULL,
-		FLG_NULL,
-	},
 /**/
-	{
-		"/Edit/Continue",
-		"<CheckItem>",
-		'O',
-		"",
-		N_MSG_MENU_AUTO_MARK_EDIT_CONT, "",
-		cb_menu_auto_mark_cont, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Edit/Priority",
-		"<CheckItem>",
-		'P',
-		"",
-		N_MSG_MENU_AUTO_MARK_EDIT_PRIORITY, "",
-		cb_menu_auto_mark_priority, NULL,
-		FLG_NULL,
-	},
-	{
-		"",
-		"",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
+
+static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
+static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
+		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+static long	auto_mark_cur_n;
+static mbr_t	*g_sel_mbr;
+
+static auto_mark_t	dflt_auto_mark_fight = {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
+static auto_mark_t	dflt_auto_mark_throw = {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_DIST_MEDIUM,
+	AUTO_MARK_ACT_THROW,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+};
+
+static auto_mark_t	dflt_auto_mark_fight_far = {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_DIST_FAR,
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+};
+
+static auto_mark_t	dflt_auto_mark_fight_all = {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+};
+
+static auto_mark_t	dflt_auto_mark_item_all = {
+	AUTO_MARK_TRGT_ITEM,
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_ACT_PICK_UP,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+};
+
+static auto_mark_t	dflt_auto_mark_item_own = {
+	AUTO_MARK_TRGT_ITEM,
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_ACT_PICK_UP,
+	AUTO_MARK_COND_OWN,
+	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+};
+
+static auto_mark_t	dflt_auto_mark_clear = {
+	AUTO_MARK_TRGT_CLEAR,
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_COND_DISPERSE,
+	FLG_AUTO_MARK_EDIT_PRIORITY,
+};
+
+static auto_mark_appoint_item_t	auto_mark_appoint_item
+		[LS_MBR_MAX_N][AUTO_MARK_MAX_N]
+		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+
+static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
+		[AUTO_MARK_APPOINT_ITEM_MAX_N] = {
+	{ FACE_MJR_WEAPON, FACE_MNR_SWORD, TRUE },
+	{ FACE_MJR_WEAPON, FACE_MNR_BOW, TRUE },
+	{ FACE_MJR_WEAPON, FACE_MNR_ARW, TRUE },
+	{ FACE_MJR_WEAPON, FACE_MNR_STONE, TRUE },
+	{ FACE_MJR_WEAPON, FACE_MNR_DAGGER, TRUE },
+
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_SHIELD, TRUE },
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_HEAD, TRUE },
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_BODY, TRUE },
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_ARM, TRUE },
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_FEET, TRUE },
+	{ FACE_MJR_ARMOR, FACE_MNR_ARMOR_ABOUT_BODY, TRUE },
+
+	{ FACE_MJR_POTION, FACE_MNR_NULL, TRUE },
+
+	{ FACE_MJR_SCROLL, FACE_MNR_NULL, TRUE },
+
+	{ FACE_MJR_STICK, FACE_MNR_WAND, TRUE },
+	{ FACE_MJR_STICK, FACE_MNR_ROD, TRUE },
+	{ FACE_MJR_STICK, FACE_MNR_STAFF, TRUE },
+
+	{ FACE_MJR_ACCESSORY, FACE_MNR_RING, TRUE },
+	{ FACE_MJR_ACCESSORY, FACE_MNR_AMULET, TRUE },
+	{ FACE_MJR_ACCESSORY, FACE_MNR_NECKLACE, TRUE },
+
+	{ FACE_MJR_FOOD, FACE_MNR_NULL, TRUE },
+
+	{ FACE_MJR_CHEST, FACE_MNR_NULL, FALSE },
+
+	{ FACE_MJR_COIN, FACE_MNR_NULL, TRUE },
+
+	{ FACE_MJR_GEM, FACE_MNR_NULL, TRUE },
+
+	{ FACE_MJR_MISC, FACE_MNR_LIGHT, TRUE },
+	{ FACE_MJR_MISC, FACE_MNR_SPIKE, TRUE },
+	{ FACE_MJR_MISC, FACE_MNR_TOBACCO, TRUE },
+	{ FACE_MJR_MISC, FACE_MNR_PIPE, TRUE },
+	{ FACE_MJR_MISC, FACE_MNR_JUNK, FALSE },
+
+	{ FACE_MJR_NULL, FACE_MNR_NULL, FALSE },
+};
+
+/**/
+
+#include	"amenu_tab.h"
+
 /**/
 
 void	init_auto_menu( void )
 {
+	long	i, j, k;
+
 	auto_mark_cur_n = 0;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+			for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+				auto_mark_appoint_item_t	*a;
+
+				a = &(auto_mark_appoint_item_dflt[k]);
+				auto_mark_appoint_item[i][j][k] = *a;
+			}
+		}
+	}
+
+	init_auto_mark_all_mbr();
+}
+
+/**/
+
+void	init_auto_mark_all_mbr( void )
+{
+	long	i;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		init_auto_mark_mbr( i );
+}
+
+/**/
+
+void	init_auto_mark_mbr( long ls_mbr_n )
+{
+	long	j;
+
+	j = 0;
+	switch( ls_mbr_n ){
+	default:
+	case 0:
+	case 1:
+	case 3:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight;
+		break;
+	case 2:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_throw;
+		break;
+	case 4:
+	case 5:
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
+		break;
+	}
+	strncpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	j++;
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j++;
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j++;
+	if( j < AUTO_MARK_MAX_N ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_own;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j++;
+	for( ; j < AUTO_MARK_MAX_N; j++ ){
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+		strncpy( msg_ttl_auto_mark[j],
+				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	j = AUTO_MARK_MAX_N - 1;
+	ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+	strncpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_CLEAR,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
 /**/
@@ -546,7 +461,7 @@ void	set_auto_mark_cont( mbr_t *mbr )
 	if( mbr == NULL )
 		return;
 
-	if( !chk_flg( mbr->auto_mark[auto_mark_cur_n].flg,
+	if( !chk_flg( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_PRIORITY ) ){
 		return;
 	}
@@ -564,9 +479,9 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 	if( chk_flg_or( mbr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return FALSE;
 
-	am = &(mbr->auto_mark[auto_mark_cur_n]);
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
-	/* $B$9$G$K%^!<%/$7$F$$$k$+!)(B */
+	/* Ǥ˥ޡƤ뤫 */
 	if( !chk_flg( am->flg, FLG_AUTO_MARK_EDIT_PRIORITY ) )
 		if( mbr->act.kind != ACT_KIND_NULL )
 			return FALSE;
@@ -601,7 +516,7 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 	if( flg_clr )
 		clr_chr_trgt_act( mbr, TRUE );
 
-	if( chk_flg( mbr->auto_mark[auto_mark_cur_n].flg,
+	if( chk_flg( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_CONT ) ){
 		mbr->flg_chr |= FLG_CHR_AUTO_MARK_CONT;
 	} else {
@@ -619,22 +534,18 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 	mnstr_t	*mnstr;
 	dist_t	dist;
 	act_kind_t	act_kind;
-	char	*act_msg;
 
-	am = &(mbr->auto_mark[auto_mark_cur_n]);
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
 	switch( am->act ){
 	case AUTO_MARK_ACT_FIGHT:
 		act_kind = ACT_KIND_MNSTR_FIGHT;
-		act_msg = MSG_ACT_MNSTR_FIGHT;
 		break;
 	case AUTO_MARK_ACT_THROW:
 		act_kind = ACT_KIND_MNSTR_THROW;
-		act_msg = MSG_ACT_MNSTR_THROW;
 		break;
 	case AUTO_MARK_ACT_TAIL:
 		act_kind = ACT_KIND_MNSTR_TAIL;
-		act_msg = MSG_ACT_MNSTR_TAIL;
 		break;
 	case AUTO_MARK_ACT_PICK_UP:
 	case AUTO_MARK_ACT_OPEN:
@@ -648,7 +559,7 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 		return FALSE;
 	}
 
-	/* $B%b%s%9%?!<$rC5$9(B */
+	/* 󥹥õ */
 	mnstr = NULL;
 	switch( am->cond ){
 	case AUTO_MARK_COND_NEAREST:
@@ -666,7 +577,7 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 	if( mnstr == NULL )
 		return FALSE;
 
-	/* $B4V9g$$$r%;%C%H(B */
+	/* ֹ礤򥻥å */
 	switch( am->dist ){
 	case AUTO_MARK_DIST_NEAR:
 		dist = DIST_NEAR;
@@ -681,15 +592,10 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 		return FALSE;
 	}
 
-	/* $B%"%/%7%g%s$r%;%C%H(B */
-	mbr->act.kind = act_kind;
-	strncpy( mbr->act.msg, act_msg, ACT_MSG_MAX_LEN );
-	mbr->act.p = NULL;
-	mbr->act.n = 0;
-	mbr->act.dflt_kind_mnstr = mbr->act.kind;
-	strncpy( mbr->act.dflt_msg_mnstr, mbr->act.msg, ACT_MSG_MAX_LEN );
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
 
-	/* $B%b%s%9%?!<$r%^!<%/$9$k(B */
+	/* 󥹥ޡ */
 	mark_mnstr( mbr, mnstr, dist );
 
 	draw_mbr_stat( mbr );
@@ -705,9 +611,8 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	item_t	*item;
 	dist_t	dist;
 	act_kind_t	act_kind;
-	char	*act_msg;
 
-	am = &(mbr->auto_mark[auto_mark_cur_n]);
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
 	switch( am->act ){
 	case AUTO_MARK_ACT_FIGHT:
@@ -716,34 +621,29 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 		return FALSE;
 	case AUTO_MARK_ACT_PICK_UP:
 		act_kind = ACT_KIND_ITEM_PICK_UP;
-		act_msg = MSG_ACT_ITEM_PICK_UP;
 		break;
 	case AUTO_MARK_ACT_OPEN:
 		act_kind = ACT_KIND_ITEM_OPEN;
-		act_msg = MSG_ACT_ITEM_OPEN;
 		break;
 	case AUTO_MARK_ACT_CLOSE:
 	case AUTO_MARK_ACT_JAM:
 		return FALSE;
 	case AUTO_MARK_ACT_DISARM:
 		act_kind = ACT_KIND_ITEM_DISARM;
-		act_msg = MSG_ACT_ITEM_DISARM;
 		break;
 	case AUTO_MARK_ACT_BREAK:
 		act_kind = ACT_KIND_ITEM_BREAK;
-		act_msg = MSG_ACT_ITEM_BREAK;
 		break;
 	case AUTO_MARK_ACT_PEEP:
 		return FALSE;
 	case AUTO_MARK_ACT_SRCH:
 		act_kind = ACT_KIND_ITEM_SRCH;
-		act_msg = MSG_ACT_ITEM_SRCH;
 		break;
 	default:
 		return FALSE;
 	}
 
-	/* $B%"%$%F%`$rC5$9(B */
+	/* ƥõ */
 	item = NULL;
 	switch( am->cond ){
 	case AUTO_MARK_COND_NEAREST:
@@ -763,7 +663,7 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	if( item == NULL )
 		return FALSE;
 
-	/* $B4V9g$$$r%;%C%H(B */
+	/* ֹ礤򥻥å */
 	switch( am->dist ){
 	case AUTO_MARK_DIST_NEAR:
 		dist = DIST_NEAR;
@@ -778,13 +678,10 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 		return FALSE;
 	}
 
-	/* $B%"%/%7%g%s$r%;%C%H(B */
-	mbr->act.kind = act_kind;
-	strncpy( mbr->act.msg, act_msg, ACT_MSG_MAX_LEN );
-	mbr->act.p = NULL;
-	mbr->act.n = 0;
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
 
-	/* $B%"%$%F%`$r%^!<%/$9$k(B */
+	/* ƥޡ */
 	mark_item( mbr, item, dist );
 
 	draw_mbr_stat( mbr );
@@ -800,9 +697,8 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 	door_t	*door;
 	dist_t	dist;
 	act_kind_t	act_kind;
-	char	*act_msg;
 
-	am = &(mbr->auto_mark[auto_mark_cur_n]);
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
 	switch( am->act ){
 	case AUTO_MARK_ACT_FIGHT:
@@ -812,37 +708,30 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		return FALSE;
 	case AUTO_MARK_ACT_OPEN:
 		act_kind = ACT_KIND_DOOR_OPEN;
-		act_msg = MSG_ACT_DOOR_OPEN;
 		break;
 	case AUTO_MARK_ACT_CLOSE:
 		act_kind = ACT_KIND_DOOR_CLOSE;
-		act_msg = MSG_ACT_DOOR_CLOSE;
 		break;
 	case AUTO_MARK_ACT_JAM:
 		act_kind = ACT_KIND_DOOR_JAM;
-		act_msg = MSG_ACT_DOOR_JAM;
 		break;
 	case AUTO_MARK_ACT_DISARM:
 		act_kind = ACT_KIND_DOOR_DISARM;
-		act_msg = MSG_ACT_DOOR_DISARM;
 		break;
 	case AUTO_MARK_ACT_BREAK:
 		act_kind = ACT_KIND_DOOR_BREAK;
-		act_msg = MSG_ACT_DOOR_BREAK;
 		break;
 	case AUTO_MARK_ACT_PEEP:
 		act_kind = ACT_KIND_DOOR_PEEP;
-		act_msg = MSG_ACT_DOOR_PEEP;
 		break;
 	case AUTO_MARK_ACT_SRCH:
 		act_kind = ACT_KIND_DOOR_SRCH;
-		act_msg = MSG_ACT_DOOR_SRCH;
 		break;
 	default:
 		return FALSE;
 	}
 
-	/* $B%I%"$rC5$9(B */
+	/* ɥõ */
 	door = NULL;
 	switch( am->cond ){
 	case AUTO_MARK_COND_NEAREST:
@@ -860,7 +749,7 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 	if( door == NULL )
 		return FALSE;
 
-	/* $B4V9g$$$r%;%C%H(B */
+	/* ֹ礤򥻥å */
 	switch( am->dist ){
 	case AUTO_MARK_DIST_NEAR:
 		dist = DIST_NEAR;
@@ -875,13 +764,10 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		return FALSE;
 	}
 
-	/* $B%"%/%7%g%s$r%;%C%H(B */
-	mbr->act.kind = act_kind;
-	strncpy( mbr->act.msg, act_msg, ACT_MSG_MAX_LEN );
-	mbr->act.p = NULL;
-	mbr->act.n = 0;
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
 
-	/* $B%I%"$r%^!<%/$9$k(B */
+	/* ɥޡ */
 	mark_door( mbr, door, dist );
 
 	draw_mbr_stat( mbr );
@@ -897,11 +783,10 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 	mbr_t	*p;
 	dist_t	dist;
 	act_kind_t	act_kind;
-	char	*act_msg;
 
-	am = &(mbr->auto_mark[auto_mark_cur_n]);
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
-	/* $B%a%s%P!<$rC5$9(B */
+	/* Сõ */
 	p = NULL;
 	switch( am->cond ){
 	case AUTO_MARK_COND_NEAREST:
@@ -921,7 +806,7 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 	if( p == NULL )
 		return FALSE;
 
-	/* $B4V9g$$$r%;%C%H(B */
+	/* ֹ礤򥻥å */
 	switch( am->dist ){
 	case AUTO_MARK_DIST_NEAR:
 		dist = DIST_NEAR;
@@ -939,15 +824,12 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 	switch( am->act ){
 	case AUTO_MARK_ACT_FIGHT:
 		act_kind = ACT_KIND_MBR_FIGHT;
-		act_msg = MSG_ACT_MBR_FIGHT;
 		break;
 	case AUTO_MARK_ACT_THROW:
 		act_kind = ACT_KIND_MBR_THROW;
-		act_msg = MSG_ACT_MBR_THROW;
 		break;
 	case AUTO_MARK_ACT_TAIL:
 		act_kind = ACT_KIND_MBR_TAIL;
-		act_msg = MSG_ACT_MBR_TAIL;
 		break;
 	case AUTO_MARK_ACT_PICK_UP:
 	case AUTO_MARK_ACT_OPEN:
@@ -962,13 +844,10 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 		return FALSE;
 	}
 
-	/* $B%"%/%7%g%s$r%;%C%H(B */
-	mbr->act.kind = act_kind;
-	strncpy( mbr->act.msg, act_msg, ACT_MSG_MAX_LEN );
-	mbr->act.p = NULL;
-	mbr->act.n = 0;
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
 
-	/* $B%a%s%P!<$r%^!<%/$9$k(B */
+	/* Сޡ */
 	mark_mbr( mbr, p, dist );
 
 	draw_mbr_stat( mbr );
@@ -1013,7 +892,7 @@ char	*cb_menu_auto_mark_edit_init(
 {
 	menu_t	*p;
 
-	/* $B%?%$%H%k(B */
+	/* ȥ */
 	p = srch_menu( *pp, "Title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
@@ -1021,52 +900,52 @@ char	*cb_menu_auto_mark_edit_init(
 			get_msg_ttl_auto_mark( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
-	/* $BBP>](B */
+	/* о */
 	p = srch_menu( *pp, "Target" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_TRGT,
 			get_msg_menu_auto_mark_edit_trgt( g_sel_mbr ) );
 
-	/* $B4V9g$$(B */
+	/* ֹ礤 */
 	p = srch_menu( *pp, "Dist" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_DIST,
 			get_msg_menu_auto_mark_edit_dist( g_sel_mbr ) );
 
-	/* $B9TF0(B */
+	/* ư */
 	p = srch_menu( *pp, "Action" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_ACT,
 			get_msg_menu_auto_mark_edit_act( g_sel_mbr ) );
 
-	/* $B>r7o(B */
+	/*  */
 	p = srch_menu( *pp, "Condition" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_COND,
 			get_msg_menu_auto_mark_edit_cond( g_sel_mbr ) );
 
-	/* $B%"%$%F%`<oJL(B */
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	/* ƥ */
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_ITEM ){
 		clr_flg_menu( *pp, "Appoint item", FLG_MENU_HIDDEN );
 	} else {
 		set_flg_menu( *pp, "Appoint item", FLG_MENU_HIDDEN );
 	}
 
-	/* $BO"B3%^!<%/(B */
-	if( chk_flg( g_sel_mbr->auto_mark[auto_mark_cur_n].flg,
+	/* Ϣ³ޡ */
+	if( chk_flg( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_CONT ) ){
 		set_chk_on_menu( *pp, "Continue" );
 	} else {
 		set_chk_off_menu( *pp, "Continue" );
 	}
 
-	/* $B8=:_$N@_Dj$h$jM%@h(B */
-	if( chk_flg( g_sel_mbr->auto_mark[auto_mark_cur_n].flg,
+	/* ߤͥ */
+	if( chk_flg( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_PRIORITY ) ){
 		set_chk_on_menu( *pp, "Priority" );
 	} else {
@@ -1093,7 +972,7 @@ char	*cb_menu_auto_mark_trgt_init(
 			g_sel_mbr->name );
 
 	s = NULL;
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
 		s = "Monster";
 		break;
@@ -1129,27 +1008,27 @@ char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt )
 	auto_mark_trgt_t	trgt;
 
 	trgt = (auto_mark_trgt_t)((*pp)->arg);
-	g_sel_mbr->auto_mark[auto_mark_cur_n].trgt = trgt;
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt = trgt;
 
 	switch( trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].act
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 				= AUTO_MARK_ACT_FIGHT;
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].act
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 				= AUTO_MARK_ACT_PICK_UP;
 		break;
 	case AUTO_MARK_TRGT_DOOR:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].act
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 				= AUTO_MARK_ACT_OPEN;
 		break;
 	case AUTO_MARK_TRGT_TRAP:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].act
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 				= AUTO_MARK_ACT_DISARM;
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].act
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 				= AUTO_MARK_ACT_TAIL;
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
@@ -1169,11 +1048,11 @@ char	*cb_menu_auto_mark_dist_init(
 	menu_t	*p;
 	char	*s;
 
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_UNCHANGE ){
 		return STR_MENU_CANCEL;
 	}
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_CLEAR ){
 		return STR_MENU_CANCEL;
 	}
@@ -1186,7 +1065,7 @@ char	*cb_menu_auto_mark_dist_init(
 			g_sel_mbr->name );
 
 	s = NULL;
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].dist ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].dist ){
 	case AUTO_MARK_DIST_NEAR:
 		s = "Near";
 		break;
@@ -1207,7 +1086,7 @@ char	*cb_menu_auto_mark_dist_init(
 
 char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt )
 {
-	g_sel_mbr->auto_mark[auto_mark_cur_n].dist
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].dist
 			= (auto_mark_dist_t)((*pp)->arg);
 
 	return NULL;
@@ -1222,11 +1101,11 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_UNCHANGE ){
 		return STR_MENU_CANCEL;
 	}
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_CLEAR ){
 		return STR_MENU_CANCEL;
 	}
@@ -1239,7 +1118,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 			g_sel_mbr->name );
 
 	s = NULL;
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].act ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act ){
 	case AUTO_MARK_ACT_FIGHT:
 		s = "Fight";
 		break;
@@ -1277,9 +1156,9 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 	*dflt = srch_menu( *pp, s );
 
-	/* $BBP>]$K1~$8$F%a%K%e!<9`L\$NL58z2=(B */
+	/* оݤ˱ƥ˥塼ܤ̵ */
 
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
 		set_flg_menu( *pp, "Pick up", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "Open", FLG_MENU_HIDDEN );
@@ -1339,7 +1218,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt )
 {
-	g_sel_mbr->auto_mark[auto_mark_cur_n].act
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
 			= (auto_mark_act_t)((*pp)->arg);
 
 	return NULL;
@@ -1356,11 +1235,11 @@ char	*cb_menu_auto_mark_cond_init(
 
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_UNCHANGE ){
 		return STR_MENU_CANCEL;
 	}
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_CLEAR ){
 		return STR_MENU_CANCEL;
 	}
@@ -1372,10 +1251,10 @@ char	*cb_menu_auto_mark_cond_init(
 			get_msg_ttl_auto_mark( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
-	/* $B%G%U%)%k%H$N%+!<%=%k0LCV@_Dj(B */
+	/* ǥեȤΥ */
 
 	s = NULL;
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].cond ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond ){
 	case AUTO_MARK_COND_NEAREST:
 		s = "Nearest";
 		break;
@@ -1391,9 +1270,9 @@ char	*cb_menu_auto_mark_cond_init(
 	}
 	*dflt = srch_menu( *pp, s );
 
-	/* $BBP>]$K1~$8$F%a%K%e!<9`L\$NL58z2=(B */
+	/* оݤ˱ƥ˥塼ܤ̵ */
 
-	switch( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt ){
+	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_DOOR:
 	case AUTO_MARK_TRGT_TRAP:
 	case AUTO_MARK_TRGT_MNSTR:
@@ -1430,19 +1309,19 @@ char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 {
 	switch( (auto_mark_cond_t)((*pp)->arg) ){
 	case AUTO_MARK_COND_NEAREST:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].cond
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
 				= AUTO_MARK_COND_NEAREST;
 		break;
 	case AUTO_MARK_COND_DISPERSE:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].cond
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
 				= AUTO_MARK_COND_DISPERSE;
 		break;
 	case AUTO_MARK_COND_STAGGER:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].cond
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
 				= AUTO_MARK_COND_STAGGER;
 		break;
 	case AUTO_MARK_COND_OWN:
-		g_sel_mbr->auto_mark[auto_mark_cur_n].cond
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
 				= AUTO_MARK_COND_OWN;
 		break;
 	}
@@ -1461,7 +1340,7 @@ char	*cb_menu_auto_mark_appoint_item(
 	auto_mark_appoint_item_t	*apo;
 	long	i;
 
-	if( g_sel_mbr->auto_mark[auto_mark_cur_n].trgt
+	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			!= AUTO_MARK_TRGT_ITEM ){
 		return STR_MENU_CANCEL;
 	}
@@ -1619,10 +1498,10 @@ char	*cb_menu_auto_mark_appoint_item_mnr(
 char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt )
 {
 	if( chk_flg( (*pp)->flg, FLG_MENU_CHK_ON ) ){
-		g_sel_mbr->auto_mark[auto_mark_cur_n].flg
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg
 				|= FLG_AUTO_MARK_EDIT_CONT;
 	} else {
-		g_sel_mbr->auto_mark[auto_mark_cur_n].flg
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg
 				&= ~(FLG_AUTO_MARK_EDIT_CONT);
 	}
 
@@ -1634,10 +1513,10 @@ char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 {
 	if( chk_flg( (*pp)->flg, FLG_MENU_CHK_ON ) ){
-		g_sel_mbr->auto_mark[auto_mark_cur_n].flg
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg
 				|= FLG_AUTO_MARK_EDIT_PRIORITY;
 	} else {
-		g_sel_mbr->auto_mark[auto_mark_cur_n].flg
+		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg
 				&= ~(FLG_AUTO_MARK_EDIT_PRIORITY);
 	}
 
@@ -1648,7 +1527,6 @@ char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 {
-	mbr_t	**ls_mbr = get_ls_mbr();
 	long	n, i, j;
 	auto_mark_t	am;
 	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
@@ -1658,14 +1536,12 @@ char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 	/**/
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		am = ls_mbr[i]->auto_mark[n];
+		am = ls_auto_mark[i][n];
 
-		for( j = n - 1; j >= 0; j-- ){
-			ls_mbr[i]->auto_mark[j + 1]
-					= ls_mbr[i]->auto_mark[j];
-		}
+		for( j = n - 1; j >= 0; j-- )
+			ls_auto_mark[i][j + 1] = ls_auto_mark[i][j];
 
-		ls_mbr[i]->auto_mark[0] = am;
+		ls_auto_mark[i][0] = am;
 	}
 
 	/**/
@@ -1694,7 +1570,7 @@ char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr )
 {
-	switch( mbr->auto_mark[auto_mark_cur_n].trgt ){
+	switch( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
 		return MSG_MENU_AUTO_MARK_TRGT_MNSTR;
 	case AUTO_MARK_TRGT_ITEM:
@@ -1720,13 +1596,13 @@ char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr )
 {
 	auto_mark_trgt_t	trgt;
 
-	trgt = mbr->auto_mark[auto_mark_cur_n].trgt;
+	trgt = ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].trgt;
 	if( (trgt == AUTO_MARK_TRGT_UNCHANGE)
 			|| (trgt ==AUTO_MARK_TRGT_CLEAR) ){
 		return MSG_MENU_AUTO_MARK_INVALID;
 	}
 
-	switch( mbr->auto_mark[auto_mark_cur_n].dist ){
+	switch( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].dist ){
 	case AUTO_MARK_DIST_NEAR:
 		return MSG_MENU_AUTO_MARK_DIST_NEAR;
 	case AUTO_MARK_DIST_MEDIUM:
@@ -1744,13 +1620,13 @@ char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr )
 {
 	auto_mark_trgt_t	trgt;
 
-	trgt = mbr->auto_mark[auto_mark_cur_n].trgt;
+	trgt = ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].trgt;
 	if( (trgt == AUTO_MARK_TRGT_UNCHANGE)
 			|| (trgt ==AUTO_MARK_TRGT_CLEAR) ){
 		return MSG_MENU_AUTO_MARK_INVALID;
 	}
 
-	switch( mbr->auto_mark[auto_mark_cur_n].act ){
+	switch( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].act ){
 	case AUTO_MARK_ACT_FIGHT:
 		return MSG_MENU_AUTO_MARK_ACT_FIGHT;
 	case AUTO_MARK_ACT_THROW:
@@ -1784,13 +1660,13 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 {
 	auto_mark_trgt_t	trgt;
 
-	trgt = mbr->auto_mark[auto_mark_cur_n].trgt;
+	trgt = ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].trgt;
 	if( (trgt == AUTO_MARK_TRGT_UNCHANGE)
 			|| (trgt ==AUTO_MARK_TRGT_CLEAR) ){
 		return MSG_MENU_AUTO_MARK_INVALID;
 	}
 
-	switch( mbr->auto_mark[auto_mark_cur_n].cond ){
+	switch( ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].cond ){
 	case AUTO_MARK_COND_NEAREST:
 		return MSG_MENU_AUTO_MARK_COND_NEAREST;
 	case AUTO_MARK_COND_DISPERSE:
@@ -1813,3 +1689,23 @@ long	get_auto_mark_cur_n( void )
 
 /**/
 
+auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr )
+{
+	long	n;
+
+	if( mbr == NULL )
+		return NULL;
+
+	n = get_auto_mark_cur_n();
+
+	return auto_mark_appoint_item[mbr->ls_mbr_n][n];
+}
+
+/**/
+
+char	*get_msg_ttl_auto_mark( long n )
+{
+	return msg_ttl_auto_mark[n];
+}
+
+/**/
