@@ -1,20 +1,29 @@
 /* chr.c */
 void	init_chr( void );
 void	act_chr( chr_t *chr );
+bool_t	chk_can_act_chr( chr_t *chr );
+void	chk_clr_chr_queue( chr_t *chr );
+void	bash_or_move( chr_t *chr );
+void	act_throw_mnstr_null( chr_t *chr );
 bool_t	chk_assist_chr( chr_t *chr );
 void	clr_map_chr( chr_t *chr );
 void	set_map_chr( chr_t *chr );
-void	move_chr( chr_t *chr, move_kind_t kind );
-void	move_chr_sub( chr_t *chr, move_kind_t kind );
+void	move_chr( chr_t *chr );
+void	move_chr_sub( chr_t *chr );
+void	move_chr_towner( chr_t *chr );
+void	turn_dir_towner( chr_t *chr );
 void	move_chr_std( chr_t *chr );
+void	chk_chr_force_move( chr_t *chr );
 bool_t	chk_chr_stagger( chr_t *chr );
 bool_t	chk_chr_stagger_sub( chr_t *chr, flg_stat_t flg, long rate );
 void	move_chr_stagger( chr_t *chr );
+move_kind_t	get_move_kind_rand( chr_t *chr );
 bool_t	chk_auto_door( chr_t *chr, long x1, long y1, long x2, long y2 );
 bool_t	can_move_chr( chr_t *chr, long x, long y );
+bool_t	can_move_chr_towner( chr_t *chr, long d );
+void	set_chr_pos( chr_t *chr, long x, long y );
 void	die_chr( chr_t *p, bool_t flg_add_exp );
 void	act_chr_auto_door( chr_t *chr, long x, long y );
-void	act_chr_auto_mnstr( chr_t *chr, long x, long y );
 bool_t	chr_open_door( chr_t *chr, long dr_n );
 bool_t	chr_close_door( chr_t *chr, long dr_n );
 bool_t	chr_jam_door( chr_t *chr, long dr_n );
@@ -27,6 +36,7 @@ bool_t	chr_open_item( item_t *item, chr_t *chr );
 bool_t	chr_disarm_item( item_t *item, chr_t *chr );
 void	chr_srch_item( chr_t *chr, item_t *item );
 void	chr_srch_obj( chr_t *chr );
+void	chr_enter_door( chr_t *chr, door_t *dr );
 void	move_chr_trgt( chr_t *chr );
 bool_t	chk_auto_mark_cont( chr_t *chr );
 void	clr_chr_trgt_act( chr_t *chr, bool_t flg_force );
@@ -48,6 +58,7 @@ void	mark_mnstr_null( chr_t *chr, long x, long y, dist_t dist );
 void	mark_item( chr_t *chr, item_t *item, dist_t dist );
 void	mark_door( chr_t *chr, door_t *dr, dist_t dist );
 void	mark_trap( chr_t *chr, trap_t *trap, dist_t dist );
+void	mark_queue( chr_t *chr, bool_t flg_all_mbr );
 void	mark_square( chr_t *chr );
 void	mark_pos( chr_t *chr, long x, long y, dist_t dist );
 void	stop_zapping( chr_t *chr );
@@ -55,24 +66,58 @@ void	chr_srch_begin( chr_t *chr );
 void	chr_srch_end( chr_t *chr );
 bool_t	chk_infra_vision( chr_t *chr );
 bool_t	chr_light_up( chr_t *chr, long x, long y, bool_t flg_on );
-void	exp_chr( chr_t *chr, long exp, bool_t flg_draw );
-void	set_lev( chr_t *chr, bool_t flg_draw );
+void	exp_chr(
+	chr_t *chr, long exp,
+	bool_t flg_print_exp,
+	bool_t flg_print_lev
+);
+void	chk_up_lev( chr_t *chr, bool_t flg_draw );
+void	up_lev( chr_t *chr, abl_kind_t abl, long add, bool_t flg_draw );
+void	set_modifier( chr_t *chr );
+bool_t	calc_modifier_equip( chr_t *chr );
+bool_t	reset_modifier( modifier_t *m );
+bool_t	get_modifier_equip( chr_t *chr, modifier_t *m );
+bool_t	set_modifier_equip( chr_t *chr, modifier_t *m );
+bool_t	get_modifier_fx( chr_t *chr, modifier_t *m );
+bool_t	set_modifier_fx( chr_t *chr, modifier_t *m );
+rate_t	set_move_rate( chr_t *chr );
+rate_t	get_move_rate( chr_t *chr );
 char	*get_abl_name( abl_kind_t kind );
-long	calc_lev_to_exp( long lev, abl_kind_t abl );
+abl_kind_t	get_sub_abl( abl_kind_t abl_main );
+long	calc_lev_to_exp( long org_lev, abl_kind_t abl );
 long	calc_need_exp( long lev, abl_kind_t abl );
+long	get_lev( chr_t *chr, abl_kind_t abl );
+long	get_lev_max( chr_t *chr, abl_kind_t abl );
+rate_t	get_resi( chr_t *chr, resi_kind_t resi );
+bool_t	chk_modified_lev( chr_t *chr, abl_kind_t abl );
 long	calc_lev_to_val( long lev, abl_kind_t abl );
+long	calc_max_hp( chr_t *chr );
+long	calc_max_mp( chr_t *chr );
 long	calc_resi( rate_t resi, long n );
 long	get_generalist_lev( chr_t *p );
 long	get_specialist_lev( chr_t *p );
 long	add_hp( chr_t *p, long n );
 long	add_mp( chr_t *chr, long n );
-long	get_chr_gold( chr_t *chr );
-long	add_chr_gold( chr_t *chr, long gold );
+gold_t	get_chr_gold( chr_t *chr );
+gold_t	add_chr_gold( chr_t *chr, gold_t gold );
 square_t	*get_square( chr_t *chr );
 void	set_square( chr_t *chr, square_t *sq );
 char	*get_trgt_name( trgt_t *trgt );
+trgt_kind_t	get_trgt_kind_from_chr( chr_t *chr );
+chr_kind_t	get_chr_kind_from_trgt( trgt_t *trgt );
 bool_t	cmp_chr( chr_t *p1, chr_t *p2 );
+rate_t	calc_rate_equip( chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub );
+bool_t	chk_find_chr( chr_t *p1, chr_t *p2 );
+bool_t	roll(
+	chr_t *p1, abl_kind_t abl_m1, abl_kind_t abl_s1,
+	chr_t *p2, abl_kind_t abl_m2, abl_kind_t abl_s2
+);
 bool_t	chr_roll(
 	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub,
 	long difficulty
 );
+bool_t	resi_roll(
+	chr_t *o_p, abl_kind_t o_abl,
+	chr_t *d_p, resi_kind_t d_resi
+);
+long	roll_dice( long n );
