@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: curs.c,v 1.32 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -13,6 +39,7 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+/*#include	"misc_prot.h"*/
+/*#include	"turn_prot.h"*/
 /*#include	"dun_prot.h"*/
 /*#include	"town_prot.h"*/
 /*#include	"item_prot.h"*/
@@ -29,6 +58,7 @@
 /*#include	"chr_prot.h"*/
 /*#include	"party_prot.h"*/
 /*#include	"mnstr_prot.h"*/
+/*#include	"pet_prot.h"*/
 /*#include	"fight_prot.h"*/
 /*#include	"fx_prot.h"*/
 /*#include	"trap_prot.h"*/
@@ -42,10 +72,23 @@
 
 /**/
 
-curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
+#define	FLG_PRINT_REVERSE	0
+
+/**/
+
+static long	flg_curs, flg_curs_draw;
+static bool_t	flg_color;
+static curs_attr_t	g_current_attr;
+
+/**/
+
+static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 	{ 0, N_MSG_ATTR_NORMAL,
 		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
 
+	{ 0, N_MSG_ATTR_REV,
+		COLOR_WHITE, COLOR_BLACK, A_REVERSE, },
+
 	{ 0, N_MSG_ATTR_ERR,
 		COLOR_RED, COLOR_BLACK, A_BOLD, },
 
@@ -64,6 +107,9 @@ curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 	{ 0, N_MSG_ATTR_MAP_MNSTR,
 		COLOR_RED, COLOR_BLACK, A_BOLD, },
 
+	{ 0, N_MSG_ATTR_MAP_NPC,
+		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
+
 	{ 0, N_MSG_ATTR_MAP_CRSR,
 		COLOR_GREEN, COLOR_BLACK, A_NORMAL, },
 
@@ -109,11 +155,6 @@ curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 
 /**/
 
-long	flg_curs, flg_curs_draw;
-bool_t	flg_color;
-
-/**/
-
 void	init_curs( void )
 {
 	flg_curs = 0;
@@ -124,7 +165,7 @@ void	init_curs( void )
 
 bool_t	init_curs_color( void )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	curs_attr_n_t	n;
 
 	flg_color = TRUE;
@@ -145,7 +186,7 @@ bool_t	init_curs_color( void )
 		init_curs_color_pair( &(g_curs_attr[n]), pair_n );
 		g_curs_attr[n].color_pair_n = pair_n;
 	}
-#endif
+#endif	/* HAVE_LIBCURSES */
 
 	return TRUE;
 }
@@ -154,13 +195,13 @@ bool_t	init_curs_color( void )
 
 bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( !flg_color )
 		return FALSE;
 
 	init_pair( pair_n, p->fg, p->bg );
 	p->color_pair_n = pair_n;
-#endif
+#endif	/* HAVE_LIBCURSES */
 
 	return TRUE;
 }
@@ -197,26 +238,26 @@ bool_t	chk_curs( void )
 
 void	ena_curs( void )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		noecho();
 		cbreak();
 		raw();
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
 
 void	dis_curs( void )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		noraw();
 		nocbreak();
 		echo();
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
@@ -225,12 +266,12 @@ void	curs_clearok( WINDOW *win, bool_t bf )
 {
 	flg_curs++;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( flg_curs == 1 ){
 		clearok( win, bf );
 		ena_curs();
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
@@ -239,25 +280,25 @@ void	curs_initscr( void )
 {
 	flg_curs++;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( flg_curs == 1 ){
 		initscr();
 		ena_curs();
 		init_curs_color();
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
 
 void	curs_endwin( void )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( flg_curs == 1 ){
 		dis_curs();
 		endwin();
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 
 	flg_curs--;
 }
@@ -266,10 +307,10 @@ void	curs_endwin( void )
 
 void	curs_keypad( WINDOW *win, bool_t bf )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( g_flg_use_keypad )
 		keypad( win, bf );
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
@@ -279,18 +320,32 @@ void	curs_refresh( void )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		refresh();
 		return;
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 
 	fflush( OUT_FP );
 }
 
 /**/
 
+curs_attr_t	get_current_attr( void )
+{
+	return g_current_attr;
+}
+
+/**/
+
+void	curs_attrset_dflt( void )
+{
+	curs_attrset_dir( &(g_curs_attr[CURS_ATTR_N_NORMAL]) );
+}
+
+/**/
+
 void	curs_attrset_n( curs_attr_n_t n )
 {
 	curs_attrset_dir( &(g_curs_attr[n]) );
@@ -302,14 +357,16 @@ void	curs_attrset_dir( curs_attr_t *attr )
 {
 	int	tmp_attr;
 
+	g_current_attr = *attr;
+
 	if( !chk_curs_draw() )
 		return;
 
 	tmp_attr = 0;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	tmp_attr = COLOR_PAIR( attr->color_pair_n );
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 
 	tmp_attr |= attr->attr;
 
@@ -323,17 +380,18 @@ void	curs_attrset( int at )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		attrset( at );
 		return;
 	}
-#endif	/* D_USE_CURSES */
-
+#endif	/* HAVE_LIBCURSES */
+#if	FLG_PRINT_REVERSE
 	if( chk_flg( at, A_REVERSE ) )
 		fprintf( OUT_FP, "\033[43m" );
 	else
 		fprintf( OUT_FP, "\033[m" );
+#endif	/* FLG_PRINT_REVERSE */
 }
 
 /**/
@@ -343,15 +401,16 @@ void	curs_attron( int at )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		attron( at );
 		return;
 	}
-#endif	/* D_USE_CURSES */
-
+#endif	/* HAVE_LIBCURSES */
+#if	FLG_PRINT_REVERSE
 	if( chk_flg( at, A_REVERSE ) )
 		fprintf( OUT_FP, "\033[43m" );
+#endif	/* FLG_PRINT_REVERSE */
 }
 
 /**/
@@ -361,15 +420,34 @@ void	curs_attroff( int at )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		attroff( at );
 		return;
 	}
-#endif	/* D_USE_CURSES */
-
+#endif	/* HAVE_LIBCURSES */
+#if	FLG_PRINT_REVERSE
 	if( chk_flg( at, A_REVERSE ) )
 		fprintf( OUT_FP, "\033[m" );
+#endif	/* FLG_PRINT_REVERSE */
+}
+
+/**/
+
+void	curs_echo( void )
+{
+#if	HAVE_LIBCURSES
+	echo();
+#endif	/* HAVE_LIBCURSES */
+}
+
+/**/
+
+void	curs_noecho( void )
+{
+#if	HAVE_LIBCURSES
+	noecho();
+#endif	/* HAVE_LIBCURSES */
 }
 
 /**/
@@ -379,12 +457,12 @@ void	curs_move( int scrn_y, int scrn_x )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		move( scrn_y, scrn_x );
 		return;
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 
 	fprintf( OUT_FP, "\033[%d;%dH", scrn_y + 1, scrn_x + 1 );
 }
@@ -400,13 +478,13 @@ void	curs_printw( char *s, ... )
 
 	va_start( argptr, s );
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
 		vwprintw( stdscr, s, argptr );
 		va_end( argptr );
 		return;
 	}
-#endif	/* D_USE_CURSES */
+#endif	/* HAVE_LIBCURSES */
 
 	vfprintf( OUT_FP, s, argptr );
 
@@ -420,24 +498,40 @@ void	curs_clear( void )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
+
 	if( chk_curs() ){
 		clear();
 		return;
 	}
-#endif	/* D_USE_CURSES */
+
+#endif	/* HAVE_LIBCURSES */
+
+#ifdef	D_X68K
 
 	fprintf( OUT_FP, "\032" );
+
+#else	/* D_X68K */
+
+	{
+		long	i;
+		const long	max_n = get_max_line();
+
+		for( i = 0; i < max_n; i++ )
+			fprintf( OUT_FP, "%*s", SCREEN_WIDTH, " " );
+	}
+
+#endif	/* D_X68K */
 }
 
 /**/
 
 int	curs_getch( void )
 {
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() )
 		return getch();
-#endif
+#endif	/* HAVE_LIBCURSES */
 
 	return getchar();
 }
@@ -453,12 +547,14 @@ void	curs_getnstr( char *s, int len )
 	if( !chk_curs_draw() )
 		return;
 
-#ifdef	D_USE_CURSES
+#if	HAVE_LIBCURSES
 	if( chk_curs() ){
+# if	HAVE_GETNSTR
 		getnstr( s, len );
 		return;
+# endif	/* HAVE_GETNSTR */
 	}
-#endif
+#endif	/* HAVE_LIBCURSES */
 
 	fgets( buf, sizeof( buf ) - 1, stdin );
 	strncpy( s, buf, len );
@@ -478,3 +574,13 @@ bool_t	chk_color( void )
 	return flg_color;
 }
 
+long	get_max_line( void )
+{
+#if	HAVE_LIBCURSES
+	return LINES;
+#else	/* HAVE_LIBCURSES */
+	return SCREEN_HEIGHT;
+#endif	/* HAVE_LIBCURSES */
+}
+
+/**/
