@@ -1,10 +1,41 @@
-#ifndef	__DRAW_TAB_H__
-#define	__DRAW_TAB_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: draw_tab.h,v 1.11 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	DRAW_TAB_H
+#define	DRAW_TAB_H
 
 #include	"gmain.h"
 #include	"menu.h"
 
-/* $B$3$3$+$i(B,$B:BI8$OAjBPCM(B */
+/* ,ɸ */
 #define	WIN_STAT_NAME_DRAW_MIN_X	0
 #define	WIN_STAT_NAME_DRAW_MIN_Y	0
 #define	WIN_STAT_NAME_DRAW_WIDTH	16
@@ -33,7 +64,7 @@
 #define	WIN_STAT_DUN_LEV_DRAW_MIN_Y	0
 #define	WIN_STAT_DUN_LEV_TTL_DRAW_WIDTH	8
 #define	WIN_STAT_DUN_LEV_VAL_DRAW_WIDTH	4
-/* $B$3$3$^$G(B,$B:BI8$OAjBPCM(B */
+/* ޤ,ɸ */
 
 /* Data begin */
 
@@ -161,38 +192,43 @@
 #define	WIN_MBR_DATA_STAT_SILENCE_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 4)
 
-#define	WIN_MBR_DATA_STAT_FEAR_DRAW_MIN_X	\
+#define	WIN_MBR_DATA_STAT_CAUGHT_DRAW_MIN_X	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+#define	WIN_MBR_DATA_STAT_CAUGHT_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 5)
+
+#define	WIN_MBR_DATA_STAT_FEAR_DRAW_MIN_X	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_FEAR_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 5)
 
 #define	WIN_MBR_DATA_STAT_HALLUCINATION_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
 #define	WIN_MBR_DATA_STAT_HALLUCINATION_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 5)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 6)
 
 #define	WIN_MBR_DATA_STAT_CHARM_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_CHARM_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 6)
 
 #define	WIN_MBR_DATA_STAT_FLY_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
 #define	WIN_MBR_DATA_STAT_FLY_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 6)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 7)
 
 #define	WIN_MBR_DATA_STAT_HUNGRY_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_HUNGRY_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 7)
 
 #define	WIN_MBR_DATA_STAT_FAINT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
 #define	WIN_MBR_DATA_STAT_FAINT_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 7)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 8)
 
 #define	WIN_MBR_DATA_STAT_DRUNK_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_DRUNK_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 8)
 
@@ -256,37 +292,61 @@
 
 /* resi */
 
-#define	WIN_MBR_DATA_DRAW_LEFT_LEFT_X	0
+#define	WIN_MBR_DATA_DRAW_LEFT_LEFT_X	\
+		(WIN_MBR_DATA_DRAW_MID_X * 1 / 4 - 1)
 #define	WIN_MBR_DATA_DRAW_LEFT_MID_X	\
-		(WIN_MBR_DATA_DRAW_MID_X * 1 / 3)
+		(WIN_MBR_DATA_DRAW_MID_X * 2 / 4 - 1)
 #define	WIN_MBR_DATA_DRAW_LEFT_RIGHT_X	\
-		(WIN_MBR_DATA_DRAW_MID_X * 2 / 3)
+		(WIN_MBR_DATA_DRAW_MID_X * 3 / 4 - 1)
 
 #define	WIN_MBR_DATA_RESI_TTL_DRAW_MIN_X	0
 #define	WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_CHA_TTL_DRAW_MIN_Y + 2)
 
+#define	WIN_MBR_DATA_RESI_TTL_LAWFUL_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
+#define	WIN_MBR_DATA_RESI_TTL_LAWFUL_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 0)
+#define	WIN_MBR_DATA_RESI_TTL_NEUTRAL_1_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_MID_X
+#define	WIN_MBR_DATA_RESI_TTL_NEUTRAL_1_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 0)
+#define	WIN_MBR_DATA_RESI_TTL_CHAOTIC_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_RIGHT_X
+#define	WIN_MBR_DATA_RESI_TTL_CHAOTIC_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 0)
+
+#define	WIN_MBR_DATA_RESI_TTL_GOOD_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_RESI_TTL_GOOD_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 1)
+#define	WIN_MBR_DATA_RESI_TTL_NEUTRAL_2_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_RESI_TTL_NEUTRAL_2_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 2)
+#define	WIN_MBR_DATA_RESI_TTL_EVIL_DRAW_MIN_X	0
+#define	WIN_MBR_DATA_RESI_TTL_EVIL_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 3)
+
 #define	WIN_MBR_DATA_RESI_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_TTL_DRAW_MIN_Y + 1)
 
-#define	WIN_MBR_DATA_RESI_HEAT_TTL_DRAW_MIN_X	\
-		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
-#define	WIN_MBR_DATA_RESI_HEAT_TTL_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 0)
-
 #define	WIN_MBR_DATA_RESI_ELEC_TTL_DRAW_MIN_X	\
-		WIN_MBR_DATA_DRAW_LEFT_MID_X
+		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
 #define	WIN_MBR_DATA_RESI_ELEC_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 0)
 
-#define	WIN_MBR_DATA_RESI_WIND_TTL_DRAW_MIN_X	\
-		WIN_MBR_DATA_DRAW_LEFT_RIGHT_X
-#define	WIN_MBR_DATA_RESI_WIND_TTL_DRAW_MIN_Y	\
+#define	WIN_MBR_DATA_RESI_COLD_TTL_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_MID_X
+#define	WIN_MBR_DATA_RESI_COLD_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 0)
 
 #define	WIN_MBR_DATA_RESI_KNOC_TTL_DRAW_MIN_X	\
-		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
+		WIN_MBR_DATA_DRAW_LEFT_RIGHT_X
 #define	WIN_MBR_DATA_RESI_KNOC_TTL_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 0)
+
+#define	WIN_MBR_DATA_RESI_ACID_TTL_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
+#define	WIN_MBR_DATA_RESI_ACID_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 1)
 
 #define	WIN_MBR_DATA_RESI_SLAS_TTL_DRAW_MIN_X	\
@@ -294,24 +354,24 @@
 #define	WIN_MBR_DATA_RESI_SLAS_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 1)
 
-#define	WIN_MBR_DATA_RESI_STIN_TTL_DRAW_MIN_X	\
+#define	WIN_MBR_DATA_RESI_MIND_TTL_DRAW_MIN_X	\
 		WIN_MBR_DATA_DRAW_LEFT_RIGHT_X
-#define	WIN_MBR_DATA_RESI_STIN_TTL_DRAW_MIN_Y	\
+#define	WIN_MBR_DATA_RESI_MIND_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 1)
 
-#define	WIN_MBR_DATA_RESI_ACID_TTL_DRAW_MIN_X	\
+#define	WIN_MBR_DATA_RESI_STIN_TTL_DRAW_MIN_X	\
 		WIN_MBR_DATA_DRAW_LEFT_LEFT_X
-#define	WIN_MBR_DATA_RESI_ACID_TTL_DRAW_MIN_Y	\
+#define	WIN_MBR_DATA_RESI_STIN_TTL_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 2)
+
+#define	WIN_MBR_DATA_RESI_HEAT_TTL_DRAW_MIN_X	\
+		WIN_MBR_DATA_DRAW_LEFT_MID_X
+#define	WIN_MBR_DATA_RESI_HEAT_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 2)
 
 #define	WIN_MBR_DATA_RESI_POIS_TTL_DRAW_MIN_X	\
-		WIN_MBR_DATA_DRAW_LEFT_MID_X
-#define	WIN_MBR_DATA_RESI_POIS_TTL_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 2)
-
-#define	WIN_MBR_DATA_RESI_COLD_TTL_DRAW_MIN_X	\
 		WIN_MBR_DATA_DRAW_LEFT_RIGHT_X
-#define	WIN_MBR_DATA_RESI_COLD_TTL_DRAW_MIN_Y	\
+#define	WIN_MBR_DATA_RESI_POIS_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 2)
 
 /* abl 2/2 */
@@ -423,6 +483,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_BLIND, */
 		FALSE,	/* DATA_N_STAT_SLEEP, */
 		FALSE,	/* DATA_N_STAT_SILENCE, */
+		FALSE,	/* DATA_N_STAT_CAUGHT, */
 		FALSE,	/* DATA_N_STAT_FEAR, */
 		FALSE,	/* DATA_N_STAT_HALLUCINATION, */
 		FALSE,	/* DATA_N_STAT_CHARM, */
@@ -449,13 +510,19 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_CHA, */
 
 		FALSE,	/* DATA_N_RESI_TTL, */
+		FALSE,	/* DATA_N_RESI_TTL_LAWFUL, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+		FALSE,	/* DATA_N_RESI_TTL_CHAOTIC, */
+		FALSE,	/* DATA_N_RESI_TTL_GOOD, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+		FALSE,	/* DATA_N_RESI_TTL_EVIL, */
 		FALSE,	/* DATA_N_RESI_KNOC, */
 		FALSE,	/* DATA_N_RESI_SLAS, */
 		FALSE,	/* DATA_N_RESI_STIN, */
 		FALSE,	/* DATA_N_RESI_HEAT, */
 		FALSE,	/* DATA_N_RESI_COLD, */
-		FALSE,	/* DATA_N_RESI_WIND, */
 		FALSE,	/* DATA_N_RESI_ACID, */
+		FALSE,	/* DATA_N_RESI_MIND, */
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
@@ -509,6 +576,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_BLIND, */
 		FALSE,	/* DATA_N_STAT_SLEEP, */
 		FALSE,	/* DATA_N_STAT_SILENCE, */
+		FALSE,	/* DATA_N_STAT_CAUGHT, */
 		FALSE,	/* DATA_N_STAT_FEAR, */
 		FALSE,	/* DATA_N_STAT_HALLUCINATION, */
 		FALSE,	/* DATA_N_STAT_CHARM, */
@@ -535,13 +603,19 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_CHA, */
 
 		FALSE,	/* DATA_N_RESI_TTL, */
+		FALSE,	/* DATA_N_RESI_TTL_LAWFUL, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+		FALSE,	/* DATA_N_RESI_TTL_CHAOTIC, */
+		FALSE,	/* DATA_N_RESI_TTL_GOOD, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+		FALSE,	/* DATA_N_RESI_TTL_EVIL, */
 		FALSE,	/* DATA_N_RESI_KNOC, */
 		FALSE,	/* DATA_N_RESI_SLAS, */
 		FALSE,	/* DATA_N_RESI_STIN, */
 		FALSE,	/* DATA_N_RESI_HEAT, */
 		FALSE,	/* DATA_N_RESI_COLD, */
-		FALSE,	/* DATA_N_RESI_WIND, */
 		FALSE,	/* DATA_N_RESI_ACID, */
+		FALSE,	/* DATA_N_RESI_MIND, */
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
@@ -595,6 +669,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_BLIND, */
 		FALSE,	/* DATA_N_STAT_SLEEP, */
 		FALSE,	/* DATA_N_STAT_SILENCE, */
+		FALSE,	/* DATA_N_STAT_CAUGHT, */
 		FALSE,	/* DATA_N_STAT_FEAR, */
 		FALSE,	/* DATA_N_STAT_HALLUCINATION, */
 		FALSE,	/* DATA_N_STAT_CHARM, */
@@ -621,13 +696,19 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_CHA, */
 
 		FALSE,	/* DATA_N_RESI_TTL, */
+		FALSE,	/* DATA_N_RESI_TTL_LAWFUL, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+		FALSE,	/* DATA_N_RESI_TTL_CHAOTIC, */
+		FALSE,	/* DATA_N_RESI_TTL_GOOD, */
+		FALSE,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+		FALSE,	/* DATA_N_RESI_TTL_EVIL, */
 		FALSE,	/* DATA_N_RESI_KNOC, */
 		FALSE,	/* DATA_N_RESI_SLAS, */
 		FALSE,	/* DATA_N_RESI_STIN, */
 		FALSE,	/* DATA_N_RESI_HEAT, */
 		FALSE,	/* DATA_N_RESI_COLD, */
-		FALSE,	/* DATA_N_RESI_WIND, */
 		FALSE,	/* DATA_N_RESI_ACID, */
+		FALSE,	/* DATA_N_RESI_MIND, */
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
@@ -683,6 +764,7 @@ long	data_page_n_tab[] = {
 	0,	/* DATA_N_STAT_BLIND, */
 	0,	/* DATA_N_STAT_SLEEP, */
 	0,	/* DATA_N_STAT_SILENCE, */
+	0,	/* DATA_N_STAT_CAUGHT, */
 	0,	/* DATA_N_STAT_FEAR, */
 	0,	/* DATA_N_STAT_HALLUCINATION, */
 	0,	/* DATA_N_STAT_CHARM, */
@@ -709,13 +791,19 @@ long	data_page_n_tab[] = {
 	1,	/* DATA_N_CHA, */
 
 	1,	/* DATA_N_RESI_TTL, */
+	1,	/* DATA_N_RESI_TTL_LAWFUL, */
+	1,	/* DATA_N_RESI_TTL_NEUTRAL_1, */
+	1,	/* DATA_N_RESI_TTL_CHAOTIC, */
+	1,	/* DATA_N_RESI_TTL_GOOD, */
+	1,	/* DATA_N_RESI_TTL_NEUTRAL_2, */
+	1,	/* DATA_N_RESI_TTL_EVIL, */
 	1,	/* DATA_N_RESI_KNOC, */
 	1,	/* DATA_N_RESI_SLAS, */
 	1,	/* DATA_N_RESI_STIN, */
 	1,	/* DATA_N_RESI_HEAT, */
 	1,	/* DATA_N_RESI_COLD, */
-	1,	/* DATA_N_RESI_WIND, */
 	1,	/* DATA_N_RESI_ACID, */
+	1,	/* DATA_N_RESI_MIND, */
 	1,	/* DATA_N_RESI_ELEC, */
 	1,	/* DATA_N_RESI_POIS, */
 
@@ -737,4 +825,77 @@ long	data_page_n_tab[] = {
 	DATA_PAGE_N_ALL,	/* DATA_N_NEXT_PAGE, */
 };
 
-#endif	/* __DRAW_TAB_H__ */
+typedef struct {
+	n_msg_t	n_str;
+	char	*str;
+} kin_soku_t;
+
+kin_soku_t	okuri_tab[] = {
+	{ N_MSG_OKURI_00, NULL },
+	{ N_MSG_OKURI_01, NULL },
+	{ N_MSG_OKURI_02, NULL },
+	{ N_MSG_OKURI_03, NULL },
+	{ N_MSG_OKURI_04, NULL },
+	{ N_MSG_OKURI_05, NULL },
+	{ N_MSG_OKURI_06, NULL },
+	{ N_MSG_OKURI_07, NULL },
+	{ N_MSG_OKURI_08, NULL },
+	{ N_MSG_OKURI_09, NULL },
+	{ N_MSG_OKURI_10, NULL },
+	{ N_MSG_OKURI_11, NULL },
+	{ N_MSG_OKURI_12, NULL },
+	{ N_MSG_OKURI_13, NULL },
+	{ N_MSG_OKURI_14, NULL },
+	{ N_MSG_OKURI_15, NULL },
+	{ N_MSG_OKURI_16, NULL },
+	{ N_MSG_OKURI_17, NULL },
+	{ N_MSG_OKURI_18, NULL },
+	{ N_MSG_OKURI_19, NULL },
+	{ N_MSG_OKURI_20, NULL },
+	{ N_MSG_OKURI_21, NULL },
+	{ N_MSG_OKURI_22, NULL },
+	{ N_MSG_OKURI_23, NULL },
+	{ N_MSG_OKURI_24, NULL },
+	{ N_MSG_OKURI_25, NULL },
+	{ N_MSG_OKURI_26, NULL },
+	{ N_MSG_OKURI_27, NULL },
+	{ N_MSG_OKURI_28, NULL },
+	{ N_MSG_OKURI_29, NULL },
+	{ N_MSG_NULL, NULL },
+};
+
+kin_soku_t	kin_soku_tab[] = {
+	{ N_MSG_KIN_SOKU_00, NULL },
+	{ N_MSG_KIN_SOKU_01, NULL },
+	{ N_MSG_KIN_SOKU_02, NULL },
+	{ N_MSG_KIN_SOKU_03, NULL },
+	{ N_MSG_KIN_SOKU_04, NULL },
+	{ N_MSG_KIN_SOKU_05, NULL },
+	{ N_MSG_KIN_SOKU_06, NULL },
+	{ N_MSG_KIN_SOKU_07, NULL },
+	{ N_MSG_KIN_SOKU_08, NULL },
+	{ N_MSG_KIN_SOKU_09, NULL },
+	{ N_MSG_KIN_SOKU_10, NULL },
+	{ N_MSG_KIN_SOKU_11, NULL },
+	{ N_MSG_KIN_SOKU_12, NULL },
+	{ N_MSG_KIN_SOKU_13, NULL },
+	{ N_MSG_KIN_SOKU_14, NULL },
+	{ N_MSG_KIN_SOKU_15, NULL },
+	{ N_MSG_KIN_SOKU_16, NULL },
+	{ N_MSG_KIN_SOKU_17, NULL },
+	{ N_MSG_KIN_SOKU_18, NULL },
+	{ N_MSG_KIN_SOKU_19, NULL },
+	{ N_MSG_KIN_SOKU_20, NULL },
+	{ N_MSG_KIN_SOKU_21, NULL },
+	{ N_MSG_KIN_SOKU_22, NULL },
+	{ N_MSG_KIN_SOKU_23, NULL },
+	{ N_MSG_KIN_SOKU_24, NULL },
+	{ N_MSG_KIN_SOKU_25, NULL },
+	{ N_MSG_KIN_SOKU_26, NULL },
+	{ N_MSG_KIN_SOKU_27, NULL },
+	{ N_MSG_KIN_SOKU_28, NULL },
+	{ N_MSG_KIN_SOKU_29, NULL },
+	{ N_MSG_NULL, NULL },
+};
+
+#endif	/* DRAW_TAB_H */
