@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-/*#include	<string.h>*/
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: dun.c,v 1.34 2003/11/23 05:13:28 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 #include	"dun.h"
 #include	"town.h"
 #include	"item.h"
@@ -13,6 +39,7 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 #include	"town_prot.h"
 #include	"item_prot.h"
@@ -29,6 +58,7 @@
 #include	"chr_prot.h"
 #include	"party_prot.h"
 #include	"mnstr_prot.h"
+/*#include	"pet_prot.h"*/
 /*#include	"fight_prot.h"*/
 #include	"fx_prot.h"
 #include	"trap_prot.h"
@@ -53,10 +83,10 @@
 /**/
 
 static dun_t	dun;
-long	room_ptn_max_n;
+static long	room_ptn_max_n;
 
-crsr_ptn_t	g_crsr_ptn, g_crsr_ptn_usr[CRSR_PTN_MAX_N];
-long	g_crsr_ptn_n, g_crsr_ptn_max_n;
+static crsr_ptn_t	g_crsr_ptn, g_crsr_ptn_usr[CRSR_PTN_MAX_N];
+static long	g_crsr_ptn_n, g_crsr_ptn_max_n;
 
 /**/
 
@@ -93,16 +123,40 @@ void	init_dun( void )
 
 /**/
 
-long	*get_crsr_ptn_max_n( void )
+long	get_crsr_ptn_max_n( void )
 {
-	return &g_crsr_ptn_max_n;
+	return g_crsr_ptn_max_n;
 }
 
 /**/
 
-long	*get_crsr_ptn_n( void )
+long	set_crsr_ptn_max_n( long n )
 {
-	return &g_crsr_ptn_n;
+	long	prev;
+
+	prev = g_crsr_ptn_max_n;
+	g_crsr_ptn_max_n = n;
+
+	return prev;
+}
+
+/**/
+
+long	get_crsr_ptn_n( void )
+{
+	return g_crsr_ptn_n;
+}
+
+/**/
+
+long	set_crsr_ptn_n( long n )
+{
+	long	prev;
+
+	prev = g_crsr_ptn_n;
+	g_crsr_ptn_n = n;
+
+	return prev;
 }
 
 /**/
@@ -125,7 +179,6 @@ void	reset_dun( void )
 			dun.map.obj.mjr[y][x] = FACE_MJR_WALL;
 			dun.map.obj.mnr[y][x] = FACE_MNR_WALL;
 			dun.map.obj.flg[y][x] = FLG_NULL;
-			dun.map.light_depth[y][x] = 0;
 
 			dun.map.chr.mjr[y][x] = FACE_MJR_NULL;
 			dun.map.chr.mnr[y][x] = FACE_MNR_NULL;
@@ -134,6 +187,9 @@ void	reset_dun( void )
 			dun.map.total.mjr[y][x] = FACE_MJR_WALL;
 			dun.map.total.mnr[y][x] = FACE_MNR_WALL;
 			dun.map.total.flg[y][x] = FLG_NULL;
+
+			dun.map.light_depth_obj[y][x] = 0;
+			dun.map.light_depth_chr[y][x] = 0;
 		}
 	}
 
@@ -196,16 +252,16 @@ void	up_dun( long d )
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		if( sgn( dun.lev ) >= +1 ){
-			if( pty->mbr[i]->max_dun_lev_floor
+			if( pty->mbr[i]->dun_max_lev_floor
 					< abs( dun.lev ) ){
-				pty->mbr[i]->max_dun_lev_floor
+				pty->mbr[i]->dun_max_lev_floor
 						= abs( dun.lev );
 			}
 		}
 		if( sgn( dun.lev ) <= -1 ){
-			if( pty->mbr[i]->max_dun_lev_base
+			if( pty->mbr[i]->dun_max_lev_base
 					< abs( dun.lev ) ){
-				pty->mbr[i]->max_dun_lev_base
+				pty->mbr[i]->dun_max_lev_base
 						= abs( dun.lev );
 			}
 		}
@@ -214,17 +270,28 @@ void	up_dun( long d )
 	for( i = 0; i < MBR_MAX_N; i++ )
 		clr_chr_trgt_act( pty->mbr[i], FALSE );
 
+	reset_all( TRUE );
+}
+
+/**/
+
+void	reset_all( bool_t flg_appear )
+{
 	reset_trap();
 	clr_dun_item();
 	reset_mnstr();
 	release_all_mbr();
 	if( dun.lev == 0 ){
 		make_town();
-		if( !appear_party_town() )
-			appear_party( FALSE );
+		if( flg_appear ){
+			if( !appear_party_town( FALSE ) )
+				appear_party( FALSE );
+		}
 	} else {
 		make_dun();
-		appear_party( FALSE );
+		if( flg_appear ){
+			appear_party( FALSE );
+		}
 	}
 	next_pos_square( 0 );
 	set_flg_find_all_mnstr();
@@ -237,9 +304,7 @@ void	make_dun( void )
 {
 	long	i, j;
 	long	item_n, item_max_n;
-	item_kind_t	kind;
 	long	mnstr_n, mnstr_max_n;
-	mnstr_kind_t	mnstr_kind;
 	long	trap_n, trap_max_n;
 
 	reset_dun();
@@ -314,6 +379,7 @@ void	make_dun( void )
 	}
 
 	/* ꥢƥ */
+
 	item_n = 0;
 
 	for( i = 0; i < MAP_MAX_Y; i++ ){
@@ -323,7 +389,7 @@ void	make_dun( void )
 
 			dun.map.obj.mjr[i][j] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[i][j] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[i][j] = FLG_OBJ_PASS;
+			dun.map.obj.flg[i][j] = FLG_MAP_OBJ_PASS;
 			if( make_item( j, i, dun.lev )
 					!= ITEM_KIND_NULL ){
 				item_n++;
@@ -331,8 +397,52 @@ void	make_dun( void )
 		}
 	}
 
+	/* 󥹥 */
+
+	for( i = 0; i < MAP_MAX_Y; i++ ){
+		for( j = 0; j < MAP_MAX_X; j++ ){
+			if( dun.map.obj.mjr[i][j] != FACE_ROOM_PTN_MIMIC )
+				continue;
+
+			dun.map.obj.mjr[i][j] = FACE_MJR_FLOOR;
+			dun.map.obj.mnr[i][j] = FACE_MNR_FLOOR;
+			dun.map.obj.flg[i][j] |= FLG_MAP_OBJ_PASS;
+			if( rate_randm( MIMIC_RATE ) ){
+				make_mnstr( j, i, dun.lev,
+						MNSTR_KIND_MIMIC );
+			} else {
+				item_t	*item;
+
+				item = make_item_chest( dun.lev,
+						get_chest_n( dun.lev ) );
+				if( item == NULL )
+					continue;
+				if( !put_item( j, i, 1, item, FALSE ) ){
+					del_item( item );
+					continue;
+				}
+			}
+		}
+	}
+
+	/*  */
+
+	for( i = 0; i < MAP_MAX_Y; i++ ){
+		for( j = 0; j < MAP_MAX_X; j++ ){
+			if( dun.map.obj.mjr[i][j] != FACE_ROOM_PTN_TRAP )
+				continue;
+
+			dun.map.obj.mjr[i][j] = FACE_MJR_FLOOR;
+			dun.map.obj.mnr[i][j] = FACE_MNR_FLOOR;
+			dun.map.obj.flg[i][j] |= FLG_MAP_OBJ_PASS;
+
+			make_trap( j, i, dun.lev );
+		}
+	}
+
 	/* ॢƥ */
-	item_max_n = roll_dice( DUN_ITEM_AVE_MAX_N );
+
+	item_max_n = roll_dice( DUN_ITEM_AVE_N );
 
 	for( i = 0; i < 10240; i++ ){
 		long	x, y;
@@ -342,87 +452,44 @@ void	make_dun( void )
 
 		x = 1 + randm( MAP_MAX_X - 2 );
 		y = 1 + randm( MAP_MAX_Y - 2 );
-		kind = make_item( x, y, dun.lev );
-		if( kind != ITEM_KIND_NULL )
+		if( make_item( x, y, dun.lev ) != ITEM_KIND_NULL )
 			item_n++;
 	}
 	item_max_n = item_n;
 
 	/* 󥹥 */
+
 	mnstr_max_n = roll_dice( MNSTR_AVE_N );
 	if( mnstr_max_n > MNSTR_MAX_N )
 		mnstr_max_n = MNSTR_MAX_N;
 
 	mnstr_n = 0;
-	for( i = 0; i < 2048; i++ ){
+	for( i = 0; i < 4096; i++ ){
 		long	x, y;
 
+		if( mnstr_n >= mnstr_max_n )
+			break;
+
 		x = 1 + randm( MAP_MAX_X - 2 );
 		y = 1 + randm( MAP_MAX_Y - 2 );
-		mnstr_kind = make_mnstr_rand( x, y, dun.lev );
-		if( mnstr_kind != MNSTR_KIND_NULL )
+		if( make_mnstr_rand( x, y, dun.lev ) != NULL )
 			mnstr_n++;
-		if( mnstr_n >= mnstr_max_n )
-			break;
-	}
-
-	/* 󥹥 */
-	for( i = 0; i < MAP_MAX_Y; i++ ){
-		for( j = 0; j < MAP_MAX_X; j++ ){
-			if( dun.map.obj.mjr[i][j] != FACE_ROOM_PTN_MIMIC )
-				continue;
-
-			dun.map.obj.mjr[i][j] = FACE_MJR_FLOOR;
-			dun.map.obj.mnr[i][j] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[i][j] |= FLG_OBJ_PASS;
-			if( rate_randm( MIMIC_RATE ) ){
-				make_mnstr( j, i, dun.lev,
-						MNSTR_KIND_MIMIC );
-			} else {
-				item_t	dmy, *tmp;
-
-				tmp = alloc_item( &dmy );
-				if( tmp == NULL )
-					continue;
-
-				if( !make_item_chest( dun.lev, tmp,
-						get_chest_n( dun.lev ) ) ){
-					free_item( tmp );
-					continue;
-				}
-				if( !put_item( j, i, 1, tmp, FALSE ) ){
-					free_item( tmp );
-					continue;
-				}
-			}
-		}
 	}
 
 	/*  */
-	for( i = 0; i < MAP_MAX_Y; i++ ){
-		for( j = 0; j < MAP_MAX_X; j++ ){
-			if( dun.map.obj.mjr[i][j] != FACE_ROOM_PTN_TRAP )
-				continue;
 
-			dun.map.obj.mjr[i][j] = FACE_MJR_FLOOR;
-			dun.map.obj.mnr[i][j] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[i][j] |= FLG_OBJ_PASS;
-
-			make_trap( j, i, dun.lev );
-		}
-	}
-
-	/*  */
 	trap_max_n = roll_dice( TRAP_AVE_N );
 	if( trap_max_n > TRAP_MAX_N )
 		trap_max_n = TRAP_MAX_N;
 
 	trap_n = 0;
-	for( i = 0; i < 10240; i++ ){
+	for( i = 0; i < 1024; i++ ){
 		long	x, y;
 		trap_t	*trap;
 
-		for( i = 0; i < 128; i++ ){
+		x = 0;
+		y = 0;
+		for( j = 0; j < 128; j++ ){
 			x = 1 + randm( MAP_MAX_X - 2 );
 			y = 1 + randm( MAP_MAX_Y - 2 );
 			if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
@@ -450,22 +517,37 @@ void	make_fence( void )
 	long	n;
 
 	for( n = 0; n < MAP_MAX_Y; n++ ){
+		if( dun.map.obj.mnr[n][0] == FACE_MNR_GATE )
+			continue;
+
 		dun.map.obj.mjr[n][0] = FACE_MJR_WALL;
 		dun.map.obj.mnr[n][0] = FACE_MNR_WALL;
-		dun.map.obj.flg[n][0] &= ~(FLG_OBJ_PASS);
+		dun.map.obj.flg[n][0] &= ~(FLG_MAP_OBJ_PASS);
+	}
+	for( n = 0; n < MAP_MAX_Y; n++ ){
+		if( dun.map.obj.mnr[n][MAP_MAX_X - 1] == FACE_MNR_GATE )
+			continue;
 
 		dun.map.obj.mjr[n][MAP_MAX_X - 1] = FACE_MJR_WALL;
 		dun.map.obj.mnr[n][MAP_MAX_X - 1] = FACE_MNR_WALL;
-		dun.map.obj.flg[n][MAP_MAX_X - 1] &= ~(FLG_OBJ_PASS);
+		dun.map.obj.flg[n][MAP_MAX_X - 1] &= ~(FLG_MAP_OBJ_PASS);
 	}
+
 	for( n = 0; n < MAP_MAX_X; n++ ){
+		if( dun.map.obj.mnr[0][n] == FACE_MNR_GATE )
+			continue;
+
 		dun.map.obj.mjr[0][n] = FACE_MJR_WALL;
 		dun.map.obj.mnr[0][n] = FACE_MNR_WALL;
-		dun.map.obj.flg[0][n] &= ~(FLG_OBJ_PASS);
+		dun.map.obj.flg[0][n] &= ~(FLG_MAP_OBJ_PASS);
+	}
+	for( n = 0; n < MAP_MAX_X; n++ ){
+		if( dun.map.obj.mnr[MAP_MAX_Y - 1][n] == FACE_MNR_GATE )
+			continue;
 
 		dun.map.obj.mjr[MAP_MAX_Y - 1][n] = FACE_MJR_WALL;
 		dun.map.obj.mnr[MAP_MAX_Y - 1][n] = FACE_MNR_WALL;
-		dun.map.obj.flg[MAP_MAX_Y - 1][n] &= ~(FLG_OBJ_PASS);
+		dun.map.obj.flg[MAP_MAX_Y - 1][n] &= ~(FLG_MAP_OBJ_PASS);
 	}
 }
 
@@ -532,7 +614,7 @@ void	set_room( room_ptn_t *room, long x, long y, long n, long flg )
 			if( face == FACE_MJR_FLOOR ){
 				dun.map.obj.mjr[my][mx] = FACE_MJR_FLOOR;
 				dun.map.obj.mnr[my][mx] = FACE_MNR_FLOOR;
-				dun.map.obj.flg[my][mx] = FLG_OBJ_PASS;
+				dun.map.obj.flg[my][mx] = FLG_MAP_OBJ_PASS;
 				dun.map.sect[my][mx] = sect;
 			} else if( face == FACE_MJR_WALL ){
 				dun.map.obj.mjr[my][mx] = FACE_MJR_WALL;
@@ -542,13 +624,13 @@ void	set_room( room_ptn_t *room, long x, long y, long n, long flg )
 			} else {
 				dun.map.obj.mjr[my][mx] = face;
 				dun.map.obj.mnr[my][mx] = FACE_MNR_NULL;
-				dun.map.obj.flg[my][mx] = FLG_OBJ_PASS;
+				dun.map.obj.flg[my][mx] = FLG_MAP_OBJ_PASS;
 				dun.map.sect[my][mx] = sect;
 			}
 			if( flg_light )
-				dun.map.light_depth[my][mx] = 1;
+				dun.map.light_depth_obj[my][mx] = 1;
 			else
-				dun.map.light_depth[my][mx] = 0;
+				dun.map.light_depth_obj[my][mx] = 0;
 		}
 	}
 
@@ -1117,6 +1199,9 @@ bool_t	make_door( long bx, long by, long ex, long ey, char mnr )
 			dun.door[n].flg |= FLG_DOOR_SECRET;
 
 		dun.door[n].flg &= ~(FLG_DOOR_SRCHED);
+	} else if( mnr == FACE_MNR_GATE ){
+		dun.door[n].flg |= FLG_DOOR_GATE;
+		dun.door[n].mnr = FACE_MNR_GATE;
 	} else {
 		dun.door[n].flg |= FLG_DOOR_SHOP;
 		dun.door[n].mnr = mnr;
@@ -1145,43 +1230,53 @@ void	set_face_door( long dr_n )
 
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_OPEN ) ){
 		mjr = FACE_MJR_DOOR_OPEN;
-		flg |= FLG_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS;
 	}
 
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_JAMMED ) )
 		mnr = FACE_MNR_DOOR_JAMMED;
 
-	if( !chk_flg( dun.door[dr_n].flg, FLG_DOOR_SRCHED ) )
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SRCHED ) )
+		flg |= FLG_MAP_OBJ_FIND;
+	else
 		mnr = FACE_MNR_DOOR_NORM;
 
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_BROKEN ) ){
 		dun.door[dr_n].flg |= FLG_DOOR_OPEN;
 		mjr = FACE_MJR_DOOR_OPEN;
 		mnr = FACE_MNR_DOOR_BROKEN;
-		flg |= FLG_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS;
 	}
 
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SECRET ) ){
 		dun.door[dr_n].flg &= ~(FLG_DOOR_OPEN);
 		mjr = FACE_MJR_DOOR_CLOSE;
 		mnr = FACE_MNR_DOOR_SECRET;
-		flg &= ~FLG_OBJ_PASS;
-		flg |= FLG_OBJ_LOOK_WALL;
+		flg &= ~FLG_MAP_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_LOOK_WALL;
 	}
 
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SHOP ) ){
 		mjr = FACE_MJR_DOOR_CLOSE;
 		/* mnr  make_door() Ѥ */
 		mnr = dun.door[dr_n].mnr;
-		flg &= ~FLG_OBJ_PASS;
-		flg |= FLG_OBJ_FIND;
+		flg &= ~FLG_MAP_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_FIND;
 	}
 
 	if( chk_find_door( dr_n ) )
-		flg |= FLG_OBJ_FIND;
+		flg |= FLG_MAP_OBJ_FIND;
 	if( dun.lev == 0 )
-		flg |= FLG_OBJ_FIND;
+		flg |= FLG_MAP_OBJ_FIND;
 
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_GATE ) ){
+		mjr = FACE_MJR_DOOR_CLOSE;
+		mnr = FACE_MNR_GATE;
+		flg &= ~FLG_MAP_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_FIND;
+	}
+
+	/**/
 
 	dun.door[dr_n].mjr = mjr;
 	dun.door[dr_n].mnr = mnr;
@@ -1210,7 +1305,8 @@ bool_t	chk_find_door( long dr_n )
 
 			x = dun.door[dr_n].x + j;
 			y = dun.door[dr_n].y + i;
-			if( chk_flg( dun.map.obj.flg[y][x], FLG_OBJ_FIND ) ){
+			if( chk_flg( dun.map.obj.flg[y][x],
+					FLG_MAP_OBJ_FIND ) ){
 				return TRUE;
 			}
 		}
@@ -1221,6 +1317,56 @@ bool_t	chk_find_door( long dr_n )
 
 /**/
 
+bool_t	break_door( long dr_n )
+{
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SHOP ) ){
+		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
+		return FALSE;
+	}
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_BROKEN ) ){
+		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_BROKEN );
+		return FALSE;
+	}
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_GATE ) ){
+		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
+		return FALSE;
+	}
+
+	dun.door[dr_n].flg |= FLG_DOOR_BROKEN | FLG_DOOR_OPEN;
+	set_face_door( dr_n );
+	draw_door( dr_n );
+
+	return TRUE;
+}
+
+/**/
+
+void	get_near_pos_door( pos_t *pos, door_t *dr, chr_t *chr )
+{
+	if( pos == NULL )
+		return;
+	if( dr == NULL )
+		return;
+	if( chr == NULL )
+		return;
+
+	pos->x = dr->x;
+	pos->y = dr->y;
+
+	/* ɥΣ֥åȤʤ */
+	if( chr->x < dr->x )
+		pos->x = dr->x - 1;
+	else if( (dr->x + dr->dx - 1) < chr->x )
+		pos->x = (dr->x + dr->dx - 1) + 1;
+
+	if( chr->y < dr->y )
+		pos->y = dr->y - 1;
+	else if( (dr->y + dr->dy - 1) < chr->y )
+		pos->y = (dr->y + dr->dy - 1) + 1;
+}
+
+/**/
+
 void	make_stairs( long x, long y, char face )
 {
 	char	mjr, mnr;
@@ -1230,9 +1376,15 @@ void	make_stairs( long x, long y, char face )
 
 	if( (face == FACE_MJR_STAIRS_DOWN)
 			|| (face == FACE_MNR_STAIRS_DOWN) ){
+		if( dun.lev <= DUN_MAX_LEV_BASE )
+			return;
+
 		mjr = FACE_MJR_STAIRS_DOWN;
 		mnr = FACE_MNR_STAIRS_DOWN;
 	} else {
+		if( dun.lev >= DUN_MAX_LEV_FLOOR )
+			return;
+
 		mjr = FACE_MJR_STAIRS_UP;
 		mnr = FACE_MNR_STAIRS_UP;
 	}
@@ -1243,43 +1395,84 @@ void	make_stairs( long x, long y, char face )
 
 /**/
 
+bool_t	set_statue( long x, long y, long dun_lev, bool_t flg_self )
+{
+	long	ix, iy;
+
+	if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+		return FALSE;
+	if( !flg_self && (dun.map.chr.mjr[y][x] != FACE_MJR_NULL) )
+			return FALSE;
+
+	dun.map.obj.mjr[y][x] = FACE_MJR_WALL;
+	dun.map.obj.mnr[y][x] = FACE_MNR_WALL;
+	dun.map.obj.flg[y][x] = FLG_NULL;
+
+	ix = x + randm( 3 ) - 1;
+	iy = y + randm( 3 ) - 1;
+	make_item( ix, iy, dun_lev );
+
+	return TRUE;
+}
+
+/**/
+
 void	set_map_total( long x, long y, long dx, long dy )
+{
+	/* ط */
+	set_map_total_bg( x, y, dx, dy );
+
+	/* ° */
+	set_map_total_crsr_attr( x, y, dx, dy );
+
+	/* ֥ */
+	set_map_total_obj( x, y, dx, dy );
+
+	/* ۡࡦ */
+	set_map_total_square( x, y, dx, dy );
+
+	/* 󥹥ȥС */
+	set_map_total_chr( x, y, dx, dy );
+
+	/* Υѥ */
+	set_map_total_crsr_ptn( x, y, dx, dy );
+}
+
+/**/
+
+void	set_map_total_bg( long x, long y, long dx, long dy )
 {
 	long	i, j;
+	long	xx, yy;
 	long	mjr, mnr;
-	flg_map_t	flg, flg_total;
+	flg_map_t	flg;
 	long	dep;
 	curs_attr_n_t	attr_n;
 	curs_attr_t	*attr_dflt;
-	pos_t	*csr;
-	pos_t	*draw_pos;
-	party_t	*pty;
-
-	attr_dflt = get_curs_attr();
-
-	draw_pos = get_map_draw_pos();
-
-	/* ط */
 
 	attr_n = CURS_ATTR_N_MAP_NORMAL;
+	attr_dflt = get_curs_attr();
+
 	for( i = 0; i < dy; i++ ){
-		if( !clip_y( y + i ) )
+		yy = y + i;
+		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < dx; j++ ){
-			if( !clip_x( x + j ) )
+			xx = x + j;
+			if( !clip_x( xx ) )
 				continue;
 
-			mjr = dun.map.obj.mjr[y + i][x + j];
-			mnr = dun.map.obj.mnr[y + i][x + j];
-			flg = dun.map.obj.flg[y + i][x + j];
-			dep = dun.map.light_depth[y + i][x + j];
+			mjr = dun.map.obj.mjr[yy][xx];
+			mnr = dun.map.obj.mnr[yy][xx];
+			flg = dun.map.obj.flg[yy][xx];
+			dep = calc_light_depth( xx, yy );
 
-			if( chk_flg( flg, FLG_OBJ_LOOK_WALL ) ){
+			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_WALL ) ){
 				mjr = FACE_MJR_WALL;
 				mnr = FACE_MNR_WALL;
 			}
-			if( chk_flg( flg, FLG_OBJ_LOOK_FLOOR ) ){
+			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) ){
 				mjr = FACE_MJR_FLOOR;
 				mnr = FACE_MNR_FLOOR;
 			}
@@ -1287,193 +1480,259 @@ void	set_map_total( long x, long y, long dx, long dy )
 				mjr = FACE_MJR_NULL;
 				mnr = FACE_MNR_NULL;
 			}
-			if( !chk_flg( flg, FLG_OBJ_FIND ) ){
+			if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) ){
 				mjr = FACE_MJR_NULL;
 				mnr = FACE_MNR_NULL;
 			}
 
-			dun.map.total.mjr[y + i][x + j] = mjr;
-			dun.map.total.mnr[y + i][x + j] = mnr;
-			dun.map.total.flg[y + i][x + j] = FLG_NULL;
-			dun.map.attr[y + i][x + j] = attr_dflt[attr_n];
+			dun.map.total.mjr[yy][xx] = mjr;
+			dun.map.total.mnr[yy][xx] = mnr;
+			dun.map.total.flg[yy][xx] = FLG_NULL;
+			dun.map.attr[yy][xx] = attr_dflt[attr_n];
 		}
 	}
+}
 
-	/* ° */
+/**/
+
+void	set_map_total_crsr_attr( long x, long y, long dx, long dy )
+{
+	long	i, j;
+	long	xx, yy;
+	curs_attr_n_t	attr_n;
+	curs_attr_t	*attr_dflt;
+	pos_t	*csr;
+
+	attr_dflt = get_curs_attr();
+	csr = get_crsr();
 
 	attr_n = CURS_ATTR_N_MAP_CRSR;
-	csr = get_crsr();
 	for( i = 0; i < g_crsr_ptn.y_len; i++ ){
+		yy = csr->y + i + g_crsr_ptn.y;
+		if( !clip_y( yy ) )
+			continue;
+
 		for( j = 0; j < g_crsr_ptn.x_len; j++ ){
-			long	x, y;
 			long	c;
 
-			x = csr->x + j + g_crsr_ptn.x;
-			y = csr->y + i + g_crsr_ptn.y;
-
-			if( x < draw_pos->x )
-				continue;
-			if( y < draw_pos->y )
-				continue;
-			if( x > (draw_pos->x + WIN_MAP_WIDTH - 1) )
-				continue;
-			if( y > (draw_pos->y + WIN_MAP_HEIGHT - 1) )
+			xx = csr->x + j + g_crsr_ptn.x;
+			if( !clip_x( xx ) )
 				continue;
 
 			c = g_crsr_ptn.face[i][j * 2 + 0];
 			if( c != g_crsr_ptn.mask_chr )
-				dun.map.attr[y][x] = attr_dflt[attr_n];
+				dun.map.attr[yy][xx] = attr_dflt[attr_n];
 
 			c = g_crsr_ptn.face[i][j * 2 + 1];
 			if( c != g_crsr_ptn.mask_chr )
-				dun.map.attr[y][x] = attr_dflt[attr_n];
+				dun.map.attr[yy][xx] = attr_dflt[attr_n];
 		}
 	}
+}
 
-	/* ƥ */
+/**/
+
+void	set_map_total_obj( long x, long y, long dx, long dy )
+{
+	long	i, j;
+	long	xx, yy;
+	long	mjr, mnr;
+	flg_map_t	flg;
+	long	dep;
+	curs_attr_n_t	attr_n;
+	curs_attr_t	*attr_dflt;
 
 	attr_n = CURS_ATTR_N_MAP_ITEM;
+	attr_dflt = get_curs_attr();
+
 	for( i = 0; i < dy; i++ ){
-		if( !clip_y( y + i ) )
+		yy = y + i;
+		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < dx; j++ ){
-			if( !clip_x( x + j ) )
+			xx = x + j;
+			if( !clip_x( xx ) )
 				continue;
 
-			mjr = dun.map.obj.mjr[y + i][x + j];
-			mnr = dun.map.obj.mnr[y + i][x + j];
-			flg = dun.map.obj.flg[y + i][x + j];
-			dep = dun.map.light_depth[y + i][x + j];
+			mjr = dun.map.obj.mjr[yy][xx];
+			mnr = dun.map.obj.mnr[yy][xx];
+			flg = dun.map.obj.flg[yy][xx];
+			dep = calc_light_depth( xx, yy );
 
 			if( mjr == FACE_MJR_FLOOR )
 				continue;
 			if( mjr == FACE_MJR_WALL )
 				continue;
-			if( chk_flg( flg, FLG_OBJ_LOOK_WALL ) )
+			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_WALL ) )
 				continue;
-			if( chk_flg( flg, FLG_OBJ_LOOK_FLOOR ) )
+			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) )
 				continue;
 			if( (mjr == FACE_MJR_FLOOR) && (dep <= 0) )
 				continue;
-			if( !chk_flg( flg, FLG_OBJ_FIND ) )
+			if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) )
 				continue;
 
-			dun.map.total.mjr[y + i][x + j] = mjr;
-			dun.map.total.mnr[y + i][x + j] = mnr;
-			dun.map.total.flg[y + i][x + j] = FLG_NULL;
-			dun.map.attr[y + i][x + j] = attr_dflt[attr_n];
+			dun.map.total.mjr[yy][xx] = mjr;
+			dun.map.total.mnr[yy][xx] = mnr;
+			dun.map.total.flg[yy][xx] = FLG_NULL;
+			dun.map.attr[yy][xx] = attr_dflt[attr_n];
 		}
 	}
+}
 
-	/* ۡݥ */
+/**/
 
+void	set_map_total_square( long x, long y, long dx, long dy )
+{
+	long	i, j;
+	long	xx, yy;
+	curs_attr_t	*attr_dflt;
+	party_t	*pty;
+
+	attr_dflt = get_curs_attr();
 	pty = get_party();
+
 	for( i = -1; i <= +1; i++ ){
+		yy = pty->square.y + i;
+		if( !clip_y( yy ) )
+			continue;
+
 		for( j = -1; j <= +1; j++ ){
-			long	x, y;
 			mbr_t	*mbr;
 
-			x = pty->square.x + j;
-			y = pty->square.y + i;
+			xx = pty->square.x + j;
+			if( !clip_x( xx ) )
+				continue;
 
 			if( pty->square.chr_dir[i + 1][j + 1] == MBR_NO_POS )
 				continue;
-			if( x < draw_pos->x )
-				continue;
-			if( y < draw_pos->y )
-				continue;
-			if( x > (draw_pos->x + WIN_MAP_WIDTH - 1) )
-				continue;
-			if( y > (draw_pos->y + WIN_MAP_HEIGHT - 1) )
-				continue;
 
-			dun.map.total.mjr[y][x] = FACE_MJR_SQUARE;
-			dun.map.attr[y][x] = attr_dflt
-					[CURS_ATTR_N_MAP_SQUARE];
+			dun.map.total.mjr[yy][xx] = FACE_MJR_SQUARE;
+			dun.map.attr[yy][xx]
+					= attr_dflt[CURS_ATTR_N_MAP_SQUARE];
 
 			mbr = pty->mbr[pty->square.chr_dir[i + 1][j + 1]];
 			if( chk_flg( mbr->stat, FLG_STAT_NOT_EXIST ) ){
 				continue;
 			}
 
-			dun.map.total.mnr[y][x] = mbr->face_mnr;
+			dun.map.total.mnr[yy][xx] = mbr->face.mnr;
 		}
 	}
+}
 
-	/* 󥹥ȥС */
+/**/
+
+void	set_map_total_chr( long x, long y, long dx, long dy )
+{
+	long	i, j;
+	long	xx, yy;
+	long	mjr, mnr;
+	flg_map_t	flg, flg_total;
+	curs_attr_n_t	attr_n;
+	curs_attr_t	*attr_dflt;
+
+	attr_dflt = get_curs_attr();
 
 	for( i = 0; i < dy; i++ ){
-		if( !clip_y( y + i ) )
+		yy = y + i;
+		if( !clip_y( yy ) )
 			continue;
 		for( j = 0; j < dx; j++ ){
-			if( !clip_x( x + j ) )
+			bool_t	flg_rev_rev;
+
+			xx = x + j;
+			if( !clip_x( xx ) )
 				continue;
 
-			flg_total = dun.map.total.flg[y + i][x + j];
+			flg_total = dun.map.total.flg[yy][xx];
 
-			mjr = dun.map.chr.mjr[y + i][x + j];
-			mnr = dun.map.chr.mnr[y + i][x + j];
-			flg = dun.map.chr.flg[y + i][x + j];
+			mjr = dun.map.chr.mjr[yy][xx];
+			mnr = dun.map.chr.mnr[yy][xx];
+			flg = dun.map.chr.flg[yy][xx];
 			attr_n = CURS_ATTR_N_NORMAL;
+			flg_rev_rev = FALSE;
 
-			if( mjr == FACE_MJR_NULL )
+			if( mjr == FACE_MJR_NULL ){
 				continue;
-
-			if( mjr == FACE_MJR_MBR ){
+			} else if( mjr == FACE_MJR_MBR ){
 				mbr_t	*p;
 
 				/* Сä */
-				p = get_mbr( x + j, y + i );
-				if( p != NULL )
-					attr_n = CURS_ATTR_N_MBR_1 + p->mbr_n;
+				p = get_mbr( xx, yy );
+				if( p != NULL ){
+					attr_n = CURS_ATTR_N_MBR_1
+							+ p->mbr_n;
+				}
+				if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) ){
+					/* Ʃʤ */
+					flg_rev_rev = TRUE;
+				}
 			} else {
 				/* 󥹥ä */
-				if( !chk_flg( flg, FLG_CHR_FIND ) ){
+				if( !chk_flg( flg, FLG_MAP_CHR_FIND ) ){
 					/* ĤäƤʤ */
 					continue;
 				}
-				attr_n = CURS_ATTR_N_MAP_MNSTR;
+				if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) ){
+					/* Ʃʤ */
+					continue;
+				}
+				if( chk_flg( flg, FLG_MAP_CHR_NPC ) ){
+					attr_n = CURS_ATTR_N_MAP_NPC;
+				} else {
+					attr_n = CURS_ATTR_N_MAP_MNSTR;
+				}
 			}
-			if( chk_flg( flg, FLG_CHR_INVISIBLE ) )
-				continue;	/* Ʃʤ */
 
-			dun.map.total.mjr[y + i][x + j] = mjr;
-			dun.map.total.mnr[y + i][x + j] = mnr;
-			dun.map.total.flg[y + i][x + j] = flg_total;
-			dun.map.attr[y + i][x + j] = attr_dflt[attr_n];
+			dun.map.total.mjr[yy][xx] = mjr;
+			dun.map.total.mnr[yy][xx] = mnr;
+			dun.map.total.flg[yy][xx] = flg_total;
+			dun.map.attr[yy][xx] = attr_dflt[attr_n];
+			if( flg_rev_rev )
+				dun.map.attr[yy][xx].attr ^= A_REVERSE;
 		}
 	}
+}
 
-	/* Υѥ */
+/**/
+
+void	set_map_total_crsr_ptn( long x, long y, long dx, long dy )
+{
+	long	i, j;
+	long	xx, yy;
+	pos_t	*csr;
+	crsr_ptn_t	*ptn;
 
 	csr = get_crsr();
-	for( i = 0; i < g_crsr_ptn.y_len; i++ ){
-		for( j = 0; j < g_crsr_ptn.x_len; j++ ){
-			long	x, y;
+	ptn = get_crsr_ptn();
+
+	for( i = 0; i < ptn->y_len; i++ ){
+		yy = csr->y + i + ptn->y;
+		if( !clip_y( yy ) )
+			continue;
+
+		for( j = 0; j < ptn->x_len; j++ ){
 			long	c;
 
-			x = csr->x + j + g_crsr_ptn.x;
-			y = csr->y + i + g_crsr_ptn.y;
-
-			if( x < draw_pos->x )
-				continue;
-			if( y < draw_pos->y )
-				continue;
-			if( x > (draw_pos->x + WIN_MAP_WIDTH - 1) )
-				continue;
-			if( y > (draw_pos->y + WIN_MAP_HEIGHT - 1) )
+			xx = csr->x + j + ptn->x;
+			if( !clip_x( xx ) )
 				continue;
 
 			/* ͭ륢ȥӥ塼Ȥ褹 */
 
-			c = g_crsr_ptn.face[i][j * 2 + 0];
-			if( c != g_crsr_ptn.mask_chr )
-				dun.map.total.mjr[y][x] = c;
+			c = ptn->face[i][j * 2 + 0];
+			if( c == '\0' )
+				break;
+			if( c != ptn->mask_chr )
+				dun.map.total.mjr[yy][xx] = c;
 
-			c = g_crsr_ptn.face[i][j * 2 + 1];
-			if( c != g_crsr_ptn.mask_chr )
-				dun.map.total.mnr[y][x] = c;
+			c = ptn->face[i][j * 2 + 1];
+			if( c == '\0' )
+				break;
+			if( c != ptn->mask_chr )
+				dun.map.total.mnr[yy][xx] = c;
 		}
 	}
 }
@@ -1517,6 +1776,7 @@ void	put_path( long x, long y, long dx, long dy )
 	long	min_i, max_i;
 	long	min_j, max_j;
 	sect_t	sect;
+	long	xx, yy;
 
 	/* (dx == 0) && (dy == 0)λϥǥե */
 	min_i = 0;
@@ -1544,16 +1804,18 @@ void	put_path( long x, long y, long dx, long dy )
 	}
 
 	for( i = min_i; i < max_i; i++ ){
+		yy = y + i;
 		for( j = min_j; j < max_j; j++ ){
-			dun.map.sect[y + i][x + j] = sect;
+			xx = x + j;
+			dun.map.sect[yy][xx] = sect;
 
-			if( dun.map.obj.mjr[y + i][x + j] != FACE_MJR_WALL ){
+			if( dun.map.obj.mjr[yy][xx] != FACE_MJR_WALL ){
 				continue;
 			}
 
-			dun.map.obj.mjr[y + i][x + j] = FACE_MJR_FLOOR;
-			dun.map.obj.mnr[y + i][x + j] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[y + i][x + j] |= FLG_OBJ_PASS;
+			dun.map.obj.mjr[yy][xx] = FACE_MJR_FLOOR;
+			dun.map.obj.mnr[yy][xx] = FACE_MNR_FLOOR;
+			dun.map.obj.flg[yy][xx] |= FLG_MAP_OBJ_PASS;
 		}
 	}
 }
@@ -1571,6 +1833,8 @@ bool_t	open_door( long n )
 
 	if( chk_flg_or( flg, FLG_DOOR_SECRET | FLG_DOOR_JAMMED ) )
 		return FALSE;
+	if( chk_flg( flg, FLG_DOOR_GATE ) )
+		return FALSE;
 
 	if( chk_flg( flg, FLG_DOOR_SHOP ) ){
 		open_door_shop( n );
@@ -1601,10 +1865,11 @@ bool_t	close_door( long n )
 
 	if( chk_flg( flg, FLG_DOOR_SECRET ) )
 		return FALSE;
-	if( chk_flg( flg, FLG_DOOR_OPEN ) ){
+	if( chk_flg( flg, FLG_DOOR_OPEN ) )
 		if( chk_flg_or( flg, FLG_DOOR_JAMMED | FLG_DOOR_BROKEN ) )
 			return FALSE;
-	}
+	if( chk_flg( flg, FLG_DOOR_GATE ) )
+		return FALSE;
 
 	/* 饯ɥξˤ뤫 */
 	for( i = 0; i < dun.door[n].dy; i++ ){
@@ -1646,6 +1911,8 @@ bool_t	jam_door( long n )
 		print_msg( FLG_NULL, MSG_ERR_DOOR_JAM_JAMMED );
 		return FALSE;
 	}
+	if( chk_flg( dun.door[n].flg, FLG_DOOR_GATE ) )
+		return FALSE;
 
 	dun.door[n].flg |= FLG_DOOR_JAMMED;
 	set_face_door( n );
@@ -1674,6 +1941,8 @@ bool_t	disarm_door( long n )
 		print_msg( FLG_NULL, MSG_ERR_DOOR_DISARM_NOT_JAM );
 		return FALSE;
 	}
+	if( chk_flg( dun.door[n].flg, FLG_DOOR_GATE ) )
+		return FALSE;
 
 	dun.door[n].flg &= ~(FLG_DOOR_JAMMED);
 	set_face_door( n );
@@ -1703,6 +1972,26 @@ bool_t	srch_door( long n )
 
 /**/
 
+void	detect_door( long x, long y, long r )
+{
+	long	n;
+
+	for( n = 0; n < dun.door_n; n++ ){
+		if( (dun.door[n].x + dun.door[n].dx - 1) < (x - r) )
+			continue;
+		if( (x + r) < dun.door[n].x )
+			continue;
+		if( (dun.door[n].y + dun.door[n].dy - 1) < (y - r) )
+			continue;
+		if( (y + r) < dun.door[n].y )
+			continue;
+
+		srch_door( n );
+	}
+}
+
+/**/
+
 void	find_obj( long x, long y )
 {
 	long	i, j;
@@ -1723,8 +2012,8 @@ void	find_obj( long x, long y )
 				continue;
 
 			flg = dun.map.obj.flg[sy][sx];
-			dep = dun.map.light_depth[sy][sx];
-			if( !chk_flg( flg, FLG_OBJ_FIND ) && (dep > 0) ){
+			dep = dun.map.light_depth_obj[sy][sx];
+			if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) && (dep > 0) ){
 				find_obj_fill( sx, sy );
 				flg_redraw = TRUE;
 			}
@@ -1756,7 +2045,7 @@ void	find_obj_fill( long x, long y )
 			if( dun.map.sect[sy][sx] != sect )
 				continue;
 			if( !chk_flg( dun.map.obj.flg[sy][sx],
-					FLG_OBJ_PASS ) )
+					FLG_MAP_OBJ_PASS ) )
 				continue;
 
 			find_obj_fill_field( sx, sy );
@@ -1780,7 +2069,7 @@ void	find_obj_fill_field( long x, long y )
 			if( !clip_x( sx ) )
 				continue;
 
-			dun.map.obj.flg[sy][sx] |= FLG_OBJ_FIND;
+			dun.map.obj.flg[sy][sx] |= FLG_MAP_OBJ_FIND;
 		}
 	}
 }
@@ -1847,18 +2136,18 @@ void	turn_light_field(
 				continue;
 
 			if( !chk_flg( dun.map.obj.flg[sy][sx],
-					FLG_OBJ_PASS ) )
+					FLG_MAP_OBJ_PASS ) )
 				continue;
 
 			if( chk_flg( dun.map.obj.flg[sy][sx],
-					FLG_OBJ_LOOK_WALL ) )
+					FLG_MAP_OBJ_LOOK_WALL ) )
 				continue;
 
 			/**/
 
-			flg_on_depth = turn_light( x, y, flg_on );
+			flg_on_depth = turn_light_obj( x, y, flg_on );
 			if( flg_on_depth && flg_find )
-				dun.map.obj.flg[y][x] |= FLG_OBJ_FIND;
+				dun.map.obj.flg[y][x] |= FLG_MAP_OBJ_FIND;
 			return;
 		}
 	}
@@ -1878,9 +2167,9 @@ void	turn_light_door( door_t *dr, bool_t flg_on, bool_t flg_find )
 			sx = dr->x + dx;
 			sy = dr->y + dy;
 
-			flg_on_depth = turn_light( sx, sy, flg_on );
+			flg_on_depth = turn_light_obj( sx, sy, flg_on );
 			if( flg_on_depth && flg_find )
-				dun.map.obj.flg[sy][sx] |= FLG_OBJ_FIND;
+				dun.map.obj.flg[sy][sx] |= FLG_MAP_OBJ_FIND;
 		}
 	}
 
@@ -1889,14 +2178,39 @@ void	turn_light_door( door_t *dr, bool_t flg_on, bool_t flg_find )
 
 /**/
 
-bool_t	turn_light( long x, long y, bool_t flg_on )
+bool_t	turn_light_obj( long x, long y, bool_t flg_on )
 {
 	if( flg_on )
-		dun.map.light_depth[y][x]++;
+		dun.map.light_depth_obj[y][x]++;
 	else
-		dun.map.light_depth[y][x]--;
+		dun.map.light_depth_obj[y][x]--;
 
-	return( dun.map.light_depth[y][x] > 0 );
+	return( dun.map.light_depth_obj[y][x] > 0 );
+}
+
+/**/
+
+bool_t	turn_light_chr( long x, long y, bool_t flg_on )
+{
+	if( flg_on )
+		dun.map.light_depth_chr[y][x]++;
+	else
+		dun.map.light_depth_chr[y][x]--;
+
+	return( dun.map.light_depth_chr[y][x] > 0 );
+}
+
+/**/
+
+long	calc_light_depth( long x, long y )
+{
+	long	depth;
+
+	depth = 0;
+	depth += dun.map.light_depth_obj[y][x];
+	depth += dun.map.light_depth_chr[y][x];
+
+	return depth;
 }
 
 /**/
@@ -1931,8 +2245,10 @@ bool_t	chk_find( pos_t *pos1, pos_t *pos2 )
 
 	for( ; x <= x2; x++ ){
 		if( e < 0 ){
-			if( !chk_flg( dun.map.obj.flg[y][x], FLG_OBJ_PASS ) )
+			if( !chk_flg( dun.map.obj.flg[y][x],
+					FLG_MAP_OBJ_PASS ) ){
 				return FALSE;
+			}
 		} else {
 			do {
 				y += sgn_y;
@@ -1945,7 +2261,7 @@ bool_t	chk_find( pos_t *pos1, pos_t *pos2 )
 				}
 				e -= dx2;
 				if( !chk_flg( dun.map.obj.flg[y][x],
-						FLG_OBJ_PASS ) ){
+						FLG_MAP_OBJ_PASS ) ){
 					return FALSE;
 				}
 			} while( e >= 0 );
@@ -2224,6 +2540,46 @@ door_t	*get_door_randm( long x, long y, act_kind_t act_kind )
 
 /**/
 
+door_t	*get_door_towner( long x, long y, long r )
+{
+	door_t	*ret, *dr;
+	long	n;
+	long	xx, yy;
+	long	dx, dy;
+	char	mjr;
+
+	ret = NULL;
+	n = 0;
+	for( dy = -r; dy <= +r; dy++ ){
+		yy = y + dy;
+		if( !clip_y( yy ) )
+			continue;
+
+		for( dx = -r; dx <= +r; dx++ ){
+			xx = x + dx;
+			if( !clip_x( xx ) )
+				continue;
+
+			mjr = dun.map.obj.mjr[yy][xx];
+			if( mjr != FACE_MJR_DOOR_OPEN )
+				if( mjr != FACE_MJR_DOOR_CLOSE )
+					continue;
+
+			dr = get_door( xx, yy );
+			if( dr != NULL ){
+				n++;
+				if( per_randm( n ) ){
+					ret = dr;
+				}
+			}
+		}
+	}
+
+	return ret;
+}
+
+/**/
+
 bool_t	chk_mark_door( door_t *p, act_kind_t act_kind )
 {
 	switch( act_kind ){
@@ -2347,7 +2703,7 @@ bool_t	is_map_wall( long x, long y )
 		return TRUE;
 	if( dun.map.obj.mjr[y][x] == FACE_MJR_WALL )
 		return TRUE;
-	if( chk_flg( dun.map.obj.flg[y][x], FLG_OBJ_LOOK_WALL ) )
+	if( chk_flg( dun.map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
 		return TRUE;
 
 	return FALSE;
@@ -2357,6 +2713,8 @@ bool_t	is_map_wall( long x, long y )
 
 bool_t	clip_x( long n )
 {
+	if( n == MAP_DEL_X )
+		return FALSE;
 	if( n < 0 )
 		return FALSE;
 	if( n >= MAP_MAX_X )
@@ -2369,6 +2727,8 @@ bool_t	clip_x( long n )
 
 bool_t	clip_y( long n )
 {
+	if( n == MAP_DEL_Y )
+		return FALSE;
 	if( n < 0 )
 		return FALSE;
 	if( n >= MAP_MAX_Y )
@@ -2379,6 +2739,18 @@ bool_t	clip_y( long n )
 
 /**/
 
+bool_t	clip_pos( long x, long y )
+{
+	if( !clip_x( x ) )
+		return FALSE;
+	if( !clip_y( y ) )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
 bool_t	chk_rate_room( void )
 {
 	return rate_randm( 50 );
