@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-/*#include	<string.h>*/
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: fight.c,v 1.49 2003/11/20 07:37:24 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 #include	"item.h"
@@ -13,6 +39,7 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
 #include	"fight.h"
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 /*#include	"town_prot.h"*/
 #include	"item_prot.h"
@@ -29,11 +58,12 @@
 #include	"chr_prot.h"
 /*#include	"party_prot.h"*/
 #include	"mnstr_prot.h"
+/*#include	"pet_prot.h"*/
 #include	"fight_prot.h"
 #include	"fx_prot.h"
 #include	"trap_prot.h"
 #include	"draw_prot.h"
-/*#include	"curs_prot.h"*/
+#include	"curs_prot.h"
 /*#include	"menu_prot.h"*/
 /*#include	"tmenu_prot.h"*/
 /*#include	"amenu_prot.h"*/
@@ -47,7 +77,7 @@
 
 /* ٥뤬㤤ۤɶ */
 /* ٥뤬夬о夬ۤɺ̵ʤ */
-#define	D_ITEM_ADD_RATE
+#define	FLG_ITEM_ADD_RATE
 
 #else
 
@@ -96,20 +126,34 @@
 
 /**/
 
-attack_t	mbr_attack_bash[] = {
-	{ ATTACK_KIND_PUNCH, 1, FALSE, TRUE, 10, 10, 10, RESI_KIND_KNOC },
-	{ ATTACK_KIND_KICK, 1, FALSE, TRUE, 10, 10, 10, RESI_KIND_KNOC },
-	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N },
+static attack_t	mbr_attack_bash[] = {
+	{ ATTACK_KIND_PUNCH, 1, FALSE, TRUE, 10, 10, 10, RESI_KIND_KNOC,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
+	{ ATTACK_KIND_KICK, 1, FALSE, TRUE, 10, 10, 10, RESI_KIND_KNOC,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
+	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
-attack_t	mbr_attack_throw[] = {
-	{ ATTACK_KIND_THROW, 1, TRUE, FALSE, 10, 10, 10, RESI_KIND_KNOC },
-	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N },
+static attack_t	mbr_attack_throw[] = {
+	{ ATTACK_KIND_THROW, 1, TRUE, FALSE, 10, 10, 10, RESI_KIND_KNOC,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
+	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
-attack_t	mbr_attack_throw_light[] = {
-	{ ATTACK_KIND_THROW, 1, TRUE, FALSE, 10, 10, 10, RESI_KIND_HEAT },
-	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N },
+static attack_t	mbr_attack_throw_light[] = {
+	{ ATTACK_KIND_THROW, 1, TRUE, FALSE, 10, 10, 10, RESI_KIND_HEAT,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
+	{ ATTACK_KIND_NULL, 0, FALSE, FALSE, 0, 0, 0, RESI_KIND_MAX_N,
+		FX_KIND_NULL, 0,
+		SPELL_KIND_NULL, EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
 /**/
@@ -168,20 +212,22 @@ bool_t	set_attack_mbr_bash(
 		return FALSE;
 
 	eq = &(eq[EQUIP_KIND_WIELDING]);
-	if( eq->kind == ITEM_KIND_WPN ){
+	if( eq->kind == ITEM_KIND_WPN )
 		wpn_tab = eq->tab.wpn;
-		if( wpn_tab != NULL ){
-			if( chk_flg( wpn_tab->flg_abl, FLG_ITEM_ABL_MON ) ){
-				wpn_tab = NULL;
-			}
-		}
-	} else {
+	else
 		wpn_tab = NULL;
-	}
 
-	if( wpn_tab != NULL ){
+	if( wpn_tab == NULL ){
+		/* Ǽξ */
+		p = get_attack( flg_ave, mbr_attack_bash,
+				FALSE, TRUE, FALSE, FALSE );
+		if( p == NULL )
+			return FALSE;
+		*attack = *p;
+	} else {
 		/* ξ */
-		p = get_attack( flg_ave, wpn_tab->attack, FALSE, FALSE );
+		p = get_attack( flg_ave, wpn_tab->attack,
+				TRUE, FALSE, FALSE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		*attack = *p;
@@ -189,12 +235,6 @@ bool_t	set_attack_mbr_bash(
 		attack->hit += add_hit( eq->dat.wpn.add_hit );
 		attack->crtcl += add_wpn_crtcl( eq->dat.wpn.add_crtcl );
 		attack->dam += add_dam( eq->dat.wpn.add_dam );
-	} else {
-		/* Ǽξ */
-		p = get_attack( flg_ave, mbr_attack_bash, FALSE, TRUE );
-		if( p == NULL )
-			return FALSE;
-		*attack = *p;
 	}
 
 	return TRUE;
@@ -218,7 +258,8 @@ bool_t	set_attack_mnstr_bash(
 	if( mnstr->mnstr_tab == NULL )
 		return FALSE;
 
-	p = get_attack_randm( mnstr->mnstr_tab->attack );
+	p = get_attack( flg_ave, mnstr->mnstr_tab->attack,
+			TRUE, TRUE, FALSE, FALSE );
 	if( p == NULL )
 		return FALSE;
 
@@ -231,6 +272,7 @@ bool_t	set_attack_mnstr_bash(
 
 bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 {
+	item_t	*eq;
 	attack_t	attack;
 
 	if( chr1 == NULL )
@@ -238,6 +280,18 @@ bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 	if( chr2 == NULL )
 		return FALSE;
 
+	eq = get_mbr_item_asgn_equip( chr1 );
+	if( eq == NULL )
+		return FALSE;
+
+	/* check stick */
+
+	if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
+		if( !zap_stick( chr1, &(eq[EQUIP_KIND_BOW]) ) )
+			clr_chr_trgt_act( chr1, FALSE );
+		return TRUE;
+	}
+
 	if( dflt_attack == NULL ){
 		if( !set_attack_chr_throw( &attack, chr1, FALSE ) )
 			return FALSE;
@@ -281,14 +335,6 @@ bool_t	set_attack_mbr_throw(
 	if( eq == NULL )
 		return FALSE;
 
-	/* check stick */
-
-	if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
-		if( zap_stick( mbr, &(eq[EQUIP_KIND_BOW]) ) )
-			return TRUE;
-		clr_chr_trgt_act( mbr, FALSE );
-	}
-
 	/* Υơ֥ */
 
 	if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN )
@@ -302,7 +348,8 @@ bool_t	set_attack_mbr_throw(
 
 	if( chk_dagger( arw_tab ) ){
 		/* ξ */
-		p = get_attack( flg_ave, arw_tab->attack, TRUE, FALSE );
+		p = get_attack( flg_ave, arw_tab->attack,
+				FALSE, FALSE, TRUE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		*attack = *p;
@@ -318,7 +365,8 @@ bool_t	set_attack_mbr_throw(
 		/* ݤʤɤξ */
 
 		/* bow */
-		p = get_attack( flg_ave, bow_tab->attack, TRUE, FALSE );
+		p = get_attack( flg_ave, bow_tab->attack,
+				FALSE, FALSE, TRUE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		attack_bow = *p;
@@ -331,7 +379,8 @@ bool_t	set_attack_mbr_throw(
 				.dat.wpn.add_dam );
 
 		/* arrow */
-		p = get_attack( flg_ave, arw_tab->attack, TRUE, FALSE );
+		p = get_attack( flg_ave, arw_tab->attack,
+				FALSE, FALSE, TRUE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		attack_arw = *p;
@@ -352,10 +401,10 @@ bool_t	set_attack_mbr_throw(
 		/* ¾Υƥξ */
 		if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_LIGHT ){
 			p = get_attack( flg_ave, mbr_attack_throw_light,
-					TRUE, FALSE );
+					FALSE, FALSE, TRUE, FALSE );
 		} else {
 			p = get_attack( flg_ave, mbr_attack_throw,
-					TRUE, FALSE );
+					FALSE, FALSE, TRUE, FALSE );
 		}
 		if( p == NULL )
 			return FALSE;
@@ -383,7 +432,8 @@ bool_t	set_attack_mnstr_throw(
 	if( mnstr->mnstr_tab == NULL )
 		return FALSE;
 
-	p = get_attack_randm( mnstr->mnstr_tab->attack );
+	p = get_attack( flg_ave, mnstr->mnstr_tab->attack,
+			FALSE, FALSE, TRUE, FALSE );
 	if( p == NULL )
 		return FALSE;
 
@@ -427,19 +477,28 @@ bool_t	chk_bow( const wpn_tab_t *arw_tab, const wpn_tab_t *bow_tab )
 /**/
 
 attack_t	*get_attack(
-	bool_t flg_ave, attack_t *ls, bool_t flg_throw, bool_t flg_monk
+	bool_t flg_ave, attack_t *ls,
+	bool_t flg_bash, bool_t flg_monk,
+	bool_t flg_throw, bool_t flg_spell
 )
 {
-	if( flg_ave )
-		return get_attack_ave( ls, flg_throw, flg_monk );
-	else
-		return get_attack_randm( ls );
+	if( flg_ave ){
+		return( get_attack_ave( ls,
+				flg_bash, flg_monk,
+				flg_throw, flg_spell ) );
+	} else {
+		return( get_attack_randm( ls,
+				flg_bash, flg_monk,
+				flg_throw, flg_spell ) );
+	}
 }
 
 /**/
 
 attack_t	*get_attack_ave(
-	attack_t *ls, bool_t flg_throw, bool_t flg_monk
+	attack_t *ls,
+	bool_t flg_bash, bool_t flg_monk,
+	bool_t flg_throw, bool_t flg_spell
 )
 {
 	long	i;
@@ -464,10 +523,19 @@ attack_t	*get_attack_ave(
 
 		if( ls[i].kind == ATTACK_KIND_NULL )
 			break;
-		if( ls[i].flg_throw != flg_throw )
-			continue;
-		if( ls[i].flg_monk != flg_monk )
-			continue;
+		if( ls[i].kind == ATTACK_KIND_SPELL ){
+			if( !flg_spell )
+				continue;
+		} else if( ls[i].flg_monk ){
+			if( !flg_monk )
+				continue;
+		} else if( ls[i].flg_throw ){
+			if( !flg_throw )
+				continue;
+		} else {
+			if( !flg_bash )
+				continue;
+		}
 
 		n = ls[i].ratio;
 		sum += n;
@@ -488,7 +556,11 @@ attack_t	*get_attack_ave(
 
 /**/
 
-attack_t	*get_attack_randm( attack_t *ls )
+attack_t	*get_attack_randm(
+	attack_t *ls,
+	bool_t flg_bash, bool_t flg_monk,
+	bool_t flg_throw, bool_t flg_spell
+)
 {
 	long	i;
 	ratio_t	n, sum;
@@ -500,6 +572,20 @@ attack_t	*get_attack_randm( attack_t *ls )
 	for( i = 0; i < 1024; i++ ){
 		if( ls[i].kind == ATTACK_KIND_NULL )
 			break;
+		if( ls[i].kind == ATTACK_KIND_SPELL ){
+			if( !flg_spell )
+				continue;
+		} else if( ls[i].flg_monk ){
+			if( !flg_monk )
+				continue;
+		} else if( ls[i].flg_throw ){
+			if( !flg_throw )
+				continue;
+		} else {
+			if( !flg_bash )
+				continue;
+		}
+
 		sum += ls[i].ratio;
 	}
 
@@ -512,8 +598,22 @@ attack_t	*get_attack_randm( attack_t *ls )
 	for( i = 0; i < 1024; i++ ){
 		if( ls[i].kind == ATTACK_KIND_NULL )
 			break;
+		if( ls[i].kind == ATTACK_KIND_SPELL ){
+			if( !flg_spell )
+				continue;
+		} else if( ls[i].flg_monk ){
+			if( !flg_monk )
+				continue;
+		} else if( ls[i].flg_throw ){
+			if( !flg_throw )
+				continue;
+		} else {
+			if( !flg_bash )
+				continue;
+		}
+
 		sum += ls[i].ratio;
-		if( n < sum )
+		if( sum > n )
 			return( &(ls[i]) );
 	}
 
@@ -522,11 +622,50 @@ attack_t	*get_attack_randm( attack_t *ls )
 
 /**/
 
+ratio_t	calc_attack_sum(
+	attack_t *ls,
+	bool_t flg_bash, bool_t flg_monk,
+	bool_t flg_throw, bool_t flg_spell
+)
+{
+	ratio_t	sum;
+	long	i;
+
+	if( ls == NULL )
+		return 0;
+
+	sum = 0;
+	for( i = 0; i < 1024; i++ ){
+		if( ls[i].kind == ATTACK_KIND_NULL )
+			break;
+		if( ls[i].kind == ATTACK_KIND_SPELL ){
+			if( !flg_spell )
+				continue;
+		} else if( ls[i].flg_monk ){
+			if( !flg_monk )
+				continue;
+		} else if( ls[i].flg_throw ){
+			if( !flg_throw )
+				continue;
+		} else {
+			if( !flg_bash )
+				continue;
+		}
+
+		sum += ls[i].ratio;
+	}
+
+	return sum;
+}
+
+/**/
+
 bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 {
 	chr_kind_t	o_k, d_k;
 	long	o_hit, o_dam;
-	char	*o_name, *d_name;
+	static char	o_name[CHR_NAME_MAX_LEN + 1];
+	static char	d_name[CHR_NAME_MAX_LEN + 1];
 	long	d_def, d_ac;
 	rate_t	d_resi;
 	abl_val_t	*d_hp;
@@ -565,11 +704,6 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 		if( ((mbr_t *)o_p)->trgt.kind == TRGT_KIND_MNSTR_NULL )
 			flg_d_null = TRUE;
 
-	if( (o_p->kind != CHR_KIND_MBR) || (d_p->kind != CHR_KIND_MBR) )
-		flg_serious = TRUE;
-	else
-		flg_serious = FALSE;
-
 	if( d_k == CHR_KIND_MBR ){
 		attr_dam = CURS_ATTR_N_FX_MBR_MINUS;
 		attr_crtcl = CURS_ATTR_N_FX_MBR_CRTCL;
@@ -578,22 +712,34 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 		attr_crtcl = CURS_ATTR_N_FX_MNSTR_CRTCL;
 	}
 
+	flg_serious = TRUE;
+	if( d_p != NULL ){
+		if( d_p->attitude == ATTITUDE_MATE ){
+			if( o_p->attitude == ATTITUDE_MATE ){
+				/* ̣ɤʤø */
+				flg_serious = FALSE;
+			}
+		} else if( o_p->kind == CHR_KIND_MBR ){
+			/* ɸ¦̣ʳʤŨˤޤ魯 */
+			set_attitude_mnstr_group(
+					d_p->face.mjr, ATTITUDE_HOSTILE );
+		}
+	}
+
 	/* ¦̾μ */
 
-	o_name = o_p->name;
+	strncpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
 
 	/* ɸ¦̾ȥǡμ */
 
 	if( flg_d_null ){
-		d_name = MSG_NULL;
-
+		strncpy( d_name, MSG_NULL, CHR_NAME_MAX_LEN );
 		d_hp = NULL;
 		d_fx = NULL;
 		d_x = 0;
 		d_y = 0;
 	} else {
-		d_name = d_p->name;
-
+		strncpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
 		d_hp = &(d_p->abl.hp);
 		d_fx = &(d_p->fx);
 		d_x = d_p->x;
@@ -654,22 +800,15 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 	/* ꤬Ƥ뤫 */
 
 	if( !flg_d_null ){
-		pos_t	pos1, pos2;
-
-		if( o_k == CHR_KIND_MBR ){
-			pos1.x = o_p->x;
-			pos1.y = o_p->y;
-			pos2.x = d_p->x;
-			pos2.y = d_p->y;
-			if( !chk_find( &pos1, &pos2 ) ){
-				print_msg_n( attr_err, FLG_NULL,
+		if( !chk_find_chr( o_p, d_p ) ){
+			if( o_k == CHR_KIND_MBR ){
+				curs_attrset_n( attr_err );
+				print_msg( FLG_NULL,
 						MSG_ERR_NOT_FIND,
 						o_name, d_name );
-				return FALSE;
+				curs_attrset_dflt();
 			}
-		} else {
-			if( !chk_find_mnstr( d_p, o_p ) )
-				return FALSE;
+			return FALSE;
 		}
 	}
 
@@ -697,6 +836,7 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 	} else {
 		d_def = get_def( d_p );
 		d_def = roll_dice( d_def );
+		d_def += d_def * d_p->fx_data.bless;
 		d_ac = get_ac( d_p );
 		if( d_k == CHR_KIND_MBR ){
 			if( ((mbr_t *)d_p)->act.kind == ACT_KIND_NULL ){
@@ -707,7 +847,7 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 				d_ac /= _100_PERCENT;
 			}
 		}
-		d_resi = get_resi( d_p, attack->resi_kind );
+		d_resi = get_resi_def( d_p, attack->resi_kind );
 	}
 	if( flg_auto_hit )
 		d_def = 0;
@@ -716,6 +856,7 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 
 	o_hit = get_hit( o_p, attack );
 	o_hit = roll_dice( o_hit );
+	o_hit += o_hit * o_p->fx_data.bless;
 	o_dam = get_dam( o_p, attack );
 	flg_crtcl = rate_randm( get_crtcl( o_p, d_p, attack ) );
 
@@ -728,8 +869,11 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 		o_dam = 1;
 	if( flg_crtcl ){
 		o_dam *= 2;
-		print_msg_n( attr_crtcl, FLG_NULL,
-				MSG_FIGHT_CRTCL_STD, o_name );
+
+		curs_attrset_n( attr_crtcl );
+		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_STD, o_name );
+		curs_attrset_dflt();
+
 		vfx_crtcl( d_k, end.x, end.y );
 	}
 
@@ -770,6 +914,8 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 
 	/* ⤬ä */
 
+	fight_fx( o_p, d_p, attack );
+
 	/* ݡä */
 
 	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) ){
@@ -785,21 +931,20 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 		}
 	}
 
+	/* ø */
+
+	if( !flg_serious )
+		o_dam = 0;
+
+	if( !flg_crtcl )
+		if( chk_magic_protect( o_p, d_p, attack->flg_throw ) )
+			o_dam = 0;
+
 	/* ᡼ɽ */
 
-	if( o_dam != 0 ){
-		print_msg_n( attr_dam, FLG_NULL, MSG_FIGHT_HIT_STD,
-				o_name, d_name, o_dam );
-	}
-
-	/* ܤФ */
-
-	if( d_fx != NULL ){
-		fx_t	*fx;
-
-		fx = srch_fx( d_fx, FX_KIND_SLEEP );
-		clr_fx( fx );
-	}
+	curs_attrset_n( attr_dam );
+	print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, o_dam );
+	curs_attrset_dflt();
 
 	/*  */
 
@@ -809,8 +954,6 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 
 		if( flg_serious )
 			break;
-		if( o_dam <= 0 )
-			break;
 
 		if( attack->flg_throw )
 			o_abl = ABL_KIND_HUN;
@@ -818,29 +961,28 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 			o_abl = ABL_KIND_MON;
 		else
 			o_abl = ABL_KIND_FIG;
-		o_lev = ((mbr_t *)o_p)->abl.lev[o_abl].n;
+		o_lev = get_lev( o_p, o_abl );
 
 		d_abl = get_def_abl( d_p );
-		d_lev = ((mbr_t *)d_p)->abl.lev[d_abl].n;
+		d_lev = get_lev( d_p, d_abl );
 
 		if( o_lev >= d_lev )
 			break;
 
-		exp_chr( (mbr_t *)o_p, TRAINING_EXP, TRUE );
+		exp_chr( (mbr_t *)o_p, TRAINING_EXP, TRUE, TRUE );
 	} while( 0 );
 
 	/* HP򸺤餹 */
 
-	if( !flg_serious && (o_dam > d_p->abl.hp.n - 1) )
-			o_dam = d_p->abl.hp.n - 1;
-	add_hp( d_p, -o_dam );
-
-	if( (d_hp != NULL) && (d_hp->n <= 0) ){
+	added_fx( d_p, attack->resi_kind );
+	if( (d_hp != NULL) && (d_hp->n <= o_dam) ){
 		/*  */
-
-		print_msg_n( attr_crtcl, FLG_NULL, MSG_FIGHT_KILL_STD,
+		curs_attrset_n( attr_crtcl );
+		print_msg( FLG_NULL, MSG_FIGHT_KILL_STD,
 				o_name, d_name );
+		curs_attrset_dflt();
 	}
+	add_hp( d_p, -o_dam );
 
 	/* 񤹤 */
 
@@ -888,12 +1030,12 @@ bool_t	spell_attack(
 {
 	flg_stat_t	o_stat;
 	pos_t	o_pos, d_pos;
-	char	*o_name, *d_name;
+	static char	o_name[CHR_NAME_MAX_LEN + 1];
+	static char	d_name[CHR_NAME_MAX_LEN + 1];
 	long	dam;
 	long	ac;
 	bool_t	flg_serious;
 	curs_attr_n_t	attr_dam, attr_crtcl;
-	fx_t	*fx;
 
 	if( o_p == NULL )
 		return FALSE;
@@ -904,25 +1046,32 @@ bool_t	spell_attack(
 		return FALSE;
 	}
 
-	if( o_p->kind != CHR_KIND_MBR )
-		flg_serious = TRUE;
-	else if( d_p->kind != CHR_KIND_MBR )
-		flg_serious = TRUE;
-	else
-		flg_serious = FALSE;
+	flg_serious = TRUE;
+	if( d_p != NULL ){
+		if( d_p->attitude == ATTITUDE_MATE ){
+			if( o_p->attitude == ATTITUDE_MATE ){
+				/* ̣ɤʤø */
+				flg_serious = FALSE;
+			}
+		} else if( o_p->kind == CHR_KIND_MBR ){
+			/* ɸ¦̣ʳʤŨˤޤ魯 */
+			set_attitude_mnstr_group(
+					d_p->face.mjr, ATTITUDE_HOSTILE );
+		}
+	}
 
 	/* ¦ǡ */
 
 	o_stat = o_p->stat;
 	o_pos.x = o_p->x;
 	o_pos.y = o_p->y;
-	o_name = o_p->name;
+	strncpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
 
 	/* ɸ¦ǡ */
 
 	d_pos.x = d_p->x;
 	d_pos.y = d_p->y;
-	d_name = d_p->name;
+	strncpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
 
 	if( d_p->kind == CHR_KIND_MBR ){
 		attr_dam = CURS_ATTR_N_FX_MBR_MINUS;
@@ -975,41 +1124,95 @@ bool_t	spell_attack(
 		vfx_arw( o_p->kind, &o_pos, &d_pos, mjr, ANIM_ARW_LEN );
 	}
 
-	/* ܤФ */
+	/* ᡼η׻ */
 
-	fx = srch_fx( &(d_p->fx), FX_KIND_SLEEP );
-	clr_fx( fx );
+	dam = calc_resi( get_resi_def( d_p, resi ), dam );
+	dam -= ac;
+	if( dam < 1 )
+		dam = 1;
+	if( !flg_serious )
+		dam = 0;
+
+	/* ᡼ɽ */
+
+	curs_attrset_n( attr_dam );
+	print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
+	curs_attrset_dflt();
 
 	/* HP򸺤餹 */
 
-	dam = calc_resi( d_p->resi[resi].n, dam );
-	dam -= ac;
-	if( dam <= 0 )
-		dam = 1;
-
-	if( dam != 0 ){
-		/* ᡼ɽ */
-		print_msg_n( attr_dam, FLG_NULL, MSG_FIGHT_HIT_STD,
-				o_name, d_name, dam );
+	added_fx( d_p, resi );
+	if( d_p->abl.hp.n <= dam ){
+		/*  */
+		curs_attrset_n( attr_crtcl );
+		print_msg( FLG_NULL, MSG_FIGHT_KILL_STD, o_name, d_name );
+		curs_attrset_dflt();
 	}
-
-	if( !flg_serious && (dam > d_p->abl.hp.n - 1) )
-			dam = d_p->abl.hp.n - 1;
 	add_hp( d_p, -dam );
 
-	/*  */
-
-	if( d_p->abl.hp.n <= 0 ){
-		print_msg_n( attr_crtcl, FLG_NULL,
-				MSG_FIGHT_KILL_STD,
-				o_name, d_name );
-	}
-
 	return TRUE;
 }
 
 /**/
 
+void	added_fx( chr_t *chr, resi_kind_t resi )
+{
+	fx_t	*fx;
+
+	if( chr == NULL )
+		return;
+
+	/* ܤФ */
+
+	fx = srch_fx( &(chr->fx), FX_KIND_SLEEP );
+	clr_fx( fx );
+
+	/* ɲø */
+
+	switch( resi ){
+	case RESI_KIND_KNOC:
+	case RESI_KIND_SLAS:
+	case RESI_KIND_STIN:
+	case RESI_KIND_HEAT:
+	case RESI_KIND_COLD:
+		break;
+	case RESI_KIND_ACID:
+		fx_acid( chr );
+		break;
+	case RESI_KIND_MIND:
+	case RESI_KIND_ELEC:
+		break;
+	case RESI_KIND_POIS:
+		fx_poison( chr );
+		break;
+	case RESI_KIND_MAX_N:
+		break;
+	}
+}
+
+/**/
+
+void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
+{
+	long	o_lev;
+
+	if( o_p == NULL )
+		return;
+	if( d_p == NULL )
+		return;
+	if( attack == NULL )
+		return;
+	if( attack->fx_kind == FX_KIND_NULL )
+		return;
+
+	o_lev = get_specialist_lev( o_p );
+
+	if( !resi_roll( o_p, ABL_KIND_MAX_N, d_p, attack->resi_kind ) )
+		set_fx( d_p, attack->fx_kind, attack->fx_turn );
+}
+
+/**/
+
 bool_t	chr_break_door( chr_t *chr, long dr_n )
 {
 	long	hit;
@@ -1021,31 +1224,28 @@ bool_t	chr_break_door( chr_t *chr, long dr_n )
 	if( chr == NULL )
 		return FALSE;
 
-	if( chk_flg( dun->door[dr_n].flg, FLG_DOOR_SHOP ) ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
-		return TRUE;
-	}
-	if( chk_flg( dun->door[dr_n].flg, FLG_DOOR_BROKEN ) ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_BROKEN );
-		return TRUE;
-	}
+	clr_chr_trgt_act( chr, FALSE );
 
 	if( set_attack_chr_bash( &attack, chr, FALSE ) )
 		hit = get_hit( chr, &attack );
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit );
+	hit += hit * chr->fx_data.bless;
 
 	if( DOOR_DEF > hit ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_LEV );
+		if( chr->kind == CHR_KIND_MBR ){
+			print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_LEV,
+					chr->name );
+		}
 		return FALSE;
 	}
 
-	dun->door[dr_n].flg |= FLG_DOOR_BROKEN | FLG_DOOR_OPEN;
-	set_face_door( dr_n );
-	draw_door( dr_n );
+	if( !break_door( dr_n ) )
+		return FALSE;
 
-	print_msg( FLG_NULL, MSG_DOOR_BREAK, chr->name );
+	if( chr->kind == CHR_KIND_MBR )
+		print_msg( FLG_NULL, MSG_DOOR_BREAK, chr->name );
 
 	return TRUE;
 }
@@ -1065,6 +1265,7 @@ bool_t	chr_break_trap( chr_t *chr, trap_t *trap )
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit );
+	hit += hit * chr->fx_data.bless;
 
 	if( TRAP_DEF > hit ){
 		print_msg( FLG_NULL, MSG_ERR_TRAP_BREAK_LEV );
@@ -1101,6 +1302,7 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit );
+	hit += hit * chr->fx_data.bless;
 
 	if( ITEM_DEF > hit ){
 		print_msg( FLG_NULL, MSG_ERR_ITEM_BREAK_LEV, item->name );
@@ -1133,22 +1335,24 @@ bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 		return FALSE;
 
 	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
+	if( eq == NULL )
+		return FALSE;
 
 	if( flg_throw ){
 		if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_WPN )
 			return FALSE;
-		if( eq[EQUIP_KIND_ARW].dat.wpn.slayer == d_p->face_mjr )
+		if( eq[EQUIP_KIND_ARW].dat.wpn.slayer == d_p->face.mjr )
 			return TRUE;
 
 		if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_WPN )
 			return FALSE;
-		if( eq[EQUIP_KIND_BOW].dat.wpn.slayer == d_p->face_mjr )
+		if( eq[EQUIP_KIND_BOW].dat.wpn.slayer == d_p->face.mjr )
 			return TRUE;
 	} else {
 		if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
 			return FALSE;
 		if( eq[EQUIP_KIND_WIELDING].dat.wpn.slayer
-				== d_p->face_mjr )
+				== d_p->face.mjr )
 			return TRUE;
 	}
 
@@ -1157,6 +1361,49 @@ bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 
 /**/
 
+bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+
+	if( !chk_flg( d_p->flg_chr, FLG_CHR_MAGIC_PROTECT ) )
+		return FALSE;
+	if( o_p->kind != CHR_KIND_MBR )
+		return FALSE;
+
+	do {
+		item_t	*eq;
+
+		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
+		if( eq == NULL )
+			break;
+
+		if( flg_throw ){
+			if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_WPN )
+				break;
+			if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_WPN )
+				break;
+			if( eq[EQUIP_KIND_ARW].dat.wpn.add_hit <= 0 )
+				if( eq[EQUIP_KIND_BOW].dat.wpn.add_hit <= 0 )
+					break;
+		} else {
+			if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
+				break;
+			if( eq[EQUIP_KIND_WIELDING].dat.wpn.add_hit <= 0 )
+				break;
+		}
+
+		return FALSE;
+	} while( 0 );
+
+	print_msg( FLG_NULL, MSG_FIGHT_MAGIC_PROTECT, d_p->name );
+	return TRUE;
+}
+
+/**/
+
 long	get_hit( chr_t *p, const attack_t *attack )
 {
 	long	hit, wpn_hit;
@@ -1179,15 +1426,14 @@ long	get_hit( chr_t *p, const attack_t *attack )
 	else
 		abl = ABL_KIND_FIG;
 
-	hit += calc_lev_to_val( p->abl.lev[ABL_KIND_DEX].n,
-			ABL_KIND_DEX );
-	hit += calc_lev_to_val( p->abl.lev[abl].n, abl );
+	hit += calc_lev_to_val( get_lev( p, ABL_KIND_DEX ), ABL_KIND_DEX );
+	hit += calc_lev_to_val( get_lev( p, abl ), abl );
 
 	if( abl == ABL_KIND_MON ){
 		long	n;
 		rate_t	rate;
 
-		n = p->abl.lev[abl].n;
+		n = get_lev( p, abl );
 		wpn_hit += HIT_MON_MUL * n;
 		if( n > 0 )
 			wpn_hit += HIT_MON_ADD;
@@ -1198,15 +1444,15 @@ long	get_hit( chr_t *p, const attack_t *attack )
 		}
 	}
 
-#ifdef	D_ITEM_ADD_RATE
+#ifdef	FLG_ITEM_ADD_RATE
 
 	hit += HIT_FIT_AVE_N * wpn_hit / _100_PERCENT;
 
-#else	/* D_ITEM_ADD_RATE */
+#else	/* FLG_ITEM_ADD_RATE */
 
 	hit = hit * wpn_hit / _100_PERCENT;
 
-#endif	/* D_ITEM_ADD_RATE */
+#endif	/* FLG_ITEM_ADD_RATE */
 
 	if( hit < 1 )
 		hit = 1;
@@ -1238,15 +1484,14 @@ long	get_dam( chr_t *p, const attack_t *attack )
 	else
 		abl = ABL_KIND_FIG;
 
-	dam += calc_lev_to_val( p->abl.lev[ABL_KIND_STR].n,
-			ABL_KIND_STR );
-	dam += calc_lev_to_val( p->abl.lev[abl].n, abl );
+	dam += calc_lev_to_val( get_lev( p, ABL_KIND_STR ), ABL_KIND_STR );
+	dam += calc_lev_to_val( get_lev( p, abl ), abl );
 
 	if( abl == ABL_KIND_MON ){
 		long	n;
 		rate_t	rate;
 
-		n = p->abl.lev[abl].n;
+		n = get_lev( p, abl );
 		wpn_dam += DAM_MON_MUL * n;
 		if( n > 0 )
 			wpn_dam += DAM_MON_ADD;
@@ -1257,15 +1502,15 @@ long	get_dam( chr_t *p, const attack_t *attack )
 		}
 	}
 
-#ifdef	D_ITEM_ADD_RATE
+#ifdef	FLG_ITEM_ADD_RATE
 
 	dam += DAM_FIT_AVE_N * wpn_dam / _100_PERCENT;
 
-#else	/* D_ITEM_ADD_RATE */
+#else	/* FLG_ITEM_ADD_RATE */
 
 	dam = dam * wpn_dam / _100_PERCENT;
 
-#endif	/* D_ITEM_ADD_RATE */
+#endif	/* FLG_ITEM_ADD_RATE */
 
 	if( dam < 1 )
 		dam = 1;
@@ -1290,9 +1535,8 @@ long	get_def( chr_t *p )
 	def = 0;
 	abl = get_def_abl( p );
 
-	def += calc_lev_to_val( p->abl.lev[ABL_KIND_AGI].n,
-			ABL_KIND_AGI );
-	def += calc_lev_to_val( p->abl.lev[abl].n, abl );
+	def += calc_lev_to_val( get_lev( p, ABL_KIND_AGI ), ABL_KIND_AGI );
+	def += calc_lev_to_val( get_lev( p, abl ), abl );
 
 	if( p->kind == CHR_KIND_MBR ){
 		rate = calc_rate_abl_equip( p, abl );
@@ -1304,11 +1548,11 @@ long	get_def( chr_t *p )
 	if( armor_def < DEF_MIN_RATE )
 		armor_def = DEF_MIN_RATE;
 
-#ifdef	D_ITEM_ADD_RATE
+#ifdef	FLG_ITEM_ADD_RATE
 	def += DEF_AVE_N * armor_def / _100_PERCENT;
-#else	/* D_ITEM_ADD_RATE */
+#else	/* FLG_ITEM_ADD_RATE */
 	def = def * armor_def / _100_PERCENT;
-#endif	/* D_ITEM_ADD_RATE */
+#endif	/* FLG_ITEM_ADD_RATE */
 
 	if( def < 1 )
 		def = 1;
@@ -1352,21 +1596,19 @@ abl_kind_t	get_def_abl( chr_t *p )
 
 long	get_armor_def( chr_t *p, abl_kind_t abl )
 {
-	long	armor_def;
+	long	armor_def = 0;
 
 	if( abl == ABL_KIND_MON ){
 		long	n;
 
-		n = ((mbr_t*)p)->abl.lev[abl].n;
-		armor_def = DEF_MON_MUL * n;
+		n = get_lev( p, abl );
+		armor_def += DEF_MON_MUL * n;
 		if( n > 0 )
 			armor_def += DEF_MON_ADD;
 
 		return armor_def;
 	}
 
-	armor_def = 0;
-
 	if( p->kind == CHR_KIND_MBR ){
 		item_t	*eq;
 		equip_kind_t	n;
@@ -1387,8 +1629,12 @@ long	get_armor_def( chr_t *p, abl_kind_t abl )
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
 		armor_def += p->mnstr_tab->def;
+		armor_def += add_def( p->add_def );
 	}
 
+	/* FXͤä */
+	armor_def += p->fx_data.armor_def;
+
 	return armor_def;
 }
 
@@ -1425,8 +1671,12 @@ long	get_ac( chr_t *p )
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
 		armor_ac += p->mnstr_tab->ac;
+		armor_ac += add_ac( p->add_ac );
 	}
 
+	/* FXͤä */
+	armor_ac += p->fx_data.armor_ac;
+
 	ac = AC_AVE_N * armor_ac / _100_PERCENT;
 
 	if( ac < 1 )
@@ -1464,19 +1714,19 @@ rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack )
 
 	/* ǽ */
 
-	thf = calc_lev_to_val( p->abl.lev[ABL_KIND_THI].n, ABL_KIND_THI );
+	thf = calc_lev_to_val( get_lev( p, ABL_KIND_THI ), ABL_KIND_THI );
 	crtcl = thf / 2;
 
-#ifdef	D_ITEM_ADD_RATE
+#ifdef	FLG_ITEM_ADD_RATE
 
 	crtcl += WPN_CRTCL_FIT_AVE_N * attack->crtcl / _100_PERCENT;
 
-#else	/* D_ITEM_ADD_RATE */
+#else	/* FLG_ITEM_ADD_RATE */
 
 	crtcl += WPN_CRTCL_FIT_AVE_N;
 	crtcl = crtcl * attack->crtcl / _100_PERCENT;
 
-#endif	/* D_ITEM_ADD_RATE */
+#endif	/* FLG_ITEM_ADD_RATE */
 
 	if( crtcl < 1 )
 		crtcl = 1;
@@ -1518,8 +1768,12 @@ rate_t	get_armor_crtcl( chr_t *p )
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
 		armor_crtcl += p->mnstr_tab->armor_crtcl;
+		armor_crtcl += add_armor_crtcl( p->add_crtcl );
 	}
 
+	/* FXͤä */
+	armor_crtcl += p->fx_data.armor_crtcl;
+
 	crtcl = ARMOR_CRTCL_AVE_N * armor_crtcl / _100_PERCENT;
 
 	if( crtcl < 1 )
@@ -1588,8 +1842,8 @@ long	get_dam_spell( chr_t *p, abl_kind_t abl )
 		return 1;
 	}
 
-	dam = p->abl.lev[abl].n;
-	dam += p->abl.lev[sub_abl].n;
+	dam = get_lev( p, abl );
+	dam += get_lev( p, sub_abl );
 	dam *= DAM_SPELL_MUL;
 	dam += DAM_SPELL_ADD;
 
@@ -1601,14 +1855,14 @@ long	get_dam_spell( chr_t *p, abl_kind_t abl )
 
 /**/
 
-rate_t	get_resi( chr_t *p, resi_kind_t resi )
+rate_t	get_resi_def( chr_t *p, resi_kind_t resi )
 {
 	rate_t	n;
 
 	if( p == NULL )
 		return _100_PERCENT;
 
-	n = p->resi[resi].n;
+	n = get_resi( p, resi );
 	n = n * get_resi_armor( p, resi ) / _100_PERCENT;
 
 	if( n < 1)
@@ -1624,33 +1878,53 @@ char	*get_msg_attack( const attack_t *attack )
 	switch( attack->kind ){
 	case ATTACK_KIND_NULL:
 		break;
+	case ATTACK_KIND_SPELL:
+		break;
 	case ATTACK_KIND_PUNCH:
 		return MSG_ATTACK_PUNCH;
 	case ATTACK_KIND_KICK:
 		return MSG_ATTACK_KICK;
-	case ATTACK_KIND_BITE:
-		return MSG_ATTACK_BITE;
 	case ATTACK_KIND_KNOCK:
 		return MSG_ATTACK_KNOCK;
-	case ATTACK_KIND_STING:
-		return MSG_ATTACK_STING;
 	case ATTACK_KIND_SLASH:
 		return MSG_ATTACK_SLASH;
+	case ATTACK_KIND_STING:
+		return MSG_ATTACK_STING;
 	case ATTACK_KIND_MOW:
 		return MSG_ATTACK_MOW;
 	case ATTACK_KIND_SHOOT:
 		return MSG_ATTACK_SHOOT;
 	case ATTACK_KIND_THROW:
 		return MSG_ATTACK_THROW;
+	case ATTACK_KIND_BITE:
+		return MSG_ATTACK_BITE;
+	case ATTACK_KIND_CLAW:
+		return MSG_ATTACK_CLAW;
+	case ATTACK_KIND_NIP:
+		return MSG_ATTACK_NIP;
+	case ATTACK_KIND_STRANGLE:
+		return MSG_ATTACK_STRANGLE;
+	case ATTACK_KIND_TACKLE:
+		return MSG_ATTACK_TACKLE;
+	case ATTACK_KIND_TOUCH:
+		return MSG_ATTACK_TOUCH;
+	case ATTACK_KIND_INDICATE:
+		return MSG_ATTACK_INDICATE;
+	case ATTACK_KIND_KISS:
+		return MSG_ATTACK_KISS;
+	case ATTACK_KIND_SEDUCE:
+		return MSG_ATTACK_SEDUCE;
+	case ATTACK_KIND_CARESS_BUST:
+		return MSG_ATTACK_CARESS_BUST;
+	case ATTACK_KIND_CARESS_HIP:
+		return MSG_ATTACK_CARESS_HIP;
+	case ATTACK_KIND_CARESS_CROTCH:
+		return MSG_ATTACK_CARESS_CROTCH;
 	case ATTACK_KIND_MAX_N:
 		break;
 	}
 
-#ifdef	NDEBUG
-	return MSG_ATTACK_PUNCH;
-#else	/* NDEBUG */
-	return MSG_ATTACK_ERR;
-#endif	/* NDEBUG */
+	return MSG_NULL;
 }
 
 /**/
