@@ -1,5 +1,36 @@
-#ifndef	__FX_H__
-#define	__FX_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: fx.h,v 1.19 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	FX_H
+#define	FX_H
 
 #define	DOOR_DISARM_RATE_MUL_N	4
 #define	DOOR_DISARM_RATE_ADD_N	20
@@ -9,23 +40,34 @@
 #define	RESURRECTION_MIN_RATE	30
 #define	RESURRECTION_MAX_RATE	90
 
+#define	MAGIC_SHIELD_ADD_DEF_RATE	100
+#define	MAGIC_SHIELD_MAX_N	1
+#define	MAGE_ARMOR_ADD_AC_RATE	20
+#define	MAGE_ARMOR_MAX_N	4
+
+#define	FX_FACE_TRAP	'X'
+
 /* Turn begin */
 
 #define	FX_TURN_INFINITE_N	(-1)
 
-#define	FX_AVE_TURN_POISON_DEC	48
+#define	FX_AVE_TURN_POISON_DEC	20
 
 #define	FX_AVE_TURN_STONE	FX_TURN_INFINITE_N
 #define	FX_AVE_TURN_PARALYZE	16
-#define	FX_AVE_TURN_POISON	512
+#define	FX_AVE_TURN_POISON	1024
 #define	FX_AVE_TURN_CONFUSION	16
-#define	FX_AVE_TURN_BLIND	128
+#define	FX_AVE_TURN_BLIND	512
 #define	FX_AVE_TURN_SLEEP	32
 #define	FX_AVE_TURN_SILENCE	32
 #define	FX_AVE_TURN_FEAR	32
 #define	FX_AVE_TURN_HALLUCINATION	32
 #define	FX_AVE_TURN_CHARM	32
 #define	FX_AVE_TURN_FLY	128
+#define	FX_AVE_TURN_VANISH	128
+
+#define	FX_AVE_TURN_MAGIC_SHIELD	64
+#define	FX_AVE_TURN_MAGE_ARMOR	64
 
 #define	FX_AVE_TURN_POW_UP_HP	64
 #define	FX_AVE_TURN_POW_UP_ABL	64
@@ -35,8 +77,9 @@
 #define	FX_AVE_TURN_SPEED_DOWN	256
 
 #define	FX_AVE_TURN_DARKVISION	128
+#define	FX_AVE_TURN_RECALL	24
 
-#define	FX_AVE_TURN_RECALL	32
+#define	FX_AVE_TURN_BLESS	64
 
 #define	FX_AVE_TURN_FAINT	16
 #define	FX_TURN_DRUNK	1024
@@ -64,8 +107,8 @@ typedef enum {
 	FX_KIND_RESI_STIN,
 	FX_KIND_RESI_HEAT,
 	FX_KIND_RESI_COLD,
-	FX_KIND_RESI_WIND,
 	FX_KIND_RESI_ACID,
+	FX_KIND_RESI_MIND,
 	FX_KIND_RESI_ELEC,
 	FX_KIND_RESI_POIS,
 	FX_KIND_SHARPNESS,
@@ -82,20 +125,25 @@ typedef enum {
 	FX_KIND_UNATTRACTIVE,
 	FX_KIND_SENSE_INVISIBLE,
 	FX_KIND_POW_UP_HP,
-	FX_KIND_SPEED,
+	FX_KIND_MAGIC_SHIELD,
+	FX_KIND_MAGE_ARMOR,
+	FX_KIND_SPEED_UP,
+	FX_KIND_SPEED_DOWN,
+	FX_KIND_BLESS,
 	FX_KIND_MAX_N,
 } fx_kind_t;
 
-/* $B6uJ"EY(B */
+/* ʢ */
 
 typedef struct {
 	rate_t	rate;
 	rate_t	full_rate;
 	long	digest_p_day;
+	long	digest_n;
 	rate_t	hungry_rate, starvation_rate;
 } stomach_t;
 
-/* $B%K%3%A%s0MB8EY(B */
+/* ˥¸ */
 
 typedef struct {
 	rate_t	rate;
@@ -111,11 +159,13 @@ typedef struct fx {
 } fx_t;
 
 typedef struct fx_data {
+	rate_t	armor_def, armor_crtcl, armor_ac;
 	long	infra_vision;
 	stomach_t	stomach;
 	rate_t	drunk_rate;
 	nicotine_t	nicotine;
 	long	friend_turn;
+	rate_t	bless;
 } fx_data_t;
 
 typedef enum {
@@ -134,8 +184,8 @@ typedef enum {
 typedef struct {
 	long	xl, yl;
 	long	xr, yr;
-	char	ptn[BLAST_MAX_Y][BLAST_MAX_X];;
+	char	ptn[BLAST_MAX_Y][BLAST_MAX_X];
 } blast_t;
 
-#endif	/*__FX_H__*/
+#endif	/* FX_H */
 
