@@ -1,12 +1,44 @@
-#ifndef	__ITEM_H__
-#define	__ITEM_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: item.h,v 1.25 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	ITEM_H
+#define	ITEM_H
 
 #include	"spell.h"
+#include	"chr.h"
 #include	"mnstr.h"
 #include	"trap.h"
 
 #define	MBR_ITEM_MAX_N	16
-#define	DUN_ITEM_AVE_MAX_N	32
+#define	DUN_ITEM_AVE_N	12
 #define	ITEM_NAME_MAX_LEN	60
 #define	ITEM_ART_NAME_MAX_LEN	(ITEM_NAME_MAX_LEN + 16)
 
@@ -14,48 +46,62 @@
 #define	SPIKE_AVE_N	10
 
 #define	PUT_ITEM_R	MAP_MAX_X
+#define	BUNDLE_MAX_N	12
 
-#define	FLG_WPN_TAB_BOW	(1 << 0)
-#define	FLG_WPN_TAB_ARW	(1 << 1)
-#define	FLG_WPN_TAB_TWO_HANDED	(1 << 2)
-#define	FLG_WPN_TAB_RET	(1 << 4)
-#define	FLG_WPN_TAB_BUNDLE	(1 << 5)
-#define	FLG_WPN_TAB_NOT_SPEND	(1 << 6)
-#define	FLG_WPN_TAB_BOOMERANG	\
-		(FLG_WPN_TAB_ARW | FLG_WPN_TAB_RET | FLG_WPN_TAB_BUNDLE)
-#define	FLG_WPN_TAB_THROW	\
-		(FLG_WPN_TAB_ARW | FLG_WPN_TAB_NOT_SPEND)
+#define	CURSE_ITEM_RATE	((rate_t)30)
 
-#if	0
-#define	FLG_ITEM_ABL_FIG	(1 << 0)
-#define	FLG_ITEM_ABL_HUN	(1 << 2)
-#define	FLG_ITEM_ABL_NIN	(1 << 11)
-#endif
+/* Face begin */
 
-#define	FLG_ITEM_ABL_MON	(1 << 1)
-#define	FLG_ITEM_ABL_THI	(1 << 3)
-#define	FLG_ITEM_ABL_MAG	(1 << 4)
-#define	FLG_ITEM_ABL_SOR	(1 << 5)
-#define	FLG_ITEM_ABL_ENC	(1 << 6)
-#define	FLG_ITEM_ABL_SUM	(1 << 7)
-#define	FLG_ITEM_ABL_PRI	(1 << 8)
-#define	FLG_ITEM_ABL_SHA	(1 << 9)
-#define	FLG_ITEM_ABL_BAR	(1 << 10)
+#define	FACE_MJR_WEAPON	')'
+#define	FACE_MNR_SWORD	's'
+#define	FACE_MNR_BOW	'b'
+#define	FACE_MNR_ARW	'a'
+#define	FACE_MNR_STONE	','
+#define	FACE_MNR_DAGGER	'd'
 
-#define	FLG_ITEM_ABL_ALL_MAG	\
-		(FLG_ITEM_ABL_MAG | FLG_ITEM_ABL_SOR \
-		| FLG_ITEM_ABL_ENC | FLG_ITEM_ABL_SUM)
-#define	FLG_ITEM_ABL_MAG_SHA	\
-		(FLG_ITEM_ABL_ALL_MAG | FLG_ITEM_ABL_SHA)
+#define	FACE_MJR_ARMOR	']'
+#define	FACE_MNR_ARMOR_SHIELD	's'
+#define	FACE_MNR_ARMOR_HEAD	'h'
+#define	FACE_MNR_ARMOR_BODY	'b'
+#define	FACE_MNR_ARMOR_ARM	'a'
+#define	FACE_MNR_ARMOR_FEET	'f'
+#define	FACE_MNR_ARMOR_ABOUT_BODY	'm'
 
-#define	FLG_ITEM_DETECTED	(1 << 0)
-#define	FLG_ITEM_IDENTIFIED	(1 << 1)
-#define	FLG_ITEM_CURSE	(1 << 2)
+#define	FACE_MJR_POTION	'!'
+#define	FACE_MJR_SCROLL	'?'
+
+#define	FACE_MJR_STICK	'/'
+#define	FACE_MNR_WAND	'w'
+#define	FACE_MNR_ROD	'r'
+#define	FACE_MNR_STAFF	's'
+
+#define	FACE_MJR_ACCESSORY	'='
+#define	FACE_MNR_RING	'r'
+#define	FACE_MNR_AMULET	'a'
+#define	FACE_MNR_NECKLACE	'n'
+
+#define	FACE_MJR_FOOD	':'
+
+#define	FACE_MJR_CHEST	'&'
+
+#define	FACE_MJR_COIN	'$'
+
+#define	FACE_MJR_GEM	'*'
+
+#define	FACE_MJR_MISC	'\"'
+#define	FACE_MNR_LIGHT	'l'
+#define	FACE_MNR_SPIKE	's'
+#define	FACE_MNR_TOBACCO	't'
+#define	FACE_MNR_PIPE	'p'
+#define	FACE_MNR_DISPOSAL	'd'
+#define	FACE_MNR_JUNK	'"'
+
+/* Face end */
 
 #define	WPN_ATTACK_MAX_N	4
 
 /******************************************************************/
-/* $BNs5sBN(B */
+/*  */
 
 typedef enum {
 	CAN_USE_ITEM_YES,
@@ -77,9 +123,10 @@ typedef enum {
 	ITEM_KIND_CHEST,
 	ITEM_KIND_TOBACCO,
 	ITEM_KIND_PIPE,
+	ITEM_KIND_DISPOSAL,
 	ITEM_KIND_COIN,
 	ITEM_KIND_JUNK,
-	ITEM_KIND_MAX_N
+	ITEM_KIND_MAX_N,
 } item_kind_t;
 
 typedef enum {
@@ -192,7 +239,7 @@ typedef enum {
 	WPN_KIND_SHURIKEN,
 	WPN_KIND_BOOMERANG,
 
-	WPN_KIND_MAX_N
+	WPN_KIND_MAX_N,
 } wpn_kind_t;
 
 typedef enum {
@@ -202,7 +249,7 @@ typedef enum {
 	BOW_KIND_SLING,
 	BOW_KIND_BLOW_GUN,
 	BOW_KIND_DAGGER,
-	BOW_KIND_MAX_N
+	BOW_KIND_MAX_N,
 } bow_kind_t;
 
 typedef enum {
@@ -234,13 +281,14 @@ typedef enum {
 
 	ARMOR_KIND_LEATHER_BOOTS,
 	ARMOR_KIND_GREAVE,
+	ARMOR_KIND_SLOW_BOOTS,
 
 	ARMOR_KIND_BUCKLER_SHIELD,
 	ARMOR_KIND_ROUND_SHIELD,
 	ARMOR_KIND_KITE_SHIELD,
 	ARMOR_KIND_HEATER_SHIELD,
 
-	ARMOR_KIND_MAX_N
+	ARMOR_KIND_MAX_N,
 } armor_kind_t;
 
 typedef enum {
@@ -282,11 +330,11 @@ typedef enum {
 	POTION_KIND_FLY,
 	POTION_KIND_VANISH,
 	POTION_KIND_RESI_PHYS,
-	POTION_KIND_RESI_WIND,
 	POTION_KIND_RESI_HEAT,
 	POTION_KIND_RESI_COLD,
-	POTION_KIND_RESI_ELEC,
 	POTION_KIND_RESI_ACID,
+	POTION_KIND_RESI_MIND,
+	POTION_KIND_RESI_ELEC,
 	POTION_KIND_RESI_POIS,
 	POTION_KIND_SHARPNESS,
 	POTION_KIND_DULLNESS,
@@ -312,7 +360,7 @@ typedef enum {
 	POTION_KIND_CURE_POISON,
 	POTION_KIND_CURE_STATUS,
 	POTION_KIND_DETECT_MNSTR,
-	POTION_KIND_MAX_N
+	POTION_KIND_MAX_N,
 } potion_kind_t;
 
 typedef enum {
@@ -322,10 +370,15 @@ typedef enum {
 	SCROLL_KIND_DETECT_ITEM,
 	SCROLL_KIND_TELEPORT,
 	SCROLL_KIND_POW_UP_WPN_HIT,
+	SCROLL_KIND_POW_UP_WPN_CRTCL,
 	SCROLL_KIND_POW_UP_WPN_DAM,
+	SCROLL_KIND_POW_UP_ARMOR_DEF,
+	SCROLL_KIND_POW_UP_ARMOR_CRTCL,
+	SCROLL_KIND_POW_UP_ARMOR_AC,
+	SCROLL_KIND_PROTECT_ARMOR,
 	SCROLL_KIND_REMOVE_CURSE,
 	SCROLL_KIND_RECALL,
-	SCROLL_KIND_MAX_N
+	SCROLL_KIND_MAX_N,
 } scroll_kind_t;
 
 typedef enum {
@@ -341,7 +394,7 @@ typedef enum {
 	ACCE_KIND_RING,
 	ACCE_KIND_AMULET,
 	ACCE_KIND_NECKLACE,
-	ACCE_KIND_MAX_N
+	ACCE_KIND_MAX_N,
 } acce_kind_t;
 
 typedef enum {
@@ -349,24 +402,36 @@ typedef enum {
 	RING_KIND_SLOW_DIGESTION,
 	RING_KIND_TELEPORT_PARTY,
 	RING_KIND_TELEPORT,
-	RING_KIND_MAX_N
+	RING_KIND_SHARPNESS,
+	RING_KIND_DULLNESS,
+	RING_KIND_STRENGTH,
+	RING_KIND_WEAKNESS,
+	RING_KIND_QUICKNESS,
+	RING_KIND_SLOWNESS,
+	RING_KIND_WISE,
+	RING_KIND_FOOLISH,
+	RING_KIND_BRAINY,
+	RING_KIND_BRAINLESS,
+	RING_KIND_ATTRACTIVE,
+	RING_KIND_UNATTRACTIVE,
+	RING_KIND_MAX_N,
 } ring_kind_t;
 
 typedef enum {
 	AMULET_KIND_NULL,
 	AMULET_KIND_RESI_PHYS,
-	AMULET_KIND_RESI_WIND,
 	AMULET_KIND_RESI_HEAT,
 	AMULET_KIND_RESI_COLD,
-	AMULET_KIND_RESI_ELEC,
 	AMULET_KIND_RESI_ACID,
+	AMULET_KIND_RESI_MIND,
+	AMULET_KIND_RESI_ELEC,
 	AMULET_KIND_RESI_POIS,
-	AMULET_KIND_MAX_N
+	AMULET_KIND_MAX_N,
 } amulet_kind_t;
 
 typedef enum {
 	NECKLACE_KIND_NULL,
-	NECKLACE_KIND_MAX_N
+	NECKLACE_KIND_MAX_N,
 } necklace_kind_t;
 
 typedef enum {
@@ -374,12 +439,14 @@ typedef enum {
 	LIGHT_KIND_TORCH,
 	LIGHT_KIND_LANTERN,
 	LIGHT_KIND_LAMP,
-	LIGHT_KIND_MAX_N
+	LIGHT_KIND_MAX_N,
 } light_kind_t;
 
 typedef enum {
 	FOOD_KIND_NULL,
 	FOOD_KIND_PRESERVED,
+	FOOD_KIND_SAUSAGE,
+	FOOD_KIND_BACON,
 	FOOD_KIND_CHIPPED_BEEF,
 	FOOD_KIND_CORNED_BEEF,
 	FOOD_KIND_BREAD,
@@ -413,7 +480,7 @@ typedef enum {
 	FOOD_KIND_CRAN_BERRY,
 	FOOD_KIND_RASP_BERRY,
 	FOOD_KIND_STRAW_BERRY,
-	FOOD_KIND_MAX_N
+	FOOD_KIND_MAX_N,
 } food_kind_t;
 
 typedef unsigned long	flg_tobacco_t;
@@ -519,21 +586,77 @@ typedef enum {
 	COIN_KIND_GOLD,
 	COIN_KIND_SILVER,
 	COIN_KIND_COPPER,
-	COIN_KIND_MAX_N
+	COIN_KIND_MAX_N,
 } coin_kind_t;
 
 /******************************************************************/
-/* $B9=B$BN(B */
+/* ¤ */
 
-typedef struct {
+struct not_identified {
 	n_msg_t	name_n;
 	bool_t	flg_used;
-} color_tab_t, material_tab_t, ring_material_tab_t;
+};
+
+typedef struct not_identified	color_tab_t;
+typedef struct not_identified	material_tab_t;
+typedef struct not_identified	ring_material_tab_t;
+typedef struct not_identified	amulet_material_tab_t;
+typedef struct not_identified	necklace_material_tab_t;
 typedef n_msg_t	ttl_syllable_tab_t;
 
+/* flag weapon begin */
+
 typedef unsigned long	flg_wpn_tab_t;
+
+#define	FLG_WPN_TAB_BOW	(1 << 0)
+#define	FLG_WPN_TAB_ARW	(1 << 1)
+#define	FLG_WPN_TAB_TWO_HANDED	(1 << 2)
+#define	FLG_WPN_TAB_RET	(1 << 4)
+#define	FLG_WPN_TAB_BUNDLE	(1 << 5)
+#define	FLG_WPN_TAB_NOT_SPEND	(1 << 6)
+#define	FLG_WPN_TAB_BOOMERANG	\
+		(FLG_WPN_TAB_ARW | FLG_WPN_TAB_RET | FLG_WPN_TAB_BUNDLE)
+#define	FLG_WPN_TAB_THROW	\
+		(FLG_WPN_TAB_ARW | FLG_WPN_TAB_NOT_SPEND)
+
+/* flag weapon end */
+
+/* flag item ability begin */
+
 typedef unsigned long	flg_item_abl;
 
+#define	FLG_ITEM_ABL_FIG	(1 << 0)
+#define	FLG_ITEM_ABL_MON	(1 << 1)
+#define	FLG_ITEM_ABL_HUN	(1 << 2)
+#define	FLG_ITEM_ABL_THI	(1 << 3)
+#define	FLG_ITEM_ABL_MAG	(1 << 4)
+#define	FLG_ITEM_ABL_SOR	(1 << 5)
+#define	FLG_ITEM_ABL_ENC	(1 << 6)
+#define	FLG_ITEM_ABL_SUM	(1 << 7)
+#define	FLG_ITEM_ABL_PRI	(1 << 8)
+#define	FLG_ITEM_ABL_SHA	(1 << 9)
+#define	FLG_ITEM_ABL_BAR	(1 << 10)
+#define	FLG_ITEM_ABL_NIN	(1 << 11)
+
+#define	FLG_ITEM_ABL_ALL_MAG	\
+		(FLG_ITEM_ABL_MAG | FLG_ITEM_ABL_SOR \
+		| FLG_ITEM_ABL_ENC | FLG_ITEM_ABL_SUM)
+#define	FLG_ITEM_ABL_MAG_SHA	\
+		(FLG_ITEM_ABL_ALL_MAG | FLG_ITEM_ABL_SHA)
+
+/* flag item ability end */
+
+/* flag item begin */
+
+typedef unsigned long	flg_item_t;
+
+#define	FLG_ITEM_DETECTED	(1 << 0)
+#define	FLG_ITEM_IDENTIFIED	(1 << 1)
+#define	FLG_ITEM_PROTECTED	(1 << 2)
+#define	FLG_ITEM_CURSED	(1 << 3)
+
+/* flag item end */
+
 typedef struct {
 	wpn_kind_t	kind;
 	long	add_hit;
@@ -601,12 +724,16 @@ typedef struct {
 	long	consume_turn;
 } pipe_t;
 
+typedef struct {
+	long	n, max_n;
+} disposal_t;
+
 typedef struct {
 	coin_kind_t	kind;
 } coin_t;
 
 /******************************************************************/
-/* $B%F!<%V%k(B */
+/* ơ֥ */
 
 typedef struct {
 	char	*name;
@@ -633,12 +760,12 @@ typedef struct {
 	char	mnr;
 	equip_kind_t	equip_kind;
 	rate_t	up_resi[RESI_KIND_MAX_N];
-	rate_t	def;
-	rate_t	crtcl;
-	rate_t	ac;
+	rate_t	def, crtcl, ac;
 	long	min_lev, max_lev, sgn_lev;
 	rate_t	rate;
 	flg_item_abl	flg_abl;
+	rate_t	rate_curse;
+	modifier_t	modifier;
 } armor_tab_t;
 
 typedef struct {
@@ -691,6 +818,7 @@ typedef struct {
 	n_msg_t	material_n;
 	bool_t	flg_identified;
 	rate_t	rate_curse;
+	modifier_t	modifier;
 } acce_tab_t;
 
 typedef struct {
@@ -722,7 +850,7 @@ typedef struct {
 	rate_t	rate;
 	long	ave_n;
 	long	turn;
-	long	price;
+	gold_t	price;
 	flg_tobacco_t	flg;
 } tobacco_tab_t;
 
@@ -734,7 +862,7 @@ typedef struct {
 	long	ave_n;
 	long	consume_turn;
 	tobacco_kind_t	tobacco_kind;
-	long	price;
+	gold_t	price;
 	flg_pipe_t	flg;
 } pipe_tab_t;
 
@@ -778,10 +906,8 @@ typedef struct {
 	coin_kind_t	coin;
 } item_kind_dat_t;
 
-typedef unsigned long	flg_item_t;
-
 /******************************************************************/
-/* $B%"%$%F%`(B */
+/* ƥ */
 
 typedef struct item_t {
 	struct item_t	*next, *prev;
@@ -793,6 +919,7 @@ typedef struct item_t {
 	long	x, y;
 	long	n, stock;
 	flg_item_t	flg;
+	modifier_t	modifier;
 	union {
 		wpn_tab_t	*wpn;
 		armor_tab_t	*armor;
@@ -818,9 +945,10 @@ typedef struct item_t {
 		chest_t	chest;
 		tobacco_t	tobacco;
 		pipe_t	pipe;
+		disposal_t	disposal;
 		coin_t	coin;
 	} dat;
 } item_t;
 
-#endif	/* __ITEM_H__ */
+#endif	/* ITEM_H */
 
