@@ -1,5 +1,36 @@
-#ifndef	__MENU_H__
-#define	__MENU_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: menu.h,v 1.9 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	MENU_H
+#define	MENU_H
 
 #include	"msg.h"
 #include	"party.h"
@@ -34,8 +65,6 @@
 #define	CASE_CRSR_DOWN_RIGHT	\
 		'3': case 'n'
 
-#define	CASE_REDRAW	0x019a
-
 #define	MENU_MAX_LEN	(SCREEN_WIDTH - 4)
 #define	MENU_MAX_N_PER_PAGE	20
 #define	MENU_MAX_PAGE	32
@@ -118,4 +147,4 @@ typedef enum {
 	MBR_DATA_EDIT_KIND_MAX_N,
 } mbr_data_edit_kind_t;
 
-#endif	/* __MENU_H__ */
+#endif	/* MENU_H */
