@@ -1,5 +1,36 @@
-#ifndef	__MENU_TAB_H__
-#define	__MENU_TAB_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: menu_tab.h,v 1.17 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	MENU_TAB_H
+#define	MENU_TAB_H
 
 #if	0
 	"<Title>"
@@ -7,9 +38,9 @@
 	"<CheckItem>"
 	"<RadioItem>"
 	"<OpenWinItem>"
-	"<Separator>"	/* <RadioItem>$B$N6h@Z$j(B */
-	"<PageSeparator>"	/* $B%a%K%e!<$,J#?t%Z!<%8M-$k;~$N6h@Z$j(B */
-	"<Branch>"	/* $B%5%V%a%K%e!<(B */
+	"<Separator>"	/* <RadioItem>ζڤ */
+	"<PageSeparator>"	/* ˥塼ʣڡͭζڤ */
+	"<Branch>"	/* ֥˥塼 */
 #endif
 
 #if	0
@@ -334,7 +365,7 @@ menu_t	ls_menu_main[] = {
 		"/Move",
 		"<Item>",
 		'V',
-		"/ v",
+		"+ v",
 		N_MSG_MENU_MOVE, "",
 		cb_menu_move, NULL,
 		FLG_NULL,
@@ -449,16 +480,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Sleep",
-		"<Item>",
-		'Z',
+		"/Misc/Gold",
+		"<Branch>",
+		'G',
 		"",
-		N_MSG_MENU_SLEEP, "",
-		cb_menu_sleep, NULL,
+		N_MSG_MENU_GOLD, "",
+		cb_menu_gold, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Collect gold",
+		"/Misc/Gold/Collect",
 		"<Item>",
 		'C',
 		"",
@@ -467,7 +498,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Divide gold",
+		"/Misc/Gold/Divide",
 		"<Item>",
 		'D',
 		"",
@@ -475,6 +506,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_divide_gold, NULL,
 		FLG_NULL,
 	},
+	{
+		"/Misc/Formation",
+		"<Branch>",
+		'F',
+		"",
+		N_MSG_MENU_FORMATION, "",
+		cb_menu_formation, NULL,
+		FLG_NULL,
+	},
 	{
 		"/Misc/Cursor",
 		"<Branch>",
@@ -485,12 +525,21 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Message list",
+		"/Misc/list Message",
 		"<OpenWinItem>",
 		'M',
 		"g",
-		N_MSG_MENU_MSG, "",
-		cb_menu_msg, NULL,
+		N_MSG_MENU_LS_MSG, "",
+		cb_menu_ls_msg, NULL,
+		FLG_NULL,
+	},
+	{
+		"/Misc/list Monster",
+		"<Item>",
+		'L',
+		"",
+		N_MSG_MENU_LS_MNSTR, "",
+		cb_menu_ls_mnstr, NULL,
 		FLG_NULL,
 	},
 	{
@@ -515,7 +564,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/Misc/Config",
 		"<Branch>",
-		'G',
+		'C',
 		"",
 		N_MSG_MENU_CNF, "",
 		cb_menu_cnf, NULL,
@@ -559,15 +608,15 @@ menu_t	ls_menu_main[] = {
 	},
 	{
 		"/Misc/Config/Scroll",
-		"<Separator>",
-		'\0',
+		"<Branch>",
+		'S',
 		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
+		N_MSG_MENU_SCROLL_MODE, "",
+		cb_menu_scroll_init, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Scroll page",
+		"/Misc/Config/Scroll/Page",
 		"<RadioItem>",
 		'P',
 		"",
@@ -576,7 +625,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Scroll smooth",
+		"/Misc/Config/Scroll/Smooth",
 		"<RadioItem>",
 		'S',
 		"",
@@ -585,23 +634,14 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Scroll center",
+		"/Misc/Config/Scroll/Center",
 		"<RadioItem>",
-		'M',
+		'C',
 		"",
 		N_MSG_MENU_SCROLL_CENTER, "",
 		cb_menu_scroll_center, NULL,
 		FLG_NULL,
 	},
-	{
-		"/Misc/Config/Scroll",
-		"<Separator>",
-		'\0',
-		"",
-		N_MSG_NULL, "",
-		NULL, NULL,
-		FLG_NULL,
-	},
 	{
 		"/Misc/Config/Multi Message",
 		"<CheckItem>",
@@ -615,7 +655,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/Misc/Config/VFX",
 		"<Branch>",
-		'V',
+		'X',
 		"",
 		N_MSG_MENU_VFX, "",
 		cb_menu_vfx, NULL,
@@ -714,14 +754,24 @@ menu_t	ls_menu_main[] = {
 	},
 	{
 		"/Misc/Config/Cursor pattern",
-		"<OpenWinItem>",
-		'U',
+		"<Branch>",
+		'V',
 		"",
 		N_MSG_MENU_CRSR_PTN, "",
 		cb_menu_crsr_ptn, NULL,
 		FLG_NULL,
 	},
+	{
+		"/Misc/Config/Macro",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_MACRO, "",
+		cb_menu_macro, NULL,
+		FLG_NULL,
+	},
 /* config end */
+#ifdef	DEBUG
 	{
 		"/Misc/Wizard",
 		"<Branch>",
@@ -741,7 +791,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Wizard/On light",
+		"/Misc/Wizard/On Light",
 		"<Item>",
 		'L',
 		"",
@@ -750,7 +800,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Wizard/Off light",
+		"/Misc/Wizard/Off Light",
 		"<Item>",
 		'D',
 		"",
@@ -758,6 +808,16 @@ menu_t	ls_menu_main[] = {
 		cb_menu_wizard_off_light, NULL,
 		FLG_NULL,
 	},
+	{
+		"/Misc/Wizard/Level Up",
+		"<Item>",
+		'V',
+		"",
+		N_MSG_MENU_WIZARD_LEV_UP, "",
+		cb_menu_wizard_lev_up, NULL,
+		FLG_NULL,
+	},
+#endif	/* DEBUG */
 	{
 		"/Misc/About",
 		"<OpenWinItem>",
@@ -861,15 +921,6 @@ menu_t	ls_menu_sel_obj[] = {
 		cb_menu_sel_obj, (void *)TRGT_KIND_POS,
 		FLG_NULL,
 	},
-	{
-		"/Sel Obj/Clear",
-		"<Item>",
-		'C',
-		"",
-		N_MSG_MENU_SEL_OBJ_CLEAR, "",
-		cb_menu_sel_obj, (void *)TRGT_KIND_NULL,
-		FLG_NULL,
-	},
 	{
 		"/Sel Obj/Auto",
 		"<Branch>",
@@ -879,6 +930,15 @@ menu_t	ls_menu_sel_obj[] = {
 		cb_menu_sel_obj_auto, (void *)TRGT_KIND_AUTO,
 		FLG_NULL,
 	},
+	{
+		"/Sel Obj/Clear",
+		"<Item>",
+		'C',
+		"",
+		N_MSG_MENU_SEL_OBJ_CLEAR, "",
+		cb_menu_sel_obj, (void *)TRGT_KIND_NULL,
+		FLG_NULL,
+	},
 	{
 		"",
 		"",
@@ -1279,6 +1339,15 @@ menu_t	ls_menu_item_self[] = {
 		cb_menu_item_smoke, (void *)ACT_KIND_EQUIP,
 		FLG_NULL,
 	},
+	{
+		"/Self/Dispose",
+		"<Item>",
+		'P',
+		"",
+		N_MSG_MENU_ITEM_DISPOSE, "",
+		cb_menu_item_use, (void *)ACT_KIND_TOBACCO_DISPOSE,
+		FLG_NULL,
+	},
 	{
 		"/Self/Fill Lamp",
 		"<Item>",
@@ -1485,6 +1554,7 @@ menu_t	ls_menu_equip_wear_sel[MBR_ITEM_MAX_N * 2];
 menu_t	ls_menu_identify_item[MBR_ITEM_MAX_N * 2];
 menu_t	ls_menu_resurrection[MBR_ITEM_MAX_N * 2];
 menu_t	ls_menu_srch[1 + 4 + MBR_MAX_N + 1];
+menu_t	ls_menu_formation[1 + 1 + MBR_MAX_N + 1];
 
 menu_t	ls_menu_move_crsr[] = {
 	{
@@ -1989,4 +2059,7 @@ menu_t	ls_menu_color_sel[] = {
 	},
 };
 
-#endif	/* __MENU_TAB_H__ */
+menu_t	ls_menu_crsr_ptn[1 + 1 + CRSR_PTN_MAX_N + 1];
+menu_t	ls_menu_macro[1 + 1 + (4 * FUNC_KEY_MAX_N) + 1];
+
+#endif	/* MENU_TAB_H */
