@@ -1,3 +1,34 @@
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: msg_eng.h,v 1.98 2003/11/23 05:13:28 bowkenken Exp $
+*****************************************************************/
+
 #include	"ver.h"
 
 #define	STR_SQUARE	"Home Circle"
@@ -93,6 +124,11 @@
 	{ N_MSG_OUT_MAP_FILE_ASK_OK,
 		"Do you want out put?" },
 
+	{ N_MSG_MEASURE_CLK_TCK,
+		"ե졼ࡦ졼Ȥ¬Ǥ" },
+	{ N_MSG_MEASURE_CLK_TCK_FINISH,
+		"(%ld - %ld) / %ld == %ld" },
+
 	{ N_MSG_MAIN_RACE_HUMAN,
 		"Human" },
 	{ N_MSG_MAIN_RACE_HALF_ELF,
@@ -174,6 +210,8 @@
 		"Sleep" },
 	{ N_MSG_STAT_SILENCE,
 		"Silence" },
+	{ N_MSG_STAT_CAUGHT,
+		"Caught" },
 	{ N_MSG_STAT_FEAR,
 		"Fear" },
 	{ N_MSG_STAT_HALLUCINATION,
@@ -240,18 +278,22 @@
 		"Hunter" },
 	{ N_MSG_CLASS_THIEF,
 		"Thief" },
+	{ N_MSG_CLASS_WIZARD,
+		"Wizard" },
+	{ N_MSG_CLASS_SUMMONER,
+		"Summoner" },
 	{ N_MSG_CLASS_PRIEST,
 		"Priest" },
 	{ N_MSG_CLASS_SHAMAN,
 		"Shaman" },
 	{ N_MSG_CLASS_BARD,
 		"Bard" },
-	{ N_MSG_CLASS_WIZARD,
-		"Wizard" },
-	{ N_MSG_CLASS_SUMMONER,
-		"Summoner" },
+	{ N_MSG_CLASS_NINJA,
+		"Ninja" },
 	{ N_MSG_CLASS_BISHOP,
 		"Bishop" },
+	{ N_MSG_ERR_CLASS_NOT_100_PERCENT,
+		"%s ǽͤιפ 100%% Ǥޤ" },
 
 	{ N_MSG_MBR_DIE,
 		"*** %s was dead ***" },
@@ -261,7 +303,9 @@
 	{ N_MSG_EXP_MBR,
 		"%s gets %ld EXP" },
 	{ N_MSG_LEV_UP,
-		"*** %s was level up %s to %ld ***" },
+		"*** %s was level UP %s to %ld ***" },
+	{ N_MSG_LEV_DOWN,
+		"*** %s was level DOWN %s to %ld ***" },
 
 	{ N_MSG_STAT_DUN_LEV_TTL_FLOOR,
 		"Floor : " },
@@ -281,7 +325,9 @@
 	{ N_MSG_NAME_ARMOR,
 		"Armor" },
 	{ N_MSG_NAME_MAGIC,
-		"Magic" },
+		"Magic guild" },
+	{ N_MSG_NAME_ALCHEMY,
+		"Alchemy" },
 	{ N_MSG_NAME_GROCERY,
 		"Grocery" },
 	{ N_MSG_NAME_RESTAURANT,
@@ -290,6 +336,23 @@
 		"Tearoom" },
 	{ N_MSG_NAME_TOBACCO,
 		"Tobacco" },
+	{ N_MSG_NAME_PET_SHOP,
+		"Pet shop" },
+
+	{ N_MSG_DAY_OF_WEEK_ELEC,
+		"Light" },
+	{ N_MSG_DAY_OF_WEEK_PHYS,
+		"Moon" },
+	{ N_MSG_DAY_OF_WEEK_HEAT,
+		"Fire" },
+	{ N_MSG_DAY_OF_WEEK_COLD,
+		"Water" },
+	{ N_MSG_DAY_OF_WEEK_ACID,
+		"Earth" },
+	{ N_MSG_DAY_OF_WEEK_MIND,
+		"Air" },
+	{ N_MSG_DAY_OF_WEEK_POIS,
+		"Dark" },
 
 	{ N_MSG_AUTO_RELOAD,
 		"%s done auto reload %s" },
@@ -298,30 +361,52 @@
 		"%s punched %s" },
 	{ N_MSG_ATTACK_KICK,
 		"%s kicked %s" },
-	{ N_MSG_ATTACK_BITE,
-		"%s bited %s" },
 	{ N_MSG_ATTACK_KNOCK,
 		"%s knocked %s" },
-	{ N_MSG_ATTACK_STING,
-		"%s stinged %s" },
 	{ N_MSG_ATTACK_SLASH,
 		"%s slashed %s" },
+	{ N_MSG_ATTACK_STING,
+		"%s stinged %s" },
 	{ N_MSG_ATTACK_MOW,
 		"%s mowed %s" },
 	{ N_MSG_ATTACK_SHOOT,
 		"%s shooted %s" },
 	{ N_MSG_ATTACK_THROW,
 		"%s throwed %s" },
-	{ N_MSG_ATTACK_ERR,
-		"Error of attack message" },
+	{ N_MSG_ATTACK_BITE,
+		"%s bited %s" },
+	{ N_MSG_ATTACK_CLAW,
+		"%s clawed %s" },
+	{ N_MSG_ATTACK_NIP,
+		"%s nipped %s" },
+	{ N_MSG_ATTACK_STRANGLE,
+		"%s strangled %s" },
+	{ N_MSG_ATTACK_TACKLE,
+		"%s tackled %s" },
+	{ N_MSG_ATTACK_TOUCH,
+		"%s touched %s" },
+	{ N_MSG_ATTACK_INDICATE,
+		"%s indicated %s" },
+	{ N_MSG_ATTACK_KISS,
+		"%s kissed %s" },
+	{ N_MSG_ATTACK_SEDUCE,
+		"%s seduced %s" },
+	{ N_MSG_ATTACK_CARESS_BUST,
+		"%s caressed bust of %s" },
+	{ N_MSG_ATTACK_CARESS_HIP,
+		"%s caressed hip of %s" },
+	{ N_MSG_ATTACK_CARESS_CROTCH,
+		"%s caressed crotch of %s" },
 	{ N_MSG_FIGHT_CRTCL_STD,
 		"%s is Critical Hit" },
 	{ N_MSG_FIGHT_HIT_STD,
-		"%s hitted %s to %d" },
+		"Hitted %s to %d" },
 	{ N_MSG_FIGHT_MISS_STD,
 		"%s missed %s" },
 	{ N_MSG_FIGHT_KILL_STD,
 		"++XX %s killed %s XX++" },
+	{ N_MSG_FIGHT_MAGIC_PROTECT,
+		"This weapon don't effect to %s" },
 
 	{ N_MSG_SPELL,
 		"%s casted spell of %s" },
@@ -391,6 +476,8 @@
 		"Eat food" },
 	{ N_MSG_ACT_TOBACCO_SMOKE,
 		"Smoke Tobacco" },
+	{ N_MSG_ACT_TOBACCO_DISPOSE,
+		"Dispose" },
 	{ N_MSG_ACT_EQUIP,
 		"Equip" },
 	{ N_MSG_ACT_TAKE_OFF,
@@ -728,6 +815,8 @@
 		"Leather Boots" },
 	{ N_MSG_ARMOR_GREAVE,
 		"Greave" },
+	{ N_MSG_ARMOR_SLOW_BOOTS,
+		"Leather Boots" },
 
 	{ N_MSG_ARMOR_BUCKLER_SHIELD,
 		"Buckler Shield" },
@@ -832,10 +921,10 @@
 		"Potion of Resi Heat" },
 	{ N_MSG_POTION_RESI_COLD,
 		"Potion of Resi Cold" },
-	{ N_MSG_POTION_RESI_WIND,
-		"Potion of Resi Wind" },
 	{ N_MSG_POTION_RESI_ACID,
 		"Potion of Resi Acid" },
+	{ N_MSG_POTION_RESI_MIND,
+		"Potion of Resi Mind" },
 	{ N_MSG_POTION_RESI_ELEC,
 		"Potion of Resi Elec" },
 	{ N_MSG_POTION_RESI_POIS,
@@ -1022,8 +1111,18 @@
 		"Scroll of Teleport" },
 	{ N_MSG_SCROLL_POW_UP_WPN_HIT,
 		"Scroll of Power Up Weapon HIT" },
+	{ N_MSG_SCROLL_POW_UP_WPN_CRTCL,
+		"Scroll of Power Up Weapon CRTCL" },
 	{ N_MSG_SCROLL_POW_UP_WPN_DAM,
 		"Scroll of Power Up Weapon DAM" },
+	{ N_MSG_SCROLL_POW_UP_ARMOR_DEF,
+		"Scroll of Power Up Armor DEF" },
+	{ N_MSG_SCROLL_POW_UP_ARMOR_CRTCL,
+		"Scroll of Power Up Armor CRTCL" },
+	{ N_MSG_SCROLL_POW_UP_ARMOR_AC,
+		"Scroll of Power Up Armor AC" },
+	{ N_MSG_SCROLL_PROTECT_ARMOR,
+		"Scroll of Protect Armor" },
 	{ N_MSG_SCROLL_REMOVE_CURSE,
 		"Scroll of Remove Curse" },
 	{ N_MSG_SCROLL_RECALL,
@@ -1201,21 +1300,47 @@
 		"Ring of Teleport Party" },
 	{ N_MSG_RING_TELEPORT,
 		"Ring of Teleport" },
+	{ N_MSG_RING_SHARPNESS,
+		"Ring of Sharpness" },
+	{ N_MSG_RING_DULLNESS,
+		"Ring of Dullness" },
+	{ N_MSG_RING_STRENGTH,
+		"Ring of Strength" },
+	{ N_MSG_RING_WEAKNESS,
+		"Ring of Weakness" },
+	{ N_MSG_RING_QUICKNESS,
+		"Ring of Quickness" },
+	{ N_MSG_RING_SLOWNESS,
+		"Ring of Slowness" },
+	{ N_MSG_RING_WISE,
+		"Ring of Wise" },
+	{ N_MSG_RING_FOOLISH,
+		"Ring of Foolish" },
+	{ N_MSG_RING_BRAINY,
+		"Ring of Brainy" },
+	{ N_MSG_RING_BRAINLESS,
+		"Ring of Brainless" },
+	{ N_MSG_RING_ATTRACTIVE,
+		"Ring of Attractive" },
+	{ N_MSG_RING_UNATTRACTIVE,
+		"Ring of Unattractive" },
 	{ N_MSG_AMULET_RESI_PHYS,
 		"Amulet of Resist PHYS" },
 	{ N_MSG_AMULET_RESI_HEAT,
 		"Amulet of Resist HEAT" },
 	{ N_MSG_AMULET_RESI_COLD,
 		"Amulet of Resist COLD" },
-	{ N_MSG_AMULET_RESI_WIND,
-		"Amulet of Resist WIND" },
 	{ N_MSG_AMULET_RESI_ACID,
 		"Amulet of Resist ACID" },
+	{ N_MSG_AMULET_RESI_MIND,
+		"Amulet of Resist MIND" },
 	{ N_MSG_AMULET_RESI_ELEC,
 		"Amulet of Resist ELEC" },
 	{ N_MSG_AMULET_RESI_POIS,
 		"Amulet of Resist POIS" },
 
+#if	0
+@@@
 	{ N_MSG_RING_MATERIAL_ALUMINUM,
 		"Aluminum" },
 	{ N_MSG_RING_MATERIAL_BONE,
@@ -1258,115 +1383,120 @@
 		"Zinc" },
 	{ N_MSG_RING_MATERIAL_ZIRCONIUM,
 		"Zirconium" },
-
-#if	0
-@@@
-	{ N_MSG_RING_GEM_AMBER,
-		"Amber" },
-	{ N_MSG_RING_GEM_AGATE,
-		"Agate" },
-	{ N_MSG_RING_GEM_ALEXANDRITE,
-		"Alexandrite" },
-	{ N_MSG_RING_GEM_AMETHYST,
-		"Amethyst" },
-	{ N_MSG_RING_GEM_ANTLERITE,
-		"Antlerite" },
-	{ N_MSG_RING_GEM_AQUAMARINE,
-		"Aquamarine" },
-	{ N_MSG_RING_GEM_ARGENTITE,
-		"Argentite" },
-	{ N_MSG_RING_GEM_AZURITE,
-		"Azurite" },
-	{ N_MSG_RING_GEM_BERYL,
-		"Beryl" },
-	{ N_MSG_RING_GEM_BLOODSTONE,
-		"Bloodstone" },
-	{ N_MSG_RING_GEM_CALCITE,
-		"Calcite" },
-	{ N_MSG_RING_GEM_CARNELIAN,
-		"Carnelian" },
-	{ N_MSG_RING_GEM_CORAL,
-		"Coral" },
-	{ N_MSG_RING_GEM_CORUNDUM,
-		"Corundum" },
-	{ N_MSG_RING_GEM_CRYOLITE,
-		"Cryolite" },
-	{ N_MSG_RING_GEM_DIAMOND,
-		"Diamond" },
-	{ N_MSG_RING_GEM_DIORITE,
-		"Diorite" },
-	{ N_MSG_RING_GEM_EMERALD,
-		"Emerald" },
-	{ N_MSG_RING_GEM_FLINT,
-		"Flint" },
-	{ N_MSG_RING_GEM_FLUORITE,
-		"Fluorite" },
-	{ N_MSG_RING_GEM_GABBRO,
-		"Gabbro" },
-	{ N_MSG_RING_GEM_GARNET,
-		"Garnet" },
-	{ N_MSG_RING_GEM_GRANITE,
-		"Granite" },
-	{ N_MSG_RING_GEM_GYPSUM,
-		"Gypsum" },
-	{ N_MSG_RING_GEM_HEMATITE,
-		"Hematite" },
-	{ N_MSG_RING_GEM_JADE,
-		"Jade" },
-	{ N_MSG_RING_GEM_JASPER,
-		"Jasper" },
-	{ N_MSG_RING_GEM_KRYPTONITE,
-		"Kryptonite" },
-	{ N_MSG_RING_GEM_LAPIS_LAZULI,
-		"Lapis_LAZULI" },
-	{ N_MSG_RING_GEM_LIMESTONE,
-		"Limestone" },
-	{ N_MSG_RING_GEM_MALACHITE,
-		"Malachite" },
-	{ N_MSG_RING_GEM_MANGANITE,
-		"Manganite" },
-	{ N_MSG_RING_GEM_MARBLE,
-		"Marble" },
-	{ N_MSG_RING_GEM_MOONSTONE,
-		"Moonstone" },
-	{ N_MSG_RING_GEM_NEPTUNITE,
-		"Neptunite" },
-	{ N_MSG_RING_GEM_OBSIDIAN,
-		"Obsidian" },
-	{ N_MSG_RING_GEM_ONYX,
-		"Onyx" },
-	{ N_MSG_RING_GEM_OPAL,
-		"Opal" },
-	{ N_MSG_RING_GEM_PEARL,
-		"Pearl" },
-	{ N_MSG_RING_GEM_PYRITE,
-		"Pyrite" },
-	{ N_MSG_RING_GEM_QUARTZ,
-		"Quartz" },
-	{ N_MSG_RING_GEM_QUARTZITE,
-		"Quartzite" },
-	{ N_MSG_RING_GEM_RHODONITE,
-		"Rhodonite" },
-	{ N_MSG_RING_GEM_RHYOLITE,
-		"Rhyolite" },
-	{ N_MSG_RING_GEM_RUBY,
-		"Ruby" },
-	{ N_MSG_RING_GEM_SAPPHIRE,
-		"Sapphire" },
-	{ N_MSG_RING_GEM_SPHALERITE,
-		"Sphalerite" },
-	{ N_MSG_RING_GEM_STAUROLITE,
-		"Staurolite" },
-	{ N_MSG_RING_GEM_TIGER_EYE,
-		"Tiger_EYE" },
-	{ N_MSG_RING_GEM_TOPAZ,
-		"Topaz" },
-	{ N_MSG_RING_GEM_TURQUOISE,
-		"Turquoise" },
-	{ N_MSG_RING_GEM_ZIRCON,
-		"Zircon" },
 #endif
 
+	{ N_MSG_ACCE_MATERIAL_BONE,
+		"Bone" },
+	{ N_MSG_ACCE_MATERIAL_GOLD,
+		"Gold" },
+	{ N_MSG_ACCE_MATERIAL_SILVER,
+		"Silver" },
+
+	{ N_MSG_ACCE_GEM_AMBER,
+		"Amber" },
+	{ N_MSG_ACCE_GEM_AGATE,
+		"Agate" },
+	{ N_MSG_ACCE_GEM_ALEXANDRITE,
+		"Alexandrite" },
+	{ N_MSG_ACCE_GEM_AMETHYST,
+		"Amethyst" },
+	{ N_MSG_ACCE_GEM_ANTLERITE,
+		"Antlerite" },
+	{ N_MSG_ACCE_GEM_AQUAMARINE,
+		"Aquamarine" },
+	{ N_MSG_ACCE_GEM_ARGENTITE,
+		"Argentite" },
+	{ N_MSG_ACCE_GEM_AZURITE,
+		"Azurite" },
+	{ N_MSG_ACCE_GEM_BERYL,
+		"Beryl" },
+	{ N_MSG_ACCE_GEM_BLOODSTONE,
+		"Bloodstone" },
+	{ N_MSG_ACCE_GEM_CALCITE,
+		"Calcite" },
+	{ N_MSG_ACCE_GEM_CARNELIAN,
+		"Carnelian" },
+	{ N_MSG_ACCE_GEM_CORAL,
+		"Coral" },
+	{ N_MSG_ACCE_GEM_CORUNDUM,
+		"Corundum" },
+	{ N_MSG_ACCE_GEM_CRYOLITE,
+		"Cryolite" },
+	{ N_MSG_ACCE_GEM_DIAMOND,
+		"Diamond" },
+	{ N_MSG_ACCE_GEM_DIORITE,
+		"Diorite" },
+	{ N_MSG_ACCE_GEM_EMERALD,
+		"Emerald" },
+	{ N_MSG_ACCE_GEM_FLINT,
+		"Flint" },
+	{ N_MSG_ACCE_GEM_FLUORITE,
+		"Fluorite" },
+	{ N_MSG_ACCE_GEM_GABBRO,
+		"Gabbro" },
+	{ N_MSG_ACCE_GEM_GARNET,
+		"Garnet" },
+	{ N_MSG_ACCE_GEM_GRANITE,
+		"Granite" },
+	{ N_MSG_ACCE_GEM_GYPSUM,
+		"Gypsum" },
+	{ N_MSG_ACCE_GEM_HEMATITE,
+		"Hematite" },
+	{ N_MSG_ACCE_GEM_JADE,
+		"Jade" },
+	{ N_MSG_ACCE_GEM_JASPER,
+		"Jasper" },
+	{ N_MSG_ACCE_GEM_KRYPTONITE,
+		"Kryptonite" },
+	{ N_MSG_ACCE_GEM_LAPIS_LAZULI,
+		"Lapis_LAZULI" },
+	{ N_MSG_ACCE_GEM_LIMESTONE,
+		"Limestone" },
+	{ N_MSG_ACCE_GEM_MALACHITE,
+		"Malachite" },
+	{ N_MSG_ACCE_GEM_MANGANITE,
+		"Manganite" },
+	{ N_MSG_ACCE_GEM_MARBLE,
+		"Marble" },
+	{ N_MSG_ACCE_GEM_MOONSTONE,
+		"Moonstone" },
+	{ N_MSG_ACCE_GEM_NEPTUNITE,
+		"Neptunite" },
+	{ N_MSG_ACCE_GEM_OBSIDIAN,
+		"Obsidian" },
+	{ N_MSG_ACCE_GEM_ONYX,
+		"Onyx" },
+	{ N_MSG_ACCE_GEM_OPAL,
+		"Opal" },
+	{ N_MSG_ACCE_GEM_PEARL,
+		"Pearl" },
+	{ N_MSG_ACCE_GEM_PYRITES,
+		"Pyrites" },
+	{ N_MSG_ACCE_GEM_QUARTZ,
+		"Quartz" },
+	{ N_MSG_ACCE_GEM_QUARTZITE,
+		"Quartzite" },
+	{ N_MSG_ACCE_GEM_RHODONITE,
+		"Rhodonite" },
+	{ N_MSG_ACCE_GEM_RHYOLITE,
+		"Rhyolite" },
+	{ N_MSG_ACCE_GEM_RUBY,
+		"Ruby" },
+	{ N_MSG_ACCE_GEM_SAPPHIRE,
+		"Sapphire" },
+	{ N_MSG_ACCE_GEM_SPHALERITE,
+		"Sphalerite" },
+	{ N_MSG_ACCE_GEM_STAUROLITE,
+		"Staurolite" },
+	{ N_MSG_ACCE_GEM_TIGER_EYE,
+		"Tiger_EYE" },
+	{ N_MSG_ACCE_GEM_TOPAZ,
+		"Topaz" },
+	{ N_MSG_ACCE_GEM_TURQUOISE,
+		"Turquoise" },
+	{ N_MSG_ACCE_GEM_ZIRCON,
+		"Zircon" },
+
 /* Light */
 
 	{ N_MSG_LIGHT_TORCH,
@@ -1385,6 +1515,10 @@
 
 	{ N_MSG_FOOD_PRESERVED,
 		"Preserved Food" },
+	{ N_MSG_FOOD_SAUSAGE,
+		"Sausage" },
+	{ N_MSG_FOOD_BACON,
+		"Bacon" },
 	{ N_MSG_FOOD_CHIPPED_BEEF,
 		"Chipped Beef" },
 	{ N_MSG_FOOD_CORNED_BEEF,
@@ -1673,6 +1807,8 @@
 		"%s 櫤" STR_DISARM "" },
 	{ N_MSG_TRAP_BREAK,
 		"%s 櫤" },
+	{ N_MSG_TRAP_SRCH,
+		"%s 櫤ȯ" },
 
 	{ N_MSG_SRCH_TRAP,
 		" %s 櫤Ǥ" },
@@ -1683,6 +1819,8 @@
 		"%s  %s 򳫤" },
 	{ N_MSG_ITEM_DISARM,
 		"%s  %s Υ" STR_DISARM "" },
+	{ N_MSG_ITEM_DISARM_ALREADY,
+		"%s Υϴ˳Ƥ" },
 	{ N_MSG_ITEM_BREAK,
 		"%s  %s " },
 	{ N_MSG_SRCH_ITEM,
@@ -1698,6 +1836,8 @@
 		"%s  HP  %ld ­ʤ" },
 	{ N_MSG_ERR_MP_SHORT,
 		"%s  MP  %ld ­ʤ" },
+	{ N_MSG_ERR_GOLD_SHORT,
+		"%s  " STR_GOLD "  %ld ­ʤ" },
 
 /* FX */
 
@@ -1707,6 +1847,8 @@
 		"%s  %s ɤ" },
 	{ N_MSG_FX_ZAP_STICK,
 		"%s  %s ä" },
+	{ N_MSG_EAT_FOOD,
+		"%s  %s 򿩤٤" },
 
 	{ N_MSG_FX_STONE,
 		"%s ФˤʤäƤޤä" },
@@ -1730,23 +1872,25 @@
 		"%s ̥λ줿" },
 	{ N_MSG_FX_FLY,
 		"%s Τ⤫Ӿ夬ä" },
-	{ N_MSG_FX_VANISH,
-		"%s ΤƩˤʤä" },
+	{ N_MSG_FX_FAINT,
+		"%s Ϥޤ" },
 	{ N_MSG_FX_DRUNK,
 		"%s ϿäѤä" },
+	{ N_MSG_FX_VANISH,
+		"%s ΤƩˤʤä" },
 
 	{ N_MSG_FX_RESI_PHYS,
 		"%s ϶ˤȤ줿" },
-	{ N_MSG_FX_RESI_WIND,
-		"%s ϿϤ褤򴶤" },
 	{ N_MSG_FX_RESI_HEAT,
 		"%s äʤä" },
 	{ N_MSG_FX_RESI_COLD,
 		"%s Ȥʤä" },
-	{ N_MSG_FX_RESI_ELEC,
-		"%s ŵä" },
 	{ N_MSG_FX_RESI_ACID,
 		"%s ȩ٥٤ˤʤä" },
+	{ N_MSG_FX_RESI_MIND,
+		"%s ϿϤ褤򴶤" },
+	{ N_MSG_FX_RESI_ELEC,
+		"%s ŵä" },
 	{ N_MSG_FX_RESI_POIS,
 		"%s ϵɤʤä" },
 
@@ -1789,10 +1933,6 @@
 		"%s Ͻʤ꼣ä" },
 	{ N_MSG_FX_CURE_HP_MAX,
 		"%s Ͻ˼ä" },
-	{ N_MSG_FX_CURE_POISON,
-		"%s Ǥޤä" },
-	{ N_MSG_FX_CURE_STATUS,
-		"%s ϵʬɤʤä" },
 	{ N_MSG_FX_CREATE_FOOD,
 		"%s  %s " },
 	{ N_MSG_FX_DETECT_MNSTR,
@@ -1801,6 +1941,10 @@
 		"%s ϥƥΰ֤򴶤" },
 	{ N_MSG_FX_POW_UP_HP,
 		"%s ϥդˤʤä" },
+	{ N_MSG_FX_MAGIC_SHIELD,
+		"%s Ӥ˸ʤ⤬դ" },
+	{ N_MSG_FX_MAGE_ARMOR,
+		"%s ϸʤ夿ͤ" },
 	{ N_MSG_FX_SPEED_UP,
 		"%s ư®ʤä" },
 	{ N_MSG_FX_SPEED_DOWN,
@@ -1811,6 +1955,9 @@
 		"ηʿޤѤä" },
 	{ N_MSG_FX_TELEPORT,
 		"%s μηʿޤѤä" },
+	{ N_MSG_FX_BLESS,
+		"%s ߤ줿ͤʵ" },
+
 	{ N_MSG_FX_RECALL,
 		"㡼.." },
 	{ N_MSG_FX_TOBACCO_ABSTAIN,
@@ -1831,6 +1978,7 @@
 		"%s μϤΥ󥹥̲äƤޤä" },
 	{ N_MSG_FX_SLEEP_FAILURE,
 		"%s »򤷤ͤʵˤʤä" },
+
 	{ N_MSG_FX_POW_UP_WPN_HIT_SUCCESS,
 		"%s 郎פʤä" },
 	{ N_MSG_FX_POW_UP_WPN_HIT_FAILURE,
@@ -1843,11 +1991,37 @@
 		"%s Υ᡼礭ʤä" },
 	{ N_MSG_FX_POW_UP_WPN_DAM_FAILURE,
 		"%s ξ꤬Ĥä" },
+
+	{ N_MSG_FX_POW_UP_ARMOR_DEF_SUCCESS,
+		"%s ɶ򤱰פʤä" },
+	{ N_MSG_FX_POW_UP_ARMOR_DEF_FAILURE,
+		"%s Τ֤ä" },
+	{ N_MSG_FX_POW_UP_ARMOR_CRTCL_SUCCESS,
+		"%s ɶΥƥ뤬򤱰פʤä" },
+	{ N_MSG_FX_POW_UP_ARMOR_CRTCL_FAILURE,
+		"%s Τ֤ä" },
+	{ N_MSG_FX_POW_UP_ARMOR_AC_SUCCESS,
+		"%s ɶ񤬥᡼򸺤餹ͤˤʤä" },
+	{ N_MSG_FX_POW_UP_ARMOR_AC_FAILURE,
+		"%s Τ֤ä" },
+
+	{ N_MSG_FX_PROTECT_ARMOR_SUCCESS,
+		"%s ɶݸ줿" },
+	{ N_MSG_FX_PROTECT_ARMOR_FAILURE,
+		"%s 椬ॺॺ" },
 	{ N_MSG_FX_REMOVE_CURSE_SUCCESS,
 		"%s μ򤱤" },
 	{ N_MSG_FX_REMOVE_CURSE_FAILURE,
 		"%s äѤϤʤ" },
 
+	{ N_MSG_FX_POW_DOWN_ARMOR,
+		"%s ɶϤ" },
+	{ N_MSG_FX_PROTECTED_ARMOR,
+		"%s ɶݸƤ" },
+
+	{ N_MSG_FX_CURE_HP,
+		"%s Ϥ %ld " },
+
 /* FX CLR */
 
 	{ N_MSG_CLR_FX_STONE,
@@ -1887,10 +2061,10 @@
 		"%s Ͼ뤤" },
 	{ N_MSG_CLR_FX_RESI_COLD,
 		"%s ϴ" },
-	{ N_MSG_CLR_FX_RESI_WIND,
-		"%s ©줷ʤä" },
 	{ N_MSG_CLR_FX_RESI_ACID,
 		"%s Τҥҥꤹ" },
+	{ N_MSG_CLR_FX_RESI_MIND,
+		"%s ©줷ʤä" },
 	{ N_MSG_CLR_FX_RESI_ELEC,
 		"%s ŵѥѥ" },
 	{ N_MSG_CLR_FX_RESI_POIS,
@@ -1925,8 +2099,16 @@
 		"%s ܤʤäͤ" },
 	{ N_MSG_CLR_FX_POW_UP_HP,
 		"%s ϤҼˤʤä" },
-	{ N_MSG_CLR_FX_SPEED,
-		"%s ϸ®ä" },
+	{ N_MSG_CLR_FX_MAGIC_SHIELD,
+		"%s ϸʤ⤬̵ʤä" },
+	{ N_MSG_CLR_FX_MAGE_ARMOR,
+		"%s ϸʤæͤ" },
+	{ N_MSG_CLR_FX_SPEED_UP,
+		"%s ư٤ʤä" },
+	{ N_MSG_CLR_FX_SPEED_DOWN,
+		"%s ư®ʤä" },
+	{ N_MSG_CLR_FX_BLESS,
+		"%s ϸ" },
 
 /* ̣ʪ */
 
@@ -1978,253 +2160,189 @@
 	{ N_MSG_FX_EAT_FOOD_B02,
 		"ʤ %s ! ĹƤ!" },
 
-/* mnstr */
+	{ N_MSG_FX_PICK_GOLD,
+		"%s  %s κۤ򤹤ä" },
+
+/* Monster */
 
 	{ N_MSG_MNSTR_UNKNOWN,
-		"Υ󥹥" },
-	{ N_MSG_MNSTR_GIANT_BAT,
-		"㥤ȡХå" },
-	{ N_MSG_MNSTR_GIANT_RAT,
-		"㥤ȡå" },
-	{ N_MSG_MNSTR_MIMIC,
-		"ߥߥå" },
-#if	0
-	{ N_MSG_MNSTR_ANCIENT_BLACK_DRAGON,
-		"󥷥ȡ֥åɥ饴" },
-	{ N_MSG_MNSTR_ANCIENT_BLUE_DRAGON,
-		"󥷥ȡ֥롼ɥ饴" },
-	{ N_MSG_MNSTR_ANCIENT_RED_DRAGON,
-		"󥷥ȡåɡɥ饴" },
-	{ N_MSG_MNSTR_ANCIENT_WHITE_DRAGON,
-		"󥷥ȡۥ磻ȡɥ饴" },
-	{ N_MSG_MNSTR_ANCIENT_YELLOW_DRAGON,
-		"󥷥ȡɥ饴" },
-	{ N_MSG_MNSTR_MINOR_BLACK_DRAGON,
-		"ޥʡ֥åɥ饴" },
-	{ N_MSG_MNSTR_MINOR_BLUE_DRAGON,
-		"ޥʡ֥롼ɥ饴" },
-	{ N_MSG_MNSTR_MINOR_RED_DRAGON,
-		"ޥʡåɡɥ饴" },
-	{ N_MSG_MNSTR_MINOR_WHITE_DRAGON,
-		"ޥʡۥ磻ȡɥ饴" },
-	{ N_MSG_MNSTR_MINOR_YELLOW_DRAGON,
-		"ޥʡɥ饴" },
-	{ N_MSG_MNSTR_BEHEMOTH,
-		"ӥҥ⥹" },
-	{ N_MSG_MNSTR_SALAMANDER,
-		"ޥ" },
-	{ N_MSG_MNSTR_BANSHEE,
-		"Х󥷡" },
-	{ N_MSG_MNSTR_DJINNI,
-		"" },
-	{ N_MSG_MNSTR_EFREET,
-		"ե꡼" },
-	{ N_MSG_MNSTR_GNOME,
-		"Ρ" },
-	{ N_MSG_MNSTR_BROWNIE,
-		"֥饦ˡ" },
-	{ N_MSG_MNSTR_PHOENIX,
-		"ե˥å" },
-	{ N_MSG_MNSTR_SYLPH,
-		"" },
-	{ N_MSG_MNSTR_UNDINE,
-		"ǥ" },
-	{ N_MSG_MNSTR_WILL_O_WISP,
-		"롦" },
-	{ N_MSG_MNSTR_COATL,
-		"ȥ" },
-	{ N_MSG_MNSTR_NAGA,
-		"ʡ" },
-	{ N_MSG_MNSTR_LYCANTHROPE,
-		"饤󥹥" },
-	{ N_MSG_MNSTR_MINOTAUR,
-		"ߥΥ" },
-	{ N_MSG_MNSTR_SATYR,
-		"ƥ" },
-	{ N_MSG_MNSTR_ANDRO_SCORPION,
-		"ɥԥ" },
-	{ N_MSG_MNSTR_BIRD_MAN,
-		"Сɥޥ" },
-	{ N_MSG_MNSTR_CENTAUR,
-		"󥿥" },
-	{ N_MSG_MNSTR_MEDUSA,
-		"ǥ塼" },
-	{ N_MSG_MNSTR_GILLMAN,
-		"ޥ" },
-	{ N_MSG_MNSTR_HARPY,
-		"ϡԡ" },
-	{ N_MSG_MNSTR_LAMIA,
-		"ߥ" },
-	{ N_MSG_MNSTR_MERMAN,
-		"ޡޥ" },
-	{ N_MSG_MNSTR_GNOLL,
-		"Ρ" },
-	{ N_MSG_MNSTR_SIREN,
-		"졼" },
-	{ N_MSG_MNSTR_SCYLLA,
-		"" },
-	{ N_MSG_MNSTR_LIZARDMAN,
-		"ꥶɥޥ" },
-	{ N_MSG_MNSTR_CAVEMAN,
-		"ޥ" },
-	{ N_MSG_MNSTR_GIANT,
-		"㥤" },
-	{ N_MSG_MNSTR_HUMBABA,
-		"եХ" },
-	{ N_MSG_MNSTR_TROLL,
-		"ȥ" },
-	{ N_MSG_MNSTR_YETI,
-		"ƥ" },
-	{ N_MSG_MNSTR_BEAR,
-		"٥" },
-	{ N_MSG_MNSTR_ROC,
-		"å" },
-	{ N_MSG_MNSTR_BAT,
-		"Хå" },
-	{ N_MSG_MNSTR_GREAT_CAT,
-		"졼ȡå" },
-	{ N_MSG_MNSTR_DOG,
-		"ɥå" },
-	{ N_MSG_MNSTR_HORSE,
-		"ۡ" },
-	{ N_MSG_MNSTR_WOLF,
-		"" },
-	{ N_MSG_MNSTR_BEHOLDER,
-		"ӥۥ" },
-	{ N_MSG_MNSTR_CERBERUS,
-		"٥" },
-	{ N_MSG_MNSTR_GRIFFON,
-		"ե" },
-	{ N_MSG_MNSTR_HYDRA,
-		"ҥɥ" },
-	{ N_MSG_MNSTR_HIPPOGRIFF,
-		"ҥݥ" },
-	{ N_MSG_MNSTR_BASILISK,
-		"Хꥹ" },
-	{ N_MSG_MNSTR_CHIMERA,
-		"ޥ" },
-	{ N_MSG_MNSTR_GORGON,
-		"르" },
-	{ N_MSG_MNSTR_HELLHOUND,
-		"إ롦ϥ" },
-	{ N_MSG_MNSTR_MANTICORE,
-		"ޥƥ" },
-	{ N_MSG_MNSTR_COCKATRICE,
-		"ȥꥹ" },
-	{ N_MSG_MNSTR_PEGASUS,
-		"ڥ" },
-	{ N_MSG_MNSTR_RUST_MONSTER,
-		"饹ȡ󥹥" },
-	{ N_MSG_MNSTR_UNICORN,
-		"˥" },
-	{ N_MSG_MNSTR_WYVERN,
-		"磻С" },
-	{ N_MSG_MNSTR_DOPPELGANGER,
-		"ɥåڥ륲󥬡" },
-	{ N_MSG_MNSTR_SUCCUBUS,
-		"Х" },
-	{ N_MSG_MNSTR_DURAHAN,
-		"ǥϥ" },
-	{ N_MSG_MNSTR_GREMLIN,
-		"" },
-	{ N_MSG_MNSTR_IMP,
-		"" },
-	{ N_MSG_MNSTR_MIND_FLAYER,
-		"ޥɡե쥤䡼" },
-	{ N_MSG_MNSTR_DWARF,
-		"ɥ" },
-	{ N_MSG_MNSTR_DRYAD,
-		"ɥ饤" },
-	{ N_MSG_MNSTR_ELF,
-		"" },
-	{ N_MSG_MNSTR_FAIRY,
-		"ե꡼" },
-	{ N_MSG_MNSTR_HALFLING,
-		"ϡե" },
+		"Unknown monster" },
+/* GOD */
+/* DRAGON */
+/* ILLUSORY */
+/* FAIRY */
 	{ N_MSG_MNSTR_LEPRECHAUN,
-		"ץ饳" },
-	{ N_MSG_MNSTR_PIXY,
-		"ԥ" },
-	{ N_MSG_MNSTR_GHOST,
-		"" },
-	{ N_MSG_MNSTR_POLTERGEIST,
-		"ݥ륿" },
-	{ N_MSG_MNSTR_SPIRIT,
-		"ԥå" },
-	{ N_MSG_MNSTR_WRAITH,
-		"쥤" },
-	{ N_MSG_MNSTR_OGRE,
-		"" },
-	{ N_MSG_MNSTR_GOBLIN,
-		"֥" },
-	{ N_MSG_MNSTR_HOBGOBLIN,
-		"ۥ֥֥" },
-	{ N_MSG_MNSTR_KOBOLD,
-		"ܥ" },
-	{ N_MSG_MNSTR_ORK,
-		"" },
-	{ N_MSG_MNSTR_GIANT_SPIDER,
-		"㥤ȡѥ" },
-	{ N_MSG_MNSTR_GIANT_ANT,
-		"㥤ȡ" },
-	{ N_MSG_MNSTR_GIANT_BEETLE,
-		"㥤ȡӡȥ" },
-	{ N_MSG_MNSTR_GIANT_CENTIPEDE,
-		"㥤ȡƥԡ" },
-	{ N_MSG_MNSTR_GIANT_SCORPION,
-		"㥤ȡԥ" },
-	{ N_MSG_MNSTR_WORM,
-		"" },
-	{ N_MSG_MNSTR_GOLEM,
-		"" },
-	{ N_MSG_MNSTR_GAS_CLOUD,
-		"饦" },
-	{ N_MSG_MNSTR_GARGOYLE,
-		"" },
-	{ N_MSG_MNSTR_HOMUNCULUS,
-		"ۥ󥯥륹" },
-	{ N_MSG_MNSTR_INVISIBLE_STALKER,
-		"֥롦ȡ" },
-	{ N_MSG_MNSTR_JACK_O_LANTERN,
-		"å󥿥" },
+		"Leprechaun" },
+/* ELEMENTAL */
+	{ N_MSG_MNSTR_FIRE_ELEMENTAL,
+		"Fire elemental" },
+	{ N_MSG_MNSTR_SALAMANDER,
+		"Salamander" },
+	{ N_MSG_MNSTR_WATER_ELEMENTAL,
+		"Water elemental" },
+	{ N_MSG_MNSTR_UNDINE,
+		"Undine" },
+	{ N_MSG_MNSTR_AIR_ELEMENTAL,
+		"Air elemental" },
+	{ N_MSG_MNSTR_SYLPH,
+		"Sylph" },
+	{ N_MSG_MNSTR_EARTH_ELEMENTAL,
+		"Earth elemental" },
+	{ N_MSG_MNSTR_GNOME,
+		"Gnome" },
+	{ N_MSG_MNSTR_WILL_O_WISP,
+		"Will O Wisp," },
+	{ N_MSG_MNSTR_SHADE,
+		"Shade" },
+/* PLANT */
+	{ N_MSG_MNSTR_VENUS_FLY_TRAP,
+		"Venus fly trap" },
 	{ N_MSG_MNSTR_SLIME,
-		"饤" },
-	{ N_MSG_MNSTR_HAG,
-		"ϥ" },
-	{ N_MSG_MNSTR_DINOSAUR,
-		"ʥ" },
-	{ N_MSG_MNSTR_GIANT_LIZARD,
-		"㥤ȡꥶ" },
-	{ N_MSG_MNSTR_SNAKE,
-		"͡" },
-	{ N_MSG_MNSTR_MANDRAKE,
-		"ޥɥ쥤" },
-	{ N_MSG_MNSTR_PLANT_MONSTER,
-		"ץȡ󥹥" },
+		"Slime" },
 	{ N_MSG_MNSTR_SPORE,
-		"ݥ" },
-	{ N_MSG_MNSTR_TREANT,
-		"ȥ" },
-	{ N_MSG_MNSTR_KRAKEN,
-		"顼" },
-	{ N_MSG_MNSTR_SEA_SERPENT,
-		"ڥ" },
-	{ N_MSG_MNSTR_GHOUL,
-		"" },
-	{ N_MSG_MNSTR_MUMMY,
-		"ޥߡ" },
+		"Spore" },
+/* ANIMAL */
+	{ N_MSG_MNSTR_GIANT_BAT,
+		"Giant bat" },
+	{ N_MSG_MNSTR_GIANT_RAT,
+		"Giant rat" },
+	{ N_MSG_MNSTR_GIANT_SNAKE,
+		"Giant snake" },
+	{ N_MSG_MNSTR_VIPER_SNAKE,
+		"Viper snake" },
+	{ N_MSG_MNSTR_CAT,
+		"Cat" },
+	{ N_MSG_MNSTR_DOG,
+		"Dog" },
+	{ N_MSG_MNSTR_WOLF,
+		"Wolf" },
+	{ N_MSG_MNSTR_PYON_PYON,
+		"Pyonpyon" },
+/* INSECT */
+	{ N_MSG_MNSTR_GIANT_CENTIPEDE,
+		"Giant centipede" },
+	{ N_MSG_MNSTR_GIANT_BEE,
+		"Giant bee" },
+	{ N_MSG_MNSTR_ACID_FLY,
+		"Acid fly" },
+	{ N_MSG_MNSTR_GIANT_SCORPION,
+		"Giant scorpion" },
+	{ N_MSG_MNSTR_GIANT_ANT,
+		"Giant ant" },
+	{ N_MSG_MNSTR_GIANT_SPIDER,
+		"Giant spider" },
+	{ N_MSG_MNSTR_GIANT_BEETLE,
+		"Giant beetle" },
+/* HUMAN */
+	{ N_MSG_MNSTR_FIGHTER,
+		"Fighter" },
+	{ N_MSG_MNSTR_MONK,
+		"Monk" },
+	{ N_MSG_MNSTR_HUNTER,
+		"Hunter" },
+	{ N_MSG_MNSTR_THIEF,
+		"Thief" },
+	{ N_MSG_MNSTR_WIZARD,
+		"Wizard" },
+	{ N_MSG_MNSTR_SUMMONER,
+		"Summoner" },
+	{ N_MSG_MNSTR_PRIEST,
+		"Priest" },
+	{ N_MSG_MNSTR_FARMER,
+		"Farmer" },
+	{ N_MSG_MNSTR_CRAFTSMAN,
+		"Craftsman" },
+	{ N_MSG_MNSTR_MERCHANT,
+		"Merchant" },
+/* HYBRID */
+/* GIANT */
+	{ N_MSG_MNSTR_YETI,
+		"Yeti" },
+	{ N_MSG_MNSTR_OGRE,
+		"Ogre" },
+	{ N_MSG_MNSTR_TROLL,
+		"Troll" },
+	{ N_MSG_MNSTR_FIRE_GIANT,
+		"Fire giant" },
+	{ N_MSG_MNSTR_FROST_GIANT,
+		"Frost giant" },
+	{ N_MSG_MNSTR_CYCLOPS,
+		"Cyclops" },
+/* HUGE */
+/* AQUATIC */
+/* MAGICAL */
+	{ N_MSG_MNSTR_INVISIBLE_STALKER,
+		"Invisible stalker" },
+	{ N_MSG_MNSTR_GARGOYLE,
+		"Gargoyle" },
+	{ N_MSG_MNSTR_MIMIC,
+		"Mimic" },
+	{ N_MSG_MNSTR_WOOD_GOLEM,
+		"Wood golem" },
+	{ N_MSG_MNSTR_BONE_GOLEM,
+		"Bone golem" },
+	{ N_MSG_MNSTR_FLESH_GOLEM,
+		"Flesh golem" },
+	{ N_MSG_MNSTR_STONE_GOLEM,
+		"Stone golem" },
+	{ N_MSG_MNSTR_IRON_GOLEM,
+		"Iron golem" },
+	{ N_MSG_MNSTR_GAS_CLOUD,
+		"Gas cloud" },
+/* COMPOUND */
+	{ N_MSG_MNSTR_HIPPOGRIFF,
+		"Hippogriff" },
+	{ N_MSG_MNSTR_GRIFFON,
+		"Griffon" },
+	{ N_MSG_MNSTR_MANTICORE,
+		"Manticore" },
+	{ N_MSG_MNSTR_CHIMERA,
+		"Chimera" },
+/* UNDEAD */
 	{ N_MSG_MNSTR_SKELETON,
-		"ȥ" },
-	{ N_MSG_MNSTR_VAMPIRE,
-		"ѥ" },
-	{ N_MSG_MNSTR_WIGHT,
-		"磻" },
+		"Skeleton" },
 	{ N_MSG_MNSTR_ZOMBIE,
-		"" },
-#endif
-
-	{ N_MSG_MIMIC_FIND_MBR,
+		"Zombie" },
+	{ N_MSG_MNSTR_GHOUL,
+		"Ghoul" },
+	{ N_MSG_MNSTR_GHOST,
+		"Ghost" },
+	{ N_MSG_MNSTR_WIGHT,
+		"Wight" },
+	{ N_MSG_MNSTR_MUMMY,
+		"Mummy" },
+	{ N_MSG_MNSTR_DURAHAN,
+		"Durahan" },
+	{ N_MSG_MNSTR_BANSHEE,
+		"Banshee" },
+	{ N_MSG_MNSTR_WRAITH,
+		"Wraith" },
+	{ N_MSG_MNSTR_VAMPIRE,
+		"Vampire" },
+/* EVIL */
+	{ N_MSG_MNSTR_KOBOLD,
+		"Kobold" },
+	{ N_MSG_MNSTR_GOBLIN,
+		"Goblin" },
+	{ N_MSG_MNSTR_HOBGOBLIN,
+		"Hobgoblin" },
+	{ N_MSG_MNSTR_ORK,
+		"Ork" },
+	{ N_MSG_MNSTR_GNOLL,
+		"Gnoll" },
+	{ N_MSG_MNSTR_INCUBUS,
+		"Incubus" },
+	{ N_MSG_MNSTR_SUCCUBUS,
+		"Succubus" },
+/* EVIL_BEAST */
+/* DEVIL */
+	{ N_MSG_MNSTR_IMP,
+		"Imp" },
+/**/
+	{ N_MSG_MBR_FIND_INVISIBLE,
 		"Ԥơ %s " },
+	{ N_MSG_MNSTR_DISAPPEAR,
+		"%s ϡѤ򤯤ޤ" },
 
 /* trap */
 
@@ -2234,6 +2352,8 @@
 		"" },
 	{ N_MSG_TRAP_POISON_DARTS,
 		"ǥĤ" },
+	{ N_MSG_TRAP_BOMB,
+		"Ƥ" },
 	{ N_MSG_TRAP_TELEPORT_PARTY,
 		"ѡƥְִư" },
 	{ N_MSG_TRAP_TELEPORT,
@@ -2303,6 +2423,10 @@
 		"%s ϼʸФƤʤ" },
 	{ N_MSG_SPELL_NO_LEARN,
 		"̵" },
+	{ N_MSG_LEARN_SPELL,
+		"%s  %s μʸ򤪤ܤ" },
+	{ N_MSG_FORGET_SPELL,
+		"%s  %s μʸ˺줿" },
 
 /* [ˡ] */
 
@@ -2345,16 +2469,16 @@
 		"õ" },
 	{ N_MSG_SPELL_ANALYZE_DWEOMER,
 		"ʬ" },
-	{ N_MSG_SPELL_DETECT_DOORS,
-		"õ" },
 	{ N_MSG_SPELL_DETECT_ITEM,
 		"ƥõ" },
+	{ N_MSG_SPELL_DETECT_DOORS,
+		"ɥõ" },
+	{ N_MSG_SPELL_DETECT_TRAPS,
+		"õ" },
 	{ N_MSG_SPELL_DETECT_MAGIC,
 		"ˡ" },
 	{ N_MSG_SPELL_DETECT_MONSTER,
 		"󥹥" },
-	{ N_MSG_SPELL_DETECT_TRAPS,
-		"õ" },
 	{ N_MSG_SPELL_SENSE_INVISIBLE,
 		"ԲĻ봶" },
 
@@ -2390,10 +2514,10 @@
 		"Фε" },
 	{ N_MSG_SPELL_ICE_BLIZZARD,
 		"ɹο" },
-	{ N_MSG_SPELL_MIND_STORM,
-		"" },
 	{ N_MSG_SPELL_ACID_RAIN,
 		"α" },
+	{ N_MSG_SPELL_MIND_STORM,
+		"" },
 	{ N_MSG_SPELL_LIGHTNING_BOLT,
 		"ŷ" },
 	{ N_MSG_SPELL_POISON_CLOUD,
@@ -2561,20 +2685,20 @@
 
 	{ N_MSG_SPELL_PROTECTION,
 		"ɸ" },
+	{ N_MSG_SPELL_RESIST_PHYSICAL,
+		"ʪ" },
+	{ N_MSG_SPELL_RESIST_HEAT,
+		"Ǯ" },
+	{ N_MSG_SPELL_RESIST_COLD,
+		"" },
 	{ N_MSG_SPELL_RESIST_ACID,
 		"ڻ" },
-	{ N_MSG_SPELL_RESIST_COLD,
+	{ N_MSG_SPELL_RESIST_MIND,
 		"" },
 	{ N_MSG_SPELL_RESIST_ELECTRICITY,
 		"" },
-	{ N_MSG_SPELL_RESIST_HEAT,
-		"Ǯ" },
-	{ N_MSG_SPELL_RESIST_PHYSICAL,
-		"ʪ" },
 	{ N_MSG_SPELL_RESIST_POISON,
 		"" },
-	{ N_MSG_SPELL_RESIST_WIND,
-		"" },
 
 /*  */
 
@@ -2591,11 +2715,8 @@
 
 /* ŷϰ */
 
-#if	0
-@@@
-	{ N_MSG_SPELL_,
+	{ N_MSG_SPELL_TYPHOON,
 		"ۤν()" },
-#endif
 	{ N_MSG_SPELL_CONFLAGRATION,
 		"ۤν(к)" },
 	{ N_MSG_SPELL_EARTHQUAKE,
@@ -2605,37 +2726,12 @@
 	{ N_MSG_SPELL_INUNDATION,
 		"ۤν()" },
 
-#if	0
-@@@
-/*  */
-
-	{ N_MSG_SPELL_,
-		"ۤν(Ф)" },
-	{ N_MSG_SPELL_,
-		"ۤν(оä)" },
-	{ N_MSG_SPELL_,
-		"ۤν()" },
-	{ N_MSG_SPELL_,
-		"ۤν()" },
-	{ N_MSG_SPELL_,
-		"ۤν(Ϥ)" },
-#endif
-
 /*  */
 
 	{ N_MSG_SPELL_SUBSTITUTE,
 		"ۤν()" },
 	{ N_MSG_SPELL_BURNING_HANDS,
 		"ۤν()" },
-#if	0
-@@@
-	{ N_MSG_SPELL_,
-		"ۤν()" },
-	{ N_MSG_SPELL_,
-		"ۤν()" },
-	{ N_MSG_SPELL_,
-		"ۤν()" },
-#endif
 
 /* ANC */
 
@@ -2644,10 +2740,25 @@
 
 /* spell end */
 
+/* spell format begin */
+
+	{ N_MSG_FMT_SPELL_SPORE,
+		"%s ˦Ҥ򻵤餷" },
+	{ N_MSG_FMT_SPELL_ACID,
+		"%s ϻǤ" },
+	{ N_MSG_FMT_SPELL_ENERGY_DRAIN,
+		"%s ̿Ϥۼ" },
+	{ N_MSG_FMT_SPELL_CRY,
+		"%s ϶㤭Ф" },
+
+/* spell format end */
+
 /* color begin */
 
 	{ N_MSG_ATTR_NORMAL,
 		"̾ο" },
+	{ N_MSG_ATTR_REV,
+		"ȿžο" },
 	{ N_MSG_ATTR_ERR,
 		"顼ο" },
 	{ N_MSG_ATTR_MENU_DIS,
@@ -2660,6 +2771,8 @@
 		STR_SQUARE "ο" },
 	{ N_MSG_ATTR_MAP_MNSTR,
 		"󥹥ο" },
+	{ N_MSG_ATTR_MAP_NPC,
+		"NPCο" },
 	{ N_MSG_ATTR_MAP_CRSR,
 		"ο" },
 	{ N_MSG_ATTR_FX_MBR_PLUS,
@@ -2736,9 +2849,9 @@
 		"" },
 
 	{ N_MSG_MENU_YES,
-		"Ϥ" },
+		"Yes" },
 	{ N_MSG_MENU_NO,
-		"" },
+		"No" },
 
 	{ N_MSG_MENU_MIN,
 		"[min]" },
@@ -2857,7 +2970,7 @@
 /* menu select item begin */
 
 	{ N_MSG_MENU_ITEM_LS_EQUIP,
-		"" },
+		"Equipment" },
 
 	{ N_MSG_MENU_ITEM_QUAFF,
 		"Quaff" },
@@ -2869,6 +2982,8 @@
 		"Eat" },
 	{ N_MSG_MENU_ITEM_SMOKE,
 		"Smoke" },
+	{ N_MSG_MENU_ITEM_DISPOSE,
+		"Dispose of tobacco" },
 	{ N_MSG_MENU_ITEM_FILL_LAMP,
 		"Fill lamp" },
 	{ N_MSG_MENU_ITEM_EQUIP,
@@ -2942,14 +3057,18 @@
 		"Member data" },
 	{ N_MSG_MENU_MNSTR_DATA,
 		"Monster data" },
-	{ N_MSG_MENU_SLEEP,
-		"Sleep" },
+	{ N_MSG_MENU_GOLD,
+		STR_GOLD },
 	{ N_MSG_MENU_COLLECT_GOLD,
-		"Collect GOLD" },
+		"Collect " STR_GOLD },
 	{ N_MSG_MENU_DIVIDE_GOLD,
-		"Divide GOLD" },
-	{ N_MSG_MENU_MSG,
+		"Divide " STR_GOLD },
+	{ N_MSG_MENU_FORMATION,
+		"Formation" },
+	{ N_MSG_MENU_LS_MSG,
 		"List Message" },
+	{ N_MSG_MENU_LS_MNSTR,
+		"List Monster" },
 	{ N_MSG_MENU_OUT_MAP_FILE,
 		"Output map" },
 	{ N_MSG_MENU_SHELL,
@@ -2982,9 +3101,20 @@
 	{ N_MSG_MNSTR_DATA_NAME,
 		"%c%c is %s" },
 	{ N_MSG_MNSTR_DATA_MAX_LEV,
-		"Max Level of %c%c is %ld" },
+		"Max Level of %s is %ld" },
 	{ N_MSG_MNSTR_DATA_MIN_LEV,
-		"Min Level of %c%c is %ld" },
+		"Min Level of %s is %ld" },
+	{ N_MSG_MNSTR_DATA_AVE_LEV,
+		"Average Level of %s is %2.2lf" },
+	{ N_MSG_MNSTR_DATA_HP,
+		"HP of %s is %3ld/%3ld" },
+	{ N_MSG_MNSTR_DATA_MP,
+		"MP of %s is %3ld/%3ld" },
+
+	{ N_MSG_TTL_MENU_FORMATION_SEL_MBR,
+		"Who's member?" },
+	{ N_MSG_TTL_MENU_FORMATION_SEL_N,
+		"What's number?" },
 
 /* menu cursor begin */
 
@@ -3058,6 +3188,9 @@
 
 /* menu cursor end */
 
+	{ N_MSG_LS_MNSTR,
+		"from %3ld to %3ld : %s" },
+
 /* menu config begin */
 
 	{ N_MSG_MENU_AUTO_FIGHT,
@@ -3068,12 +3201,8 @@
 		"櫤򤱤" },
 	{ N_MSG_MENU_AUTO_RELOAD,
 		"ưŶ" },
-	{ N_MSG_MENU_SCROLL_PAGE,
-		"ڡ" },
-	{ N_MSG_MENU_SCROLL_SMOOTH,
-		"ࡼ" },
-	{ N_MSG_MENU_SCROLL_CENTER,
-		"ࡼ(濴)" },
+	{ N_MSG_MENU_SCROLL_MODE,
+		"" },
 	{ N_MSG_MENU_MUL_MSG_LINE,
 		"åԤʣ" },
 	{ N_MSG_MENU_VFX,
@@ -3082,6 +3211,15 @@
 		"ɽ" },
 	{ N_MSG_MENU_CRSR_PTN,
 		"η" },
+	{ N_MSG_MENU_MACRO,
+		"ܡɡޥ" },
+
+	{ N_MSG_MENU_SCROLL_PAGE,
+		"ڡ" },
+	{ N_MSG_MENU_SCROLL_SMOOTH,
+		"ࡼ" },
+	{ N_MSG_MENU_SCROLL_CENTER,
+		"ࡼ(濴)" },
 
 	{ N_MSG_MENU_VFX_MBR_HP_ADD,
 		"СHPβ" },
@@ -3134,8 +3272,14 @@
 	{ N_MSG_MENU_BOLD,
 		"Ĵ" },
 
-	{ N_MSG_MENU_CRSR_PTN_SEL,
-		"ֹϤƲ" },
+	{ N_MSG_MENU_FUNC_KEY,
+		"ե󥯥󡦥 F%ld" },
+	{ N_MSG_MENU_MACRO_EXEC,
+		"¹" },
+	{ N_MSG_MENU_MACRO_EDIT,
+		"Խ" },
+	{ N_MSG_GETS_MACRO_EDIT,
+		"ޥϤƲ(%ld ʸ)" },
 
 /* menu config end */
 
@@ -3150,6 +3294,8 @@
 		"" },
 	{ N_MSG_MENU_WIZARD_OFF_LIGHT,
 		"ä" },
+	{ N_MSG_MENU_WIZARD_LEV_UP,
+		"٥롦å" },
 
 /* menu wizard end */
 
@@ -3298,15 +3444,22 @@
 		"%s 㤤ޤ" },
 	{ N_MSG_MENU_REACHED_SALE,
 		"%s ޤ" },
+	{ N_MSG_NO_DEAL,
+		"%s ϰޤ" },
 
 	{ N_MSG_FMT_MENU_SHOP,
-		"%s %s %s %ld " STR_GOLD },
+		"%s %s %s %8ld " STR_GOLD },
+	{ N_MSG_FMT_MENU_MAGIC_GUILD,
+		"%-24s %8ld " STR_GOLD },
+	{ N_MSG_FMT_MENU_PET_SHOP,
+		"%-32s %8ld" STR_GOLD },
+
 	{ N_MSG_MENU_SHOP_DATA,
 		"ǽ" },
 	{ N_MSG_MENU_SHOP_COLLECT_GOLD,
-		"򽸤" },
+		STR_GOLD "򽸤" },
 	{ N_MSG_MENU_SHOP_DIVIDE_GOLD,
-		"ʬۤ" },
+		STR_GOLD "ʬۤ" },
 	{ N_MSG_MENU_SHOP_BUY,
 		"㤦" },
 	{ N_MSG_MENU_SHOP_SALE_ITEM,
@@ -3357,6 +3510,17 @@
 	{ N_MSG_MENU_CONTRIBUTION,
 		"%s  %ld " STR_GOLD " դ" },
 
+	{ N_MSG_TTL_MENU_ORDER,
+		"ʸޤ?" },
+	{ N_MSG_MENU_ORDER_MBR,
+		"%s : %s" },
+	{ N_MSG_MENU_ORDER_CHOSE,
+		"ʸ" },
+	{ N_MSG_MENU_ORDER_NULL,
+		"ޤʤ" },
+
+	{ N_MSG_MENU_BAR_ORDER,
+		"߶" },
 	{ N_MSG_MENU_BAR_FORM,
 		"ѡƥ" },
 
@@ -3414,6 +3578,11 @@
 	{ N_MSG_TTL_MENU_ASK_REMOVE_CLASS,
 		"˥饹ޤ?" },
 
+	{ N_MSG_TTL_MENU_SEL_EDIT_CLASS,
+		"饹Խ" },
+	{ N_MSG_MENU_BAR_ARRANGE_CLASS,
+		"Ƭ¤ٴ" },
+
 	{ N_MSG_MENU_NEW_MBR,
 		"New Character" },
 	{ N_MSG_MENU_NEW_CLASS,
@@ -3424,6 +3593,39 @@
 	{ N_MSG_MENU_INN_DO_STAY,
 		"񤷤īˤʤä" },
 
+	{ N_MSG_TTL_MENU_MAGIC_GUILD,
+		"%s %s %ld " STR_GOLD },
+
+/* menu pet shop begin */
+
+	{ N_MSG_TTL_MENU_PET_SHOP,
+		"%s %s %ld " STR_GOLD },
+	{ N_MSG_TTL_MENU_PET_SHOP_TAKE,
+		"%s %s Take" },
+	{ N_MSG_TTL_MENU_PET_SHOP_LEAVE,
+		"%s %s Leave" },
+
+	{ N_MSG_MENU_PET_SHOP_TAKE,
+		"Take pet" },
+	{ N_MSG_MENU_PET_SHOP_LEAVE,
+		"Leave pet" },
+	{ N_MSG_MENU_PET_SHOP_BUY,
+		"Buy pet" },
+
+	{ N_MSG_MENU_PET_SHOP_ASK_BUY,
+		"Do you buy %s ?" },
+	{ N_MSG_TTL_MENU_PET_SHOP_ASK_BUY,
+		"Do you buy really?" },
+
+	{ N_MSG_MENU_PET_SHOP_TAKE_SUCCESS,
+		"You taked %s" },
+	{ N_MSG_MENU_PET_SHOP_LEAVE_SUCCESS,
+		"You leaved %s" },
+	{ N_MSG_MENU_PET_SHOP_BUY_SUCCESS,
+		"Bought %s" },
+
+/* menu pet shop end */
+
 /* menu town end */
 
 /* menu spell begin */
@@ -3504,7 +3706,7 @@
 	{ N_MSG_MBR_DATA_GOLD_TTL,
 		STR_GOLD ": " },
 	{ N_MSG_CALENDAR,
-		"%ldǯ%ld%ld%ld%ldʬ" },
+		"%4ld/%02ld/%02ld(%sday)%02ld:%02ld" },
 
 	{ N_MSG_MBR_DATA_STAT_TTL,
 		":" },
@@ -3526,6 +3728,8 @@
 		"[̲]" },
 	{ N_MSG_MBR_DATA_STAT_SILENCE,
 		"[]" },
+	{ N_MSG_MBR_DATA_STAT_CAUGHT,
+		"[«]" },
 	{ N_MSG_MBR_DATA_STAT_FEAR,
 		"[]" },
 	{ N_MSG_MBR_DATA_STAT_HALLUCINATION,
@@ -3597,36 +3801,49 @@
 	{ N_MSG_MBR_DATA_NIN_TTL,
 		"NIN: " },
 
-	{ N_MSG_FMT_MBR_DATA_RESI,
-		"%s%3ld%" },
 	{ N_MSG_MBR_DATA_RESI_TTL,
-		"---- " },
+		"-resist-" },
+	{ N_MSG_MBR_DATA_RESI_TTL_LAWFUL,
+		"Lawful" },
+	{ N_MSG_MBR_DATA_RESI_TTL_NEUTRAL_1,
+		"Neutral" },
+	{ N_MSG_MBR_DATA_RESI_TTL_CHAOTIC,
+		"Chaotic" },
+	{ N_MSG_MBR_DATA_RESI_TTL_GOOD,
+		"Good" },
+	{ N_MSG_MBR_DATA_RESI_TTL_NEUTRAL_2,
+		"Neutral" },
+	{ N_MSG_MBR_DATA_RESI_TTL_EVIL,
+		"Evil" },
+
+	{ N_MSG_FMT_MBR_DATA_RESI,
+		"%s%4ld" },
 	{ N_MSG_MBR_DATA_RESI_KNOC_TTL,
-		": " },
+		"KNOC:" },
 	{ N_MSG_MBR_DATA_RESI_SLAS_TTL,
-		"·: " },
+		"SLAS:" },
 	{ N_MSG_MBR_DATA_RESI_STIN_TTL,
-		": " },
+		"STIN:" },
 	{ N_MSG_MBR_DATA_RESI_HEAT_TTL,
-		"Ǯ: " },
+		"FIRE:" },
 	{ N_MSG_MBR_DATA_RESI_COLD_TTL,
-		": " },
-	{ N_MSG_MBR_DATA_RESI_WIND_TTL,
-		": " },
+		"WATE:" },
 	{ N_MSG_MBR_DATA_RESI_ACID_TTL,
-		"ڻ: " },
+		"EART:" },
+	{ N_MSG_MBR_DATA_RESI_MIND_TTL,
+		"AIR :" },
 	{ N_MSG_MBR_DATA_RESI_ELEC_TTL,
-		": " },
+		"LIGH:" },
 	{ N_MSG_MBR_DATA_RESI_POIS_TTL,
-		": " },
+		"DARK:" },
 
 	{ N_MSG_MBR_DATA_CLASS_TTL,
-		"饹: " },
+		"Class: " },
 	{ N_MSG_MBR_DATA_CLASS,
 		"%s%s" },
 
 	{ N_MSG_MBR_DATA_NEXT_PAGE,
-		"Υڡ" },
+		"Next page" },
 
 	{ N_MSG_LEV_UP_LEFT_OFF,
 		" " },
@@ -3660,6 +3877,153 @@
 
 /* edit class end */
 
+/* words begin */
+
+	{ N_MSG_OKURI_00,
+		"(" },
+	{ N_MSG_OKURI_01,
+		"[" },
+	{ N_MSG_OKURI_02,
+		"{" },
+	{ N_MSG_OKURI_03,
+		"" },
+	{ N_MSG_OKURI_04,
+		"" },
+	{ N_MSG_OKURI_05,
+		"" },
+	{ N_MSG_OKURI_06,
+		"" },
+	{ N_MSG_OKURI_07,
+		"" },
+	{ N_MSG_OKURI_08,
+		"" },
+	{ N_MSG_OKURI_09,
+		"" },
+	{ N_MSG_OKURI_10,
+		"" },
+	{ N_MSG_OKURI_11,
+		"" },
+	{ N_MSG_OKURI_12,
+		"" },
+	{ N_MSG_OKURI_13,
+		"" },
+	{ N_MSG_OKURI_14,
+		"" },
+	{ N_MSG_OKURI_15,
+		"" },
+	{ N_MSG_OKURI_16,
+		"" },
+	{ N_MSG_OKURI_17,
+		"" },
+	{ N_MSG_OKURI_18,
+		"" },
+	{ N_MSG_OKURI_19,
+		"" },
+	{ N_MSG_OKURI_20,
+		"" },
+	{ N_MSG_OKURI_21,
+		"" },
+	{ N_MSG_OKURI_22,
+		"" },
+	{ N_MSG_OKURI_23,
+		"" },
+	{ N_MSG_OKURI_24,
+		"" },
+	{ N_MSG_OKURI_25,
+		"" },
+	{ N_MSG_OKURI_26,
+		"" },
+	{ N_MSG_OKURI_27,
+		"" },
+	{ N_MSG_OKURI_28,
+		"" },
+	{ N_MSG_OKURI_29,
+		"" },
+
+	{ N_MSG_KIN_SOKU_00,
+		")" },
+	{ N_MSG_KIN_SOKU_01,
+		"]" },
+	{ N_MSG_KIN_SOKU_02,
+		"}" },
+	{ N_MSG_KIN_SOKU_03,
+		"" },
+	{ N_MSG_KIN_SOKU_04,
+		"" },
+	{ N_MSG_KIN_SOKU_05,
+		"," },
+	{ N_MSG_KIN_SOKU_06,
+		"." },
+	{ N_MSG_KIN_SOKU_07,
+		"" },
+	{ N_MSG_KIN_SOKU_08,
+		"" },
+	{ N_MSG_KIN_SOKU_09,
+		"" },
+	{ N_MSG_KIN_SOKU_10,
+		"" },
+	{ N_MSG_KIN_SOKU_11,
+		"" },
+	{ N_MSG_KIN_SOKU_12,
+		"" },
+	{ N_MSG_KIN_SOKU_13,
+		"" },
+	{ N_MSG_KIN_SOKU_14,
+		"" },
+	{ N_MSG_KIN_SOKU_15,
+		"" },
+	{ N_MSG_KIN_SOKU_16,
+		"" },
+	{ N_MSG_KIN_SOKU_17,
+		"" },
+	{ N_MSG_KIN_SOKU_18,
+		"" },
+	{ N_MSG_KIN_SOKU_19,
+		"" },
+	{ N_MSG_KIN_SOKU_20,
+		"" },
+	{ N_MSG_KIN_SOKU_21,
+		"" },
+	{ N_MSG_KIN_SOKU_22,
+		"" },
+	{ N_MSG_KIN_SOKU_23,
+		"" },
+	{ N_MSG_KIN_SOKU_24,
+		"" },
+	{ N_MSG_KIN_SOKU_25,
+		"" },
+	{ N_MSG_KIN_SOKU_26,
+		"" },
+	{ N_MSG_KIN_SOKU_27,
+		"" },
+	{ N_MSG_KIN_SOKU_28,
+		"" },
+	{ N_MSG_KIN_SOKU_29,
+		"" },
+
+	{ N_MSG_WORDS_BEGIN,
+		"\"" },
+	{ N_MSG_WORDS_END,
+		"\"" },
+	{ N_MSG_WORDS_NEXT,
+		"  " },
+
+	{ N_MSG_WORDS_MALE_ORDER_MILK,
+		"ߥ륯Ȥ衣ϤäϤϡ" },
+	{ N_MSG_WORDS_DISCOUNT_DAY,
+		" %s ǡäƤޤ衣" },
+
+/* words end */
+
+/* NPC name begin */
+
+	{ N_MSG_NPC_NAME_BAR,
+		"ε" },
+	{ N_MSG_NPC_NAME_INN,
+		"ɲμ" },
+
+/* NPC name end */
+
 	{ N_MSG_FMT_MSG,
 		"%-*s" },
 	{ N_MSG_FMT_WPN_IDENTIFIED,
@@ -3670,7 +4034,9 @@
 	{ N_MSG_FMT_WPN_NOT_IDENTIFIED,
 		"%2ld %s" },
 	{ N_MSG_FMT_ARMOR_IDENTIFIED,
-		"%2ld %s[%+ld,%+ld,%+ld]" },
+		"%2ld %s[%+ld,%+ld,%+ld]%s" },
+	{ N_MSG_PROTECTED_ARMOR,
+		" [ݸ]" },
 	{ N_MSG_FMT_ARMOR_NOT_IDENTIFIED,
 		"%2ld %s" },
 	{ N_MSG_FMT_POTION_IDENTIFIED,
@@ -3729,6 +4095,8 @@
 		"%2ld %s" },
 	{ N_MSG_FMT_PIPE_STUB_IDENTIFIED,
 		"%2ld %s" },
+	{ N_MSG_FMT_DISPOSAL_IDENTIFIED,
+		"%2ld cigarette disposal(%ld/%ld)" },
 	{ N_MSG_FMT_COIN_IDENTIFIED,
 		"%2ld %s" },
 	{ N_MSG_FMT_COIN_NOT_IDENTIFIED,
@@ -3770,7 +4138,9 @@
 	{ N_MSG_ERR_DOOR_BREAK_BROKEN,
 		"ɥϴ˲Ƥޤ" },
 	{ N_MSG_ERR_DOOR_BREAK_LEV,
-		"ɥޤǤ" },
+		"%s ϥɥޤǤ" },
+	{ N_MSG_ERR_DOOR_GATE,
+		"γˤϽФޤ" },
 
 	{ N_MSG_ERR_TRAP_DISARM_LEV,
 		"櫤" STR_DISARM "˼Ԥ" },
@@ -3789,9 +4159,10 @@
 
 	{ N_MSG_ERR_EQUIP_SEL_ITEM,
 		"륢ƥबĤޤǤ" },
-
 	{ N_MSG_ERR_CHK_KEY,
 		"[%c: 0x%04x]̵ʥǤ" },
+	{ N_MSG_ERR_NOT_EXIST_ALL_MBR,
+		"С1ͤ⤤ʤΤǽФޤ" },
 
 	{ N_MSG_ERR_MENU_SEL_ITEM,
 		"%s κξ֤Ǥޤ" },
@@ -3799,8 +4170,8 @@
 		"%s κξ֤Ǥޤ" },
 	{ N_MSG_ERR_MENU_MARK_BLIND,
 		"%s ܤʤΤǥޡޤ" },
-	{ N_MSG_ERR_MENU_BAR_SEL_MBR,
-		"ѡƥ˥СäƲ" },
+	{ N_MSG_ERR_MENU_NOT_EXIST_MBR,
+		"С1ͤ⤤ޤ" },
 	{ N_MSG_ERR_MENU_WANTING,
 		"%s  %ld " STR_GOLD "­ޤ" },
 	{ N_MSG_ERR_MENU_DATA_LEV_UP,
@@ -3810,8 +4181,9 @@
 		"פ 100% ˤƲ" },
 	{ N_MSG_ERR_MENU_NEW_CLASS,
 		"ʾ奯饹ޤ" },
-	{ N_MSG_ERR_REMOVE_CLASS,
-		"ʾ奯饹Ǥޤ" },
+
+	{ N_MSG_ERR_MENU_PET_SHOP_BUY,
+		"ʾڥåȤޤ" },
 
 	{ N_MSG_ERR_MENU_PAGE_OVER,
 		"˥塼Υڡ¿ޤ" },
@@ -3826,6 +4198,8 @@
 		"ʳ뤷" },
 	{ N_MSG_ERR_THROW,
 		"%s ꤲʪ̵ʤޤ" },
+	{ N_MSG_ERR_THROW_RANGE,
+		"%s ꤲʪϤȤɤʤ" },
 	{ N_MSG_ERR_MNSTR_NULL,
 		"ˤϥ󥹥Ϥޤ" },
 	{ N_MSG_ERR_NOT_FIND,
@@ -3835,11 +4209,11 @@
 	{ N_MSG_ERR_ITEM_FULL,
 		"%s ϻʪäѤǤ" },
 	{ N_MSG_ERR_ITEM_FLY,
-		"%s ⤫ǤΤ %s 򽦤ޤ" },
+		"%s ⤫ǤΤǥƥ򽦤ޤ" },
 	{ N_MSG_ERR_GIVE_MBR_ITEM,
-		"%s ϻʪäѤ %s Ƥޤ" },
+		"%s ϻʪäѤǥƥƤޤ" },
 	{ N_MSG_ERR_GIVE_MBR_CHEST,
-		"%s Ϥʾ %s ŤƻƤޤ" },
+		"%s ϽŤƤʾ奢ƥƤޤ" },
 	{ N_MSG_ERR_ITEM_BREAK_BROKEN,
 		"%s ϴ˲Ƥޤ" },
 	{ N_MSG_ERR_ITEM_BREAK_LEV,
@@ -3855,8 +4229,12 @@
 		"ؤκ̾ǡ۾Ǥ\n" },
 	{ N_MSG_ERR_AMULET_MATERIAL,
 		"κ̾ǡ۾Ǥ\n" },
+	{ N_MSG_ERR_NECKLACE_MATERIAL,
+		"κ̾ǡ۾Ǥ\n" },
 	{ N_MSG_ERR_WPN_RATE_TAB,
 		"ǡ۾Ǥ\n" },
+	{ N_MSG_ERR_MNSTR_LEV_TAB,
+		"󥹥Υ٥롦ǡ۾Ǥ\n" },
 	{ N_MSG_ERR_SET_TTY,
 		"ü꤬ޤǤ\n" },
 	{ N_MSG_ERR_HOME_DIR,
@@ -3865,6 +4243,9 @@
 	{ N_MSG_ERR_GAME_DIR_SAVE,
 		"'%s'˽񤭹ޤǤ" },
 
+	{ N_MSG_ERR_REMOVE_CLASS,
+		"ʾ奯饹ޤ" },
+
 	{ N_MSG_ERR_TOWN_MAP,
 		"ޥåסǡ۾Ǥ\n" },
 	{ N_MSG_ERR_TOWN_MAP_X_SIZE,
