@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: party.c,v 1.61 2003/11/21 18:35:21 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
 #include	"item.h"
@@ -13,6 +39,7 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+#include	"pet.h"
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 #include	"town_prot.h"
 #include	"item_prot.h"
@@ -29,11 +58,12 @@
 #include	"chr_prot.h"
 #include	"party_prot.h"
 #include	"mnstr_prot.h"
+#include	"pet_prot.h"
 #include	"fight_prot.h"
 #include	"fx_prot.h"
 #include	"trap_prot.h"
 #include	"draw_prot.h"
-/*#include	"curs_prot.h"*/
+#include	"curs_prot.h"
 #include	"menu_prot.h"
 /*#include	"tmenu_prot.h"*/
 #include	"amenu_prot.h"
@@ -49,11 +79,11 @@
 
 #define	FRIEND_MAX_TURN	(TURN_A_DAY * 1)
 
-mbr_t	*ls_mbr[LS_MBR_MAX_N + 1];
-mbr_t	ls_mbr_buf[LS_MBR_MAX_N + 1];
-party_t	party;
+static mbr_t	*ls_mbr[LS_MBR_MAX_N + 1];
+static mbr_t	ls_mbr_buf[LS_MBR_MAX_N + 1];
+static party_t	party;
 
-long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
+static long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 
 	/* HP  MP  DEX STR */
 	/* QUI WIS INT CHA */
@@ -97,106 +127,37 @@ long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 	   0,  0,  0,  0, },
 };
 
-rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
-	/* KNOC,SLAS,STIN,HEAT,COLD,WIND,ACID,ELEC,POIS, */
+static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
+	/* KNOC,SLAS,STIN,HEAT,COLD,ACID,WIND,ELEC,POIS, */
 /* MAIN_RACE_HUMAN */
 	{   100, 100, 100, 100, 100, 100, 100, 100, 100 },
 /* MAIN_RACE_HALF_ELF */
 	{    90,  90,  90, 100, 100, 100, 100, 100, 100 },
 /* MAIN_RACE_ELF */
-	{    80,  80,  80, 100, 100, 150, 100, 100, 100 },
+	{    80,  80,  80, 100, 100, 100, 150, 100, 100 },
 /* MAIN_RACE_DWARF */
 	{   150, 150, 150, 100, 100, 100, 100, 100, 200 },
 /* MAIN_RACE_VIVID */
-	{    70,  70,  70, 100, 100, 200, 100, 100, 100 },
+	{    70,  70,  70, 100, 100, 100, 200, 100, 100 },
 };
 
-stomach_t	ave_stomach[MAIN_RACE_MAX_N] = {
+static stomach_t	ave_stomach[MAIN_RACE_MAX_N] = {
 #if	0
 typedef struct {
 	rate_t	rate;
 	rate_t	full_rate;
 	long	digest_p_day;
+	rate_t	digest_rate;
 	rate_t	hungry_rate, starvation_rate;
 } stomach_t;
 #endif
-	{ 100, 100, 20, 70, 30 },	/* MAIN_RACE_HUMAN, */
-	{ 100,  80, 15, 70, 30 },	/* MAIN_RACE_HALF_ELF, */
-	{ 100,  50, 10, 70, 30 },	/* MAIN_RACE_ELF, */
-	{ 100, 200, 25, 70, 30 },	/* MAIN_RACE_DWARF, */
-	{ 100, 180, 25, 70, 30 },	/* MAIN_RACE_VIVID, */
+	{ 100, 100, 20, 0, 70, 30 },	/* MAIN_RACE_HUMAN, */
+	{ 100,  80, 15, 0, 70, 30 },	/* MAIN_RACE_HALF_ELF, */
+	{ 100,  50, 10, 0, 70, 30 },	/* MAIN_RACE_ELF, */
+	{ 100, 200, 25, 0, 70, 30 },	/* MAIN_RACE_DWARF, */
+	{ 100, 180, 25, 0, 70, 30 },	/* MAIN_RACE_VIVID, */
 };
 
-/* auto mark */
-
-char	msg_ttl_auto_mark[AUTO_MARK_MAX_N][MSG_TTL_AUTO_MARK_MAX_LEN + 1];
-
-auto_mark_t	dflt_auto_mark_fight = {
-	AUTO_MARK_TRGT_MNSTR,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_FIGHT,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_throw = {
-	AUTO_MARK_TRGT_MNSTR,
-	AUTO_MARK_DIST_MEDIUM,
-	AUTO_MARK_ACT_THROW,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_fight_far = {
-	AUTO_MARK_TRGT_MNSTR,
-	AUTO_MARK_DIST_FAR,
-	AUTO_MARK_ACT_FIGHT,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_fight_all = {
-	AUTO_MARK_TRGT_MNSTR,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_FIGHT,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_item_all = {
-	AUTO_MARK_TRGT_ITEM,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_PICK_UP,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_item_own = {
-	AUTO_MARK_TRGT_ITEM,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_PICK_UP,
-	AUTO_MARK_COND_OWN,
-	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
-};
-
-auto_mark_t	dflt_auto_mark_unchange = {
-	AUTO_MARK_TRGT_UNCHANGE,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_FIGHT,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY,
-};
-
-auto_mark_t	dflt_auto_mark_clear = {
-	AUTO_MARK_TRGT_CLEAR,
-	AUTO_MARK_DIST_NEAR,
-	AUTO_MARK_ACT_FIGHT,
-	AUTO_MARK_COND_DISPERSE,
-	FLG_AUTO_MARK_EDIT_PRIORITY,
-};
-
-/**/
-
 /* class */
 
 #include	"class_tab.h"
@@ -265,7 +226,7 @@ void	init_party( void )
 	race.sub = SUB_RACE_NULL;
 	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
-			MALE, CLASS_N_FIGHTER, 0 );
+			MALE, CLASS_N_NINJA, 0 );
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
@@ -288,7 +249,7 @@ void	init_party( void )
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
 	strncpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
-	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'F', race,
+	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
 
 	race.main = MAIN_RACE_ELF;
@@ -303,9 +264,8 @@ void	init_party( void )
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
 
-	/**/
-
-	init_party_auto_mark();
+	for( i = 0; i < MBR_MAX_N; i++ )
+		join_mbr( i, i );
 }
 
 /**/
@@ -317,8 +277,8 @@ void	init_party_debug( void )
 	item_kind_dat_t	sub_kind;
 
 	for( i = 0; i < 7; i++ ){
-		ls_mbr[i]->max_dun_lev_floor = 0;
-		ls_mbr[i]->max_dun_lev_base = 128;
+		ls_mbr[i]->dun_max_lev_floor = 0;
+		ls_mbr[i]->dun_max_lev_base = 128;
 	}
 
 	/* item */
@@ -558,11 +518,6 @@ void	init_party_debug( void )
 	i = 0;
 	ls_mbr[i]->nicotine.poisoning_rate = _100_PERCENT;
 #endif
-
-	/**/
-
-	for( i = 0; i < MBR_MAX_N; i++ )
-		join_mbr( i, i );
 }
 
 /**/
@@ -572,17 +527,13 @@ item_t	*init_mbr_item(
 	bool_t flg_ident, bool_t curse, bool_t flg_eq
 )
 {
-	item_t	*item, dmy;
+	item_t	*item;
 	long	tab_n;
 	long	lev;
 
 	if( mbr == NULL )
 		return NULL;
 
-	item = alloc_item( &dmy );
-	if( item == NULL )
-		return NULL;
-
 	lev = -10;
 
 	switch( kind ){
@@ -605,6 +556,7 @@ item_t	*init_mbr_item(
 		break;
 	case ITEM_KIND_SPIKE:
 	case ITEM_KIND_CHEST:
+	case ITEM_KIND_DISPOSAL:
 	case ITEM_KIND_JUNK:
 		break;
 	}
@@ -662,6 +614,8 @@ item_t	*init_mbr_item(
 		tab_n = get_pipe_tab_n( get_pipe_tab(
 				sub_kind->pipe ) );
 		break;
+	case ITEM_KIND_DISPOSAL:
+		break;
 	case ITEM_KIND_COIN:
 		tab_n = get_coin_tab_n( get_coin_tab(
 				sub_kind->coin ) );
@@ -672,60 +626,72 @@ item_t	*init_mbr_item(
 	if( tab_n < 0 )
 		return NULL;
 
+	item = NULL;
+
 	switch( kind ){
 	case ITEM_KIND_NULL:
 	case ITEM_KIND_MAX_N:
 		return NULL;
 	case ITEM_KIND_WPN:
-		make_item_wpn( lev, item, tab_n, curse );
+		item = make_item_wpn( lev, tab_n, curse );
 		break;
 	case ITEM_KIND_ARMOR:
-		make_item_armor( lev, item, tab_n, curse );
+		item = make_item_armor( lev, tab_n, curse );
 		break;
 	case ITEM_KIND_POTION:
-		make_item_potion( lev, item, tab_n );
+		item = make_item_potion( lev, tab_n );
 		break;
 	case ITEM_KIND_SCROLL:
-		make_item_scroll( lev, item, tab_n );
+		item = make_item_scroll( lev, tab_n );
 		break;
 	case ITEM_KIND_STICK:
-		make_item_stick( lev, item, tab_n );
+		item = make_item_stick( lev, tab_n );
 		break;
 	case ITEM_KIND_ACCE:
-		make_item_acce( lev, item, tab_n );
+		item = make_item_acce( lev, tab_n );
 		break;
 	case ITEM_KIND_LIGHT:
-		make_item_light( lev, item, tab_n );
+		item = make_item_light( lev, tab_n );
 		break;
 	case ITEM_KIND_SPIKE:
-		make_item_spike( lev, item );
+		item = make_item_spike( lev );
 		break;
 	case ITEM_KIND_FOOD:
-		make_item_food( lev, item, tab_n );
+		item = make_item_food( lev, tab_n );
 		break;
 	case ITEM_KIND_CHEST:
-		make_item_chest( lev, item, 4 );
+		item = make_item_chest( lev, 4 );
 		break;
 	case ITEM_KIND_TOBACCO:
-		make_item_tobacco( lev, item, tab_n );
+		item = make_item_tobacco( lev, tab_n );
 		break;
 	case ITEM_KIND_PIPE:
-		make_item_pipe( lev, item, tab_n );
+		item = make_item_pipe( lev, tab_n );
+		break;
+	case ITEM_KIND_DISPOSAL:
+		item = make_item_disposal( lev );
 		break;
 	case ITEM_KIND_COIN:
-		make_item_coin( lev, item, tab_n );
+		item = make_item_coin( lev, tab_n );
 		break;
 	case ITEM_KIND_JUNK:
-		item->kind = ITEM_KIND_JUNK;
+		item = make_item_junk( lev );
 		break;
 	}
 
+	if( item == NULL )
+		return NULL;
+
 	item->flg |= FLG_ITEM_DETECTED;
 	if( flg_ident )
 		item->flg |= FLG_ITEM_IDENTIFIED;
 	set_item_name( item );
 
-	give_mbr_item( mbr, item );
+	if( !give_mbr_item( mbr, item, FALSE ) ){
+		del_item( item );
+		return NULL;
+	}
+
 	if( flg_eq )
 		equip_item_sel( mbr, item );
 
@@ -734,70 +700,9 @@ item_t	*init_mbr_item(
 
 /**/
 
-void	init_party_auto_mark( void )
-{	long	i, j;
-
-	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		j = 0;
-		switch( i ){
-		default:
-		case 0:
-		case 1:
-		case 3:
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_fight;
-			break;
-		case 2:
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_throw;
-			break;
-		case 4:
-		case 5:
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_fight_far;
-			break;
-		}
-		strncpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_FIGHT,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
-		j++;
-		if( j < AUTO_MARK_MAX_N ){
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_fight_all;
-			strncpy( msg_ttl_auto_mark[j],
-					MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-					MSG_TTL_AUTO_MARK_MAX_LEN );
-		}
-		j++;
-		if( j < AUTO_MARK_MAX_N ){
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_item_all;
-			strncpy( msg_ttl_auto_mark[j],
-					MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
-					MSG_TTL_AUTO_MARK_MAX_LEN );
-		}
-		j++;
-		if( j < AUTO_MARK_MAX_N ){
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_item_own;
-			strncpy( msg_ttl_auto_mark[j],
-					MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
-					MSG_TTL_AUTO_MARK_MAX_LEN );
-		}
-		j++;
-		for( ; j < AUTO_MARK_MAX_N; j++ ){
-			ls_mbr[i]->auto_mark[j] = dflt_auto_mark_clear;
-			strncpy( msg_ttl_auto_mark[j],
-					MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-					MSG_TTL_AUTO_MARK_MAX_LEN );
-		}
-		j = AUTO_MARK_MAX_N - 1;
-		ls_mbr[i]->auto_mark[j] = dflt_auto_mark_clear;
-		strncpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
-	}
-}
-
-/**/
-
 void	new_mbr_reset( mbr_t *mbr )
 {
-	new_mbr( mbr, mbr->name, mbr->face_mnr, mbr->race, mbr->sex,
+	new_mbr( mbr, mbr->name, mbr->face.mnr, mbr->race, mbr->sex.cur,
 			mbr->class_n, mbr->ls_mbr_n );
 }
 
@@ -811,64 +716,73 @@ void	new_mbr(
 	long	lev;
 	long	i;
 
+	reset_modifier( &(mbr->modifier_equip) );
+	reset_modifier( &(mbr->modifier_fx) );
+
 	mbr->prev = NULL;
 	mbr->next = NULL;
 	mbr->kind = CHR_KIND_MBR;
 	strncpy( mbr->name, name, MBR_NAME_MAX_LEN );
 	mbr->mbr_n = MBR_N_NOT_JOIN;
 	mbr->ls_mbr_n = ls_mbr_n;
-	mbr->face_mjr = FACE_MJR_MBR;
-	mbr->face_mnr = face;
+	mbr->face.mjr = FACE_MJR_MBR;
+	mbr->face.mnr = face;
+	mbr->face.mjr_org = FACE_MJR_MBR;
+	mbr->face.mnr_org = face;
 	mbr->race = race;
-	mbr->sex = sex;
-	mbr->x = -1;
-	mbr->y = -1;
-	mbr->pre_x = -1;
-	mbr->pre_y = -1;
-	mbr->move_rate = _100_PERCENT;
+	mbr->sex.cur = sex;
+	mbr->sex.org = sex;
+	mbr->x = MAP_DEL_X;
+	mbr->y = MAP_DEL_Y;
+	mbr->pre_x = MAP_DEL_X;
+	mbr->pre_y = MAP_DEL_Y;
+
+	mbr->move.speed.rate = _100_PERCENT;
+	mbr->move.speed.rate_org = _100_PERCENT;
+	mbr->move.speed.n = 0;
+	mbr->move.force_kind = MOVE_KIND_NULL;
+	for( i = 0; i < MOVE_LS_KIND_MAX_N; i++ ){
+		long	j;
+
+		j = 0;
+		mbr->move.ls[i][j].kind = MOVE_KIND_STD;
+		mbr->move.ls[i][j].ratio = 10;
+		j++;
+		mbr->move.ls[i][j].kind = MOVE_KIND_NULL;
+		mbr->move.ls[i][j].ratio = 0;
+		j++;
+	}
+
 	mbr->gold = DFLT_GOLD;
-	mbr->max_dun_lev_floor = 0;
-	mbr->max_dun_lev_base = 0;
+	mbr->dun_max_lev_floor = 0;
+	mbr->dun_max_lev_base = 0;
 
 	mbr->trgt.dist = DIST_NEAR;
 	mbr->trgt.dflt_dist_mnstr = DIST_NEAR;
-	mbr->act.dflt_kind_mnstr
-			= ACT_KIND_MNSTR_FIGHT;
+	mbr->act.dflt_kind_mnstr = ACT_KIND_MNSTR_FIGHT;
 	strncpy( mbr->act.dflt_msg_mnstr,
 			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
 	clr_chr_trgt_act( mbr, TRUE );
 
-	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
-		mbr->auto_mark[i] = dflt_auto_mark_clear;
-		strncpy( msg_ttl_auto_mark[i],
-				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
-	}
-
-	mbr->flg_chr = FLG_NULL;
-	mbr->flg_chr |= FLG_CHR_AUTO_DOOR;
-	mbr->flg_chr |= FLG_CHR_AVOID_TRAP;
-	mbr->flg_map = FLG_NULL;
-
+	mbr->flg_chr = (FLG_CHR_AUTO_DOOR | FLG_CHR_AVOID_TRAP);
+	mbr->flg_map = FLG_MAP_CHR_FIND;
+	mbr->attitude = ATTITUDE_MATE;
+	mbr->owner = NULL;
 	mbr->stat = FLG_NULL;
 
 	for( i = 0; i < ABL_KIND_MAX_N; i++ ){
-		mbr->abl.lev[i].max = abl_init[mbr->race.main][i];
-
-		lev = mbr->abl.lev[i].max;
+		lev = abl_init[mbr->race.main][i];
 
+		mbr->abl.lev[i].max = lev;
 		mbr->abl.exp[i].max = calc_lev_to_exp( lev, i );
 
-		mbr->abl.exp[i].n = mbr->abl.exp[i].max;
 		mbr->abl.lev[i].n = mbr->abl.lev[i].max;
+		mbr->abl.lev[i].add = 0;
+		mbr->abl.exp[i].n = mbr->abl.exp[i].max;
 	}
-
-	lev = mbr->abl.lev[ABL_KIND_HP].max;
-	mbr->abl.hp.max = calc_lev_to_val( lev, ABL_KIND_HP );
+	mbr->abl.hp.max = calc_max_hp( mbr );
+	mbr->abl.mp.max = calc_max_mp( mbr );
 	mbr->abl.hp.n = mbr->abl.hp.max;
-
-	lev = mbr->abl.lev[ABL_KIND_MP].max;
-	mbr->abl.mp.max = calc_lev_to_val( lev, ABL_KIND_MP );
 	mbr->abl.mp.n = mbr->abl.mp.max;
 
 	mbr->class_n = class_n;
@@ -876,12 +790,19 @@ void	new_mbr(
 	for( i = 0; i < RESI_KIND_MAX_N; i++ ){
 		mbr->resi[i].n = resi_init[mbr->race.main][i];
 		mbr->resi[i].max = resi_init[mbr->race.main][i];
+		mbr->resi[i].add_n = 0;
 	}
-	mbr->ac = 0;
+	mbr->add_def = 0;
+	mbr->add_crtcl = 0;
+	mbr->add_ac = 0;
 
 	mbr->fx.next = &(mbr->fx);
 	mbr->fx.prev = &(mbr->fx);
 
+	mbr->fx_data.armor_def = 0;
+	mbr->fx_data.armor_crtcl = 0;
+	mbr->fx_data.armor_ac = 0;
+
 	mbr->fx_data.infra_vision = 0;
 
 	mbr->fx_data.stomach.rate = _100_PERCENT;
@@ -889,6 +810,8 @@ void	new_mbr(
 			= ave_stomach[race.main].full_rate;
 	mbr->fx_data.stomach.digest_p_day
 			= ave_stomach[race.main].digest_p_day;
+	mbr->fx_data.stomach.digest_n
+			= ave_stomach[race.main].digest_n;
 	mbr->fx_data.stomach.hungry_rate
 			= ave_stomach[race.main].hungry_rate;
 	mbr->fx_data.stomach.starvation_rate
@@ -901,14 +824,23 @@ void	new_mbr(
 
 	mbr->fx_data.friend_turn = FRIEND_MAX_TURN;
 
+	mbr->fx_data.bless = 0;
+
 	mbr->mnstr_kind = MNSTR_KIND_NULL;
 	mbr->mnstr_tab = NULL;
 
+	mbr->work.flg = FLG_NULL;
 	mbr->work.caught = 0;
+	mbr->work.catch_chr = NULL;
+	mbr->work.towner_dx = 0;
+	mbr->work.towner_dy = 0;
+	mbr->work.enter_door = NULL;
 
 	/**/
 
-	exp_chr( mbr, DFLT_EXP, FALSE );
+	init_auto_mark_mbr( mbr->ls_mbr_n );
+
+	exp_chr( mbr, DFLT_EXP, FALSE, FALSE );
 }
 
 /**/
@@ -1013,7 +945,19 @@ void	appear_party( bool_t flg_clr_map )
 			break;	/* ư褿 */
 	}
 
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		if( chk_flg_or( party.mbr[n]->stat,
+				FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD ) ){
+			continue;
+		}
+
+		find_obj( party.mbr[n]->x, party.mbr[n]->y );
+	}
+
 	set_map_all_mbr();
+
+	appear_all_pet( flg_clr_map );
 }
 
 /**/
@@ -1038,12 +982,36 @@ void	set_map_all_mbr( void )
 
 /**/
 
+void	move_all_mbr_trgt( void )
+{
+	party_t	*pty = get_party();
+	long	i;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg_or( pty->mbr[i]->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			continue;
+		}
+
+		move_chr_trgt( pty->mbr[i] );
+	}
+}
+
+/**/
+
 void	act_party( void )
 {
 	long	i;
 
-	for( i = 0; i < MBR_MAX_N; i++ )
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		if( chk_flg_or( party.mbr[i]->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			continue;
+		}
+
 		act_chr( party.mbr[i] );
+		set_modifier( party.mbr[i] );
+	}
 
 	switch( party.act.kind ){
 	default:
@@ -1073,13 +1041,13 @@ bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
 
 	if( dun->map.chr.mjr[y1][x1] != FACE_MJR_NULL ){
 		if( dun->map.chr.mjr[y1][x1] != FACE_MJR_MBR ){
-			act_chr_auto_mnstr( mbr, x1, y1 );
+			set_mbr_act_auto_mnstr( mbr, x1, y1 );
 			return TRUE;
 		}
 	}
 	if( dun->map.chr.mjr[y2][x2] != FACE_MJR_NULL ){
 		if( dun->map.chr.mjr[y2][x2] != FACE_MJR_MBR ){
-			act_chr_auto_mnstr( mbr, x2, y2 );
+			set_mbr_act_auto_mnstr( mbr, x2, y2 );
 			return TRUE;
 		}
 	}
@@ -1117,8 +1085,12 @@ void	die_mbr( mbr_t *mbr )
 {
 	long	i;
 
-	print_msg_n( CURS_ATTR_N_FX_MBR_CRTCL, FLG_NULL,
-			MSG_MBR_DIE, mbr->name );
+	if( mbr == NULL )
+		return;
+
+	curs_attrset_n( CURS_ATTR_N_FX_MBR_CRTCL );
+	print_msg( FLG_NULL, MSG_MBR_DIE, mbr->name );
+	curs_attrset_dflt();
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		if( chk_flg_or( party.mbr[i]->stat,
@@ -1142,7 +1114,21 @@ void	die_mbr( mbr_t *mbr )
 
 /**/
 
-void	act_mbr_auto_mnstr( mbr_t *mbr, long x, long y )
+bool_t	chk_can_act_mbr( mbr_t *p )
+{
+	if( chk_flg_or( p->stat,
+			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD
+			| FLG_STAT_STONE | FLG_STAT_PARALYZE
+			| FLG_STAT_SLEEP | FLG_STAT_FAINT ) ){
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/**/
+
+void	set_mbr_act_auto_mnstr( mbr_t *mbr, long x, long y )
 {
 	mnstr_t	*mnstr;
 
@@ -1178,7 +1164,7 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 
 			x = dun->door[dr_n].x + dx;
 			y = dun->door[dr_n].y + dy;
-			dun->map.obj.flg[y][x] |= FLG_OBJ_PASS;
+			dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
 		}
 	}
 
@@ -1197,7 +1183,7 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 
 			x = dun->door[dr_n].x + dx;
 			y = dun->door[dr_n].y + dy;
-			dun->map.obj.flg[y][x] &= ~FLG_OBJ_PASS;
+			dun->map.obj.flg[y][x] &= ~FLG_MAP_OBJ_PASS;
 		}
 	}
 
@@ -1270,55 +1256,42 @@ void	mbr_srch_item( mbr_t *mbr, item_t *item )
 
 void	mbr_srch_obj( mbr_t *mbr )
 {
+	party_t	*pty = get_party();
 	long	dx, dy;
 	long	x, y;
-	char	mjr, mnr;
-	flg_map_t	flg;
-	door_t	*dr;
-	dun_t	*dun;
 	bool_t	flg_find;
-	party_t	*pty;
 
 	if( mbr == NULL )
 		return;
 
 	flg_find = FALSE;
 
-	dun = get_dun();
 	x = mbr->x;
 	y = mbr->y;
 	for( dy = -1; dy <= +1; dy++ ){
 		if( !clip_y( y + dy ) )
 			continue;
-
 		for( dx = -1; dx <= +1; dx++ ){
 			if( !clip_x( x + dx ) )
 				continue;
 
-			flg = dun->map.obj.flg[y + dy][x + dx];
-			mjr = dun->map.obj.mjr[y + dy][x + dx];
-			mnr = dun->map.obj.mnr[y + dy][x + dx];
-
-			if( (mjr == FACE_MJR_DOOR_CLOSE)
-					|| (mjr == FACE_MJR_DOOR_OPEN) ){
-				dr = get_door( x + dx, y + dy );
-				if( chk_flg( dr->flg, FLG_DOOR_SECRET ) ){
-					flg_find = TRUE;
-					print_msg( FLG_NULL,
-							MSG_DOOR_SRCH );
-				}
-				srch_door( dr->n );
-			}
+			if( mbr_srch_obj_sub( mbr, x + dx, y + dy ) )
+				flg_find = TRUE;
 		}
 	}
 
-	pty = get_party();
 	if( flg_find && chk_flg( pty->flg, FLG_PARTY_SRCH_AUTO_OFF ) ){
-		long	n;
+		long	i;
 
-		for( n = 0; n < MBR_MAX_N; n++ ){
-			if( pty->mbr[n]->act.kind == ACT_KIND_SRCH ){
-				clr_chr_trgt_act( pty->mbr[n], FALSE );
+		for( i = 0; i < MBR_MAX_N; i++ ){
+			if( chk_flg_or( pty->mbr[i]->stat,
+					FLG_STAT_NOT_EXIST
+					| FLG_STAT_DEAD ) ){
+				continue;
+			}
+
+			if( pty->mbr[i]->act.kind == ACT_KIND_SRCH ){
+				clr_chr_trgt_act( pty->mbr[i], FALSE );
 			}
 		}
 	}
@@ -1326,6 +1299,51 @@ void	mbr_srch_obj( mbr_t *mbr )
 
 /**/
 
+bool_t	mbr_srch_obj_sub( mbr_t *mbr, long x, long y )
+{
+	dun_t	*dun = get_dun();
+	bool_t	flg_find;
+	char	mjr, mnr;
+	flg_map_t	flg;
+
+	flg_find = FALSE;
+
+	mjr = dun->map.obj.mjr[y][x];
+	mnr = dun->map.obj.mnr[y][x];
+	flg = dun->map.obj.flg[y][x];
+
+	if( (mjr == FACE_MJR_DOOR_CLOSE) || (mjr == FACE_MJR_DOOR_OPEN) ){
+		door_t	*dr;
+
+		dr = get_door( x, y );
+		if( dr != NULL ){
+			if( chk_flg( dr->flg, FLG_DOOR_SECRET ) ){
+				flg_find = TRUE;
+				print_msg( FLG_NULL, MSG_DOOR_SRCH,
+						mbr->name );
+			}
+			srch_door( dr->n );
+		}
+	}
+	if( mjr == FACE_MJR_TRAP ){
+		trap_t	*trap;
+
+		trap = get_trap( x, y );
+		if( trap != NULL ){
+			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) ){
+				flg_find = TRUE;
+				print_msg( FLG_NULL, MSG_TRAP_SRCH,
+						mbr->name );
+			}
+			find_trap( trap );
+		}
+	}
+
+	return flg_find;
+}
+
+/**/
+
 void	clr_party_act( void )
 {
 	party.act.kind = ACT_KIND_NULL;
@@ -1357,7 +1375,7 @@ void	not_join_mbr( long ls_mbr_n, long mbr_n )
 
 void	collect_gold( mbr_t *mbr )
 {
-	long	gold;
+	gold_t	gold;
 	long	i;
 
 	if( mbr == NULL )
@@ -1437,22 +1455,33 @@ void	divide_gold( void )
 void	exp_party( long exp, bool_t flg_draw )
 {
 	party_t	*pty = get_party();
+	pet_t	**pet = get_party_pet();
 	long	i, n, mod_n;
 	flg_stat_t	flg;
 	long	exp_add, exp_mod;
 
 	flg = FLG_NULL;
 	flg |= FLG_STAT_NOT_EXIST | FLG_STAT_DEAD | FLG_STAT_STONE;
-	flg |= FLG_STAT_SLEEP | FLG_STAT_FAINT;
 
 	n = 0;
 	mod_n = 0;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( !chk_flg_or( party.mbr[i]->stat, flg ) ){
-			n++;
-			if( randm( n ) == 0 )
-				mod_n = i;
-		}
+		if( chk_flg_or( party.mbr[i]->stat, flg ) )
+			continue;
+
+		n++;
+		if( randm( n ) == 0 )
+			mod_n = i;
+	}
+	for( i = 0; i < PET_MAX_N; i++ ){
+		if( pet[i] == NULL )
+			continue;
+		if( chk_flg_or( pet[i]->stat, flg ) )
+			continue;
+
+		n++;
+		if( randm( n ) == 0 )
+			mod_n = MBR_MAX_N + i;
 	}
 	if( n <= 0 )
 		return;
@@ -1461,18 +1490,36 @@ void	exp_party( long exp, bool_t flg_draw )
 	exp_mod = exp % n;
 
 	if( flg_draw ){
-		print_msg_n( CURS_ATTR_N_FX_MBR_PLUS, FLG_NULL,
-				MSG_EXP_PARTY, exp_add );
+		curs_attrset_n( CURS_ATTR_N_FX_MBR_PLUS );
+		print_msg( FLG_NULL, MSG_EXP_PARTY, exp_add );
+		curs_attrset_dflt();
 	}
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		if( chk_flg_or( party.mbr[i]->stat, flg ) )
 			continue;
 
-		if( i == mod_n )
-			exp_chr( pty->mbr[i], exp_add + exp_mod, FALSE );
-		else
-			exp_chr( pty->mbr[i], exp_add, FALSE );
+		if( mod_n == i ){
+			exp_chr( pty->mbr[i], exp_add + exp_mod,
+					FALSE, TRUE );
+		} else {
+			exp_chr( pty->mbr[i], exp_add,
+					FALSE, TRUE );
+		}
+	}
+	for( i = 0; i < PET_MAX_N; i++ ){
+		if( pet[i] == NULL )
+			continue;
+		if( chk_flg_or( pet[i]->stat, flg ) )
+			continue;
+
+		if( mod_n == MBR_MAX_N + i ){
+			exp_chr( pet[i], exp_add + exp_mod,
+					FALSE, TRUE );
+		} else {
+			exp_chr( pet[i], exp_add,
+					FALSE, TRUE );
+		}
 	}
 }
 
@@ -1821,74 +1868,16 @@ char	*get_race_str( race_t *race )
 	static char	str_tmp[RACE_STR_MAX_LEN * 3 + 1];
 	static char	str_name[RACE_STR_MAX_LEN + 1];
 
+	if( race == NULL )
+		return MSG_NULL;
+
 	str_main[0] = '\0';
 	str_sub[0] = '\0';
 	str_tmp[0] = '\0';
 	str_name[0] = '\0';
 
-	switch( race->main ){
-	case MAIN_RACE_HUMAN:
-		strncpy( str_main, MSG_MAIN_RACE_HUMAN,
-				RACE_STR_MAX_LEN );
-		break;
-	case MAIN_RACE_HALF_ELF:
-		strncpy( str_main, MSG_MAIN_RACE_HALF_ELF,
-				RACE_STR_MAX_LEN );
-		break;
-	case MAIN_RACE_ELF:
-		strncpy( str_main, MSG_MAIN_RACE_ELF,
-				RACE_STR_MAX_LEN );
-		break;
-	case MAIN_RACE_DWARF:
-		strncpy( str_main, MSG_MAIN_RACE_DWARF,
-				RACE_STR_MAX_LEN );
-		break;
-	case MAIN_RACE_VIVID:
-		strncpy( str_main, MSG_MAIN_RACE_VIVID,
-				RACE_STR_MAX_LEN );
-		break;
-	case MAIN_RACE_MAX_N:
-		break;
-	}
-
-	switch( race->sub ){
-	case SUB_RACE_NULL:
-		break;
-	case SUB_RACE_CAT:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_CAT,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_DOG:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_DOG,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_MOUSE:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_MOUSE,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_RABBIT:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_RABBIT,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_MONKEY:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_MONKEY,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_PIG:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_PIG,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_BIRD:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_BIRD,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_LIZARD:
-		str_max_n_cat( str_sub, MSG_SUB_RACE_LIZARD,
-				RACE_STR_MAX_LEN );
-		break;
-	case SUB_RACE_MAX_N:
-		break;
-	}
+	strncpy( str_main, get_race_str_main( race ), RACE_STR_MAX_LEN );
+	strncpy( str_sub, get_race_str_sub( race ), RACE_STR_MAX_LEN );
 
 	if( race->sub == SUB_RACE_NULL )
 		sprintf( str_tmp, MSG_RACE_STR_PUREBRED, str_main );
@@ -1902,11 +1891,71 @@ char	*get_race_str( race_t *race )
 
 /**/
 
+char	*get_race_str_main( race_t *race )
+{
+	if( race == NULL )
+		return MSG_NULL;
+
+	switch( race->main ){
+	case MAIN_RACE_HUMAN:
+		return MSG_MAIN_RACE_HUMAN;
+	case MAIN_RACE_HALF_ELF:
+		return MSG_MAIN_RACE_HALF_ELF;
+	case MAIN_RACE_ELF:
+		return MSG_MAIN_RACE_ELF;
+	case MAIN_RACE_DWARF:
+		return MSG_MAIN_RACE_DWARF;
+	case MAIN_RACE_VIVID:
+		return MSG_MAIN_RACE_VIVID;
+	case MAIN_RACE_MAX_N:
+		break;
+	}
+
+	return MSG_NULL;
+}
+
+/**/
+
+char	*get_race_str_sub( race_t *race )
+{
+	if( race == NULL )
+		return MSG_NULL;
+
+	switch( race->sub ){
+	case SUB_RACE_NULL:
+		break;
+	case SUB_RACE_CAT:
+		return MSG_SUB_RACE_CAT;
+	case SUB_RACE_DOG:
+		return MSG_SUB_RACE_DOG;
+	case SUB_RACE_MOUSE:
+		return MSG_SUB_RACE_MOUSE;
+	case SUB_RACE_RABBIT:
+		return MSG_SUB_RACE_RABBIT;
+	case SUB_RACE_MONKEY:
+		return MSG_SUB_RACE_MONKEY;
+	case SUB_RACE_PIG:
+		return MSG_SUB_RACE_PIG;
+	case SUB_RACE_BIRD:
+		return MSG_SUB_RACE_BIRD;
+	case SUB_RACE_LIZARD:
+		return MSG_SUB_RACE_LIZARD;
+	case SUB_RACE_MAX_N:
+		break;
+	}
+
+	return MSG_NULL;
+}
+
+/**/
+
 char	*get_race_name( race_t *race )
 {
 	if( race == NULL )
 		return "";
 
+#if	0
+/*@@@*/
 	if( race->sub == SUB_RACE_NULL ){
 		switch( race->main ){
 		case MAIN_RACE_HUMAN:
@@ -1923,6 +1972,7 @@ char	*get_race_name( race_t *race )
 			break;
 		}
 	}
+#endif
 
 	return race->name;
 }
@@ -1937,15 +1987,12 @@ long	add_hp_mbr( mbr_t *mbr, long n )
 		return 0;
 
 	pre_hp = mbr->abl.hp.n;
-	if( (mbr->abl.hp.n <= 1) && (n <= -1) ){
+
+	mbr->abl.hp.n += n;
+	if( mbr->abl.hp.n > mbr->abl.hp.max )
+		mbr->abl.hp.n = mbr->abl.hp.max;
+	if( mbr->abl.hp.n < 0 )
 		mbr->abl.hp.n = 0;
-	} else {
-		mbr->abl.hp.n += n;
-		if( mbr->abl.hp.n > mbr->abl.hp.max )
-			mbr->abl.hp.n = mbr->abl.hp.max;
-		if( mbr->abl.hp.n < 1 )
-			mbr->abl.hp.n = 1;
-	}
 
 	add = mbr->abl.hp.n - pre_hp;
 	if( add != 0 ){
@@ -1961,6 +2008,19 @@ long	add_hp_mbr( mbr_t *mbr, long n )
 
 /**/
 
+bool_t	chk_not_exist_all_mbr( void )
+{
+	long	i;
+
+	for( i = 0; i < MBR_MAX_N; i++ )
+		if( !chk_flg_or( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
 mbr_t	**get_ls_mbr( void )
 {
 	return ls_mbr;
@@ -2070,12 +2130,10 @@ class_t	*get_class_tab( void )
 bool_t	remove_class( long class_n )
 {
 	mbr_t	**ls_mbr = get_ls_mbr();
-	class_t	*p;
+	class_t	*p = get_class_tab();
 	long	n, max_n;
 	long	i;
 
-	p = get_class_tab();
-
 	if( p[1].name[0] == '\0' ){
 		print_msg( FLG_NULL, MSG_S, MSG_ERR_REMOVE_CLASS );
 		return FALSE;
@@ -2091,7 +2149,7 @@ bool_t	remove_class( long class_n )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		if( ls_mbr[i]->class_n > class_n )
 			ls_mbr[i]->class_n--;
-		if( ls_mbr[i]->class_n > max_n )
+		else if( ls_mbr[i]->class_n > max_n )
 			ls_mbr[i]->class_n = max_n;
 	}
 
@@ -2116,9 +2174,25 @@ bool_t	cmp_class( class_t *org, class_t *dst )
 
 /**/
 
-char	*get_msg_ttl_auto_mark( long n )
+void	arrange_class( long class_n )
 {
-	return msg_ttl_auto_mark[n];
+	mbr_t	**ls_mbr = get_ls_mbr();
+	class_t	*p = get_class_tab();
+	class_t	tmp;
+	long	n;
+	long	i;
+
+	tmp = p[class_n];
+	for( n = class_n - 1; n >= 0; n-- )
+		p[n + 1] = p[n];
+	p[0] = tmp;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		if( ls_mbr[i]->class_n < class_n )
+			ls_mbr[i]->class_n++;
+		else if( ls_mbr[i]->class_n == class_n )
+			ls_mbr[i]->class_n = 0;
+	}
 }
 
 /**/
