@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: spell.c,v 1.45 2003/11/23 04:29:50 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
@@ -13,6 +39,7 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,6 +49,8 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 /*#include	"town_prot.h"*/
 #include	"item_prot.h"
@@ -29,6 +58,7 @@
 #include	"chr_prot.h"
 #include	"party_prot.h"
 #include	"mnstr_prot.h"
+/*#include	"pet_prot.h"*/
 /*#include	"fight_prot.h"*/
 #include	"fx_prot.h"
 #include	"trap_prot.h"
@@ -46,13 +76,13 @@
 
 /**/
 
-cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
+static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
 
-mbr_t	*g_sel_mbr;
-spell_tab_t	*g_sel_spell;
+static mbr_t	*g_sel_mbr;
+static spell_tab_t	*g_sel_spell;
 
-pos_t	g_vfx_bgn[VFX_ARW_MAX_N], g_vfx_end[VFX_ARW_MAX_N];
-long	g_vfx_n;
+static pos_t	g_vfx_bgn[VFX_ARW_MAX_N], g_vfx_end[VFX_ARW_MAX_N];
+static long	g_vfx_n;
 
 /**/
 
@@ -87,17 +117,20 @@ void	init_spell_debug( void )
 	long	m;
 	spell_kind_t	k;
 
+	m = 0;
+	for( k = SPELL_KIND_NIN_MIN_N + 1; k < SPELL_KIND_NIN_MAX_N; k++ )
+		cast_tab[m][k].flg_cast = TRUE;
+
 	m = 3;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = TRUE;
 
 	m = 5;
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
-		if( spell_tab[k].kind == SPELL_KIND_NULL )
-			break;
-		if( spell_tab[k].kind == SPELL_KIND_MAX_N )
-			break;
-
+		if( k == SPELL_KIND_CREATE_FOOD )
+			continue;
+		if( k == SPELL_KIND_CREATE_UNDEAD )
+			continue;
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 }
@@ -141,67 +174,68 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 			continue;
 
 		kind = (spell_kind_t)(ls[i].arg);
-		if( chk_can_mbr_cast( g_sel_mbr, get_spell_tab( kind ) ) )
+		if( chk_can_chr_cast( g_sel_mbr, kind ) ){
 			ls[i].flg &= ~FLG_MENU_HIDDEN;
-		else
+			ls[i].key = key;
+			key++;
+		} else {
 			ls[i].flg |= FLG_MENU_HIDDEN;
-
-		ls[i].key = key;
-		key++;
+			ls[i].key = '\0';
+		}
 	}
 
 	flg = FALSE;
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_MAG].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
 		clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_SOR].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
 		clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_ENC].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
 		clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_SUM].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
 		clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_PRI].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_PRI ) > 0 ){
 		clr_flg_menu( ls, "PRI", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "PRI", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_SHA].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_SHA ) > 0 ){
 		clr_flg_menu( ls, "SHA", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SHA", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_BAR].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_BAR ) > 0 ){
 		clr_flg_menu( ls, "BAR", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "BAR", FLG_MENU_HIDDEN );
 	}
 
-	if( g_sel_mbr->abl.lev[ABL_KIND_NIN].n > 0 ){
+	if( get_lev( g_sel_mbr, ABL_KIND_NIN ) > 0 ){
 		clr_flg_menu( ls, "NIN", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
@@ -282,7 +316,7 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 			return str_goto;
 	}
 
-	/* $B%"%/%7%g%s$r@_Dj(B */
+	/*  */
 
 	set_chr_act( g_sel_mbr, ACT_KIND_SPELL,
 			g_sel_spell, NULL,
@@ -307,7 +341,7 @@ char	*menu_spell_trgt( mbr_t *mbr )
 	if( mbr == NULL )
 		return STR_MENU_ERR;
 
-	/* $B0JA0$N%?!<%2%C%H$K%+!<%=%k$r0\F0(B */
+	/* ΥåȤ˥ư */
 
 	crsr = get_crsr();
 	if( crsr == NULL )
@@ -317,14 +351,14 @@ char	*menu_spell_trgt( mbr_t *mbr )
 		crsr->y = mbr->trgt.true_y;
 	}
 
-	/* $B%?!<%2%C%H$K%+!<%=%k$r0\F0(B */
+	/* åȤ˥ư */
 
 	while( 1 ){
 		str_goto = exec_menu_point_crsr();
 		if( str_goto != NULL )
 			return str_goto;
 
-		/* $B%?!<%2%C%H$rA*Br(B */
+		/* åȤ */
 
 		str_goto = exec_menu_sel_obj( &trgt_kind, *crsr );
 		if( str_goto == NULL ){
@@ -338,7 +372,7 @@ char	*menu_spell_trgt( mbr_t *mbr )
 			return str_goto;
 	}
 
-	/* $B%?!<%2%C%H$r%^!<%/(B */
+	/* åȤޡ */
 	switch( trgt_kind ){
 	case TRGT_KIND_NULL:
 	case TRGT_KIND_AUTO:
@@ -378,6 +412,8 @@ char	*menu_spell_trgt( mbr_t *mbr )
 			return STR_MENU_ERR;
 		mark_trap( mbr, trap, DIST_FAR );
 		break;
+	case TRGT_KIND_QUEUE:
+		return STR_MENU_ERR;
 	case TRGT_KIND_SQUARE:
 		mark_square( mbr );
 		break;
@@ -388,9 +424,10 @@ char	*menu_spell_trgt( mbr_t *mbr )
 
 /**/
 
-void	chr_cast_spell( chr_t *chr, spell_tab_t *tab )
+void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 {
 	long	hp, mp;
+	curs_attr_t	prev_attr;
 
 	if( chr == NULL )
 		return;
@@ -438,34 +475,44 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab )
 	}
 	chr->abl.hp.n -= hp;
 	chr->abl.mp.n -= mp;
+
 	draw_mbr_stat( chr );
 
-	print_msg_mbr( chr, FLG_NULL, MSG_SPELL, chr->name, tab->name );
+	if( fmt == NULL )
+		print_msg( FLG_NULL, MSG_SPELL, chr->name, tab->name );
+	else
+		print_msg( FLG_NULL, fmt, chr->name );
 
-	set_vfx_attr( CURS_ATTR_N_VFX );
+	get_vfx_attr( &prev_attr );
+	set_vfx_attr_n( CURS_ATTR_N_VFX );
 
 	switch( (extent_kind_t)(chr->act.n) ){
 	case EXTENT_KIND_NULL:
 	case EXTENT_KIND_MAX_N:
 		break;
 	case EXTENT_KIND_NORMAL:
-		chr_cast_spell_normal( chr, tab, _100_PERCENT );
+		chr_cast_spell_normal( chr, FALSE, tab, _100_PERCENT );
 		break;
 	case EXTENT_KIND_SPREAD:
-		chr_cast_spell_spread( chr, tab, _100_PERCENT );
+		chr_cast_spell_spread( chr, FALSE, tab, _100_PERCENT );
 		break;
 	case EXTENT_KIND_MASS:
-		chr_cast_spell_mass( chr, tab, _100_PERCENT );
+		chr_cast_spell_mass( chr, FALSE, tab, _100_PERCENT );
 		break;
 	case EXTENT_KIND_HALF:
-		chr_cast_spell_normal( chr, tab, 50 );
+		chr_cast_spell_normal( chr, FALSE, tab, 50 );
 		break;
 	}
+
+	set_vfx_attr( &prev_attr );
 }
 
 /**/
 
-void	chr_cast_spell_normal( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_normal(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	long	x, y;
 	trgt_kind_t	trgt_kind;
@@ -487,7 +534,8 @@ void	chr_cast_spell_normal( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		g_vfx_end[0].x = x * 2;
 		g_vfx_end[0].y = y;
 		vfx_arw_line( g_vfx_bgn, g_vfx_end,
-				STR_ANIM_SPELL, ANIM_SPELL_LEN,
+				get_spell_vfx_str( tab->kind ),
+				ANIM_SPELL_LEN,
 				ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N,
 				TRUE );
 	} else {
@@ -497,12 +545,15 @@ void	chr_cast_spell_normal( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		p = NULL;
 	}
 
-	chr_cast_spell_sub( chr, tab, rate, x, y, trgt_kind, p );
+	chr_cast_spell_sub( chr, flg_item, tab, rate, x, y, trgt_kind, p );
 }
 
 /**/
 
-void	chr_cast_spell_spread( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_spread(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	long	x, y;
 	trgt_kind_t	trgt_kind;
@@ -524,29 +575,34 @@ void	chr_cast_spell_spread( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		g_vfx_end[0].x = x * 2;
 		g_vfx_end[0].y = y;
 		vfx_arw_line( g_vfx_bgn, g_vfx_end,
-				STR_ANIM_SPELL, ANIM_SPELL_LEN,
+				get_spell_vfx_str( tab->kind ),
+				ANIM_SPELL_LEN,
 				ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N,
 				TRUE );
 
-		chr_cast_spell_blast( chr, tab, rate, x, y, trgt_kind, p );
+		chr_cast_spell_blast( chr, flg_item, tab, rate,
+				x, y, trgt_kind, p );
 	} else {
 		x = chr->x;
 		y = chr->y;
 		trgt_kind = TRGT_KIND_NULL;
 		p = NULL;
 
-		chr_cast_spell_sub( chr, tab, rate, x, y, trgt_kind, p );
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
+				x, y, trgt_kind, p );
 	}
 }
 
 /**/
 
 void	chr_cast_spell_blast(
-	chr_t *chr, spell_tab_t *tab, rate_t rate,
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate,
 	long x, long y, trgt_kind_t trgt_kind, void *p
 )
 {
 	blast_t	*blast;
+	char	*blast_str;
 	long	nx, ny;
 	long	xx, yy;
 
@@ -556,8 +612,8 @@ void	chr_cast_spell_blast(
 		return;
 
 	blast = get_blast();
-
-	draw_blast( x, y, blast );
+	blast_str = get_spell_vfx_str( tab->kind );
+	draw_blast( x, y, blast, blast_str );
 
 	for( ny = 0; ny < blast->yl; ny++ ){
 		for( nx = 0; nx < blast->xl; nx++ ){
@@ -587,6 +643,7 @@ void	chr_cast_spell_blast(
 			case TRGT_KIND_TRAP:
 				p = get_trap( xx, yy );
 				break;
+			case TRGT_KIND_QUEUE:
 			case TRGT_KIND_SQUARE:
 			case TRGT_KIND_AUTO:
 			case TRGT_KIND_MAX_N:
@@ -597,20 +654,24 @@ void	chr_cast_spell_blast(
 
 			draw_map( xx, yy, 1, 1 );
 
-			chr_cast_spell_sub( chr, tab, rate,
+			chr_cast_spell_sub( chr, flg_item, tab, rate,
 					xx, yy, trgt_kind, p );
 
-			draw_blast( x, y, blast );
+			draw_blast( x, y, blast, blast_str );
 		}
 	}
 
 	draw_map( x - blast->xr, y - blast->yr,
-			blast->xl, blast->yl );
+			blast->xl + str_len_draw( blast_str ),
+			blast->yl );
 }
 
 /**/
 
-void	chr_cast_spell_mass( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	if( chr == NULL )
 		return;
@@ -618,7 +679,7 @@ void	chr_cast_spell_mass( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		return;
 
 	if( !tab->flg_trgt ){
-		chr_cast_spell_normal( chr, tab, rate );
+		chr_cast_spell_normal( chr, flg_item, tab, rate );
 		return;
 	}
 
@@ -629,28 +690,33 @@ void	chr_cast_spell_mass( chr_t *chr, spell_tab_t *tab, rate_t rate )
 	case TRGT_KIND_MAX_N:
 		break;
 	case TRGT_KIND_MBR:
-		chr_cast_spell_mass_mbr( chr, tab, rate );
+		chr_cast_spell_mass_mbr( chr, flg_item, tab, rate );
 		break;
 	case TRGT_KIND_MNSTR:
 	case TRGT_KIND_MNSTR_NULL:
 	case TRGT_KIND_POS:
-		chr_cast_spell_mass_mnstr( chr, tab, rate );
+		chr_cast_spell_mass_mnstr( chr, flg_item, tab, rate );
 		break;
 	case TRGT_KIND_ITEM:
-		chr_cast_spell_mass_item( chr, tab, rate );
+		chr_cast_spell_mass_item( chr, flg_item, tab, rate );
 		break;
 	case TRGT_KIND_DOOR:
-		chr_cast_spell_mass_door( chr, tab, rate );
+		chr_cast_spell_mass_door( chr, flg_item, tab, rate );
 		break;
 	case TRGT_KIND_TRAP:
-		chr_cast_spell_mass_trap( chr, tab, rate );
+		chr_cast_spell_mass_trap( chr, flg_item, tab, rate );
+		break;
+	case TRGT_KIND_QUEUE:
 		break;
 	}
 }
 
 /**/
 
-void	chr_cast_spell_mass_mbr( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass_mbr(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	party_t	*pty = get_party();
 	long	i;
@@ -686,7 +752,7 @@ void	chr_cast_spell_mass_mbr( chr_t *chr, spell_tab_t *tab, rate_t rate )
 	}
 
 	vfx_arw_mul_line( g_vfx_n, g_vfx_bgn, g_vfx_end,
-			STR_ANIM_SPELL, ANIM_SPELL_LEN,
+			get_spell_vfx_str( tab->kind ), ANIM_SPELL_LEN,
 			ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N, TRUE );
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
@@ -702,7 +768,7 @@ void	chr_cast_spell_mass_mbr( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		if( !chk_find( &pos1, &pos2 ) )
 			continue;
 
-		chr_cast_spell_sub( chr, tab, rate,
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
 				pty->mbr[i]->x, pty->mbr[i]->y,
 				TRGT_KIND_MBR, pty->mbr[i] );
 	}
@@ -710,10 +776,12 @@ void	chr_cast_spell_mass_mbr( chr_t *chr, spell_tab_t *tab, rate_t rate )
 
 /**/
 
-void	chr_cast_spell_mass_mnstr( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass_mnstr(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
-	mnstr_t	*mnstr, *head, *p;
-	pos_t	pos1, pos2;
+	mnstr_t	*mns_head, *mns_p, *mns_pp;
 
 	if( chr == NULL )
 		return;
@@ -722,58 +790,61 @@ void	chr_cast_spell_mass_mnstr( chr_t *chr, spell_tab_t *tab, rate_t rate )
 
 	g_vfx_n = 0;
 
-	head = get_mnstr_used();
-	for( mnstr = head->next->next; mnstr->prev != head;
-			mnstr = mnstr->next ){
-		p = mnstr->prev;
-		if( chk_flg_or( p->stat,
+	mns_head = get_mnstr_used();
+	for( mns_p = mns_head->next->next; mns_p != NULL;
+			mns_p = mns_p->next ){
+		mns_pp = mns_p->prev;
+		if( mns_pp == mns_head )
+			break;
+
+		if( chk_flg_or( mns_pp->stat,
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
 
-		pos1.x = chr->x;
-		pos1.y = chr->y;
-		pos2.x = p->x;
-		pos2.y = p->y;
-		if( !chk_find_mnstr( chr, p ) )
+		if( !chk_find_chr( chr, mns_pp ) )
 			continue;
 
 		if( g_vfx_n < VFX_ARW_MAX_N ){
-			g_vfx_bgn[g_vfx_n].x = pos1.x * 2;
-			g_vfx_bgn[g_vfx_n].y = pos1.y;
-			g_vfx_end[g_vfx_n].x = pos2.x * 2;
-			g_vfx_end[g_vfx_n].y = pos2.y;
+			g_vfx_bgn[g_vfx_n].x = chr->x * 2;
+			g_vfx_bgn[g_vfx_n].y = chr->y;
+			g_vfx_end[g_vfx_n].x = mns_pp->x * 2;
+			g_vfx_end[g_vfx_n].y = mns_pp->y;
 			g_vfx_n++;
 		}
 	}
 
 	vfx_arw_mul_line( g_vfx_n, g_vfx_bgn, g_vfx_end,
-			STR_ANIM_SPELL, ANIM_SPELL_LEN,
+			get_spell_vfx_str( tab->kind ), ANIM_SPELL_LEN,
 			ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N, TRUE );
 
-	for( mnstr = head->next->next; mnstr->prev != head;
-			mnstr = mnstr->next ){
-		p = mnstr->prev;
-		if( chk_flg_or( p->stat,
+	mns_head = get_mnstr_used();
+	for( mns_p = mns_head->next->next; mns_p != NULL;
+			mns_p = mns_p->next ){
+		mns_pp = mns_p->prev;
+		if( mns_pp == mns_head )
+			break;
+
+		if( chk_flg_or( mns_pp->stat,
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
 
-		pos1.x = chr->x;
-		pos1.y = chr->y;
-		pos2.x = p->x;
-		pos2.y = p->y;
-		if( !chk_find_mnstr( chr, p ) )
+		if( !chk_find_chr( chr, mns_pp ) )
 			continue;
 
-		chr_cast_spell_sub( chr, tab, rate,
-				p->x, p->y, TRGT_KIND_MNSTR, p );
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
+				mns_pp->x, mns_pp->y,
+				TRGT_KIND_MNSTR, mns_pp );
 	}
 }
 
 /**/
 
-void	chr_cast_spell_mass_item( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass_item(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	item_t	*item, *head, *p;
 	pos_t	pos1, pos2;
@@ -807,7 +878,7 @@ void	chr_cast_spell_mass_item( chr_t *chr, spell_tab_t *tab, rate_t rate )
 	}
 
 	vfx_arw_mul_line( g_vfx_n, g_vfx_bgn, g_vfx_end,
-			STR_ANIM_SPELL, ANIM_SPELL_LEN,
+			get_spell_vfx_str( tab->kind ), ANIM_SPELL_LEN,
 			ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N, TRUE );
 
 	for( item = head->next->next; item->prev != head;
@@ -821,14 +892,17 @@ void	chr_cast_spell_mass_item( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		if( !chk_find( &pos1, &pos2 ) )
 			continue;
 
-		chr_cast_spell_sub( chr, tab, rate,
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
 				p->x, p->y, TRGT_KIND_ITEM, p );
 	}
 }
 
 /**/
 
-void	chr_cast_spell_mass_door( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass_door(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	dun_t	*dun = get_dun();
 	long	i;
@@ -846,6 +920,8 @@ void	chr_cast_spell_mass_door( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		pos1.y = chr->y;
 		pos2.x = dun->door[i].x;
 		pos2.y = dun->door[i].y;
+		get_near_pos_door( &pos2, &(dun->door[i]), chr );
+
 		if( !chk_find( &pos1, &pos2 ) )
 			continue;
 
@@ -859,7 +935,7 @@ void	chr_cast_spell_mass_door( chr_t *chr, spell_tab_t *tab, rate_t rate )
 	}
 
 	vfx_arw_mul_line( g_vfx_n, g_vfx_bgn, g_vfx_end,
-			STR_ANIM_SPELL, ANIM_SPELL_LEN,
+			get_spell_vfx_str( tab->kind ), ANIM_SPELL_LEN,
 			ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N, TRUE );
 
 	for( i = 0; i < dun->door_n; i++ ){
@@ -867,10 +943,12 @@ void	chr_cast_spell_mass_door( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		pos1.y = chr->y;
 		pos2.x = dun->door[i].x;
 		pos2.y = dun->door[i].y;
+		get_near_pos_door( &pos2, &(dun->door[i]), chr );
+
 		if( !chk_find( &pos1, &pos2 ) )
 			continue;
 
-		chr_cast_spell_sub( chr, tab, rate,
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
 				dun->door[i].x, dun->door[i].y,
 				TRGT_KIND_DOOR, &(dun->door[i]) );
 	}
@@ -878,7 +956,10 @@ void	chr_cast_spell_mass_door( chr_t *chr, spell_tab_t *tab, rate_t rate )
 
 /**/
 
-void	chr_cast_spell_mass_trap( chr_t *chr, spell_tab_t *tab, rate_t rate )
+void	chr_cast_spell_mass_trap(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate
+)
 {
 	trap_t	*trap, *head, *p;
 	pos_t	pos1, pos2;
@@ -912,7 +993,7 @@ void	chr_cast_spell_mass_trap( chr_t *chr, spell_tab_t *tab, rate_t rate )
 	}
 
 	vfx_arw_mul_line( g_vfx_n, g_vfx_bgn, g_vfx_end,
-			STR_ANIM_SPELL, ANIM_SPELL_LEN,
+			get_spell_vfx_str( tab->kind ), ANIM_SPELL_LEN,
 			ANIM_SPELL_FRAME_N, ANIM_SPELL_CLR_FRAME_N, TRUE );
 
 	for( trap = head->next->next; trap->prev != head;
@@ -926,7 +1007,7 @@ void	chr_cast_spell_mass_trap( chr_t *chr, spell_tab_t *tab, rate_t rate )
 		if( !chk_find( &pos1, &pos2 ) )
 			continue;
 
-		chr_cast_spell_sub( chr, tab, rate,
+		chr_cast_spell_sub( chr, flg_item, tab, rate,
 				p->x, p->y, TRGT_KIND_TRAP, p );
 	}
 }
@@ -934,11 +1015,13 @@ void	chr_cast_spell_mass_trap( chr_t *chr, spell_tab_t *tab, rate_t rate )
 /**/
 
 void	chr_cast_spell_sub(
-	chr_t *chr, spell_tab_t *tab, rate_t rate,
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate,
 	long x, long y, trgt_kind_t trgt_kind, void *p
 )
 {
-	long	turn_resi;
+	bool_t	flg_chr;
+	const long	turn_resi = FX_AVE_TURN_POW_UP_RESI;
 
 	if( chr == NULL )
 		return;
@@ -947,6 +1030,13 @@ void	chr_cast_spell_sub(
 	if( !chk_cast_spell_trgt( tab->kind, trgt_kind ) )
 		return;
 
+	if( (trgt_kind == TRGT_KIND_MBR)
+			|| (trgt_kind == TRGT_KIND_MNSTR) ){
+		flg_chr = TRUE;
+	} else {
+		flg_chr = FALSE;
+	}
+
 	if( (trgt_kind == TRGT_KIND_MNSTR_NULL)
 			|| (trgt_kind == TRGT_KIND_POS) ){
 		mnstr_t	*mnstr;
@@ -958,7 +1048,22 @@ void	chr_cast_spell_sub(
 		p = mnstr;
 	}
 
-	turn_resi = FX_AVE_TURN_POW_UP_RESI;
+	if( flg_chr ){
+		chr_t	*chr2;
+
+		chr2 = (chr_t *)p;
+		if( chr2->gold < tab->gold ){
+			print_msg_mbr( chr2, FLG_NULL, MSG_ERR_GOLD_SHORT,
+					chr2->name, tab->gold - chr2->gold );
+			return;
+		}
+		chr2->gold -= tab->gold;
+	}
+
+	/* ʸ뤫å */
+	if( flg_chr )
+		if( !chk_spell( chr, (chr_t *)p, tab, flg_item ) )
+			return;
 
 	switch( tab->kind ){
 	case SPELL_KIND_NULL:
@@ -972,6 +1077,15 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_DARKNESS:
 		fx_darkness( x, y );
 		break;
+	case SPELL_KIND_TELEPORT_PARTY:
+		fx_teleport_party();
+		break;
+	case SPELL_KIND_TELEPORT:
+		fx_teleport( trgt_kind, p );
+		break;
+	case SPELL_KIND_RECALL:
+		fx_recall();
+		break;
 	case SPELL_KIND_KNOCK:
 		fx_knock( get_door( x, y ) );
 		break;
@@ -983,15 +1097,6 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_DISPEL_MAGIC:
 		break;
-	case SPELL_KIND_TELEPORT_PARTY:
-		teleport_party();
-		break;
-	case SPELL_KIND_TELEPORT:
-		fx_teleport( trgt_kind, p );
-		break;
-	case SPELL_KIND_RECALL:
-		recall();
-		break;
 	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_ANIMATE_OBJECTS:
 	case SPELL_KIND_SHELTER:
@@ -999,8 +1104,6 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_CREATE_FOOD:
 		fx_create_food( chr );
 		break;
-	case SPELL_KIND_CREATE_UNDEAD:
-		break;
 	case SPELL_KIND_IDENTIFY_ITEM:
 		exec_menu_identify_item( chr );
 		break;
@@ -1012,7 +1115,10 @@ void	chr_cast_spell_sub(
 		fx_detect_item( chr );
 		break;
 	case SPELL_KIND_DETECT_DOORS:
+		fx_detect_door( chr );
+		break;
 	case SPELL_KIND_DETECT_TRAPS:
+		fx_detect_trap( chr );
 		break;
 	case SPELL_KIND_DETECT_MONSTER:
 		fx_detect_mnstr( chr );
@@ -1023,7 +1129,9 @@ void	chr_cast_spell_sub(
 		fx_std( p, FX_KIND_FLY );
 		break;
 	case SPELL_KIND_FEATHER_FALL:
+		break;
 	case SPELL_KIND_VANISH:
+		fx_std( p, FX_KIND_VANISH );
 		break;
 	case SPELL_KIND_DARKVISION:
 		fx_darkvision( p );
@@ -1049,14 +1157,14 @@ void	chr_cast_spell_sub(
 		fx_spell_attack( chr, trgt_kind, p, RESI_KIND_COLD,
 				ABL_KIND_SOR, rate );
 		break;
-	case SPELL_KIND_MIND_STORM:
-		fx_spell_attack( chr, trgt_kind, p, RESI_KIND_WIND,
-				ABL_KIND_SOR, rate );
-		break;
 	case SPELL_KIND_ACID_RAIN:
 		fx_spell_attack( chr, trgt_kind, p, RESI_KIND_ACID,
 				ABL_KIND_SOR, rate );
 		break;
+	case SPELL_KIND_MIND_STORM:
+		fx_spell_attack( chr, trgt_kind, p, RESI_KIND_MIND,
+				ABL_KIND_SOR, rate );
+		break;
 	case SPELL_KIND_LIGHTNING_BOLT:
 		fx_spell_attack( chr, trgt_kind, p, RESI_KIND_ELEC,
 				ABL_KIND_SOR, rate );
@@ -1066,8 +1174,14 @@ void	chr_cast_spell_sub(
 				ABL_KIND_SOR, rate );
 		break;
 	case SPELL_KIND_DEATH_SPELL:
-	case SPELL_KIND_MAGE_ARMOR:
+		fx_death_spell( chr, trgt_kind, p );
+		break;
 	case SPELL_KIND_MAGIC_SHIELD:
+		fx_magic_armor( p, FX_KIND_MAGIC_SHIELD );
+		break;
+	case SPELL_KIND_MAGE_ARMOR:
+		fx_magic_armor( p, FX_KIND_MAGE_ARMOR );
+		break;
 	case SPELL_KIND_STONESKIN:
 	case SPELL_KIND_IRON_BODY:
 	case SPELL_KIND_SPELL_RESISTANCE:
@@ -1151,6 +1265,7 @@ void	chr_cast_spell_sub(
 		fx_abl( p, FX_KIND_UNATTRACTIVE, FX_AVE_TURN_POW_DOWN_ABL );
 		break;
 	case SPELL_KIND_ENERGY_DRAIN:
+		fx_energy_drain( p );
 		break;
 	case SPELL_KIND_SLOW:
 		fx_speed_up( chr, p, -1, FX_AVE_TURN_SPEED_DOWN );
@@ -1163,6 +1278,7 @@ void	chr_cast_spell_sub(
 /* SUM */
 	case SPELL_KIND_SUM_MIN_N:
 		break;
+	case SPELL_KIND_CREATE_UNDEAD:
 	case SPELL_KIND_SUMMON_MONSTER:
 	case SPELL_KIND_DISMISSAL:
 		break;
@@ -1240,12 +1356,12 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_RESIST_COLD:
 		fx_resi( p, FX_KIND_RESI_COLD, turn_resi );
 		break;
-	case SPELL_KIND_RESIST_WIND:
-		fx_resi( p, FX_KIND_RESI_WIND, turn_resi );
-		break;
 	case SPELL_KIND_RESIST_ACID:
 		fx_resi( p, FX_KIND_RESI_ACID, turn_resi );
 		break;
+	case SPELL_KIND_RESIST_MIND:
+		fx_resi( p, FX_KIND_RESI_MIND, turn_resi );
+		break;
 	case SPELL_KIND_RESIST_ELECTRICITY:
 		fx_resi( p, FX_KIND_RESI_ELEC, turn_resi );
 		break;
@@ -1253,11 +1369,14 @@ void	chr_cast_spell_sub(
 		fx_resi( p, FX_KIND_RESI_POIS, turn_resi );
 		break;
 	case SPELL_KIND_BLESS:
+		fx_bless( p );
 		break;
 	case SPELL_KIND_REMOVE_CURSE:
 		fx_remove_curse( chr, p );
 		break;
 	case SPELL_KIND_DISPEL_UNDEAD:
+		fx_dispel_undead( chr, trgt_kind, p, rate );
+		break;
 	case SPELL_KIND_SANCTUARY:
 	case SPELL_KIND_WISH:
 		break;
@@ -1268,12 +1387,14 @@ void	chr_cast_spell_sub(
 /* NIN */
 	case SPELL_KIND_NIN_MIN_N:
 		break;
+	case SPELL_KIND_TYPHOON:
 	case SPELL_KIND_CONFLAGRATION:
 	case SPELL_KIND_EARTHQUAKE:
 	case SPELL_KIND_THUNDERCLOUD:
 	case SPELL_KIND_INUNDATION:
 	case SPELL_KIND_SUBSTITUTE:
 	case SPELL_KIND_BURNING_HANDS:
+		break;
 	case SPELL_KIND_NIN_MAX_N:
 		break;
 /* ANC */
@@ -1291,6 +1412,30 @@ void	chr_cast_spell_sub(
 
 /**/
 
+bool_t	chk_spell(
+	chr_t *o_p, chr_t *d_p,
+	spell_tab_t *tab, bool_t flg_item
+)
+{
+	abl_kind_t	o_abl;
+
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+	if( tab == NULL )
+		return FALSE;
+
+	if( flg_item )
+		o_abl = ABL_KIND_MAX_N;
+	else
+		o_abl = tab->abl;
+
+	return( !resi_roll( o_p, o_abl, d_p, tab->resi ) );
+}
+
+/**/
+
 bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 {
 	switch( spell ){
@@ -1300,18 +1445,17 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_MAG_MIN_N:
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
+	case SPELL_KIND_TELEPORT_PARTY:
+	case SPELL_KIND_TELEPORT:
+	case SPELL_KIND_RECALL:
 	case SPELL_KIND_KNOCK:
 	case SPELL_KIND_LOCK:
 	case SPELL_KIND_DISARM_TRAP:
 	case SPELL_KIND_DISPEL_MAGIC:
-	case SPELL_KIND_TELEPORT_PARTY:
-	case SPELL_KIND_TELEPORT:
-	case SPELL_KIND_RECALL:
 	case SPELL_KIND_MIRROR_IMAGE:
 	case SPELL_KIND_ANIMATE_OBJECTS:
 	case SPELL_KIND_SHELTER:
 	case SPELL_KIND_CREATE_FOOD:
-	case SPELL_KIND_CREATE_UNDEAD:
 	case SPELL_KIND_IDENTIFY_ITEM:
 	case SPELL_KIND_SEARCHING:
 	case SPELL_KIND_ANALYZE_DWEOMER:
@@ -1327,7 +1471,10 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 			return FALSE;
 		break;
 	case SPELL_KIND_FEATHER_FALL:
+		break;
 	case SPELL_KIND_VANISH:
+		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
+			return FALSE;
 		break;
 	case SPELL_KIND_DARKVISION:
 		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
@@ -1343,13 +1490,13 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_MAGIC_MISSILE:
 	case SPELL_KIND_FIRE_BALL:
 	case SPELL_KIND_ICE_BLIZZARD:
-	case SPELL_KIND_MIND_STORM:
 	case SPELL_KIND_ACID_RAIN:
+	case SPELL_KIND_MIND_STORM:
 	case SPELL_KIND_LIGHTNING_BOLT:
 	case SPELL_KIND_POISON_CLOUD:
 	case SPELL_KIND_DEATH_SPELL:
-	case SPELL_KIND_MAGE_ARMOR:
 	case SPELL_KIND_MAGIC_SHIELD:
+	case SPELL_KIND_MAGE_ARMOR:
 	case SPELL_KIND_STONESKIN:
 	case SPELL_KIND_IRON_BODY:
 	case SPELL_KIND_SPELL_RESISTANCE:
@@ -1390,7 +1537,6 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 			return FALSE;
 		break;
 	case SPELL_KIND_ENERGY_DRAIN:
-		break;
 	case SPELL_KIND_SLOW:
 		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
 			return FALSE;
@@ -1400,6 +1546,7 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_ENC_MAX_N:
 /* SUM */
 	case SPELL_KIND_SUM_MIN_N:
+	case SPELL_KIND_CREATE_UNDEAD:
 	case SPELL_KIND_SUMMON_MONSTER:
 	case SPELL_KIND_DISMISSAL:
 	case SPELL_KIND_SUM_MAX_N:
@@ -1439,8 +1586,8 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_RESIST_PHYSICAL:
 	case SPELL_KIND_RESIST_HEAT:
 	case SPELL_KIND_RESIST_COLD:
-	case SPELL_KIND_RESIST_WIND:
 	case SPELL_KIND_RESIST_ACID:
+	case SPELL_KIND_RESIST_MIND:
 	case SPELL_KIND_RESIST_ELECTRICITY:
 	case SPELL_KIND_RESIST_POISON:
 		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
@@ -1453,6 +1600,9 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 			return FALSE;
 		break;
 	case SPELL_KIND_DISPEL_UNDEAD:
+		if( (trgt != TRGT_KIND_MBR) && (trgt != TRGT_KIND_MNSTR) )
+			return FALSE;
+		break;
 	case SPELL_KIND_SANCTUARY:
 	case SPELL_KIND_WISH:
 	case SPELL_KIND_PRI_MAX_N:
@@ -1460,6 +1610,7 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 /* BAR */
 /* NIN */
 	case SPELL_KIND_NIN_MIN_N:
+	case SPELL_KIND_TYPHOON:
 	case SPELL_KIND_CONFLAGRATION:
 	case SPELL_KIND_EARTHQUAKE:
 	case SPELL_KIND_THUNDERCLOUD:
@@ -1481,26 +1632,241 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 
 /**/
 
-bool_t	chk_can_chr_cast( chr_t *chr, spell_tab_t *tab )
+bool_t	chk_can_chr_cast( chr_t *chr, spell_kind_t kind )
 {
+	cast_tab_t	*tab;
+
 	if( chr == NULL )
 		return FALSE;
+	if( chr->kind != CHR_KIND_MBR )
+		return FALSE;
+
+	tab = get_cast_tab( chr, kind );
 	if( tab == NULL )
 		return FALSE;
 
-	if( chr->kind == CHR_KIND_MBR )
-		return chk_can_mbr_cast( chr, tab );
-
-	return FALSE;
+	return tab->flg_cast;
 }
 
 /**/
 
-bool_t	chk_can_mbr_cast( chr_t *chr, spell_tab_t *tab )
+bool_t	set_can_chr_cast( chr_t *chr, spell_kind_t kind, bool_t flg )
+{
+	cast_tab_t	*tab;
+
+	if( chr == NULL )
+		return FALSE;
+	if( chr->kind != CHR_KIND_MBR )
+		return FALSE;
+
+	tab = get_cast_tab( chr, kind );
+	if( tab == NULL )
+		return FALSE;
+
+	tab->flg_cast = flg;
+
+	if( flg ){
+		print_msg( FLG_NULL, MSG_LEARN_SPELL,
+				chr->name, get_spell_name( kind ) );
+	} else {
+		print_msg( FLG_NULL, MSG_FORGET_SPELL,
+				chr->name, get_spell_name( kind ) );
+	}
+
+	return tab->flg_cast;
+}
+
+/**/
+
+char	*get_spell_vfx_str( spell_kind_t spell_kind )
+{
+	switch( spell_kind ){
+	case SPELL_KIND_NULL:
+/* MAG */
+	case SPELL_KIND_MAG_MIN_N:
+	case SPELL_KIND_LIGHT:
+	case SPELL_KIND_DARKNESS:
+	case SPELL_KIND_TELEPORT_PARTY:
+	case SPELL_KIND_TELEPORT:
+	case SPELL_KIND_RECALL:
+		break;
+	case SPELL_KIND_KNOCK:
+		return "+'";
+	case SPELL_KIND_LOCK:
+		return "+^";
+	case SPELL_KIND_DISARM_TRAP:
+		return "^*";
+	case SPELL_KIND_DISPEL_MAGIC:
+	case SPELL_KIND_MIRROR_IMAGE:
+	case SPELL_KIND_ANIMATE_OBJECTS:
+	case SPELL_KIND_SHELTER:
+	case SPELL_KIND_CREATE_FOOD:
+	case SPELL_KIND_IDENTIFY_ITEM:
+	case SPELL_KIND_SEARCHING:
+	case SPELL_KIND_ANALYZE_DWEOMER:
+	case SPELL_KIND_DETECT_ITEM:
+	case SPELL_KIND_DETECT_DOORS:
+	case SPELL_KIND_DETECT_TRAPS:
+	case SPELL_KIND_DETECT_MAGIC:
+	case SPELL_KIND_DETECT_MONSTER:
+	case SPELL_KIND_SENSE_INVISIBLE:
+	case SPELL_KIND_FLY:
+	case SPELL_KIND_FEATHER_FALL:
+	case SPELL_KIND_VANISH:
+	case SPELL_KIND_DARKVISION:
+	case SPELL_KIND_PASSWALL:
+	case SPELL_KIND_POLYMORPH_OTHER:
+	case SPELL_KIND_POLYMORPH_SELF:
+	case SPELL_KIND_STEALTH:
+	case SPELL_KIND_MAG_MAX_N:
+/* SOR */
+	case SPELL_KIND_SOR_MIN_N:
+		break;
+	case SPELL_KIND_MAGIC_MISSILE:
+		return "||";
+	case SPELL_KIND_FIRE_BALL:
+		return "oo";
+	case SPELL_KIND_ICE_BLIZZARD:
+		return "~~";
+	case SPELL_KIND_ACID_RAIN:
+		return "//";
+	case SPELL_KIND_MIND_STORM:
+		return "@@";
+	case SPELL_KIND_LIGHTNING_BOLT:
+		return "<<";
+	case SPELL_KIND_POISON_CLOUD:
+		return "Oo";
+	case SPELL_KIND_DEATH_SPELL:
+		return "XX";
+	case SPELL_KIND_MAGE_ARMOR:
+	case SPELL_KIND_MAGIC_SHIELD:
+	case SPELL_KIND_STONESKIN:
+	case SPELL_KIND_IRON_BODY:
+	case SPELL_KIND_SPELL_RESISTANCE:
+	case SPELL_KIND_COUNTER_MAGIC:
+	case SPELL_KIND_STONE:
+	case SPELL_KIND_PARALYZE:
+	case SPELL_KIND_POISON:
+	case SPELL_KIND_CONFUSION:
+	case SPELL_KIND_BLINDNESS:
+	case SPELL_KIND_SLEEP:
+	case SPELL_KIND_SILENCE:
+	case SPELL_KIND_FEAR:
+	case SPELL_KIND_HALLUCINATION:
+	case SPELL_KIND_CHARM:
+	case SPELL_KIND_SOR_MAX_N:
+/* ENC */
+	case SPELL_KIND_ENC_MIN_N:
+		break;
+	case SPELL_KIND_SHARPNESS:
+	case SPELL_KIND_STRENGTH:
+	case SPELL_KIND_QUICKNESS:
+	case SPELL_KIND_WISE:
+	case SPELL_KIND_BRAINY:
+	case SPELL_KIND_ATTRACTIVE:
+	case SPELL_KIND_POWER_UP_HP:
+	case SPELL_KIND_HASTE:
+		return "@+";
+	case SPELL_KIND_DULLNESS:
+	case SPELL_KIND_WEAKNESS:
+	case SPELL_KIND_SLOWNESS:
+	case SPELL_KIND_FOOLISH:
+	case SPELL_KIND_BRAINLESS:
+	case SPELL_KIND_UNATTRACTIVE:
+	case SPELL_KIND_ENERGY_DRAIN:
+	case SPELL_KIND_SLOW:
+		return "@-";
+	case SPELL_KIND_HUNGER:
+	case SPELL_KIND_CANCELLATION:
+	case SPELL_KIND_ENC_MAX_N:
+/* SUM */
+	case SPELL_KIND_SUM_MIN_N:
+	case SPELL_KIND_CREATE_UNDEAD:
+	case SPELL_KIND_SUMMON_MONSTER:
+	case SPELL_KIND_DISMISSAL:
+	case SPELL_KIND_SUM_MAX_N:
+/* PRI */
+	case SPELL_KIND_PRI_MIN_N:
+		break;
+	case SPELL_KIND_CURE_HP_LIGHT:
+		return "+";
+	case SPELL_KIND_CURE_HP_MODERATE:
+		return "+!";
+	case SPELL_KIND_CURE_HP_SERIOUS:
+		return "+!!";
+	case SPELL_KIND_CURE_HP_MAX:
+		return "+!!!";
+	case SPELL_KIND_REGENERATION:
+	case SPELL_KIND_CURE_MP:
+	case SPELL_KIND_TRANSFER_MP:
+	case SPELL_KIND_RESTORE_EXPERIENCE:
+		return "+?";
+	case SPELL_KIND_RESURRECTION:
+		break;
+	case SPELL_KIND_HEAL:
+	case SPELL_KIND_CURE_STATUS:
+	case SPELL_KIND_CURE_STONE:
+	case SPELL_KIND_CURE_PARALYZE:
+	case SPELL_KIND_CURE_POISON:
+	case SPELL_KIND_CURE_CONFUSION:
+	case SPELL_KIND_CURE_BLINDNESS:
+	case SPELL_KIND_CURE_SLEEP:
+	case SPELL_KIND_CURE_SILENCE:
+	case SPELL_KIND_CURE_FEAR:
+	case SPELL_KIND_CURE_HALLUCINATION:
+	case SPELL_KIND_CURE_CHARM:
+		return "+%";
+	case SPELL_KIND_PROTECTION:
+	case SPELL_KIND_RESIST_PHYSICAL:
+	case SPELL_KIND_RESIST_HEAT:
+	case SPELL_KIND_RESIST_COLD:
+	case SPELL_KIND_RESIST_ACID:
+	case SPELL_KIND_RESIST_MIND:
+	case SPELL_KIND_RESIST_ELECTRICITY:
+	case SPELL_KIND_RESIST_POISON:
+		return "+[";
+	case SPELL_KIND_BLESS:
+	case SPELL_KIND_REMOVE_CURSE:
+		break;
+	case SPELL_KIND_DISPEL_UNDEAD:
+		return "+Z";
+	case SPELL_KIND_SANCTUARY:
+	case SPELL_KIND_WISH:
+	case SPELL_KIND_PRI_MAX_N:
+/* SHA */
+/* BAR */
+/* NIN */
+	case SPELL_KIND_NIN_MIN_N:
+	case SPELL_KIND_TYPHOON:
+	case SPELL_KIND_CONFLAGRATION:
+	case SPELL_KIND_EARTHQUAKE:
+	case SPELL_KIND_THUNDERCLOUD:
+	case SPELL_KIND_INUNDATION:
+	case SPELL_KIND_SUBSTITUTE:
+	case SPELL_KIND_BURNING_HANDS:
+	case SPELL_KIND_NIN_MAX_N:
+/* ANC */
+	case SPELL_KIND_ANC_MIN_N:
+	case SPELL_KIND_NOTHING:
+	case SPELL_KIND_ANC_MAX_N:
+/* end */
+	case SPELL_KIND_MAX_N:
+		break;
+	}
+
+	return "**";
+}
+
+/**/
+
+cast_tab_t	*get_cast_tab( chr_t *chr, spell_kind_t kind )
 {
 	long	m;
 	spell_kind_t	k;
 
+	if( chr == NULL )
+		return NULL;
+
 	m = chr->ls_mbr_n;
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
 		if( cast_tab[m][k].kind == SPELL_KIND_NULL )
@@ -1508,11 +1874,11 @@ bool_t	chk_can_mbr_cast( chr_t *chr, spell_tab_t *tab )
 		if( cast_tab[m][k].kind == SPELL_KIND_MAX_N )
 			break;
 
-		if( cast_tab[m][k].kind == tab->kind )
-			return cast_tab[m][k].flg_cast;
+		if( cast_tab[m][k].kind == kind )
+			return &(cast_tab[m][k]);
 	}
 
-	return FALSE;
+	return NULL;
 }
 
 /**/
@@ -1529,6 +1895,12 @@ char	*get_spell_name( spell_kind_t kind )
 		return MSG_SPELL_LIGHT;
 	case SPELL_KIND_DARKNESS:
 		return MSG_SPELL_DARKNESS;
+	case SPELL_KIND_TELEPORT_PARTY:
+		return MSG_SPELL_TELEPORT_PARTY;
+	case SPELL_KIND_TELEPORT:
+		return MSG_SPELL_TELEPORT;
+	case SPELL_KIND_RECALL:
+		return MSG_SPELL_RECALL;
 	case SPELL_KIND_KNOCK:
 		return MSG_SPELL_KNOCK;
 	case SPELL_KIND_LOCK:
@@ -1537,12 +1909,6 @@ char	*get_spell_name( spell_kind_t kind )
 		return MSG_SPELL_DISARM_TRAP;
 	case SPELL_KIND_DISPEL_MAGIC:
 		return MSG_SPELL_DISPEL_MAGIC;
-	case SPELL_KIND_TELEPORT_PARTY:
-		return MSG_SPELL_TELEPORT_PARTY;
-	case SPELL_KIND_TELEPORT:
-		return MSG_SPELL_TELEPORT;
-	case SPELL_KIND_RECALL:
-		return MSG_SPELL_RECALL;
 	case SPELL_KIND_MIRROR_IMAGE:
 		return MSG_SPELL_MIRROR_IMAGE;
 	case SPELL_KIND_ANIMATE_OBJECTS:
@@ -1551,8 +1917,6 @@ char	*get_spell_name( spell_kind_t kind )
 		return MSG_SPELL_SHELTER;
 	case SPELL_KIND_CREATE_FOOD:
 		return MSG_SPELL_CREATE_FOOD;
-	case SPELL_KIND_CREATE_UNDEAD:
-		return MSG_SPELL_CREATE_UNDEAD;
 	case SPELL_KIND_IDENTIFY_ITEM:
 		return MSG_SPELL_IDENTIFY_ITEM;
 	case SPELL_KIND_SEARCHING:
@@ -1598,20 +1962,20 @@ char	*get_spell_name( spell_kind_t kind )
 		return MSG_SPELL_FIRE_BALL;
 	case SPELL_KIND_ICE_BLIZZARD:
 		return MSG_SPELL_ICE_BLIZZARD;
-	case SPELL_KIND_MIND_STORM:
-		return MSG_SPELL_MIND_STORM;
 	case SPELL_KIND_ACID_RAIN:
 		return MSG_SPELL_ACID_RAIN;
+	case SPELL_KIND_MIND_STORM:
+		return MSG_SPELL_MIND_STORM;
 	case SPELL_KIND_LIGHTNING_BOLT:
 		return MSG_SPELL_LIGHTNING_BOLT;
 	case SPELL_KIND_POISON_CLOUD:
 		return MSG_SPELL_POISON_CLOUD;
 	case SPELL_KIND_DEATH_SPELL:
 		return MSG_SPELL_DEATH_SPELL;
-	case SPELL_KIND_MAGE_ARMOR:
-		return MSG_SPELL_MAGE_ARMOR;
 	case SPELL_KIND_MAGIC_SHIELD:
 		return MSG_SPELL_MAGIC_SHIELD;
+	case SPELL_KIND_MAGE_ARMOR:
+		return MSG_SPELL_MAGE_ARMOR;
 	case SPELL_KIND_STONESKIN:
 		return MSG_SPELL_STONESKIN;
 	case SPELL_KIND_IRON_BODY:
@@ -1686,6 +2050,8 @@ char	*get_spell_name( spell_kind_t kind )
 /* SUM */
 	case SPELL_KIND_SUM_MIN_N:
 		return NULL;
+	case SPELL_KIND_CREATE_UNDEAD:
+		return MSG_SPELL_CREATE_UNDEAD;
 	case SPELL_KIND_SUMMON_MONSTER:
 		return MSG_SPELL_SUMMON_MONSTER;
 	case SPELL_KIND_DISMISSAL:
@@ -1745,10 +2111,10 @@ char	*get_spell_name( spell_kind_t kind )
 		return MSG_SPELL_RESIST_HEAT;
 	case SPELL_KIND_RESIST_COLD:
 		return MSG_SPELL_RESIST_COLD;
-	case SPELL_KIND_RESIST_WIND:
-		return MSG_SPELL_RESIST_WIND;
 	case SPELL_KIND_RESIST_ACID:
 		return MSG_SPELL_RESIST_ACID;
+	case SPELL_KIND_RESIST_MIND:
+		return MSG_SPELL_RESIST_MIND;
 	case SPELL_KIND_RESIST_ELECTRICITY:
 		return MSG_SPELL_RESIST_ELECTRICITY;
 	case SPELL_KIND_RESIST_POISON:
@@ -1770,6 +2136,8 @@ char	*get_spell_name( spell_kind_t kind )
 /* NIN */
 	case SPELL_KIND_NIN_MIN_N:
 		return NULL;
+	case SPELL_KIND_TYPHOON:
+		return MSG_SPELL_TYPHOON;
 	case SPELL_KIND_CONFLAGRATION:
 		return MSG_SPELL_CONFLAGRATION;
 	case SPELL_KIND_EARTHQUAKE:
@@ -1819,3 +2187,17 @@ spell_tab_t	*get_spell_tab( spell_kind_t kind )
 }
 
 /**/
+
+gold_t	get_price_spell( spell_kind_t kind )
+{
+	spell_tab_t	*tab;
+
+	tab = get_spell_tab( kind );
+	if( tab == NULL )
+		return( (gold_t)0 );
+
+	return( (gold_t)tab->price );
+}
+
+/**/
+
