@@ -1,5 +1,36 @@
-#ifndef	__SPELL_TAB_H__
-#define	__SPELL_TAB_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: spell_tab.h,v 1.20 2003/11/19 13:19:13 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	SPELL_TAB_H
+#define	SPELL_TAB_H
 
 #include	"menu.h"
 #include	"spell_prot.h"
@@ -14,7 +45,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B6&DLKbK!(B] */
+/* [ˡ] */
 	{
 		"/Spell/MAG",
 		"<Branch>",
@@ -24,7 +55,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B6&DLKbK!(B] $B$=$NB>(B */
+/* [ˡ] ¾ */
 	{
 		"/Spell/MAG/Title Misc",
 		"<Title>",
@@ -55,6 +86,36 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/MAG/TELEPORT_PARTY",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_TELEPORT_PARTY, "",
+		cb_menu_spell, (void *)SPELL_KIND_TELEPORT_PARTY,
+		FLG_NULL,
+	},
+
+	{
+		"/Spell/MAG/TELEPORT",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_TELEPORT, "",
+		cb_menu_spell, (void *)SPELL_KIND_TELEPORT,
+		FLG_NULL,
+	},
+
+	{
+		"/Spell/MAG/RECALL",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_RECALL, "",
+		cb_menu_spell, (void *)SPELL_KIND_RECALL,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/MAG/KNOCK",
 		"<Branch>",
@@ -95,36 +156,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/Spell/MAG/TELEPORT",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_TELEPORT, "",
-		cb_menu_spell, (void *)SPELL_KIND_TELEPORT,
-		FLG_NULL,
-	},
-
-	{
-		"/Spell/MAG/TELEPORT_PARTY",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_TELEPORT_PARTY, "",
-		cb_menu_spell, (void *)SPELL_KIND_TELEPORT_PARTY,
-		FLG_NULL,
-	},
-
-	{
-		"/Spell/MAG/RECALL",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_RECALL, "",
-		cb_menu_spell, (void *)SPELL_KIND_RECALL,
-		FLG_NULL,
-	},
-
 	{
 		"/Spell/MAG/MIRROR_IMAGE",
 		"<Branch>",
@@ -194,7 +225,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B6&DLKbK!(B] $BC5CN(B */
+/* [ˡ] õ */
 	{
 		"/Spell/MAG/Title Detect",
 		"<Title>",
@@ -236,12 +267,12 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_DOORS",
+		"/Spell/MAG/DETECT_MAGIC",
 		"<Branch>",
 		'\0',
 		"",
-		N_MSG_SPELL_DETECT_DOORS, "",
-		cb_menu_spell, (void *)SPELL_KIND_DETECT_DOORS,
+		N_MSG_SPELL_DETECT_MAGIC, "",
+		cb_menu_spell, (void *)SPELL_KIND_DETECT_MAGIC,
 		FLG_NULL,
 	},
 
@@ -256,22 +287,12 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_MAGIC",
+		"/Spell/MAG/DETECT_DOORS",
 		"<Branch>",
 		'\0',
 		"",
-		N_MSG_SPELL_DETECT_MAGIC, "",
-		cb_menu_spell, (void *)SPELL_KIND_DETECT_MAGIC,
-		FLG_NULL,
-	},
-
-	{
-		"/Spell/MAG/DETECT_MONSTER",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DETECT_MONSTER, "",
-		cb_menu_spell, (void *)SPELL_KIND_DETECT_MONSTER,
+		N_MSG_SPELL_DETECT_DOORS, "",
+		cb_menu_spell, (void *)SPELL_KIND_DETECT_DOORS,
 		FLG_NULL,
 	},
 
@@ -285,6 +306,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/MAG/DETECT_MONSTER",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DETECT_MONSTER, "",
+		cb_menu_spell, (void *)SPELL_KIND_DETECT_MONSTER,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/MAG/SENSE_INVISIBLE",
 		"<Branch>",
@@ -314,7 +345,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B6&DLKbK!(B] $B%9%F%$%?%9JQ2=(B */
+/* [ˡ] ƥѲ */
 	{
 		"/Spell/MAG/Title Change status",
 		"<Title>",
@@ -374,7 +405,7 @@ menu_t	ls_menu_spell[] = {
 		cb_menu_spell, (void *)SPELL_KIND_PASSWALL,
 		FLG_NULL,
 	},
-/* [$B6&DLKbK!(B] $BFC<l%U%i%0JQ2=(B */
+/* [ˡ] üե饰Ѳ */
 	{
 		"/Spell/MAG/POLYMORPH_OTHER",
 		"<Branch>",
@@ -424,7 +455,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B@oF.KbK!(B] */
+/* [Ʈˡ] */
 	{
 		"/Spell/SOR",
 		"<Branch>",
@@ -434,7 +465,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B@oF.KbK!(B] $B967b(B */
+/* [Ʈˡ]  */
 	{
 		"/Spell/SOR/Title Attack",
 		"<Title>",
@@ -475,16 +506,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/Spell/SOR/WIND_STORM",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MIND_STORM, "",
-		cb_menu_spell, (void *)SPELL_KIND_MIND_STORM,
-		FLG_NULL,
-	},
-
 	{
 		"/Spell/SOR/ACID_RAIN",
 		"<Branch>",
@@ -495,6 +516,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/SOR/MIND_STORM",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MIND_STORM, "",
+		cb_menu_spell, (void *)SPELL_KIND_MIND_STORM,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/SOR/LIGHTNING_BOLT",
 		"<Branch>",
@@ -544,7 +575,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B@oF.KbK!(B] $BKI8f(B */
+/* [Ʈˡ] ɸ */
 	{
 		"/Spell/SOR/Title Defense",
 		"<Title>",
@@ -555,16 +586,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/Spell/SOR/MAGE_ARMOR",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MAGE_ARMOR, "",
-		cb_menu_spell, (void *)SPELL_KIND_MAGE_ARMOR,
-		FLG_NULL,
-	},
-
 	{
 		"/Spell/SOR/MAGIC_SHIELD",
 		"<Branch>",
@@ -575,6 +596,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/SOR/MAGE_ARMOR",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MAGE_ARMOR, "",
+		cb_menu_spell, (void *)SPELL_KIND_MAGE_ARMOR,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/SOR/STONESKIN",
 		"<Branch>",
@@ -634,7 +665,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B@oF.KbK!(B] $B%9%F!<%?%90[>o(B */
+/* [Ʈˡ] ơ۾ */
 	{
 		"/Spell/SOR/Title Weaken status",
 		"<Title>",
@@ -764,7 +795,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B] */
+/* [ˡ] */
 	{
 		"/Spell/ENC",
 		"<Branch>",
@@ -774,7 +805,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B] $B%"%S%j%F%#6/2=(B */
+/* [ˡ] ӥƥ */
 	{
 		"/Spell/ENC/Title Strengthen ability",
 		"<Title>",
@@ -864,7 +895,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B] $B6/2=(B */
+/* [ˡ]  */
 	{
 		"/Spell/ENC/Title Strengthen misc",
 		"<Title>",
@@ -884,7 +915,7 @@ menu_t	ls_menu_spell[] = {
 		cb_menu_spell, (void *)SPELL_KIND_POWER_UP_HP,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B]  */
+/* [ˡ]  */
 	{
 		"/Spell/ENC/HASTE",
 		"<Branch>",
@@ -914,7 +945,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B] $B%"%S%j%F%#<eBN(B */
+/* [ˡ] ӥƥ */
 	{
 		"/Spell/ENC/Title Weaken ability",
 		"<Title>",
@@ -1004,7 +1035,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B] $B<eBN(B */
+/* [ˡ]  */
 	{
 		"/Spell/ENC/Title Weaken misc",
 		"<Title>",
@@ -1024,7 +1055,7 @@ menu_t	ls_menu_spell[] = {
 		cb_menu_spell, (void *)SPELL_KIND_ENERGY_DRAIN,
 		FLG_NULL,
 	},
-/* [$B1g8nKbK!(B]  */
+/* [ˡ]  */
 	{
 		"/Spell/ENC/SLOW",
 		"<Branch>",
@@ -1074,7 +1105,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B>$4-KbK!(B] */
+/* [ˡ] */
 	{
 		"/Spell/SUM",
 		"<Branch>",
@@ -1084,7 +1115,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B>$4-KbK!(B] $B>$4-(B */
+/* [ˡ]  */
 	{
 		"/Spell/SUM/Title Summon",
 		"<Title>",
@@ -1134,7 +1165,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BANN7<vJ8(B] */
+/* [ηʸ] */
 	{
 		"/Spell/PRI",
 		"<Branch>",
@@ -1144,7 +1175,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BANN7<vJ8(B] $B2sI|(B */
+/* [ηʸ]  */
 	{
 		"/Spell/PRI/Title Cure",
 		"<Title>",
@@ -1274,7 +1305,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BANN7<vJ8(B] $B>uBV2sI|(B */
+/* [ηʸ] ֲ */
 	{
 		"/Spell/PRI/Title Cure status",
 		"<Title>",
@@ -1404,7 +1435,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BANN7<vJ8(B] $BDq93(B */
+/* [ηʸ]  */
 	{
 		"/Spell/PRI/Title Resist",
 		"<Title>",
@@ -1455,16 +1486,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/Spell/PRI/RESIST_WIND",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_RESIST_WIND, "",
-		cb_menu_spell, (void *)SPELL_KIND_RESIST_WIND,
-		FLG_NULL,
-	},
-
 	{
 		"/Spell/PRI/RESIST_ACID",
 		"<Branch>",
@@ -1475,6 +1496,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/PRI/RESIST_MIND",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_RESIST_MIND, "",
+		cb_menu_spell, (void *)SPELL_KIND_RESIST_MIND,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/PRI/RESIST_ELECTRICITY",
 		"<Branch>",
@@ -1514,7 +1545,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BANN7<vJ8(B] $B?@@;(B */
+/* [ηʸ]  */
 	{
 		"/Spell/PRI/Title Holy",
 		"<Title>",
@@ -1594,7 +1625,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$B@:NnKbK!(B]  */
+/* [ˡ]  */
 	{
 		"/Spell/SHA",
 		"<Branch>",
@@ -1604,8 +1635,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-
-/* [$B<v2N(B]  */
+/* []  */
 	{
 		"/Spell/BAR",
 		"<Branch>",
@@ -1615,8 +1645,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-
-/* [$BG&=Q(B] */
+/* [Ǧ] */
 	{
 		"/Spell/NIN",
 		"<Branch>",
@@ -1626,7 +1655,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BG&=Q(B] $BE7JQCO0[(B */
+/* [Ǧ] ŷϰ */
 	{
 		"/Spell/NIN/Title Disaster",
 		"<Title>",
@@ -1637,6 +1666,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/Spell/NIN/TYPHOON",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_TYPHOON, "",
+		cb_menu_spell, (void *)SPELL_KIND_TYPHOON,
+		FLG_NULL,
+	},
+
 	{
 		"/Spell/NIN/CONFLAGRATION",
 		"<Branch>",
@@ -1696,7 +1735,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [$BG&=Q(B]  */
+/* [Ǧ]  */
 	{
 		"/Spell/NIN/Title Misc",
 		"<Title>",
@@ -1815,658 +1854,1030 @@ menu_t	ls_menu_spell_extent[] = {
 	},
 };
 
-/**/
+/******************************************************************/
+
+#if	0
+typedef struct {
+	spell_kind_t	kind;
+	n_msg_t	n_name;
+	char	*name;
+	long	hp, mp;
+	gold_t	gold;
+	abl_kind_t	abl;
+	flg_extent_t	flg_extent;
+	bool_t	flg_trgt;
+	resi_kind_t	resi;
+	gold_t	price;
+} spell_tab_t;
+#endif
 
 spell_tab_t	spell_tab[] = {
 	{
 		SPELL_KIND_NULL,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_HP, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
 /* MAG */
 	{
 		SPELL_KIND_MAG_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_MAG, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
+
 	{
 		SPELL_KIND_LIGHT,
 		N_MSG_SPELL_LIGHT, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_ELEC,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DARKNESS,
 		N_MSG_SPELL_DARKNESS, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
-	},
-	{
-		SPELL_KIND_KNOCK,
-		N_MSG_SPELL_KNOCK, "",
-		0, 2, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_LOCK,
-		N_MSG_SPELL_LOCK, "",
-		0, 2, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_DISARM_TRAP,
-		N_MSG_SPELL_DISARM_TRAP, "",
-		0, 2, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_DISPEL_MAGIC,
-		N_MSG_SPELL_DISPEL_MAGIC, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_TELEPORT,
-		N_MSG_SPELL_TELEPORT, "",
-		0, 4, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_POIS,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_TELEPORT_PARTY,
 		N_MSG_SPELL_TELEPORT_PARTY, "",
-		0, 2, FLG_EXTENT_NORMAL, FALSE,
+		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_TELEPORT,
+		N_MSG_SPELL_TELEPORT, "",
+		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_RECALL,
 		N_MSG_SPELL_RECALL, "",
-		0, 10, FLG_EXTENT_NORMAL, FALSE,
+		0, 10, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_KNOCK,
+		N_MSG_SPELL_KNOCK, "",
+		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
+	{
+		SPELL_KIND_LOCK,
+		N_MSG_SPELL_LOCK, "",
+		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
+	{
+		SPELL_KIND_DISARM_TRAP,
+		N_MSG_SPELL_DISARM_TRAP, "",
+		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
+	{
+		SPELL_KIND_DISPEL_MAGIC,
+		N_MSG_SPELL_DISPEL_MAGIC, "",
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_MIRROR_IMAGE,
 		N_MSG_SPELL_MIRROR_IMAGE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ANIMATE_OBJECTS,
 		N_MSG_SPELL_ANIMATE_OBJECTS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SHELTER,
 		N_MSG_SPELL_SHELTER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CREATE_FOOD,
 		N_MSG_SPELL_CREATE_FOOD, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CREATE_UNDEAD,
 		N_MSG_SPELL_CREATE_UNDEAD, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_IDENTIFY_ITEM,
 		N_MSG_SPELL_IDENTIFY_ITEM, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SEARCHING,
 		N_MSG_SPELL_SEARCHING, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ANALYZE_DWEOMER,
 		N_MSG_SPELL_ANALYZE_DWEOMER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_DETECT_DOORS,
-		N_MSG_SPELL_DETECT_DOORS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_DETECT_ITEM,
-		N_MSG_SPELL_DETECT_ITEM, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DETECT_MAGIC,
 		N_MSG_SPELL_DETECT_MAGIC, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
-		SPELL_KIND_DETECT_MONSTER,
-		N_MSG_SPELL_DETECT_MONSTER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		SPELL_KIND_DETECT_ITEM,
+		N_MSG_SPELL_DETECT_ITEM, "",
+		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_DETECT_DOORS,
+		N_MSG_SPELL_DETECT_DOORS, "",
+		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_DETECT_TRAPS,
 		N_MSG_SPELL_DETECT_TRAPS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_DETECT_MONSTER,
+		N_MSG_SPELL_DETECT_MONSTER, "",
+		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_SENSE_INVISIBLE,
 		N_MSG_SPELL_SENSE_INVISIBLE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_FLY,
 		N_MSG_SPELL_FLY, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_FEATHER_FALL,
 		N_MSG_SPELL_FEATHER_FALL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_VANISH,
 		N_MSG_SPELL_VANISH, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DARKVISION,
 		N_MSG_SPELL_DARKVISION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_PASSWALL,
 		N_MSG_SPELL_PASSWALL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_POLYMORPH_OTHER,
 		N_MSG_SPELL_POLYMORPH_OTHER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_POLYMORPH_SELF,
 		N_MSG_SPELL_POLYMORPH_SELF, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_STEALTH,
 		N_MSG_SPELL_STEALTH, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_MAG_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_MAG, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
 /* SOR */
 	{
 		SPELL_KIND_SOR_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_SOR, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
+
 	{
 		SPELL_KIND_MAGIC_MISSILE,
 		N_MSG_SPELL_MAGIC_MISSILE, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_KNOC,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_FIRE_BALL,
 		N_MSG_SPELL_FIRE_BALL, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_HEAT,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ICE_BLIZZARD,
 		N_MSG_SPELL_ICE_BLIZZARD, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
-	},
-	{
-		SPELL_KIND_MIND_STORM,
-		N_MSG_SPELL_MIND_STORM, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_COLD,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ACID_RAIN,
 		N_MSG_SPELL_ACID_RAIN, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_ACID,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_MIND_STORM,
+		N_MSG_SPELL_MIND_STORM, "",
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_LIGHTNING_BOLT,
 		N_MSG_SPELL_LIGHTNING_BOLT, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_ELEC,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_POISON_CLOUD,
 		N_MSG_SPELL_POISON_CLOUD, "",
-		0, 4, FLG_EXTENT_ALL, TRUE,
+		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
+		RESI_KIND_POIS,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DEATH_SPELL,
 		N_MSG_SPELL_DEATH_SPELL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_MAGE_ARMOR,
-		N_MSG_SPELL_MAGE_ARMOR, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_MAGIC_SHIELD,
 		N_MSG_SPELL_MAGIC_SHIELD, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 1, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_MAGE_ARMOR,
+		N_MSG_SPELL_MAGE_ARMOR, "",
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_STONESKIN,
 		N_MSG_SPELL_STONESKIN, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_IRON_BODY,
 		N_MSG_SPELL_IRON_BODY, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SPELL_RESISTANCE,
 		N_MSG_SPELL_SPELL_RESISTANCE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_COUNTER_MAGIC,
 		N_MSG_SPELL_COUNTER_MAGIC, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_STONE,
 		N_MSG_SPELL_STONE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_PARALYZE,
 		N_MSG_SPELL_PARALYZE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_BLINDNESS,
 		N_MSG_SPELL_BLINDNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_POISON,
 		N_MSG_SPELL_POISON, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_POIS,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CONFUSION,
 		N_MSG_SPELL_CONFUSION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SILENCE,
 		N_MSG_SPELL_SILENCE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SLEEP,
 		N_MSG_SPELL_SLEEP, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_FEAR,
 		N_MSG_SPELL_FEAR, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_HALLUCINATION,
 		N_MSG_SPELL_HALLUCINATION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CHARM,
 		N_MSG_SPELL_CHARM, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SOR_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_SOR, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
 /* ENC */
 	{
 		SPELL_KIND_ENC_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_ENC, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
+
 	{
 		SPELL_KIND_SHARPNESS,
 		N_MSG_SPELL_SHARPNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_STRENGTH,
 		N_MSG_SPELL_STRENGTH, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_QUICKNESS,
 		N_MSG_SPELL_QUICKNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_WISE,
 		N_MSG_SPELL_WISE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_BRAINY,
 		N_MSG_SPELL_BRAINY, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ATTRACTIVE,
 		N_MSG_SPELL_ATTRACTIVE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_POWER_UP_HP,
 		N_MSG_SPELL_POWER_UP_HP, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_HASTE,
 		N_MSG_SPELL_HASTE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DULLNESS,
 		N_MSG_SPELL_DULLNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_WEAKNESS,
 		N_MSG_SPELL_WEAKNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SLOWNESS,
 		N_MSG_SPELL_SLOWNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_FOOLISH,
 		N_MSG_SPELL_FOOLISH, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_BRAINLESS,
 		N_MSG_SPELL_BRAINLESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_UNATTRACTIVE,
 		N_MSG_SPELL_UNATTRACTIVE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ENERGY_DRAIN,
 		N_MSG_SPELL_ENERGY_DRAIN, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MIND,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SLOW,
 		N_MSG_SPELL_SLOW, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_HUNGER,
 		N_MSG_SPELL_HUNGER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CANCELLATION,
 		N_MSG_SPELL_CANCELLATION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_ENC_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_ENC, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
 /* SUM */
 	{
 		SPELL_KIND_SUM_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_SUM, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
+
 	{
 		SPELL_KIND_SUMMON_MONSTER,
 		N_MSG_SPELL_SUMMON_MONSTER, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SUM, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DISMISSAL,
 		N_MSG_SPELL_DISMISSAL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_SUM, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SUM_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_SUM, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
 /* PRI */
 	{
 		SPELL_KIND_PRI_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_PRI, FLG_NULL, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)0),
 	},
+
 	{
 		SPELL_KIND_CURE_HP_LIGHT,
 		N_MSG_SPELL_CURE_HP_LIGHT, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_HP_MODERATE,
 		N_MSG_SPELL_CURE_HP_MODERATE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_HP_SERIOUS,
 		N_MSG_SPELL_CURE_HP_SERIOUS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_HP_MAX,
 		N_MSG_SPELL_CURE_HP_MAX, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_MP,
 		N_MSG_SPELL_CURE_MP, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_TRANSFER_MP,
 		N_MSG_SPELL_TRANSFER_MP, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_REGENERATION,
 		N_MSG_SPELL_REGENERATION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		RESI_KIND_MAX_N,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESTORE_EXPERIENCE,
 		N_MSG_SPELL_RESTORE_EXPERIENCE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESURRECTION,
 		N_MSG_SPELL_RESURRECTION, "",
-		0, 1, FLG_EXTENT_NORMAL, FALSE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_NORMAL, FALSE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_HEAL,
 		N_MSG_SPELL_HEAL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_STATUS,
 		N_MSG_SPELL_CURE_STATUS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_STONE,
 		N_MSG_SPELL_CURE_STONE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_PARALYZE,
 		N_MSG_SPELL_CURE_PARALYZE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_BLINDNESS,
 		N_MSG_SPELL_CURE_BLINDNESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_POISON,
 		N_MSG_SPELL_CURE_POISON, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_CONFUSION,
 		N_MSG_SPELL_CURE_CONFUSION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_SILENCE,
 		N_MSG_SPELL_CURE_SILENCE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_SLEEP,
 		N_MSG_SPELL_CURE_SLEEP, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_FEAR,
 		N_MSG_SPELL_CURE_FEAR, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_CURE_CHARM,
 		N_MSG_SPELL_CURE_CHARM, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_PROTECTION,
 		N_MSG_SPELL_PROTECTION, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESIST_PHYSICAL,
 		N_MSG_SPELL_RESIST_PHYSICAL, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESIST_HEAT,
 		N_MSG_SPELL_RESIST_HEAT, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESIST_COLD,
 		N_MSG_SPELL_RESIST_COLD, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
-	},
-	{
-		SPELL_KIND_RESIST_WIND,
-		N_MSG_SPELL_RESIST_WIND, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESIST_ACID,
 		N_MSG_SPELL_RESIST_ACID, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
+	{
+		SPELL_KIND_RESIST_MIND,
+		N_MSG_SPELL_RESIST_MIND, "",
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_RESIST_ELECTRICITY,
 		N_MSG_SPELL_RESIST_ELECTRICITY, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_RESIST_POISON,
 		N_MSG_SPELL_RESIST_POISON, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_BLESS,
 		N_MSG_SPELL_BLESS, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_REMOVE_CURSE,
 		N_MSG_SPELL_REMOVE_CURSE, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_DISPEL_UNDEAD,
 		N_MSG_SPELL_DISPEL_UNDEAD, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SANCTUARY,
 		N_MSG_SPELL_SANCTUARY, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_WISH,
 		N_MSG_SPELL_WISH, "",
-		0, 1, FLG_EXTENT_STD, TRUE,
+		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_PRI_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_PRI, FLG_NULL, TRUE,
+		((gold_t)0),
 	},
 /* SHA */
+
+
+
+
+
 /* BAR */
+
+
+
+
+
 /* NIN */
 	{
 		SPELL_KIND_NIN_MIN_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_NIN, FLG_NULL, TRUE,
+		((gold_t)0),
 	},
+
+	{
+		SPELL_KIND_TYPHOON,
+		N_MSG_SPELL_TYPHOON, "",
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
+		((gold_t)100),
+	},
+
 	{
 		SPELL_KIND_CONFLAGRATION,
 		N_MSG_SPELL_CONFLAGRATION, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_EARTHQUAKE,
 		N_MSG_SPELL_EARTHQUAKE, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_THUNDERCLOUD,
 		N_MSG_SPELL_THUNDERCLOUD, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_INUNDATION,
 		N_MSG_SPELL_INUNDATION, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_SUBSTITUTE,
 		N_MSG_SPELL_SUBSTITUTE, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_BURNING_HANDS,
 		N_MSG_SPELL_BURNING_HANDS, "",
-		1, 0, FLG_EXTENT_STD, TRUE,
+		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_STD, TRUE,
+		((gold_t)100),
 	},
+
 	{
 		SPELL_KIND_NIN_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_NIN, FLG_NULL, TRUE,
+		((gold_t)0),
 	},
 /* end */
 	{
 		SPELL_KIND_MAX_N,
 		N_MSG_NULL, "",
-		0, 0, FLG_NULL, TRUE,
+		0, 0, 0, ABL_KIND_HP, FLG_NULL, TRUE,
+		((gold_t)0),
 	},
 };
 
-#endif	/* __SPELL_TAB_H__ */
+#endif	/* SPELL_TAB_H */
