@@ -1,18 +1,45 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: tmenu.c,v 1.27 2003/11/23 05:13:28 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
-/*#include	"mnstr.h"*/
+#include	"mnstr.h"
+#include	"pet.h"
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,13 +49,16 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 #include	"town_prot.h"
 #include	"item_prot.h"
-/*#include	"spell_prot.h"*/
+#include	"spell_prot.h"
 #include	"chr_prot.h"
 #include	"party_prot.h"
-/*#include	"mnstr_prot.h"*/
+#include	"mnstr_prot.h"
+#include	"pet_prot.h"
 /*#include	"fight_prot.h"*/
 #include	"fx_prot.h"
 /*#include	"trap_prot.h"*/
@@ -57,16 +87,20 @@
 
 #define	CHARGE_STAY_INN	10
 
+#define	ORDER_MILK_LEV	20
+
 /**/
 
 #include	"tmenu_tab.h"
 
 /**/
 
-mbr_t	*g_sel_mbr, *g_sel_ls_mbr;
-shop_n_t	g_shop_n;
-deal_kind_t	g_deal_kind;
-item_t	*g_sel_art;
+static mbr_t	*g_sel_mbr, *g_sel_ls_mbr;
+static shop_n_t	g_shop_n;
+static deal_kind_t	g_deal_kind;
+static item_t	*g_sel_art;
+static long	g_sel_class_n;
+static item_t	*g_mbr_order[MBR_MAX_N];
 
 /**/
 
@@ -78,15 +112,23 @@ void	init_tmenu( void )
 	g_sel_mbr = pty->mbr[0];
 	g_sel_ls_mbr = ls_mbr[0];
 	g_sel_art = NULL;
+	g_sel_class_n = 0;
 }
 
 /**/
 
 char	*menu_shop_sel_mbr( shop_n_t shop_n )
 {
+	bool_t	flg_sel_dead;
+
 	g_shop_n = shop_n;
 	g_deal_kind = DEAL_KIND_BUY;
 
+	if( g_shop_n == SHOP_N_TEMPLE )
+		flg_sel_dead = TRUE;
+	else
+		flg_sel_dead = FALSE;
+
 	while( 1 ){
 		char	ttl[MENU_MSG_MAX_LEN + 1];
 		char	*str_goto;
@@ -94,53 +136,49 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n )
 		sprintf( ttl, MSG_MENU_SHOP_SEL_MBR,
 				get_shop_name( g_shop_n ) );
 
-		switch( g_shop_n ){
-		case SHOP_N_INN:
-		case SHOP_N_BAR:
-			break;
-		case SHOP_N_TEMPLE:
-			str_goto = exec_menu_sel_mbr(
-					&g_sel_mbr, ttl, TRUE );
-			if( str_goto != NULL )
-				return str_goto;
+		str_goto = exec_menu_sel_mbr(
+				&g_sel_mbr, ttl, flg_sel_dead );
+		if( str_goto != NULL )
+			return str_goto;
 
-			while( 1 ){
+		while( 1 ){
+			switch( g_shop_n ){
+			case SHOP_N_NULL:
+			case SHOP_N_MAX_N:
+			case SHOP_N_INN:
+			case SHOP_N_BAR:
+			case SHOP_N_RESTAURANT:
+				return STR_MENU_ERR;
+				break;
+			case SHOP_N_TEMPLE:
 				str_goto = exec_menu( ls_menu_temple,
 						NULL, str_goto );
-
-				if( str_goto == NULL )
-					continue;
-				if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
-					break;
-				if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
-					break;
-			}
-			break;
-		case SHOP_N_WPN:
-		case SHOP_N_ARMOR:
-		case SHOP_N_MAGIC:
-		case SHOP_N_GROCERY:
-		case SHOP_N_RESTAURANT:
-		case SHOP_N_TEAROOM:
-		case SHOP_N_TOBACCO:
-			str_goto = exec_menu_sel_mbr(
-					&g_sel_mbr, ttl, FALSE );
-			if( str_goto != NULL )
-				return str_goto;
-
-			g_sel_art = NULL;
-			while( 1 ){
+				break;
+			case SHOP_N_MAGIC:
+				str_goto = exec_menu( ls_menu_magic_guild,
+						NULL, str_goto );
+				break;
+			case SHOP_N_WPN:
+			case SHOP_N_ARMOR:
+			case SHOP_N_ALCHEMY:
+			case SHOP_N_GROCERY:
+			case SHOP_N_TEAROOM:
+			case SHOP_N_TOBACCO:
 				str_goto = menu_shop( g_shop_n, g_sel_mbr,
 						str_goto );
-
-				if( str_goto == NULL )
-					continue;
-				if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
-					break;
-				if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
-					break;
+				break;
+			case SHOP_N_PET_SHOP:
+				str_goto = exec_menu( ls_menu_pet_shop,
+						NULL, str_goto );
+				break;
 			}
-			break;
+
+			if( str_goto == NULL )
+				continue;
+			if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
+				break;
+			if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+				break;
 		}
 	}
 
@@ -149,13 +187,11 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n )
 
 /**/
 
-char	*cb_menu_temple_init(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 {
 	long	len;
 	menu_t	*p;
-	long	price;
+	gold_t	price;
 
 	len = 0;
 	for( p = *pp; p->path[0] != '\0'; p++ ){
@@ -166,22 +202,30 @@ char	*cb_menu_temple_init(
 	}
 
 	p = srch_menu( *pp, "Title" );
+	if( p == NULL )
+		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_TEMPLE,
 			get_shop_name( SHOP_N_TEMPLE ),
 			g_sel_mbr->name, g_sel_mbr->gold );
 
 	price = get_price_temple_remove_curse( g_sel_mbr );
 	p = srch_menu( *pp, "Remove curse" );
+	if( p == NULL )
+		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), price );
 
 	price = get_price_temple_cure_status( g_sel_mbr );
 	p = srch_menu( *pp, "Cure status" );
+	if( p == NULL )
+		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), price );
 
 	price = get_price_temple_resurrection( g_sel_mbr );
 	p = srch_menu( *pp, "Resurrection" );
+	if( p == NULL )
+		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), price );
 
@@ -190,11 +234,9 @@ char	*cb_menu_temple_init(
 
 /**/
 
-char	*cb_menu_temple_remove_curse(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt )
 {
-	long	price;
+	gold_t	price;
 	ask_t	ask;
 
 	price = get_price_temple_remove_curse( g_sel_mbr );
@@ -233,11 +275,9 @@ char	*cb_menu_temple_remove_curse(
 
 /**/
 
-char	*cb_menu_temple_cure_status(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 {
-	long	price;
+	gold_t	price;
 	ask_t	ask;
 
 	price = get_price_temple_cure_status( g_sel_mbr );
@@ -276,11 +316,9 @@ char	*cb_menu_temple_cure_status(
 
 /**/
 
-char	*cb_menu_temple_resurrection(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 {
-	long	price;
+	gold_t	price;
 	ask_t	ask;
 
 	price = get_price_temple_resurrection( g_sel_mbr );
@@ -319,11 +357,9 @@ char	*cb_menu_temple_resurrection(
 
 /**/
 
-char	*cb_menu_temple_contribution(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt )
 {
-	long	price;
+	gold_t	price;
 	char	*str_goto;
 	ask_t	ask;
 
@@ -364,6 +400,226 @@ char	*cb_menu_temple_contribution(
 
 /**/
 
+char	*menu_restaurant( void )
+{
+	g_shop_n = SHOP_N_RESTAURANT;
+
+	return menu_order();
+}
+
+/**/
+
+bool_t	chk_shop_order( shop_n_t g_shop_n )
+{
+	if( g_shop_n == SHOP_N_BAR )
+		return TRUE;
+	if( g_shop_n == SHOP_N_RESTAURANT )
+		return TRUE;
+
+	return FALSE;
+}
+
+/**/
+
+char	*menu_order( void )
+{
+	long	i;
+	char	*str_goto;
+
+	g_sel_mbr = NULL;
+	g_sel_art = NULL;
+
+	for( i = 0; i < MBR_MAX_N; i++ )
+		g_mbr_order[i] = NULL;
+
+	while( 1 ){
+		str_goto = menu_order_sel_mbr();
+		if( str_goto != NULL ){
+			if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
+				return NULL;
+			if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+				return NULL;
+		}
+	}
+
+	return STR_MENU_ERR;
+}
+
+/**/
+
+char	*menu_order_sel_mbr( void )
+{
+	party_t	*pty = get_party();
+	mbr_t	**mbr;
+	menu_t	*p, *dflt;
+	long	i, k;
+	long	mbr_n;
+
+	p = ls_menu_order_sel_mbr;
+	dflt = NULL;
+
+	mbr = pty->mbr;
+	mbr_n = 0;
+	k = 0;
+
+	strncpy( p[k].path, "/Order", MENU_PATH_MAX_LEN );
+	strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	p[k].key = '\0';
+	p[k].accel_key[0] = '\0';
+	p[k].msg[0] = '\0';
+	p[k].call_back = NULL;
+	p[k].arg = NULL;
+	p[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( p[k].path, "/Order/--", MENU_PATH_MAX_LEN );
+	strncpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	p[k].key = '\0';
+	p[k].accel_key[0] = '\0';
+	strncpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
+	p[k].call_back = NULL;
+	p[k].arg = NULL;
+	p[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		char	*name;
+
+		if( chk_flg_or( mbr[i]->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD
+				| FLG_STAT_STONE | FLG_STAT_PARALYZE
+				| FLG_STAT_CONFUSION | FLG_STAT_SLEEP
+				| FLG_STAT_FEAR | FLG_STAT_HALLUCINATION ) ){
+			continue;
+		}
+
+		if( (g_sel_mbr != NULL) && (g_sel_mbr->mbr_n == i) )
+			dflt = &(p[k]);
+
+		sprintf( p[k].path, "/Order/%ld", i );
+		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		p[k].key = 'A' + i;
+		p[k].accel_key[0] = '\0';
+		if( g_mbr_order[i] == NULL )
+			name = MSG_MENU_ORDER_NULL;
+		else
+			name = g_mbr_order[i]->name;
+		sprintf( p[k].msg, MSG_MENU_ORDER_MBR, mbr[i]->name, name );
+		p[k].call_back = cb_menu_order_sel;
+		p[k].arg = mbr[i];
+		p[k].flg = FLG_NULL;
+		k++;
+
+		mbr_n++;
+	}
+
+	strncpy( p[k].path, "/Order/Chose", MENU_PATH_MAX_LEN );
+	strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	p[k].key = 'Z';
+	p[k].accel_key[0] = '\0';
+	strncpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
+	p[k].call_back = cb_menu_order_chose;
+	p[k].arg = NULL;
+	p[k].flg = FLG_NULL;
+	k++;
+
+	p[k].path[0] = '\0';
+
+	if( mbr_n <= 0 ){
+		print_msg( FLG_NULL, MSG_ERR_MENU_NOT_EXIST_MBR );
+		return STR_MENU_ERR;
+	}
+
+	return exec_menu( p, dflt, NULL );
+}
+
+/**/
+
+char	*cb_menu_order_sel( menu_t **pp, menu_t **dflt )
+{
+	char	*str_goto;
+
+	g_sel_mbr = (mbr_t *)((*pp)->arg);
+
+	str_goto = menu_shop( g_shop_n, g_sel_mbr, NULL );
+	if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+		return STR_MENU_CANCEL;
+
+	if( g_sel_mbr == NULL )
+		return STR_MENU_ERR;
+	g_mbr_order[g_sel_mbr->mbr_n] = g_sel_art;
+
+	return str_goto;
+}
+
+/**/
+
+char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
+{
+	party_t	*pty = get_party();
+	long	i;
+
+	g_sel_mbr = NULL;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		item_t	*item, *tmp;
+		gold_t	price;
+
+		item = g_mbr_order[i];
+		if( item == NULL )
+			continue;
+
+		price = get_price( g_shop_n, item, DEAL_KIND_BUY );
+		if( !chk_pay( price, pty->mbr[i] ) )
+			continue;
+
+		tmp = alloc_item();
+		if( tmp == NULL )
+			return STR_MENU_ERR;
+		copy_item( tmp, item );
+		tmp->stock = 1;
+
+		if( tmp->kind == ITEM_KIND_FOOD ){
+			eat_food( pty->mbr[i], tmp );
+		} else if( tmp->kind == ITEM_KIND_POTION ){
+			quaff_potion( pty->mbr[i], tmp, TRUE );
+			chk_order_milk( pty->mbr[i], g_shop_n, item );
+		}
+
+		item->stock--;
+		if( item->stock <= 0 )
+			inc_item( item, -item->n );
+
+		g_mbr_order[i] = NULL;
+	}
+
+	return "/Order";
+}
+
+/**/
+
+bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
+{
+	if( mbr == NULL )
+		return FALSE;
+	if( item == NULL )
+		return FALSE;
+
+	if( mbr->sex.cur != MALE )
+		return FALSE;
+	if( get_specialist_lev( mbr ) >= ORDER_MILK_LEV )
+		return FALSE;
+	if( shop_n != SHOP_N_BAR )
+		return FALSE;
+	if( item->dat.potion.kind != POTION_KIND_MILK )
+		return FALSE;
+
+	print_words( MSG_NPC_NAME_BAR, MSG_WORDS_MALE_ORDER_MILK );
+	return TRUE;
+}
+
+/**/
+
 char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 {
 	menu_t	*ls, *dflt;
@@ -379,6 +635,9 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 
 	pty = get_party();
 
+	if( mbr == NULL )
+		return STR_MENU_ERR;
+
 	art_head = get_begin_article( mbr, shop_n, g_deal_kind );
 	if( art_head == NULL )
 		return STR_MENU_ERR;
@@ -503,7 +762,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		sprintf( ls[i].msg,
 				MSG_FMT_ART_NAME,
 				max_len, ls_art[j]->art_name,
-				get_price( ls_art[j], g_deal_kind ) );
+				get_price( g_shop_n, ls_art[j],
+				g_deal_kind ) );
 		j++;
 	}
 
@@ -556,50 +816,50 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].flg = FLG_NULL;
 	(*k)++;
 
-	/* Sale equip */
+	if( !chk_shop_order( g_shop_n ) ){
+		/* Sale equip */
+		if( g_deal_kind != DEAL_KIND_SALE_EQUIP ){
+			strncpy( ls[*k].path, "/Shop/Sale equip",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			ls[*k].key = 'X';
+			ls[*k].accel_key[0] = '\0';
+			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
+					MENU_MSG_MAX_LEN );
+			ls[*k].call_back = cb_menu_shop_sale_equip;
+			ls[*k].arg = NULL;
+			ls[*k].flg = FLG_NULL;
+			(*k)++;
+		}
 
-	if( g_deal_kind != DEAL_KIND_SALE_EQUIP ){
-		strncpy( ls[*k].path, "/Shop/Sale equip",
-				MENU_PATH_MAX_LEN );
-		strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[*k].key = 'X';
-		ls[*k].accel_key[0] = '\0';
-		strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
-				MENU_MSG_MAX_LEN );
-		ls[*k].call_back = cb_menu_shop_sale_equip;
-		ls[*k].arg = NULL;
-		ls[*k].flg = FLG_NULL;
-		(*k)++;
-	}
+		/* Sale item */
+		if( g_deal_kind != DEAL_KIND_SALE_ITEM ){
+			strncpy( ls[*k].path, "/Shop/Sale item",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			ls[*k].key = 'Y';
+			ls[*k].accel_key[0] = '\0';
+			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
+					MENU_MSG_MAX_LEN );
+			ls[*k].call_back = cb_menu_shop_sale_item;
+			ls[*k].arg = NULL;
+			ls[*k].flg = FLG_NULL;
+			(*k)++;
+		}
 
-	/* Sale item */
-
-	if( g_deal_kind != DEAL_KIND_SALE_ITEM ){
-		strncpy( ls[*k].path, "/Shop/Sale item",
-				MENU_PATH_MAX_LEN );
-		strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[*k].key = 'Y';
-		ls[*k].accel_key[0] = '\0';
-		strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
-				MENU_MSG_MAX_LEN );
-		ls[*k].call_back = cb_menu_shop_sale_item;
-		ls[*k].arg = NULL;
-		ls[*k].flg = FLG_NULL;
-		(*k)++;
-	}
-
-	/* Buy */
-
-	if( g_deal_kind != DEAL_KIND_BUY ){
-		strncpy( ls[*k].path, "/Shop/Buy", MENU_PATH_MAX_LEN );
-		strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[*k].key = 'Z';
-		ls[*k].accel_key[0] = '\0';
-		strncpy( ls[*k].msg, MSG_MENU_SHOP_BUY, MENU_MSG_MAX_LEN );
-		ls[*k].call_back = cb_menu_shop_buy;
-		ls[*k].arg = NULL;
-		ls[*k].flg = FLG_NULL;
-		(*k)++;
+		/* Buy */
+		if( g_deal_kind != DEAL_KIND_BUY ){
+			strncpy( ls[*k].path, "/Shop/Buy", MENU_PATH_MAX_LEN );
+			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			ls[*k].key = 'Z';
+			ls[*k].accel_key[0] = '\0';
+			strncpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
+					MENU_MSG_MAX_LEN );
+			ls[*k].call_back = cb_menu_shop_buy;
+			ls[*k].arg = NULL;
+			ls[*k].flg = FLG_NULL;
+			(*k)++;
+		}
 	}
 
 	/* <PageSeparator> */
@@ -673,9 +933,7 @@ char	*menu_town_mbr_data(
 
 /**/
 
-char	*cb_menu_shop_collect_gold(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_shop_collect_gold( menu_t **pp, menu_t **dflt )
 {
 	collect_gold( g_sel_mbr );
 
@@ -684,9 +942,7 @@ char	*cb_menu_shop_collect_gold(
 
 /**/
 
-char	*cb_menu_shop_divide_gold(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_shop_divide_gold( menu_t **pp, menu_t **dflt )
 {
 	divide_gold();
 
@@ -698,15 +954,25 @@ char	*cb_menu_shop_divide_gold(
 char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 {
 	item_t	*art;
-	long	price;
+	gold_t	price;
 
 	art = (item_t *)((*pp)->arg);
-	price = get_price( art, g_deal_kind );
-
 	g_sel_art = art;
 
+	if( chk_shop_order( g_shop_n ) )
+		return "/Order";
+
 	chk_item_data( g_sel_art );
 
+	price = get_price( g_shop_n, art, g_deal_kind );
+	if( price <= 0 ){
+		if( (g_deal_kind == DEAL_KIND_SALE_ITEM)
+				|| (g_deal_kind == DEAL_KIND_SALE_EQUIP) ){
+			print_msg( FLG_NULL, MSG_NO_DEAL, art->art_name );
+			return STR_MENU_CANCEL;
+		}
+	}
+
 	if( g_deal_kind == DEAL_KIND_BUY ){
 		if( !menu_shop_buy( g_shop_n, g_sel_mbr, art ) )
 			return STR_MENU_CANCEL;
@@ -716,12 +982,12 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		if( !menu_shop_sale_item( g_shop_n, g_sel_mbr, art ) )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, price );
+		add_chr_gold( g_sel_mbr, +price );
 	} else if( g_deal_kind == DEAL_KIND_SALE_EQUIP ){
 		if( !menu_shop_sale_equip( g_shop_n, g_sel_mbr, art ) )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, price );
+		add_chr_gold( g_sel_mbr, +price );
 	}
 
 	return "/Shop";
@@ -761,8 +1027,8 @@ bool_t	menu_shop_buy(
 )
 {
 	ask_t	ask;
-	item_t	*tmp, dmy;
-	long	price;
+	item_t	*tmp;
+	gold_t	price;
 
 	/* ̾ɽ */
 	print_msg( FLG_NULL, MSG_MENU_BUY, item->name );
@@ -778,33 +1044,25 @@ bool_t	menu_shop_buy(
 		return FALSE;
 	}
 
-	price = get_price( item, DEAL_KIND_BUY );
+	price = get_price( g_shop_n, item, DEAL_KIND_BUY );
 	if( !chk_pay( price, g_sel_mbr ) )
 		return FALSE;
 
-	tmp = alloc_item( &dmy );
+	tmp = alloc_item();
 	if( tmp == NULL )
 		return FALSE;
 	copy_item( tmp, item );
-
 	tmp->stock = 1;
-	if( g_shop_n == SHOP_N_RESTAURANT ){
-		if( tmp->kind == ITEM_KIND_FOOD )
-			eat_food( g_sel_mbr, tmp );
-		if( tmp->kind == ITEM_KIND_POTION )
-			quaff_potion( g_sel_mbr, tmp, TRUE );
-	} else if( !give_mbr_item( g_sel_mbr, tmp ) ){
-		print_msg( FLG_NULL, MSG_ERR_ITEM_FULL, g_sel_mbr->name );
-		return TRUE;
-	}
+
+	if( !give_mbr_item( g_sel_mbr, tmp, FALSE ) )
+		return FALSE;
 
 	item->stock--;
 	if( item->stock <= 0 )
 		inc_item( item, -item->n );
 
-	if( g_shop_n != SHOP_N_RESTAURANT )
-		print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
-				MSG_MENU_REACHED_BUY, item->name );
+	print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
+			MSG_MENU_REACHED_BUY, item->name );
 
 	return TRUE;
 }
@@ -835,7 +1093,7 @@ bool_t	menu_shop_sale(
 )
 {
 	ask_t	ask;
-	item_t	*tmp, dmy;
+	item_t	*tmp;
 	item_t	*asgn;
 
 	/* ̾ɽ */
@@ -858,6 +1116,7 @@ bool_t	menu_shop_sale(
 	default:
 	case SHOP_N_INN:
 	case SHOP_N_BAR:
+	case SHOP_N_MAGIC:
 	case SHOP_N_RESTAURANT:
 	case SHOP_N_TEAROOM:
 	case SHOP_N_TOBACCO:
@@ -871,15 +1130,15 @@ bool_t	menu_shop_sale(
 	case SHOP_N_ARMOR:
 		asgn = get_shop_armor_item_asgn();
 		break;
-	case SHOP_N_MAGIC:
-		asgn = get_shop_magic_item_asgn();
+	case SHOP_N_ALCHEMY:
+		asgn = get_shop_alchemy_item_asgn();
 		break;
 	case SHOP_N_GROCERY:
 		asgn = get_shop_grocery_item_asgn();
 		break;
 	}
 
-	tmp = alloc_item( &dmy );
+	tmp = alloc_item();
 	if( tmp == NULL )
 		return FALSE;
 	copy_item( tmp, item );
@@ -912,9 +1171,16 @@ item_t	*get_begin_article(
 
 	if( kind == DEAL_KIND_BUY ){
 		switch( shop_n ){
+		case SHOP_N_NULL:
+		case SHOP_N_MAX_N:
 		case SHOP_N_INN:
-		case SHOP_N_BAR:
 			return NULL;
+		case SHOP_N_BAR:
+			art_head = get_shop_bar_item_asgn();
+			if( art_head == NULL )
+				return NULL;
+			return art_head->next;
+			break;
 		case SHOP_N_TEMPLE:
 			art_head = get_shop_temple_item_asgn();
 			if( art_head == NULL )
@@ -934,7 +1200,9 @@ item_t	*get_begin_article(
 			return art_head->next;
 			break;
 		case SHOP_N_MAGIC:
-			art_head = get_shop_magic_item_asgn();
+			return NULL;
+		case SHOP_N_ALCHEMY:
+			art_head = get_shop_alchemy_item_asgn();
 			if( art_head == NULL )
 				return NULL;
 			return art_head->next;
@@ -963,6 +1231,8 @@ item_t	*get_begin_article(
 				return NULL;
 			return art_head->next;
 			break;
+		case SHOP_N_PET_SHOP:
+			return NULL;
 		}
 	} else if( kind == DEAL_KIND_SALE_ITEM ){
 		art_head = get_mbr_item_asgn( mbr );
@@ -1021,9 +1291,19 @@ bool_t	chk_deal_article(
 )
 {
 	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
 	case SHOP_N_INN:
-	case SHOP_N_BAR:
 		return FALSE;
+	case SHOP_N_BAR:
+		if( deal_kind != DEAL_KIND_BUY )
+			return FALSE;
+
+		if( art->kind == ITEM_KIND_POTION )
+			return TRUE;
+		if( art->kind == ITEM_KIND_FOOD )
+			return TRUE;
+		break;
 	case SHOP_N_TEMPLE:
 		return FALSE;
 	case SHOP_N_WPN:
@@ -1035,6 +1315,8 @@ bool_t	chk_deal_article(
 			return TRUE;
 		break;
 	case SHOP_N_MAGIC:
+		return FALSE;
+	case SHOP_N_ALCHEMY:
 		if( art->kind == ITEM_KIND_POTION )
 			return TRUE;
 		if( art->kind == ITEM_KIND_SCROLL )
@@ -1053,8 +1335,9 @@ bool_t	chk_deal_article(
 			return TRUE;
 		if( art->kind == ITEM_KIND_TOBACCO ){
 			if( art->dat.tobacco.kind
-					== TOBACCO_KIND_ABSTAIN_GUM )
+					== TOBACCO_KIND_ABSTAIN_GUM ){
 				return TRUE;
+			}
 		}
 		if( art->kind == ITEM_KIND_POTION ){
 			if( art->dat.potion.kind == POTION_KIND_WATER )
@@ -1067,10 +1350,10 @@ bool_t	chk_deal_article(
 		if( deal_kind != DEAL_KIND_BUY )
 			return FALSE;
 
-		if( art->kind == ITEM_KIND_FOOD )
-			return TRUE;
 		if( art->kind == ITEM_KIND_POTION )
 			return TRUE;
+		if( art->kind == ITEM_KIND_FOOD )
+			return TRUE;
 		break;
 	case SHOP_N_TEAROOM:
 		if( deal_kind != DEAL_KIND_BUY )
@@ -1087,7 +1370,11 @@ bool_t	chk_deal_article(
 			return TRUE;
 		if( art->kind == ITEM_KIND_PIPE )
 			return TRUE;
+		if( art->kind == ITEM_KIND_DISPOSAL )
+			return TRUE;
 		break;
+	case SHOP_N_PET_SHOP:
+		return FALSE;
 	}
 
 	return FALSE;
@@ -1104,6 +1391,15 @@ char	*menu_bar( void )
 
 /**/
 
+char	*cb_menu_bar_order( menu_t **pp, menu_t **dflt )
+{
+	g_shop_n = SHOP_N_BAR;
+
+	return menu_order();
+}
+
+/**/
+
 char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 {
 	long	i, j, k;
@@ -1369,7 +1665,7 @@ char	*cb_menu_bar_join_sub( menu_t **pp, menu_t **dflt )
 
 	next_g_sel_ls_mbr();
 
-	return "/Bar/Form";
+	return "/Bar/Form/Form";
 }
 
 /**/
@@ -1388,7 +1684,7 @@ char	*cb_menu_bar_not_join( menu_t **pp, menu_t **dflt )
 
 	next_g_sel_ls_mbr();
 
-	return "/Bar/Form";
+	return "/Bar/Form/Form";
 }
 
 /**/
@@ -1424,7 +1720,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_sel_mbr;
 
 	k = 0;
-	strncpy( p[k].path, "/Bar/Edit member",
+	strncpy( p[k].path, "/Edit member",
 			MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
@@ -1440,7 +1736,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/Bar/Edit member/--",
+		strncpy( p[k].path, "/Edit member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
@@ -1462,7 +1758,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/Bar/Edit member/%ld",
+			sprintf( p[k].path, "/Edit member/%ld",
 					ls_mbr_n );
 			strncpy( p[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
@@ -1478,7 +1774,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/Bar/Edit member/--",
+		strncpy( p[k].path, "/Edit member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
@@ -1549,7 +1845,7 @@ char	*cb_menu_bar_data_form( menu_t **pp, menu_t **dflt )
 {
 	menu_town_mbr_data( MBR_DATA_EDIT_KIND_EDIT, TRUE );
 
-	return "/Bar/Form";
+	return "/Bar/Form/Form";
 }
 
 /**/
@@ -1558,7 +1854,7 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 {
 	menu_town_mbr_data( MBR_DATA_EDIT_KIND_EDIT, TRUE );
 
-	return "/Bar/Edit member/Edit member";
+	return "/Bar/Form/Edit member/Edit member";
 }
 
 /**/
@@ -1585,7 +1881,7 @@ char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt )
 
 	g_sel_ls_mbr = ls_mbr[0];
 
-	return "/Bar/Edit member/Edit member";
+	return "/Bar/Form/Edit member/Edit member";
 }
 
 /**/
@@ -1761,24 +2057,22 @@ char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	return "/Bar/Edit member/Remove member";
+	return "/Bar/Form/Edit member/Remove member";
 }
 
 /**/
 
 char	*cb_menu_bar_edit_class( menu_t **pp, menu_t **dflt )
 {
-	long	class_n;
 	char	*str_goto;
 
-	class_n = 0;
-
 	while( 1 ){
-		str_goto = exec_menu_class( &class_n );
+		str_goto = exec_menu_class( &g_sel_class_n );
 		if( str_goto != NULL )
 			return str_goto;
 
-		str_goto = menu_edit_class( class_n );
+		str_goto = exec_menu( ls_menu_bar_sel_edit_class,
+				NULL, NULL );
 		if( str_goto != NULL )
 			return str_goto;
 	}
@@ -1786,6 +2080,13 @@ char	*cb_menu_bar_edit_class( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_bar_edit_class_sub( menu_t **pp, menu_t **dflt )
+{
+	return menu_edit_class( g_sel_class_n );
+}
+
+/**/
+
 char	*menu_edit_class( long n )
 {
 	class_t	*p;
@@ -1819,6 +2120,15 @@ char	*menu_edit_class( long n )
 
 /**/
 
+char	*cb_menu_bar_arrange_class( menu_t **pp, menu_t **dflt )
+{
+	arrange_class( g_sel_class_n );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 {
 	class_t	*p;
@@ -2177,9 +2487,524 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 
 	stay_inn();
 
-	print_msg( FLG_NULL, MSG_S, MSG_MENU_INN_DO_STAY );
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls, *p;
+	unsigned char	key;
+	bool_t	flg;
+	long	i;
+
+	if( g_sel_mbr == NULL )
+		return STR_MENU_ERR;
+
+	ls = *pp;
+
+	p = srch_menu( *pp, "Title" );
+	if( p == NULL )
+		return STR_MENU_ERR;
+	sprintf( p->msg, MSG_TTL_MENU_MAGIC_GUILD,
+			get_shop_name( SHOP_N_MAGIC ),
+			g_sel_mbr->name, g_sel_mbr->gold );
+
+	key = 'A';
+	for( i = 0; i < 1024; i++ ){
+		spell_kind_t	kind;
+
+		if( ls[i].path[0] == '\0' )
+			break;
+		if( strcmp( ls[i].kind, "<PageSeparator>" ) == 0 ){
+			key = 'A';
+			continue;
+		}
+		if( ls[i].key == 'Z' ){
+			if( key == 'A' )
+				ls[i].flg &= ~FLG_MENU_HIDDEN;
+			else
+				ls[i].flg |= FLG_MENU_HIDDEN;
+			continue;
+		}
+		if( ls[i].arg == NULL )
+			continue;
+
+		/**/
+
+		kind = (spell_kind_t)(ls[i].arg);
+
+		sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
+				get_spell_name( kind ),
+				get_price_spell( kind ) );
+
+		if( chk_can_chr_cast( g_sel_mbr, kind ) ){
+			ls[i].flg |= FLG_MENU_HIDDEN;
+			ls[i].key = '\0';
+		} else {
+			ls[i].flg &= ~FLG_MENU_HIDDEN;
+			ls[i].key = key;
+			key++;
+		}
+	}
+
+	flg = FALSE;
+
+	if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
+		clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+		flg = TRUE;
+	} else {
+		set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
+	}
+
+	if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
+		clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+		flg = TRUE;
+	} else {
+		set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
+	}
+
+	if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
+		clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+		flg = TRUE;
+	} else {
+		set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
+	}
+
+	if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
+		clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+		flg = TRUE;
+	} else {
+		set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
+	}
+
+	if( !flg ){
+		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
+		return STR_MENU_CANCEL;
+	}
 
 	return NULL;
 }
 
 /**/
+
+char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
+{
+	spell_kind_t	kind;
+	spell_tab_t	*tab;
+	ask_t	ask;
+
+	if( g_sel_mbr == NULL )
+		return STR_MENU_ERR;
+
+	kind = (spell_kind_t)((*pp)->arg);
+	tab = get_spell_tab( kind );
+	if( tab == NULL )
+		return STR_MENU_ERR;
+
+	if( !chk_pay( (gold_t)tab->price, g_sel_mbr ) )
+		return STR_MENU_CANCEL;
+
+	/* ̾ɽ */
+	print_msg( FLG_NULL, MSG_MENU_BUY, tab->name );
+
+	/* 㤦ǧ */
+	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, FALSE );
+	switch( ask ){
+	case ASK_YES:
+		break;
+	case ASK_NO:
+	case ASK_CANCEL:
+	case ASK_ERR:
+		return STR_MENU_CANCEL;
+	}
+
+	add_chr_gold( g_sel_mbr, -(gold_t)tab->price );
+	set_can_chr_cast( g_sel_mbr, kind, TRUE );
+
+	return "/Magic Guild";
+}
+
+/**/
+
+char	*cb_menu_magic_guild_no_learn( menu_t **pp, menu_t **dflt )
+{
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*p;
+
+	if( g_sel_mbr == NULL )
+		return STR_MENU_ERR;
+
+	p = srch_menu( *pp, "Title" );
+	if( p == NULL )
+		return STR_MENU_ERR;
+	sprintf( p->msg, MSG_TTL_MENU_PET_SHOP,
+			get_shop_name( SHOP_N_PET_SHOP ),
+			g_sel_mbr->name, g_sel_mbr->gold );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
+{
+	pet_t	**ls_pet;
+	menu_t	*ls;
+	long	k;
+	long	i, n, max_n;
+	char	key;
+
+	ls_pet = get_ls_pet();
+
+	ls = ls_menu_pet_shop_take;
+	k = 0;
+	key = 'A';
+	n = 0;
+	max_n = LS_PET_MAX_N;
+
+	strncpy( ls[k].path, "/Pet Shop Take", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( ls[k].path, "/Pet Shop Take/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_TAKE,
+			get_shop_name( SHOP_N_PET_SHOP ),
+			g_sel_mbr->name );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < max_n; i++ ){
+		if( ls_pet[i] == NULL )
+			continue;
+		if( chk_flg( ls_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+		if( !chk_can_join_pet( ls_pet[i] ) )
+			continue;
+
+		if( (n != 0) && ((n % PET_SHOP_PET_N_PER_PAGE) == 0) ){
+			strncpy( ls[k].path, "/Pet Shop Take/Page Separator",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].key = '\0';
+			ls[k].accel_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+
+			key = 'A';
+		}
+
+		sprintf( ls[k].path, "/Pet Shop Take/%ld", (long)(i + 1) );
+		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].key = key;
+		ls[k].accel_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL,
+		strncpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_pet_shop_take_sel;
+		ls[k].arg = (void *)(ls_pet[i]);
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+		n++;
+	}
+	ls[k].path[0] = '\0';
+
+	if( n <= 0 )
+		return STR_MENU_CANCEL;
+
+	*pp = ls;
+	*dflt = NULL;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_pet_shop_take_sel( menu_t **pp, menu_t **dflt )
+{
+	pet_t	*pet;
+
+	pet = (pet_t *)((*pp)->arg);
+	if( pet == NULL )
+		return STR_MENU_ERR;
+
+	pet->owner = g_sel_mbr;
+	join_pet( pet );
+	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_TAKE_SUCCESS, pet->name );
+
+	return "/Pet Shop";
+}
+
+/**/
+
+char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
+{
+	pet_t	**party_pet;
+	menu_t	*ls;
+	long	k;
+	long	i, n, max_n;
+	char	key;
+
+	party_pet = get_party_pet();
+
+	ls = ls_menu_pet_shop_leave;
+	k = 0;
+	key = 'A';
+	n = 0;
+	max_n = PET_MAX_N;
+
+	strncpy( ls[k].path, "/Pet Shop Leave", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( ls[k].path, "/Pet Shop Leave/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_LEAVE,
+			get_shop_name( SHOP_N_PET_SHOP ),
+			g_sel_mbr->name );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < max_n; i++ ){
+		if( party_pet[i] == NULL )
+			continue;
+		if( chk_flg( party_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+		if( !chk_can_not_join_pet( party_pet[i] ) )
+			continue;
+
+		if( (n != 0) && ((n % PET_SHOP_PET_N_PER_PAGE) == 0) ){
+			strncpy( ls[k].path, "/Pet Shop Leave/Page Separator",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].key = '\0';
+			ls[k].accel_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+
+			key = 'A';
+		}
+
+		sprintf( ls[k].path, "/Pet Shop Leave/%ld", (long)(i + 1) );
+		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].key = key;
+		ls[k].accel_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL,
+		strncpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_pet_shop_leave_sel;
+		ls[k].arg = (void *)(party_pet[i]);
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+		n++;
+	}
+	ls[k].path[0] = '\0';
+
+	if( n <= 0 )
+		return STR_MENU_CANCEL;
+
+	*pp = ls;
+	*dflt = NULL;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_pet_shop_leave_sel( menu_t **pp, menu_t **dflt )
+{
+	pet_t	*pet;
+
+	pet = (pet_t *)((*pp)->arg);
+	if( pet == NULL )
+		return STR_MENU_ERR;
+
+	not_join_pet( pet );
+	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_LEAVE_SUCCESS, pet->name );
+
+	return "/Pet Shop";
+}
+
+/**/
+
+char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
+{
+	art_ls_pet_shop_t	*art_ls_pet_shop;
+	menu_t	*ls;
+	long	k;
+	long	i, max_n;
+	char	key;
+
+	art_ls_pet_shop = get_art_ls_pet_shop();
+
+	ls = ls_menu_pet_shop_buy;
+	k = 0;
+	key = 'A';
+	max_n = PET_SHOP_PET_MAX_N;
+
+	strncpy( ls[k].path, "/Pet Shop Buy", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( ls[k].path, "/Pet Shop Buy/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].key = '\0';
+	ls[k].accel_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP,
+			get_shop_name( SHOP_N_PET_SHOP ),
+			g_sel_mbr->name, g_sel_mbr->gold );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < max_n; i++ ){
+		if( art_ls_pet_shop[i].kind == MNSTR_KIND_NULL )
+			break;
+
+		if( (i != 0) && ((i % PET_SHOP_PET_N_PER_PAGE) == 0) ){
+			strncpy( ls[k].path, "/Pet Shop Buy/Page Separator",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].key = '\0';
+			ls[k].accel_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+
+			key = 'A';
+		}
+
+		sprintf( ls[k].path, "/Pet Shop Buy/%ld", (long)(i + 1) );
+		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].key = key;
+		ls[k].accel_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL,
+		sprintf( ls[k].msg, MSG_FMT_MENU_PET_SHOP,
+				get_mnstr_name( art_ls_pet_shop[i].kind ),
+				art_ls_pet_shop[i].price );
+		ls[k].call_back = cb_menu_pet_shop_buy_sel;
+		ls[k].arg = (void *)i;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+	}
+	ls[k].path[0] = '\0';
+
+	*pp = ls;
+	*dflt = NULL;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
+{
+	art_ls_pet_shop_t	*art_ls_pet_shop;
+	long	n;
+	mnstr_kind_t	kind;
+	gold_t	price;
+	ask_t	ask;
+	pet_t	*pet;
+
+	if( g_sel_mbr == NULL )
+		return STR_MENU_ERR;
+
+	art_ls_pet_shop = get_art_ls_pet_shop();
+
+	n = (long)((*pp)->arg);
+	kind = art_ls_pet_shop[n].kind;
+	if( kind == MNSTR_KIND_NULL )
+		return STR_MENU_ERR;
+
+	price = art_ls_pet_shop[n].price;
+	if( !chk_pay( price, g_sel_mbr ) )
+		return STR_MENU_CANCEL;
+
+	/* ̾ɽ */
+	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_ASK_BUY,
+			get_mnstr_name( kind ) );
+
+	ask = exec_menu_ask( MSG_TTL_MENU_PET_SHOP_ASK_BUY, ASK_NO, FALSE );
+	switch( ask ){
+	case ASK_YES:
+		break;
+	case ASK_NO:
+	case ASK_CANCEL:
+	case ASK_ERR:
+		return STR_MENU_CANCEL;
+	}
+
+	pet = make_pet( 10, kind );
+	if( pet == NULL ){
+		print_msg( FLG_NULL, MSG_S, MSG_ERR_MENU_PET_SHOP_BUY );
+		return STR_MENU_CANCEL;
+	}
+
+	pet->owner = g_sel_mbr;
+	join_pet( pet );
+	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_BUY_SUCCESS, pet->name );
+
+	return "/Pet Shop";
+}
+
+/**/
+
