@@ -1,18 +1,45 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-#include	<string.h>
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: town.c,v 1.34 2003/11/23 05:13:28 bowkenken Exp $
+*****************************************************************/
 
-/*#include	"gmain.h"*/
+#include	"gmain.h"
+/*#include	"misc.h"*/
+#include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
-/*#include	"mnstr.h"*/
+#include	"mnstr.h"
+#include	"pet.h"
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
@@ -22,13 +49,16 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+#include	"turn_prot.h"
 #include	"dun_prot.h"
 #include	"town_prot.h"
 #include	"item_prot.h"
 /*#include	"spell_prot.h"*/
 #include	"chr_prot.h"
 #include	"party_prot.h"
-/*#include	"mnstr_prot.h"*/
+#include	"mnstr_prot.h"
+#include	"pet_prot.h"
 /*#include	"fight_prot.h"*/
 #include	"fx_prot.h"
 /*#include	"trap_prot.h"*/
@@ -42,18 +72,21 @@
 
 /**/
 
-#define	ART_LEVEL_WPN	10
-#define	ART_LEVEL_ARMOR	10
-#define	ART_LEVEL_POTION	10
-#define	ART_LEVEL_SCROLL	10
-#define	ART_LEVEL_STICK	10
-#define	ART_LEVEL_ACCE	10
-#define	ART_LEVEL_LIGHT	10
-#define	ART_LEVEL_FOOD	10
-#define	ART_LEVEL_CHEST	10
-#define	ART_LEVEL_TOBACCO	10
-#define	ART_LEVEL_PIPE	10
-#define	ART_LEVEL_SPIKE	10
+#define	TOWNER_AVE_N	64
+
+#define	ART_LEVEL_WPN	-20
+#define	ART_LEVEL_ARMOR	-10
+#define	ART_LEVEL_POTION	-10
+#define	ART_LEVEL_SCROLL	-10
+#define	ART_LEVEL_STICK	-10
+#define	ART_LEVEL_ACCE	-10
+#define	ART_LEVEL_LIGHT	-10
+#define	ART_LEVEL_FOOD	-10
+#define	ART_LEVEL_CHEST	-10
+#define	ART_LEVEL_TOBACCO	-10
+#define	ART_LEVEL_PIPE	-10
+#define	ART_LEVEL_DISPOSAL	-10
+#define	ART_LEVEL_SPIKE	-10
 
 /**/
 
@@ -115,12 +148,16 @@
 
 /**/
 
+#define	PRICE_DISPOSAL	10
+
+/**/
+
 #define	PRICE_TEMPLE_REMOVE_CURSE	50
 #define	PRICE_TEMPLE_CURE_STATUS_MUL	10
 #define	PRICE_TEMPLE_CURE_STATUS_ADD	50
 #define	PRICE_TEMPLE_RESURRECTION_MUL	20
 #define	PRICE_TEMPLE_RESURRECTION_ADD	100
-#define	PRICE_TEMPLE_SMOKER_ADD_RATE	100
+#define	PRICE_TEMPLE_SMOKER_ADD_RATE	((rate_t)100)
 
 /**/
 
@@ -129,11 +166,30 @@
 #include	"town_ptn.xpm"
 #include	"town_tab.h"
 
-town_ptn_t	town_ptn, town_ptn_trans;
+static town_ptn_t	town_ptn, town_ptn_trans;
 
-long	g_morning_glow_n, g_evening_glow_n;
+static long	g_morning_glow_n, g_evening_glow_n;
 static bool_t	g_flg_night;
 
+/*  */
+
+#define	DAY_OF_WEEK_DISCOUNT	DAY_OF_WEEK_PHYS
+
+#define	DISCOUNT_RATE	((rate_t)20)
+
+#define	DISCOUNT_BEGIN_HOUR	6
+#define	DISCOUNT_END_HOUR	10
+#define	DISCOUNT_OPEN_HOUR	9
+
+#define	DISCOUNT_QUEUE_MAX_N	(32 + MBR_MAX_N)
+#define	DISCOUNT_QUEUE_R	2
+
+shop_n_t	g_discount_shop_n;
+door_t	*g_discount_door;
+bool_t	g_discount_flg_sold_out;
+pos_t	g_discount_queue[DISCOUNT_QUEUE_MAX_N];
+long	g_discount_queue_n;
+
 /**/
 
 void	init_town( void )
@@ -147,6 +203,8 @@ void	init_town( void )
 	load_town_ptn( &town_ptn );
 	if( trans_town_ptn( &town_ptn_trans, &town_ptn ) )
 		town_ptn = town_ptn_trans;
+
+	clr_discount();
 }
 
 /**/
@@ -400,6 +458,7 @@ bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 void	make_town( void )
 {
 	dun_t *dun;
+	long	mnstr_n, mnstr_max_n;
 	long	i, j;
 	long	n;
 
@@ -433,11 +492,21 @@ void	make_town( void )
 	}
 
 	/* ޥåפüɤˤ */
+
 	make_fence();
 
+	/*  */
+
+	make_streetlamp();
+
 	/* ŹΤѰ */
+
 	reset_item_town();
 
+	for( n = 0; n < 1024; n++ )
+		if( !make_art_town( SHOP_N_BAR,
+				&(art_ls_bar[n]) ) )
+			break;
 	for( n = 0; n < 1024; n++ )
 		if( !make_art_town( SHOP_N_WPN,
 				&(art_ls_wpn[n]) ) )
@@ -447,7 +516,7 @@ void	make_town( void )
 				&(art_ls_armor[n]) ) )
 			break;
 	for( n = 0; n < 1024; n++ )
-		if( !make_art_town( SHOP_N_MAGIC,
+		if( !make_art_town( SHOP_N_ALCHEMY,
 				&(art_ls_magic[n]) ) )
 			break;
 	for( n = 0; n < 1024; n++ )
@@ -466,6 +535,26 @@ void	make_town( void )
 		if( !make_art_town( SHOP_N_TOBACCO,
 				&(art_ls_tobacco[n]) ) )
 			break;
+
+	/* ͤϤ */
+
+	mnstr_max_n = roll_dice( TOWNER_AVE_N );
+	if( mnstr_max_n > MNSTR_MAX_N )
+		mnstr_max_n = MNSTR_MAX_N;
+
+	mnstr_n = 0;
+	for( i = 0; i < 4096; i++ ){
+		long	x, y;
+
+		if( mnstr_n >= mnstr_max_n )
+			break;
+
+		x = 1 + randm( MAP_MAX_X - 2 );
+		y = 1 + randm( MAP_MAX_Y - 2 );
+
+		if( make_mnstr_rand( x, y, 0 ) != NULL )
+			mnstr_n++;
+	}
 }
 
 /**/
@@ -491,7 +580,7 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		mjr = FACE_MJR_WALL;
 		mnr = FACE_MNR_WALL;
 	}
-	flg = FLG_OBJ_FIND;
+	flg = FLG_MAP_OBJ_FIND;
 	flg_light = TRUE;
 
 	switch( mjr ){
@@ -499,19 +588,19 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		mjr = FACE_MJR_FLOOR;
 		mnr = FACE_MNR_FLOOR;
 		if( chk_night() ){
-			flg &= ~(FLG_OBJ_FIND);
+			flg &= ~(FLG_MAP_OBJ_FIND);
 			flg_light = FALSE;
 		}
-		flg |= FLG_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS;
 		break;
 	case FACE_MJR_WALL:
 		break;
 	case FACE_MJR_FLOOR:
 		if( chk_night() ){
-			flg &= ~(FLG_OBJ_FIND);
+			flg &= ~(FLG_MAP_OBJ_FIND);
 			flg_light = FALSE;
 		}
-		flg |= FLG_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS;
 		break;
 	case FACE_MJR_DOOR_OPEN:
 		mjr = FACE_MJR_DOOR_CLOSE;
@@ -520,7 +609,7 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 		break;
 	case FACE_MJR_STAIRS_UP:
 	case FACE_MJR_STAIRS_DOWN:
-		flg |= FLG_OBJ_PASS;
+		flg |= FLG_MAP_OBJ_PASS;
 		break;
 	default:
 		print_msg( FLG_NULL, MSG_S, MSG_ERR_TOWN_MAP );
@@ -530,20 +619,64 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 	dun->map.obj.mnr[y][x] = mnr;
 	dun->map.obj.flg[y][x] = flg;
 	if( flg_light )
-		dun->map.light_depth[y][x] = 1;
+		dun->map.light_depth_obj[y][x] = 1;
 	else
-		dun->map.light_depth[y][x] = 0;
+		dun->map.light_depth_obj[y][x] = 0;
 	dun->map.sect[y][x] = SECT_NULL;
 }
 
 /**/
 
+void	make_streetlamp( void )
+{
+	dun_t	*dun = get_dun();
+	long	x, y;
+
+	for( y = 0; y < MAP_MAX_Y; y++ ){
+		for( x = 0; x < MAP_MAX_X; x++ ){
+			char	mjr, mnr;
+
+			mjr = dun->map.obj.mjr[y][x];
+			mnr = dun->map.obj.mnr[y][x];
+			if( mjr != FACE_MJR_WALL )
+				continue;
+			if( mnr != FACE_MNR_STREETLAMP )
+				continue;
+
+			on_streetlamp( x, y );
+		}
+	}
+}
+
+/**/
+
+void	on_streetlamp( long x, long y )
+{
+	dun_t	*dun = get_dun();
+	long	dx, dy;
+
+	for( dy = -STREETLAMP_R; dy <= +STREETLAMP_R; dy++ ){
+		for( dx = -STREETLAMP_R; dx <= +STREETLAMP_R; dx++ ){
+			long	xx, yy;
+
+			xx = x + dx;
+			yy = y + dy;
+			if( !clip_pos( xx, yy ) )
+				continue;
+
+			dun->map.light_depth_obj[yy][xx]++;
+		}
+	}
+}
+
+/**/
+
 bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 {
 	item_kind_t	item_kind;
 	long	ave_stock;
 	long	tab_n;
-	item_t	*item, *asgn, dmy;
+	item_t	*item, *asgn;
 	wpn_kind_t	wpn_kind;
 	armor_kind_t	armor_kind;
 	potion_kind_t	potion_kind;
@@ -558,6 +691,7 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 	tobacco_kind_t	tobacco_kind;
 	tobacco_brand_t	tobacco_brand;
 	pipe_kind_t	pipe_kind;
+	art_ls_bar_t	*art_bar;
 	art_ls_wpn_t	*art_wpn;
 	art_ls_armor_t	*art_armor;
 	art_ls_magic_t	*art_magic;
@@ -565,6 +699,7 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 	art_ls_restaurant_t	*art_restaurant;
 	art_ls_tearoom_t	*art_tearoom;
 	art_ls_tobacco_t	*art_tobacco;
+	long	lev;
 
 	/**/
 
@@ -587,8 +722,19 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 	tobacco_brand = TOBACCO_BRAND_NULL;
 	pipe_kind = PIPE_KIND_NULL;
 
+	item = NULL;
+
 	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
+		return FALSE;
 	case SHOP_N_BAR:
+		art_bar = (art_ls_bar_t *)art_ls;
+		item_kind = art_bar->kind;
+		ave_stock = art_bar->ave_stock;
+		food_kind = art_bar->food;
+		potion_kind = art_bar->potion;
+		break;
 	case SHOP_N_INN:
 	case SHOP_N_TEMPLE:
 		return FALSE;
@@ -605,6 +751,8 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 		armor_kind = art_armor->armor;
 		break;
 	case SHOP_N_MAGIC:
+		return FALSE;
+	case SHOP_N_ALCHEMY:
 		art_magic = (art_ls_magic_t *)art_ls;
 		item_kind = art_magic->kind;
 		ave_stock = art_magic->ave_stock;
@@ -647,15 +795,13 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 		tobacco_brand = art_tobacco->tobacco_brand;
 		pipe_kind = art_tobacco->pipe;
 		break;
+	case SHOP_N_PET_SHOP:
+		return FALSE;
 	}
 
 	if( item_kind == ITEM_KIND_NULL )
 		return FALSE;
 
-	item = alloc_item( &dmy );
-	if( item == NULL )
-		return FALSE;
-
 	switch( item_kind ){
 	case ITEM_KIND_NULL:
 	case ITEM_KIND_MAX_N:
@@ -666,33 +812,45 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 		tab_n = get_wpn_tab_n( get_wpn_tab( wpn_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_wpn( ART_LEVEL_WPN, item, tab_n, FALSE );
+		lev = sgn( ART_LEVEL_WPN );
+		lev *= randm( abs( ART_LEVEL_WPN ) ) + 1;
+		item = make_item_wpn( lev, tab_n, FALSE );
+		if( item == NULL )
+			return FALSE;
 		item->n = item->tab.wpn->ave_n;
 		break;
 	case ITEM_KIND_ARMOR:
 		tab_n = get_armor_tab_n( get_armor_tab( armor_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_armor( ART_LEVEL_ARMOR, item, tab_n, FALSE );
+		item = make_item_armor( ART_LEVEL_ARMOR, tab_n, FALSE );
+		if( item == NULL )
+			return FALSE;
 		break;
 	case ITEM_KIND_POTION:
 		tab_n = get_potion_tab_n( get_potion_tab( potion_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_potion( ART_LEVEL_POTION, item, tab_n );
+		item = make_item_potion( ART_LEVEL_POTION, tab_n );
+		if( item == NULL )
+			return FALSE;
 		break;
 	case ITEM_KIND_SCROLL:
 		tab_n = get_scroll_tab_n( get_scroll_tab( scroll_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_scroll( ART_LEVEL_SCROLL, item, tab_n );
+		item = make_item_scroll( ART_LEVEL_SCROLL, tab_n );
+		if( item == NULL )
+			return FALSE;
 		break;
 	case ITEM_KIND_STICK:
 		tab_n = get_stick_tab_n( get_stick_tab(
 				stick_kind, spell_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_stick( ART_LEVEL_STICK, item, tab_n );
+		item = make_item_stick( ART_LEVEL_STICK, tab_n );
+		if( item == NULL )
+			return FALSE;
 		item->dat.stick.n = item->tab.stick->use_n;
 		break;
 	case ITEM_KIND_ACCE:
@@ -702,65 +860,93 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 				necklace_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_acce( ART_LEVEL_ACCE, item, tab_n );
+		item = make_item_acce( ART_LEVEL_ACCE, tab_n );
+		if( item == NULL )
+			return FALSE;
 		break;
 	case ITEM_KIND_LIGHT:
 		tab_n = get_light_tab_n( get_light_tab( light_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_light( ART_LEVEL_LIGHT, item, tab_n );
+		item = make_item_light( ART_LEVEL_LIGHT, tab_n );
+		if( item == NULL )
+			return FALSE;
 		item->dat.light.turn = item->tab.light->max_turn;
 		break;
 	case ITEM_KIND_SPIKE:
-		make_item_spike( ART_LEVEL_SPIKE, item );
+		item = make_item_spike( ART_LEVEL_SPIKE );
+		if( item == NULL )
+			return FALSE;
 		item->n = SPIKE_AVE_N;
 		break;
 	case ITEM_KIND_FOOD:
 		tab_n = get_food_tab_n( get_food_tab( food_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_food( ART_LEVEL_FOOD, item, tab_n );
+		item = make_item_food( ART_LEVEL_FOOD, tab_n );
+		if( item == NULL )
+			return FALSE;
 		item->n = 1;
 		break;
 	case ITEM_KIND_CHEST:
-		make_item_chest( ART_LEVEL_CHEST, item,
+		item = make_item_chest( ART_LEVEL_CHEST,
 				get_chest_n( ART_LEVEL_CHEST ) );
+		if( item == NULL )
+			return FALSE;
 		break;
 	case ITEM_KIND_TOBACCO:
 		tab_n = get_tobacco_tab_n( get_tobacco_tab(
 				tobacco_kind, tobacco_brand ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_tobacco( ART_LEVEL_TOBACCO, item, tab_n );
+		item = make_item_tobacco( ART_LEVEL_TOBACCO, tab_n );
+		if( item == NULL )
+			return FALSE;
 		item->n = item->tab.tobacco->ave_n;
 		break;
 	case ITEM_KIND_PIPE:
 		tab_n = get_pipe_tab_n( get_pipe_tab( pipe_kind ) );
 		if( tab_n <= -1 )
 			return TRUE;
-		make_item_pipe( ART_LEVEL_PIPE, item, tab_n );
+		item = make_item_pipe( ART_LEVEL_PIPE, tab_n );
+		if( item == NULL )
+			return FALSE;
 		if( chk_flg( item->tab.pipe->flg, FLG_PIPE_CONSUMPTION ) )
 			item->n = item->tab.pipe->ave_n;
 		break;
+	case ITEM_KIND_DISPOSAL:
+		item = make_item_disposal( ART_LEVEL_DISPOSAL );
+		if( item == NULL )
+			return FALSE;
+		break;
 	}
+
 	if( ave_stock == 1 )
 		item->stock = 1;
 	else
 		item->stock = roll_dice( ave_stock );
+	if( (item->kind == ITEM_KIND_WPN)
+			&& (item->dat.wpn.slayer != FACE_MJR_NULL) ){
+		item->stock = 1;
+	}
 	if( item->stock <= 0 ){
 		del_item( item );
 		return TRUE;
 	}
 
 	item->flg |= FLG_ITEM_DETECTED | FLG_ITEM_IDENTIFIED;
-	item->flg &= ~(FLG_ITEM_CURSE);
+	item->flg &= ~(FLG_ITEM_CURSED);
 	set_item_name( item );
 
 	asgn = NULL;
 	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
 	case SHOP_N_INN:
-	case SHOP_N_BAR:
 		return TRUE;
+	case SHOP_N_BAR:
+		asgn = get_shop_bar_item_asgn();
+		break;
 	case SHOP_N_TEMPLE:
 		asgn = get_shop_temple_item_asgn();
 		break;
@@ -771,7 +957,9 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 		asgn = get_shop_armor_item_asgn();
 		break;
 	case SHOP_N_MAGIC:
-		asgn = get_shop_magic_item_asgn();
+		return TRUE;
+	case SHOP_N_ALCHEMY:
+		asgn = get_shop_alchemy_item_asgn();
 		break;
 	case SHOP_N_GROCERY:
 		asgn = get_shop_grocery_item_asgn();
@@ -785,6 +973,8 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 	case SHOP_N_TOBACCO:
 		asgn = get_shop_tobacco_item_asgn();
 		break;
+	case SHOP_N_PET_SHOP:
+		return TRUE;
 	}
 	ins_ls_item( asgn, item );
 
@@ -802,32 +992,24 @@ void	make_door_town( long mx, long my, char mnr )
 	dun = get_dun();
 
 	/* ǤϿߤ */
-	if( (mx - 1) >= 0 )
-		if( dun->map.obj.mjr[my][mx - 1]
-				== FACE_MJR_DOOR_CLOSE )
+	if( clip_x( mx - 1 ) )
+		if( dun->map.obj.mjr[my][mx - 1] == FACE_MJR_DOOR_CLOSE )
 			return;
-	if( (my - 1) >= 0 )
-		if( dun->map.obj.mjr[my - 1][mx]
-				== FACE_MJR_DOOR_CLOSE )
+	if( clip_x( my - 1 ) )
+		if( dun->map.obj.mjr[my - 1][mx] == FACE_MJR_DOOR_CLOSE )
 			return;
 
 
-	for( i = 0; i < AREA_MAX_X; i++ ){
-		if( dun->map.obj.mjr[my][mx + i]
-				!= FACE_MJR_DOOR_CLOSE ){
+	for( i = 0; i < AREA_MAX_X; i++ )
+		if( dun->map.obj.mjr[my][mx + i] != FACE_MJR_DOOR_CLOSE )
 			break;
-		}
-	}
 	dx = i - 1;
 	if( dx < 0 )
 		return;
 
-	for( i = 0; i < AREA_MAX_Y; i++ ){
-		if( dun->map.obj.mjr[my + i][mx]
-				!= FACE_MJR_DOOR_CLOSE ){
+	for( i = 0; i < AREA_MAX_Y; i++ )
+		if( dun->map.obj.mjr[my + i][mx] != FACE_MJR_DOOR_CLOSE )
 			break;
-		}
-	}
 	dy = i - 1;
 	if( dy < 0 )
 		return;
@@ -880,7 +1062,7 @@ bool_t	chk_shop_face_ls( void )
 
 /**/
 
-bool_t	appear_party_town( void )
+bool_t	appear_party_town( bool_t flg_clr_map )
 {
 	dun_t *dun;
 	long	i, j;
@@ -911,8 +1093,23 @@ bool_t	appear_party_town( void )
 	if( !flg_find )
 		return FALSE;
 
-	clr_map_all_mbr();
+	if( flg_clr_map )
+		clr_map_all_mbr();
 
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		long	nx, ny;
+
+		if( chk_flg_or( pty->mbr[n]->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
+			continue;
+
+		nx = pty->square.x + pty->square.chr_pos[n].x;
+		ny = pty->square.y + pty->square.chr_pos[n].y;
+		if( !can_move_chr( pty->mbr[n], nx, ny ) ){
+			/* ֤˰ưʤ */
+			return FALSE;
+		}
+	}
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		long	nx, ny;
 
@@ -926,11 +1123,6 @@ bool_t	appear_party_town( void )
 		pty->mbr[n]->y = ny;
 		pty->mbr[n]->pre_x = nx;
 		pty->mbr[n]->pre_y = ny;
-		if( !can_move_chr( pty->mbr[n], nx, ny ) ){
-			/* ֤˰ưʤ */
-			set_map_all_mbr();
-			return FALSE;
-		}
 	}
 
 	for( n = 0; n < MBR_MAX_N; n++ )
@@ -938,6 +1130,8 @@ bool_t	appear_party_town( void )
 
 	set_map_all_mbr();
 
+	appear_all_pet( flg_clr_map );
+
 	return TRUE;
 }
 
@@ -983,6 +1177,7 @@ bool_t	enter_shop( void )
 		return FALSE;
 
 	clr_map_all_mbr();
+	clr_map_all_pet();
 
 	face_mnr = (char)(pty->act.n);
 	dr_n = (long)(pty->act.n2);
@@ -1000,28 +1195,41 @@ bool_t	enter_shop( void )
 		dun->map.chr.mjr[y][x] = FACE_MJR_NULL;
 		dun->map.chr.mnr[y][x] = FACE_MNR_NULL;
 	}
-	switch( face_mnr ){
-	case FACE_MNR_SHOP_INN:
-		menu_inn();
-		break;
-	case FACE_MNR_SHOP_BAR:
-		menu_bar();
-		break;
-	case FACE_MNR_SHOP_TEMPLE:
-	case FACE_MNR_SHOP_WPN:
-	case FACE_MNR_SHOP_ARMOR:
-	case FACE_MNR_SHOP_MAGIC:
-	case FACE_MNR_SHOP_GROCERY:
-	case FACE_MNR_SHOP_RESTAURANT:
-	case FACE_MNR_SHOP_TEAROOM:
-	case FACE_MNR_SHOP_TOBACCO:
-		menu_shop_sel_mbr( get_shop_n( face_mnr ) );
-		break;
-	default:
-		return FALSE;
-	}
 
-	party_exit_shop( dr_n );
+	while( 1 ){
+		switch( face_mnr ){
+		case FACE_MNR_SHOP_INN:
+			menu_inn();
+			break;
+		case FACE_MNR_SHOP_BAR:
+			menu_bar();
+			break;
+		case FACE_MNR_SHOP_RESTAURANT:
+			menu_restaurant();
+			break;
+		case FACE_MNR_SHOP_TEMPLE:
+		case FACE_MNR_SHOP_WPN:
+		case FACE_MNR_SHOP_ARMOR:
+		case FACE_MNR_SHOP_MAGIC:
+		case FACE_MNR_SHOP_ALCHEMY:
+		case FACE_MNR_SHOP_GROCERY:
+		case FACE_MNR_SHOP_TEAROOM:
+		case FACE_MNR_SHOP_TOBACCO:
+		case FACE_MNR_SHOP_PET_SHOP:
+			menu_shop_sel_mbr( get_shop_n( face_mnr ) );
+			break;
+		default:
+			return FALSE;
+		}
+
+		if( chk_not_exist_all_mbr() ){
+			print_msg( FLG_NULL, MSG_S,
+					MSG_ERR_NOT_EXIST_ALL_MBR );
+		} else {
+			party_exit_shop( dr_n );
+			break;
+		}
+	}
 
 	redraw_all();
 	clr_msg();
@@ -1079,7 +1287,7 @@ void	party_exit_shop( long dr_n )
 				}
 				if( !chk_flg( dun->map.obj.flg
 						[y + dy][x + dx],
-						FLG_OBJ_PASS ) ){
+						FLG_MAP_OBJ_PASS ) ){
 					flg = FALSE;
 					break;
 				}
@@ -1091,6 +1299,8 @@ void	party_exit_shop( long dr_n )
 		if( !flg )
 			continue;
 
+		/* ̤˽Ф */
+
 		pty->square.x = x + 1;
 		pty->square.y = y + 1;
 		for( j = 0; j < MBR_MAX_N; j++ ){
@@ -1101,17 +1311,15 @@ void	party_exit_shop( long dr_n )
 		}
 
 		set_map_all_mbr();
+		appear_all_pet( FALSE );
 
 		return;
 	}
 
-	for( j = 0; j < MBR_MAX_N; j++ ){
-		pty->mbr[j]->y = 0;
-		pty->mbr[j]->y = 0;
-	}
-	set_map_all_mbr();
-	if( !appear_party_town() )
-		appear_party( TRUE );
+	/* ̵˽Ф */
+
+	if( !appear_party_town( FALSE ) )
+		appear_party( FALSE );
 }
 
 /**/
@@ -1137,11 +1345,12 @@ bool_t	chk_package_item( item_t *item )
 	case ITEM_KIND_LIGHT:
 	case ITEM_KIND_FOOD:
 	case ITEM_KIND_CHEST:
+	case ITEM_KIND_DISPOSAL:
 	case ITEM_KIND_COIN:
 	case ITEM_KIND_JUNK:
 		return FALSE;
-	case ITEM_KIND_TOBACCO:
 	case ITEM_KIND_SPIKE:
+	case ITEM_KIND_TOBACCO:
 		return TRUE;
 	case ITEM_KIND_PIPE:
 		if( chk_flg( item->tab.pipe->flg, FLG_PIPE_CONSUMPTION ) )
@@ -1183,15 +1392,24 @@ void	stay_inn( void )
 			mbr->abl.mp.n = mbr->abl.mp.max;
 		}
 
-		mbr->fx_data.drunk_rate = 0;
+		mbr->fx_data.drunk_rate = (rate_t)0;
 
 		/* Ȥ */
-		take_meal_fill_mbr( mbr );
+		take_meal_fill_chr( mbr );
+
+		/* ̤ۤդ */
+		clean_all_disposal( mbr );
 	}
 
 	set_turn( get_turn() + turn );
+	print_msg( FLG_NULL, MSG_S, MSG_MENU_INN_DO_STAY );
 
-	make_town();
+	reset_all( FALSE );
+
+	if( chk_discount() ){
+		print_words( MSG_NPC_NAME_INN, MSG_WORDS_DISCOUNT_DAY,
+				get_shop_name( g_discount_shop_n ) );
+	}
 }
 
 /**/
@@ -1303,9 +1521,9 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 
 /**/
 
-bool_t	chk_pay( long price, mbr_t *mbr )
+bool_t	chk_pay( gold_t price, mbr_t *mbr )
 {
-	long	gold;
+	gold_t	gold;
 
 	if( mbr == NULL )
 		return FALSE;
@@ -1323,14 +1541,14 @@ bool_t	chk_pay( long price, mbr_t *mbr )
 
 /**/
 
-long	get_price( item_t *item, deal_kind_t kind )
+gold_t	get_price( shop_n_t shop_n, item_t *item, deal_kind_t kind )
 {
-	long	price;
+	gold_t	price;
 
 	if( item == NULL )
-		return 0;
+		return( (gold_t)0 );
 
-	price = 0;
+	price = (gold_t)0;
 
 	switch( item->kind ){
 	case ITEM_KIND_NULL:
@@ -1351,6 +1569,7 @@ long	get_price( item_t *item, deal_kind_t kind )
 	case ITEM_KIND_FOOD:
 	case ITEM_KIND_CHEST:
 		/*@@@*/
+		price = (gold_t)1;
 		break;
 	case ITEM_KIND_TOBACCO:
 		if( item->tab.tobacco != NULL )
@@ -1360,31 +1579,44 @@ long	get_price( item_t *item, deal_kind_t kind )
 		if( item->tab.pipe != NULL )
 			price = item->tab.pipe->price;
 		break;
+	case ITEM_KIND_DISPOSAL:
+		price = PRICE_DISPOSAL;
 	case ITEM_KIND_COIN:
+		price = (gold_t)1;
 		break;
 	case ITEM_KIND_JUNK:
-		price = 0;
+		price = (gold_t)0;
 		break;
 	}
 
+	if( !chk_flg( item->flg, FLG_ITEM_IDENTIFIED ) )
+		price = (gold_t)0;
+
 	price *= item->n;
 
 	switch( kind ){
 	case DEAL_KIND_BUY:
-		return price;
+		if( chk_discount() && (shop_n == g_discount_shop_n) )
+			price -= price * DISCOUNT_RATE / _100_PERCENT;
+		break;
 	case DEAL_KIND_SALE_ITEM:
 	case DEAL_KIND_SALE_EQUIP:
-		return( price / 2 );
+		price /= 2;
+		if( chk_discount() && (shop_n == g_discount_shop_n) )
+			price += price * DISCOUNT_RATE / _100_PERCENT;
+		break;
 	}
+	if( price < 1 )
+		price = 1;
 
-	return 0;
+	return price;
 }
 
 /**/
 
-long	get_price_wpn( item_t *item )
+gold_t	get_price_wpn( item_t *item )
 {
-	long	price;
+	gold_t	price;
 	long	mul_type;
 	rate_t	hit, crtcl, dam;
 	ratio_t	ratio;
@@ -1393,13 +1625,13 @@ long	get_price_wpn( item_t *item )
 	long	i;
 
 	if( item == NULL )
-		return 0;
+		return( (gold_t)0 );
 	if( item->kind != ITEM_KIND_WPN )
-		return 0;
+		return( (gold_t)0 );
 	if( item->tab.wpn == NULL )
-		return 0;
-	if( chk_flg( item->flg, FLG_ITEM_CURSE) )
-		return 0;
+		return( (gold_t)0 );
+	if( chk_flg( item->flg, FLG_ITEM_CURSED) )
+		return( (gold_t)0 );
 
 	price = PRICE_WPN_BASE;
 
@@ -1440,7 +1672,7 @@ long	get_price_wpn( item_t *item )
 		mul_type++;
 	}
 	if( ratio <= 0 )
-		return 0;
+		return( (gold_t)0 );
 
 	hit /= ratio;
 	crtcl /= ratio;
@@ -1460,11 +1692,11 @@ long	get_price_wpn( item_t *item )
 	/**/
 
 	if( item->dat.wpn.add_hit < 0 )
-		return 0;
+		return( (gold_t)0 );
 	if( item->dat.wpn.add_crtcl < 0 )
-		return 0;
+		return( (gold_t)0 );
 	if( item->dat.wpn.add_dam < 0 )
-		return 0;
+		return( (gold_t)0 );
 
 	if( flg_arw ){
 		price += item->dat.wpn.add_hit * PRICE_ARW_ADD_HIT_MUL;
@@ -1516,16 +1748,16 @@ long	get_price_wpn( item_t *item )
 
 /**/
 
-long	get_price_armor( item_t *item )
+gold_t	get_price_armor( item_t *item )
 {
-	long	price;
+	gold_t	price;
 
 	if( item == NULL )
-		return 0;
+		return( (gold_t)0 );
 	if( item->kind != ITEM_KIND_ARMOR )
-		return 0;
+		return( (gold_t)0 );
 	if( item->tab.armor == NULL )
-		return 0;
+		return( (gold_t)0 );
 
 	price = PRICE_ARMOR_BASE;
 
@@ -1545,11 +1777,11 @@ long	get_price_armor( item_t *item )
 	/**/
 
 	if( item->dat.armor.add_def < 0 )
-		return 0;
+		return( (gold_t)0 );
 	if( item->dat.armor.add_crtcl < 0 )
-		return 0;
+		return( (gold_t)0 );
 	if( item->dat.armor.add_ac < 0 )
-		return 0;
+		return( (gold_t)0 );
 
 	price += item->dat.armor.add_def * PRICE_ARMOR_ADD_DEF_MUL;
 	price += item->dat.armor.add_crtcl * PRICE_ARMOR_ADD_CRTCL_MUL;
@@ -1574,23 +1806,23 @@ long	get_price_armor( item_t *item )
 
 /**/
 
-long	get_price_temple_remove_curse( mbr_t *mbr )
+gold_t	get_price_temple_remove_curse( mbr_t *mbr )
 {
 	if( mbr == NULL )
-		return 0;
+		return( (gold_t)0 );
 
 	return PRICE_TEMPLE_REMOVE_CURSE;
 }
 
 /**/
 
-long	get_price_temple_cure_status( mbr_t *mbr )
+gold_t	get_price_temple_cure_status( mbr_t *mbr )
 {
-	long	price;
+	gold_t	price;
 	rate_t	smoker;
 
 	if( mbr == NULL )
-		return 0;
+		return( (gold_t)0 );
 
 	price = get_specialist_lev( mbr );
 	price *= PRICE_TEMPLE_CURE_STATUS_MUL;
@@ -1607,13 +1839,13 @@ long	get_price_temple_cure_status( mbr_t *mbr )
 
 /**/
 
-long	get_price_temple_resurrection( mbr_t *mbr )
+gold_t	get_price_temple_resurrection( mbr_t *mbr )
 {
-	long	price;
+	gold_t	price;
 	rate_t	smoker;
 
 	if( mbr == NULL )
-		return 0;
+		return( (gold_t)0 );
 
 	price = get_specialist_lev( mbr );
 	price *= PRICE_TEMPLE_RESURRECTION_MUL;
@@ -1643,6 +1875,8 @@ shop_n_t	get_shop_n( char face_mnr )
 		return SHOP_N_ARMOR;
 	case FACE_MNR_SHOP_MAGIC:
 		return SHOP_N_MAGIC;
+	case FACE_MNR_SHOP_ALCHEMY:
+		return SHOP_N_ALCHEMY;
 	case FACE_MNR_SHOP_GROCERY:
 		return SHOP_N_GROCERY;
 	case FACE_MNR_SHOP_RESTAURANT:
@@ -1651,6 +1885,8 @@ shop_n_t	get_shop_n( char face_mnr )
 		return SHOP_N_TEAROOM;
 	case FACE_MNR_SHOP_TOBACCO:
 		return SHOP_N_TOBACCO;
+	case FACE_MNR_SHOP_PET_SHOP:
+		return SHOP_N_PET_SHOP;
 	}
 
 	return SHOP_N_INN;
@@ -1658,9 +1894,49 @@ shop_n_t	get_shop_n( char face_mnr )
 
 /**/
 
+char	get_shop_mnr_face( shop_n_t n )
+{
+	switch( n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
+		break;
+	case SHOP_N_INN:
+		return FACE_MNR_SHOP_INN;
+	case SHOP_N_BAR:
+		return FACE_MNR_SHOP_BAR;
+	case SHOP_N_TEMPLE:
+		return FACE_MNR_SHOP_TEMPLE;
+	case SHOP_N_WPN:
+		return FACE_MNR_SHOP_WPN;
+	case SHOP_N_ARMOR:
+		return FACE_MNR_SHOP_ARMOR;
+	case SHOP_N_MAGIC:
+		return FACE_MNR_SHOP_MAGIC;
+	case SHOP_N_ALCHEMY:
+		return FACE_MNR_SHOP_ALCHEMY;
+	case SHOP_N_GROCERY:
+		return FACE_MNR_SHOP_GROCERY;
+	case SHOP_N_RESTAURANT:
+		return FACE_MNR_SHOP_RESTAURANT;
+	case SHOP_N_TEAROOM:
+		return FACE_MNR_SHOP_TEAROOM;
+	case SHOP_N_TOBACCO:
+		return FACE_MNR_SHOP_TOBACCO;
+	case SHOP_N_PET_SHOP:
+		return FACE_MNR_SHOP_PET_SHOP;
+	}
+
+	return FACE_MNR_NULL;
+}
+
+/**/
+
 char	*get_shop_name( shop_n_t shop_n )
 {
 	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
+		return MSG_NULL;
 	case SHOP_N_BAR:
 		return MSG_NAME_BAR;
 	case SHOP_N_INN:
@@ -1673,6 +1949,8 @@ char	*get_shop_name( shop_n_t shop_n )
 		return MSG_NAME_ARMOR;
 	case SHOP_N_MAGIC:
 		return MSG_NAME_MAGIC;
+	case SHOP_N_ALCHEMY:
+		return MSG_NAME_ALCHEMY;
 	case SHOP_N_GROCERY:
 		return MSG_NAME_GROCERY;
 	case SHOP_N_RESTAURANT:
@@ -1681,6 +1959,8 @@ char	*get_shop_name( shop_n_t shop_n )
 		return MSG_NAME_TEAROOM;
 	case SHOP_N_TOBACCO:
 		return MSG_NAME_TOBACCO;
+	case SHOP_N_PET_SHOP:
+		return MSG_NAME_PET_SHOP;
 	}
 
 	return MSG_NULL;
@@ -1715,11 +1995,11 @@ void	set_map_sunshine( void )
 				continue;
 
 			if( flg_on_light ){
-				dun->map.obj.flg[y][x] |= FLG_OBJ_FIND;
-				dun->map.light_depth[y][x] = 1;
+				dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_FIND;
+				dun->map.light_depth_obj[y][x] = 1;
 			} else {
-				dun->map.obj.flg[y][x] &= ~(FLG_OBJ_FIND);
-				dun->map.light_depth[y][x] = 0;
+				dun->map.obj.flg[y][x] &= ~(FLG_MAP_OBJ_FIND);
+				dun->map.light_depth_obj[y][x] = 0;
 			}
 		}
 	}
@@ -1845,14 +2125,17 @@ void	set_map_glow( long dx, long dy, bool_t flg_morning )
 				continue;
 
 			if( flg_morning )
-				dun->map.light_depth[yy][xx]++;
+				dun->map.light_depth_obj[yy][xx]++;
 			else
-				dun->map.light_depth[yy][xx]--;
+				dun->map.light_depth_obj[yy][xx]--;
 
-			if( dun->map.light_depth[yy][xx] > 0 )
-				dun->map.obj.flg[yy][xx] |= FLG_OBJ_FIND;
-			else
-				dun->map.obj.flg[yy][xx] &= ~(FLG_OBJ_FIND);
+			if( calc_light_depth( xx, yy ) > 0 ){
+				dun->map.obj.flg[yy][xx]
+						|= FLG_MAP_OBJ_FIND;
+			} else {
+				dun->map.obj.flg[yy][xx]
+						&= ~(FLG_MAP_OBJ_FIND);
+			}
 		}
 	}
 
@@ -1861,6 +2144,380 @@ void	set_map_glow( long dx, long dy, bool_t flg_morning )
 
 /**/
 
+bool_t	chk_discount( void )
+{
+	if( !chk_discount_day() )
+		return FALSE;
+	if( !chk_discount_turn() )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_discount_day()
+{
+	long	day;
+
+	day = get_game_day();
+
+	if( (day % DAY_OF_WEEK_MAX_N) == DAY_OF_WEEK_DISCOUNT ){
+		if( g_discount_shop_n == SHOP_N_NULL ){
+			set_discount();
+		}
+		return TRUE;
+	} else {
+		if( g_discount_shop_n != SHOP_N_NULL ){
+			clr_discount();
+		}
+		return FALSE;
+	}
+
+	return FALSE;
+}
+
+/**/
+
+bool_t	chk_discount_turn()
+{
+	long	day;
+	long	turn;
+
+	day = get_game_day();
+	turn = get_turn();
+
+	if( g_discount_shop_n == SHOP_N_NULL )
+		return FALSE;
+	if( g_discount_flg_sold_out )
+		return FALSE;
+
+	if( turn < (DISCOUNT_BEGIN_HOUR * TURN_PER_HOUR) )
+		return FALSE;
+	if( turn > (DISCOUNT_END_HOUR * TURN_PER_HOUR) )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_discount_open()
+{
+	long	turn;
+
+	turn = get_turn();
+
+	if( !chk_discount_turn() )
+		return FALSE;
+
+	if( turn < (DISCOUNT_OPEN_HOUR * TURN_PER_HOUR) )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_discount_door( door_t *dr )
+{
+	if( dr == NULL )
+		return FALSE;
+
+	if( dr != g_discount_door )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_queue_chr( chr_t *chr )
+{
+	if( chr == NULL )
+		return FALSE;
+
+	if( chr->trgt.kind != TRGT_KIND_QUEUE )
+		return FALSE;
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_discount_mark( chr_t *chr )
+{
+	long	dx, dy;
+
+	if( chr == NULL )
+		return FALSE;
+
+	if( chr->trgt.kind == TRGT_KIND_QUEUE )
+		return TRUE;
+	if( !chk_discount() )
+		return FALSE;
+	if( chk_discount_open() )
+		return FALSE;
+
+	if( g_discount_queue_n + 1 > get_queue_max_n( chr ) )
+		return FALSE;
+
+	dx = g_discount_queue[g_discount_queue_n].x - chr->x;
+	dy = g_discount_queue[g_discount_queue_n].y - chr->y;
+	if( abs( dx ) > DISCOUNT_QUEUE_R )
+		return FALSE;
+	if( abs( dy ) > DISCOUNT_QUEUE_R )
+		return FALSE;
+
+	mark_queue( chr, TRUE );
+	return TRUE;
+}
+
+/**/
+
+void	set_discount()
+{
+	door_t	*dr;
+
+	g_discount_shop_n = randm( SHOP_N_MAX_N );
+	g_discount_flg_sold_out = FALSE;
+
+	dr = get_shop_door( g_discount_shop_n );
+	if( dr == NULL )
+		return;
+	g_discount_door = dr;
+
+	set_discount_queue( dr );
+}
+
+/**/
+
+void	clr_discount( void )
+{
+	g_discount_shop_n = SHOP_N_NULL;
+	g_discount_door = NULL;
+	g_discount_flg_sold_out = TRUE;
+}
+
+/**/
+
+void	set_discount_sold_out()
+{
+	g_discount_flg_sold_out = TRUE;
+}
+
+/**/
+
+bool_t	set_discount_queue( door_t *dr )
+{
+	dun_t	*dun = get_dun();
+	long	x, y;
+	long	dx, dy;
+	bool_t	ret;
+	long	i;
+
+	do {
+		dx = 0;
+		dy = -1;
+		x = dr->x - 1;
+		y = dr->y;
+		if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_PASS ) )
+			break;
+
+		dx = 0;
+		dy = +1;
+		x = dr->x + dr->dx;
+		y = dr->y;
+		if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_PASS ) )
+			break;
+
+		dx = +1;
+		dy = 0;
+		x = dr->x;
+		y = dr->y - 1;
+		if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_PASS ) )
+			break;
+
+		dx = -1;
+		dy = 0;
+		x = dr->x;
+		y = dr->y + dr->dy;
+		if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_PASS ) )
+			break;
+
+		return FALSE;
+	} while( 0 );
+
+	ret = TRUE;
+
+	g_discount_queue_n = 0;
+	for( i = 0; i < DISCOUNT_QUEUE_MAX_N; i++ ){
+		g_discount_queue[i].x = x;
+		g_discount_queue[i].y = y;
+		x += dx;
+		y += dy;
+		if( !clip_pos( x, y ) ){
+			ret = FALSE;
+			continue;
+		}
+
+		if( dx <= -1 ){
+			if( chk_flg( dun->map.obj.flg[y - 1][x],
+					FLG_MAP_OBJ_PASS ) ){
+				dx = 0;
+				dy = -1;
+			}
+		} else if( dx >= +1 ){
+			if( chk_flg( dun->map.obj.flg[y + 1][x],
+					FLG_MAP_OBJ_PASS ) ){
+				dx = 0;
+				dy = +1;
+			}
+		} else if( dy <= -1 ){
+			if( chk_flg( dun->map.obj.flg[y][x + 1],
+					FLG_MAP_OBJ_PASS ) ){
+				dx = +1;
+				dy = 0;
+			}
+		} else if( dy >= +1 ){
+			if( chk_flg( dun->map.obj.flg[y][x - 1],
+					FLG_MAP_OBJ_PASS ) ){
+				dx = -1;
+				dy = 0;
+			}
+		}
+	}
+
+	return ret;
+}
+
+/**/
+
+pos_t	*get_queue_tail( chr_t *chr )
+{
+	if( g_discount_queue_n + 1 > get_queue_max_n( chr ) )
+		return NULL;
+
+	return( &(g_discount_queue[g_discount_queue_n]) );
+}
+
+/**/
+
+void	inc_queue_n( chr_t *chr )
+{
+	if( g_discount_queue_n + 1 > get_queue_max_n( chr ) )
+		return;
+
+	g_discount_queue_n++;
+}
+
+/**/
+
+long	get_queue_n( chr_t *chr )
+{
+	if( g_discount_queue_n + 1 > get_queue_max_n( chr ) )
+		return -1;
+
+	return g_discount_queue_n;
+}
+
+/**/
+
+long	get_queue_max_n( chr_t *chr )
+{
+	if( chr->kind == CHR_KIND_MBR )
+		return DISCOUNT_QUEUE_MAX_N;
+	else
+		return DISCOUNT_QUEUE_MAX_N - MBR_MAX_N;
+}
+
+/**/
+
+void	chk_dec_chr_queue( chr_t *chr )
+{
+	long	qn;
+	pos_t	*q;
+
+	if( chr == NULL )
+		return;
+	if( chr->trgt.kind != TRGT_KIND_QUEUE )
+		return;
+
+	if( !chk_discount() )
+		return;
+
+	qn = chr->trgt.n;
+	if( qn <= 0 )
+		return;
+
+	q = &(g_discount_queue[qn - 1]);
+	if( can_move_chr( chr, q->x, q->y ) ){
+		chr->trgt.p = q;
+		chr->trgt.n = qn - 1;
+		if( (g_discount_queue_n - 1) <= qn )
+			g_discount_queue_n--;
+		if( g_discount_queue_n < 0 )
+			g_discount_queue_n = 0;
+	}
+}
+
+/**/
+
+void	chk_clr_chr_queue( chr_t *chr )
+{
+	if( chr == NULL )
+		return;
+	if( chr->trgt.kind != TRGT_KIND_QUEUE )
+		return;
+
+	if( chk_discount() )
+		return;
+
+	clr_chr_trgt_act( chr, FALSE );
+}
+
+/**/
+
+void	chk_enter_discount_shop( chr_t *chr )
+{
+	if( chr == NULL )
+		return;
+	if( chr->trgt.kind != TRGT_KIND_QUEUE )
+		return;
+
+	if( !chk_discount() )
+		return;
+	if( !chk_discount_open() )
+		return;
+	if( chr->trgt.n != 0 )
+		return;
+
+	set_chr_act( chr, ACT_KIND_DOOR_OPEN, NULL, NULL, 0, 0 );
+	mark_door( chr, g_discount_door, DIST_NEAR );
+}
+
+/**/
+
+door_t	*get_shop_door( shop_n_t n )
+{
+	dun_t	*dun = get_dun();
+	char	mnr;
+	door_t	*dr;
+	long	i;
+
+	mnr = get_shop_mnr_face( n );
+
+	for( i = 0; i < dun->door_n; i++ ){
+		dr = &(dun->door[i]);
+		if( dr->mnr == mnr )
+			return dr;
+	}
+
+	return NULL;
+}
+
+/**/
+
 town_ptn_col_tab_t	*get_town_ptn_col_tab( void )
 {
 	return town_ptn_col_tab;
@@ -1875,6 +2532,13 @@ long	get_town_ptn_col_tab_max_n( void )
 
 /**/
 
+art_ls_pet_shop_t	*get_art_ls_pet_shop( void )
+{
+	return art_ls_pet_shop;
+}
+
+/**/
+
 bool_t	save_town( void )
 {
 	if( !save_town_ptn( &town_ptn ) ){
