@@ -1,22 +1,57 @@
-#ifndef	__TOWN_TAB_H__
-#define	__TOWN_TAB_H__
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: town_tab.h,v 1.17 2003/11/21 12:53:32 bowkenken Exp $
+*****************************************************************/
+
+#ifndef	TOWN_TAB_H
+#define	TOWN_TAB_H
 
 long	town_ptn_col_tab_max_n;
 town_ptn_col_tab_t	town_ptn_col_tab[] = {
 	{ 0xffffff, '.', ' ' },
 	{ 0x00ffff, '>', '>' },
 	{ 0xff0000, '+', ' ' },
-	{ 0xff0069, '+', 'i' },	/* INN */
-	{ 0xff0062, '+', 'b' },	/* BAR */
-	{ 0xff0077, '+', 'w' },	/* WEAPON */
-	{ 0xff0061, '+', 'a' },	/* ARMOR */
-	{ 0xff006d, '+', 'm' },	/* MAGIC */
-	{ 0xff0063, '+', 't' },	/* TEMPLE */
-	{ 0xff0067, '+', 'g' },	/* GROCERY */
-	{ 0xff0072, '+', 'r' },	/* RESTAURANT */
-	{ 0xff0074, '+', 'c' },	/* TEAROOM */
-	{ 0xff0073, '+', 's' },	/* TOBACCO */
+	{ 0xff0010, '+', FACE_MNR_GATE },
+	{ 0xff0110, '+', FACE_MNR_SHOP_INN },
+	{ 0xff0120, '+', FACE_MNR_SHOP_BAR },
+	{ 0xff0130, '+', FACE_MNR_SHOP_TEMPLE },
+	{ 0xff0140, '+', FACE_MNR_SHOP_WPN },
+	{ 0xff0150, '+', FACE_MNR_SHOP_ARMOR },
+	{ 0xff0160, '+', FACE_MNR_SHOP_MAGIC },
+	{ 0xff0170, '+', FACE_MNR_SHOP_ALCHEMY },
+	{ 0xff0180, '+', FACE_MNR_SHOP_GROCERY },
+	{ 0xff0190, '+', FACE_MNR_SHOP_RESTAURANT },
+	{ 0xff01a0, '+', FACE_MNR_SHOP_TEAROOM },
+	{ 0xff01b0, '+', FACE_MNR_SHOP_TOBACCO },
+	{ 0xff01c0, '+', FACE_MNR_SHOP_PET_SHOP },
 	{ 0x808080, '#', '#' },
+	{ 0x00ff41, '#', FACE_MNR_STREETLAMP },
 	{ 0xffff41, '#', 'A' },
 	{ 0xffff42, '#', 'B' },
 	{ 0xffff43, '#', 'C' },
@@ -84,15 +119,35 @@ g_shop_face_ls_t	g_shop_face_ls[] = {
 	{ FACE_MNR_SHOP_WPN, FALSE },
 	{ FACE_MNR_SHOP_ARMOR, FALSE },
 	{ FACE_MNR_SHOP_MAGIC, FALSE },
+	{ FACE_MNR_SHOP_ALCHEMY, FALSE },
 	{ FACE_MNR_SHOP_GROCERY, FALSE },
 	{ FACE_MNR_SHOP_RESTAURANT, FALSE },
 	{ FACE_MNR_SHOP_TEAROOM, FALSE },
 	{ FACE_MNR_SHOP_TOBACCO, FALSE },
+	{ FACE_MNR_SHOP_PET_SHOP, FALSE },
 };
 
 const long	g_shop_face_ls_max_n
 		= sizeof( g_shop_face_ls ) / sizeof( g_shop_face_ls[0] );
 
+typedef struct {
+	item_kind_t	kind;
+	long	ave_stock;
+	food_kind_t	food;
+	potion_kind_t	potion;
+} art_ls_bar_t;
+
+art_ls_bar_t	art_ls_bar[] = {
+	{ ITEM_KIND_FOOD, 256, FOOD_KIND_POTAGE,
+		POTION_KIND_NULL },
+	{ ITEM_KIND_POTION, 256, FOOD_KIND_NULL,
+		POTION_KIND_MILK },
+	{ ITEM_KIND_POTION, 256, FOOD_KIND_NULL,
+		POTION_KIND_ALE },
+	{ ITEM_KIND_NULL, 0, FOOD_KIND_NULL,
+		POTION_KIND_NULL },
+};
+
 typedef struct {
 	item_kind_t	kind;
 	long	ave_stock;
@@ -301,7 +356,7 @@ art_ls_magic_t	art_ls_magic[] = {
 	},
 
 	{ ITEM_KIND_POTION, 12,
-		POTION_KIND_RESI_WIND,
+		POTION_KIND_RESI_ACID,
 		SCROLL_KIND_NULL,
 		STICK_KIND_NULL,
 		SPELL_KIND_NULL,
@@ -311,7 +366,7 @@ art_ls_magic_t	art_ls_magic[] = {
 	},
 
 	{ ITEM_KIND_POTION, 12,
-		POTION_KIND_RESI_ACID,
+		POTION_KIND_RESI_MIND,
 		SCROLL_KIND_NULL,
 		STICK_KIND_NULL,
 		SPELL_KIND_NULL,
@@ -410,6 +465,16 @@ art_ls_magic_t	art_ls_magic[] = {
 		NECKLACE_KIND_NULL,
 	},
 
+	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_POW_UP_WPN_CRTCL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
 		SCROLL_KIND_POW_UP_WPN_DAM,
@@ -420,6 +485,46 @@ art_ls_magic_t	art_ls_magic[] = {
 		NECKLACE_KIND_NULL,
 	},
 
+	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_POW_UP_ARMOR_DEF,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_POW_UP_ARMOR_CRTCL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_POW_UP_ARMOR_AC,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_SCROLL, 12,
+		POTION_KIND_NULL,
+		SCROLL_KIND_PROTECT_ARMOR,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
 		SCROLL_KIND_REMOVE_CURSE,
@@ -474,7 +579,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_WAND,
-		SPELL_KIND_MIND_STORM,
+		SPELL_KIND_ACID_RAIN,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -484,7 +589,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_WAND,
-		SPELL_KIND_ACID_RAIN,
+		SPELL_KIND_MIND_STORM,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -644,7 +749,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_ROD,
-		SPELL_KIND_MIND_STORM,
+		SPELL_KIND_ACID_RAIN,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -654,7 +759,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_ROD,
-		SPELL_KIND_ACID_RAIN,
+		SPELL_KIND_MIND_STORM,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -814,7 +919,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_STAFF,
-		SPELL_KIND_MIND_STORM,
+		SPELL_KIND_ACID_RAIN,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -824,7 +929,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
 		STICK_KIND_STAFF,
-		SPELL_KIND_ACID_RAIN,
+		SPELL_KIND_MIND_STORM,
 		RING_KIND_NULL,
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
@@ -1089,7 +1194,67 @@ art_ls_magic_t	art_ls_magic[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
-/* amulet */
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_SHARPNESS,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_STRENGTH,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_QUICKNESS,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_WISE,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_BRAINY,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_ATTRACTIVE,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_ACCE, 3,
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
@@ -1126,7 +1291,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		STICK_KIND_NULL,
 		SPELL_KIND_NULL,
 		RING_KIND_NULL,
-		AMULET_KIND_RESI_WIND,
+		AMULET_KIND_RESI_ACID,
 		NECKLACE_KIND_NULL,
 	},
 
@@ -1136,7 +1301,7 @@ art_ls_magic_t	art_ls_magic[] = {
 		STICK_KIND_NULL,
 		SPELL_KIND_NULL,
 		RING_KIND_NULL,
-		AMULET_KIND_RESI_ACID,
+		AMULET_KIND_RESI_MIND,
 		NECKLACE_KIND_NULL,
 	},
 
@@ -1289,6 +1454,10 @@ art_ls_restaurant_t	art_ls_restaurant[] = {
 		POTION_KIND_NULL },
 	{ ITEM_KIND_FOOD, 256, FOOD_KIND_SOFT_BOILED_EGGS,
 		POTION_KIND_NULL },
+	{ ITEM_KIND_FOOD, 256, FOOD_KIND_SAUSAGE,
+		POTION_KIND_NULL },
+	{ ITEM_KIND_FOOD, 256, FOOD_KIND_BACON,
+		POTION_KIND_NULL },
 	{ ITEM_KIND_FOOD, 256, FOOD_KIND_BEEF_STEAK,
 		POTION_KIND_NULL },
 	{ ITEM_KIND_FOOD, 256, FOOD_KIND_PORK_SAUTE,
@@ -1660,12 +1829,28 @@ art_ls_tobacco_t	art_ls_tobacco[] = {
 		TOBACCO_BRAND_NULL,
 		PIPE_KIND_CIGARET_HOLDER },
 
+	/* DISPOSAL */
+	{ ITEM_KIND_DISPOSAL, 16,
+		TOBACCO_KIND_NULL,
+		TOBACCO_BRAND_NULL,
+		PIPE_KIND_NULL },
+
+	/* END */
 	{ ITEM_KIND_NULL, 0,
 		TOBACCO_KIND_NULL,
 		TOBACCO_BRAND_NULL,
 		PIPE_KIND_NULL },
 };
 
-/**/
+art_ls_pet_shop_t	art_ls_pet_shop[] = {
+	{ MNSTR_KIND_CAT,
+		(gold_t)500, },
+	{ MNSTR_KIND_DOG,
+		(gold_t)500, },
+	{ MNSTR_KIND_PYON_PYON,
+		(gold_t)1000, },
+	{ MNSTR_KIND_NULL,
+		(gold_t)0, },
+};
 
-#endif	/* __TOWN_TAB_H__ */
+#endif	/* TOWN_TAB_H */
