@@ -1,11 +1,37 @@
-/*#include	<stddef.h>*/
-/*#include	<stdio.h>*/
-/*#include	<string.h>*/
-/*#include	<ctype.h>*/
-/*#include	<time.h>*/
-/*#include	<sys/stat.h>*/
+/*****************************************************************
+* L&L - Labyrinths & Legends
+* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
+* 
+* Created by BowKenKen
+*   e-mail: bowkenken@users.sourceforge.jp
+*   URL: https://sourceforge.jp/projects/lnl/
+* 
+* License is GPL
+* 
+* ܥץϥե꡼եȥǤ
+* ʤϡ Free Software Foundation ɽ
+*  GNU ̸ͭѵΡ֥С󣲡
+* ϤʹߤγƥС椫餤줫򤷡
+* ΥС˽äܥץ
+* ۤޤѹ뤳ȤǤޤ
+* 
+* ܥץͭѤȤϻפޤۤˤäƤϡ
+* ԾڤŪŬˤĤƤΰۤݾڤޤ,
+* ʤݾڤԤʤޤ
+* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
+* 
+* ʤϡܥץȰ GNU ̸ͭѵ
+* μ̤äƤϤǤǤʤϡ
+*   Free Software Foundation, Inc.,
+*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+* ؼ񤤤Ƥ
+* 
+* $Id: trap.c,v 1.22 2003/11/19 13:19:14 bowkenken Exp $
+*****************************************************************/
 
 #include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
 #include	"dun.h"
 /*#include	"town.h"*/
 #include	"item.h"
@@ -13,28 +39,32 @@
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
-/*#include	"fight.h"*/
+/*#include	"pet.h"*/
+#include	"fight.h"
 #include	"fx.h"
 #include	"trap.h"
 #include	"draw.h"
 /*#include	"curs.h"*/
-/*#include	"menu.h"*/
+#include	"menu.h"
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 #include	"gmain_prot.h"
+#include	"misc_prot.h"
+/*#include	"turn_prot.h"*/
 #include	"dun_prot.h"
 /*#include	"town_prot.h"*/
 /*#include	"item_prot.h"*/
-/*#include	"spell_prot.h"*/
+#include	"spell_prot.h"
 #include	"chr_prot.h"
 /*#include	"party_prot.h"*/
 /*#include	"mnstr_prot.h"*/
-/*#include	"fight_prot.h"*/
+/*#include	"pet_prot.h"*/
+#include	"fight_prot.h"
 #include	"fx_prot.h"
 #include	"trap_prot.h"
 #include	"draw_prot.h"
 /*#include	"curs_prot.h"*/
-/*#include	"menu_prot.h"*/
+#include	"menu_prot.h"
 /*#include	"tmenu_prot.h"*/
 /*#include	"amenu_prot.h"*/
 /*#include	"gfile_prot.h"*/
@@ -47,41 +77,42 @@
 #define	TRAP_MAX_RATE	100
 #define	TRAP_MIN_RATE	50
 
-#define	FX_AVE_TURN_TRAP_SLEEP	64
-#define	FX_AVE_TURN_TRAP_POISON_DARTS	(FX_AVE_TURN_POISON_DEC * 32)
-#define	POISON_DEC_N_TRAP	1
-
 #define	TRAP_ROOM_RATE	1
 #define	TRAP_ROOM_N	50
 
 /**/
 
-trap_t	trap_buf[TRAP_MAX_N];
-trap_t	trap_free;
-trap_t	dun_trap_asgn;
+static trap_t	trap_buf[TRAP_MAX_N];
+static trap_t	trap_free;
+static trap_t	dun_trap_asgn;
 
-long	trap_tab_max_n;
+static long	trap_tab_max_n;
 
-trap_tab_t	trap_tab[] = {
+static trap_tab_t	trap_tab[] = {
 	{ TRAP_KIND_SLEEP, NULL, N_MSG_TRAP_SLEEP,
-		80, 1, DUN_MAX_LEV, -1 },
+		80, 1, DUN_MAX_LEV_BASE, -1 },
 
 	{ TRAP_KIND_ARW, NULL, N_MSG_TRAP_ARW,
-		80, 2, DUN_MAX_LEV, -1 },
+		80, 2, DUN_MAX_LEV_BASE, -1 },
 
 	{ TRAP_KIND_POISON_DARTS, NULL, N_MSG_TRAP_POISON_DARTS,
-		80, 3, DUN_MAX_LEV, -1 },
+		80, 3, DUN_MAX_LEV_BASE, -1 },
+
+	{ TRAP_KIND_BOMB, NULL, N_MSG_TRAP_BOMB,
+		80, 10, DUN_MAX_LEV_BASE, -1 },
 
 	{ TRAP_KIND_TELEPORT_PARTY, NULL, N_MSG_TRAP_TELEPORT_PARTY,
-		80, 1, DUN_MAX_LEV, -1 },
+		80, 20, DUN_MAX_LEV_BASE, -1 },
 
 	{ TRAP_KIND_TELEPORT, NULL, N_MSG_TRAP_TELEPORT,
-		80, 3, DUN_MAX_LEV, -1 },
+		80, 30, DUN_MAX_LEV_BASE, -1 },
 
 	{ TRAP_KIND_NULL, NULL, N_MSG_NULL,
-		0, DUN_MAX_LEV, DUN_MAX_LEV, 0 },
+		0, DUN_MAX_LEV_BASE, DUN_MAX_LEV_BASE, 0 },
 };
 
+chr_t	g_dmy_chr;
+
 /**/
 
 void	init_trap( void )
@@ -138,10 +169,6 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 		if( dun->map.obj.mjr[y][x] != FACE_MJR_FLOOR )
 			return NULL;
 
-	trap = alloc_trap( &dmy );
-	if( trap == NULL )
-		return NULL;
-
 	n = 0;
 	for( i = 128; i > 0; i-- ){
 		n = randm( trap_tab_max_n );
@@ -158,9 +185,14 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 
 		break;
 	}
+	if( i <= 0 )
+		return NULL;
+
+	trap = alloc_trap( &dmy );
+	if( trap == NULL )
+		return NULL;
+
 	do {
-		if( i <= 0 )
-			break;
 		if( !make_trap_std( dun_lev, trap, n ) )
 			break;
 		if( (x != MAP_DEL_X) && (y != MAP_DEL_Y) )
@@ -185,6 +217,7 @@ bool_t	make_trap_std( long dun_lev, trap_t *trap, long n )
 	trap->kind = trap_tab[n].kind;
 	trap->x = MAP_DEL_X;
 	trap->y = MAP_DEL_Y;
+	trap->lev = dun_lev;
 	trap->difficulty = abs( dun_lev );
 	trap->difficulty *= TRAP_DIFFICULTY_LEV_RATE;
 	trap->difficulty /= _100_PERCENT;
@@ -216,7 +249,8 @@ bool_t	set_trap( long x, long y, trap_t *trap )
 
 	dun->map.obj.mjr[y][x] = FACE_MJR_TRAP;
 	dun->map.obj.mnr[y][x] = FACE_MNR_NULL;
-	dun->map.obj.flg[y][x] |= (FLG_OBJ_PASS | FLG_OBJ_LOOK_FLOOR);
+	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_LOOK_FLOOR;
 
 	ins_ls_trap( &dun_trap_asgn, trap );
 
@@ -235,7 +269,7 @@ void	make_trap_room( long area_x, long area_y, long lev )
 		return;
 
 	n = 0;
-	for( i = 0; i < 10240; i++ ){
+	for( i = 0; i < 1024; i++ ){
 		long	mx, my;
 		trap_t	*trap;
 
@@ -255,11 +289,11 @@ void	make_trap_room( long area_x, long area_y, long lev )
 
 /**/
 
-void	chk_trap_chest( item_t *item, mbr_t *mbr, rate_t rate )
+void	chk_trap_chest( item_t *item, chr_t *chr, rate_t rate )
 {
-	if( mbr == NULL )
+	if( chr == NULL )
 		return;
-	if( chk_flg_or( mbr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
+	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
 	if( item == NULL )
 		return;
@@ -269,89 +303,177 @@ void	chk_trap_chest( item_t *item, mbr_t *mbr, rate_t rate )
 	if( !rate_randm( rate ) )
 		return;
 
-	caught_trap( item->dat.chest.trap, mbr );
+	caught_trap( item->dat.chest.trap, chr );
 
 	free_trap_chest( item );
 }
 
 /**/
 
-void	chk_trap( mbr_t *mbr )
+void	chk_trap( chr_t *chr )
 {
 	trap_t	*trap;
 	dun_t	*dun;
 
-	if( mbr == NULL )
+	if( chr == NULL )
 		return;
-	if( chk_flg_or( mbr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
+	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
-	if( chk_flg( mbr->stat, FLG_STAT_FLY ) )
+	if( chk_flg( chr->stat, FLG_STAT_FLY ) )
 		return;
 
 	dun = get_dun();
 
-	if( dun->map.obj.mjr[mbr->y][mbr->x] != FACE_MJR_TRAP )
+	if( dun->map.obj.mjr[chr->y][chr->x] != FACE_MJR_TRAP )
 		return;
 
-	trap = get_trap( mbr->x, mbr->y );
+	trap = get_trap( chr->x, chr->y );
 	if( trap == NULL )
 		return;
 
-	dun->map.obj.flg[mbr->y][mbr->x] &= ~FLG_OBJ_LOOK_FLOOR;
-	dun->map.obj.flg[mbr->y][mbr->x] |= FLG_OBJ_FIND;
-	draw_trap( trap );
+	find_trap( trap );
 
-	if( chr_roll( mbr, ABL_KIND_THI, ABL_KIND_AGI, trap->difficulty ) )
-		print_msg( FLG_NULL, MSG_NOT_TRAPPED, mbr->name );
+	if( chr_roll( chr, ABL_KIND_THI, ABL_KIND_AGI, trap->difficulty ) )
+		print_msg_mbr( chr, FLG_NULL, MSG_NOT_TRAPPED, chr->name );
 	else
-		caught_trap( trap, mbr );
+		caught_trap( trap, chr );
 }
 
 /**/
 
-void	caught_trap( trap_t *trap, mbr_t *mbr )
+void	find_trap( trap_t *trap )
 {
-	fx_t	*fx;
+	dun_t	*dun = get_dun();
 
-	if( mbr == NULL )
-		return;
-	if( chk_flg_or( mbr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
-		return;
 	if( trap == NULL )
 		return;
 
+	if( !clip_x( trap->x ) )
+		return;
+	if( !clip_y( trap->y ) )
+		return;
+
+	dun->map.obj.flg[trap->y][trap->x] &= ~FLG_MAP_OBJ_LOOK_FLOOR;
+	dun->map.obj.flg[trap->y][trap->x] |= FLG_MAP_OBJ_FIND;
+	draw_trap( trap );
+}
+
+/**/
+
+void	caught_trap( trap_t *trap, chr_t *chr )
+{
+	if( trap == NULL )
+		return;
+	if( trap->tab == NULL )
+		return;
+	if( chr == NULL )
+		return;
+	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
+		return;
+
+	print_msg_mbr( chr, FLG_NULL, MSG_TRAPPED,
+			chr->name, trap->tab->name );
+
+	g_dmy_chr.kind = CHR_KIND_NULL;
+	strncpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
+	g_dmy_chr.x = trap->x;
+	g_dmy_chr.y = trap->y;
+	g_dmy_chr.trgt.kind = get_trgt_kind_from_chr( chr );
+	g_dmy_chr.trgt.x = chr->x;
+	g_dmy_chr.trgt.y = chr->y;
+	g_dmy_chr.trgt.true_x = g_dmy_chr.trgt.x;
+	g_dmy_chr.trgt.true_y = g_dmy_chr.trgt.y;
+	g_dmy_chr.trgt.p = chr;
+
 	switch( trap->kind ){
 	case TRAP_KIND_NULL:
 	case TRAP_KIND_MAX_N:
 		return;
 	case TRAP_KIND_SLEEP:
-		print_msg( FLG_NULL, MSG_FX_SLEEP, mbr->name );
-		set_fx( mbr, FX_KIND_SLEEP,
-				FX_AVE_TURN_TRAP_SLEEP );
+		chr_cast_spell_spread( &g_dmy_chr, TRUE,
+				get_spell_tab( SPELL_KIND_SLEEP ),
+				_100_PERCENT );
 		break;
 	case TRAP_KIND_ARW:
+		set_trap_arw_pos( chr, &g_dmy_chr.x, &g_dmy_chr.y );
+		chr_cast_spell_normal( &g_dmy_chr, TRUE,
+				get_spell_tab( SPELL_KIND_MAGIC_MISSILE ),
+				_100_PERCENT );
 		break;
 	case TRAP_KIND_POISON_DARTS:
-		print_msg( FLG_NULL, MSG_FX_POISON, mbr->name );
-		fx = set_fx( mbr, FX_KIND_POISON,
-				FX_AVE_TURN_TRAP_POISON_DARTS );
-		if( fx == NULL )
-			return;
-		if( fx->n < POISON_DEC_N_TRAP )
-			fx->n = POISON_DEC_N_TRAP;
-
+		chr_cast_spell_normal( &g_dmy_chr, TRUE,
+				get_spell_tab( SPELL_KIND_POISON_CLOUD ),
+				_100_PERCENT );
+		break;
+	case TRAP_KIND_BOMB:
+		chr_cast_spell_spread( &g_dmy_chr, TRUE,
+				get_spell_tab( SPELL_KIND_MAGIC_MISSILE ),
+				_100_PERCENT );
 		break;
 	case TRAP_KIND_TELEPORT_PARTY:
 		teleport_party();
 		break;
 	case TRAP_KIND_TELEPORT:
-		teleport_mbr( mbr );
+		teleport_chr( chr );
 		break;
 	}
 }
 
 /**/
 
+void	set_trap_arw_pos( chr_t *chr, long *x, long *y )
+{
+	dun_t	*dun = get_dun();
+	long	mx, my;
+	long	nx, ny;
+	long	i;
+
+	if( chr == NULL )
+		return;
+
+	*x = chr->x;
+	*y = chr->y;
+
+	switch( randm( 4 ) ){
+	default:
+	case 0:
+		mx = chr->x;
+		my = (chr->y / AREA_MAX_Y) * AREA_MAX_Y;
+		break;
+	case 1:
+		mx = (chr->x / AREA_MAX_X) * AREA_MAX_X;
+		my = chr->y;
+		break;
+	case 2:
+		mx = chr->x;
+		my = (chr->y / AREA_MAX_Y) * AREA_MAX_Y;
+		my += AREA_MAX_Y - 1;
+		break;
+	case 3:
+		mx = (chr->x / AREA_MAX_X) * AREA_MAX_X;
+		mx += AREA_MAX_X - 1;
+		my = chr->y;
+		break;
+	}
+
+	nx = chr->x;
+	ny = chr->y;
+	for( i = max( AREA_MAX_X, AREA_MAX_Y ); i >= 0; i-- ){
+		nx += sgn( mx - chr->x );
+		ny += sgn( my - chr->y );
+		if( !clip_pos( nx, ny ) )
+			break;
+		if( !chk_flg( dun->map.obj.flg[ny][nx],
+				FLG_MAP_OBJ_PASS ) ){
+			break;
+		}
+		*x = nx;
+		*y = ny;
+	}
+}
+
+/**/
+
 void	disarm_trap( trap_t *p )
 {
 	dun_t	*dun;
@@ -370,6 +492,26 @@ void	disarm_trap( trap_t *p )
 
 /**/
 
+void	detect_trap( long x, long y, long r )
+{
+	trap_t	*p;
+
+	for( p = dun_trap_asgn.next; p != &dun_trap_asgn; p = p->next ){
+		if( p->x < (x - r) )
+			continue;
+		if( p->x > (x + r) )
+			continue;
+		if( p->y < (y - r) )
+			continue;
+		if( p->y > (y + r) )
+			continue;
+
+		find_trap( p );
+	}
+}
+
+/**/
+
 void	ins_ls_trap( trap_t *ls, trap_t *p )
 {
 	if( ls == NULL )
@@ -395,7 +537,7 @@ void	ins_ls_trap( trap_t *ls, trap_t *p )
 trap_t	*alloc_trap( trap_t *dmy )
 {
 	trap_t	*p;
-	/* $B0l;~E*$J%"%$%F%`%j%9%H$K$V$i2<$2$k(B */
+	/* ŪʥƥꥹȤˤ֤鲼 */
 
 	dmy->prev = dmy;
 	dmy->next = dmy;
