@@ -5,10 +5,13 @@ trap_t	*make_trap( long x, long y, long dun_lev );
 bool_t	make_trap_std( long dun_lev, trap_t *trap, long n );
 bool_t	set_trap( long x, long y, trap_t *trap );
 void	make_trap_room( long area_x, long area_y, long lev );
-void	chk_trap_chest( item_t *item, mbr_t *mbr, rate_t rate );
-void	chk_trap( mbr_t *mbr );
-void	caught_trap( trap_t *trap, mbr_t *mbr );
+void	chk_trap_chest( item_t *item, chr_t *chr, rate_t rate );
+void	chk_trap( chr_t *chr );
+void	find_trap( trap_t *trap );
+void	caught_trap( trap_t *trap, chr_t *chr );
+void	set_trap_arw_pos( chr_t *chr, long *x, long *y );
 void	disarm_trap( trap_t *p );
+void	detect_trap( long x, long y, long r );
 void	ins_ls_trap( trap_t *ls, trap_t *p );
 trap_t	*alloc_trap( trap_t *dmy );
 void	free_trap_chest( item_t *chest );
